(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 9.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       157,          7]
NotebookDataLength[   1271940,      21634]
NotebookOptionsPosition[   1249115,      20909]
NotebookOutlinePosition[   1249678,      20931]
CellTagsIndexPosition[   1249635,      20928]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{
Cell[TextData[{
 StyleBox["Numerical algorithms of the paper: ",
  FontSize->16,
  FontSlant->"Italic"],
 StyleBox["\n",
  FontSize->24,
  FontWeight->"Bold"],
 StyleBox["Title:  ",
  FontSize->16,
  FontWeight->"Bold"],
 StyleBox[" ",
  FontSize->14],
 StyleBox["Fast, Accurate and Robust Adaptive Finite Difference Methods for \
Fractional Diffusion Equations",
  FontSize->24,
  FontWeight->"Bold"],
 StyleBox["\n",
  FontWeight->"Bold"],
 StyleBox["Journal",
  FontSize->16,
  FontWeight->"Bold"],
 StyleBox[":  ",
  FontWeight->"Bold"],
 StyleBox["Numerical Algorithms",
  FontSize->24,
  FontWeight->"Bold"],
 StyleBox["\n",
  FontWeight->"Bold"],
 StyleBox["Authors:  ",
  FontSize->16,
  FontWeight->"Bold"],
 StyleBox[" ",
  FontSize->18,
  FontWeight->"Bold"],
 StyleBox["Santos B. Yuste* and J. Quintana-Murillo",
  FontSize->24,
  FontWeight->"Bold"],
 StyleBox["  ",
  FontSize->18,
  FontWeight->"Bold"],
 StyleBox["\n",
  FontSize->16,
  FontWeight->"Bold"],
 StyleBox["Departamento de F\[IAcute]sica and Instituto de \
Computaci\[OAcute]n Cient\[IAcute]fica Avanzada (ICCAEX), Universidad de \
Extremadura, 06006 Badajoz, Spain\n* santos@unex.es",
  FontSize->16]
}], "Subsection",
 CellChangeTimes->{{3.6369034391145773`*^9, 3.6369035051013517`*^9}, {
   3.6369035444836044`*^9, 3.6369035779155164`*^9}, {3.636903622228051*^9, 
   3.6369036488275723`*^9}, 3.6369039677638144`*^9, {3.6372436272015777`*^9, 
   3.6372436288576727`*^9}, {3.6385999599136*^9, 3.6386000523086*^9}, {
   3.6386001589245996`*^9, 3.6386003043326*^9}, 3.6386005756446*^9, 
   3.6386029935196*^9}],

Cell[CellGroupData[{

Cell[TextData[{
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 "  version..."
}], "Text",
 CellChangeTimes->{{3.6368133071609125`*^9, 3.6368133481612577`*^9}, 
   3.6386033532855997`*^9},
 FontSize->10],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"StringJoin", "[", 
   RowBox[{"{", 
    RowBox[{"\"\<The running \!\(\*
StyleBox[\"Mathematica\",
FontSlant->\"Italic\"]\) version is \>\"", ",", 
     RowBox[{"ToString", "[", "$Version", "]"}]}], "}"}], "]"}], 
  " "}]], "Input",
 CellChangeTimes->{{3.6368123785457993`*^9, 3.6368124347310123`*^9}, {
  3.6368126010005226`*^9, 3.636812602072584*^9}, {3.6368127441887126`*^9, 
  3.636812744368723*^9}, {3.6368131810516996`*^9, 3.6368131915062976`*^9}},
 FontSize->10],

Cell[BoxData["\<\"The running \
\\!\\(\\*\\nStyleBox[\\\"Mathematica\\\",\\nFontSlant->\\\"Italic\\\"]\\) \
version is 10.1.0  for Microsoft Windows (64-bit) (March 24, 2015)\"\>"], \
"Output",
 CellChangeTimes->{3.6385163317967997`*^9, 3.6386024369906*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Numerical algorithms for the T&E and predictive adaptive methods.\
\>", "Subchapter",
 CellChangeTimes->{{3.6371524922410097`*^9, 3.63715252674827*^9}, {
  3.6386006874046*^9, 3.6386007285966*^9}}],

Cell[TextData[{
 "We start implementing the  L1 finite difference scheme with variable \
timesteps for solving the fractional PDE \n",
 Cell[GraphicsData["Metafile", "\<\
CF5dJ6E]HGAYHf4PEfU^I6mgLb15CDHPAVmbKF5d0@0004`T0@0006`0003oooooooooodP9001c0P00
0000000000159`00cPT00215CDH0004094`00;40000700000000000000000000HA<006PK003B0000
:@400000000000000000050d0`0XR0@0AP0002`0000P0000ADe6:`500@0L00004000008@`=/00000
F08005P200160000O04007010015CDH[7T0500`0000000007d0300`000000000<402010000040000
0020?b501`0<000000000290100<0000000002Y0000T000060000000P3l0000000000000P3l00000
000002]0000<0000000001i01P0<0000000002501@0<0000000001i02@0<0000000002Y0000T0000
60000000P3l0000000000000P3l00000000002501`0<0000000002Y0000T000060000;02;3X00000
00000;02;3X00=K30409aB]0000<0000000002Y0000T000060000;02;3X0000000000;02;3X00=K3
0409aB]0000<0000000002Y0000T000060000;02;3X0000000000;02;3X00=JW0009Z@Y0080T0000
60000>7ohOl100000000000000200Ue:P09MBB4000080000HP0000`000010000900002@00000000n
000000000000000n00000000000200009`0001P00001000000000>7oh@0000009@0000`000010000
9@0000`000080020EP000300003oooooooooodP9001B0P001@000?coo?oloh`B?4Z<4Sa:o?olooco
9@0000`0000700209@0000`000000020900002@00000001100000000000000110000000000020000
AP000;PQ002/8@00ADe6:b]0000<0000000001i01P0<0000000002501@0<0000000001i02@0<0000
000002Y0000T000060000;02;3X0000000000;02;3X00=JW0009ZB501`0<0000000002]0000<0000
000002Y0000T000060000=:n_D4000000000094V_D7I9[k5A>abARA0100<0000000000Q000FX8000
W200008@`=/200000`0008`P00010000c0000041001_oOooI04008OmoomF8`00HjGoool`002fZ?oo
84E=AP000@2<8000O00000@0000`0000K000000000201`00>0@00:D2001m0@000000000000000000
eED:04S@1@1W06D0KP1U0780H@1d06D0I00P0680N@0P05L0C@1602l0A@1=04H0801R0640H`1[06D0
KP1T0200K`1V0200L01c07@0K`1U06@0J@1d0000J@1^0700M@1d0000000A0000300000H0000:0000
40000000000000004P0000`0000100005P0000`0000H0000600000`000000000DP00070100010000
>Oooo`0000000000000009010000000000020T<0C@1=04T0<@0`0000000000000000000000000000
00000000000000000000000000000000000000000000000010000<S:60000000200000L000000000
SU<gMLS:600`bQP0k;1300@000240000b<XH00000000000030000000000100008<XH000000240000
X0l0008000030000b<XH000000000000?<XH07nN@`3l2P@2P<XH0000@`040000S[E30;>6HgAXOP@2
8HQ600000000000000000040001<bQP002m:00c;603PW480HfPlM?koool004<0gKE306Qn10800000
00040VQn10;8bQP00@0003P07P0;0000b<XH06Qn10810`00/7d40P40001POP@2I7H02000000U0000
30000040001D0000E0000041001`oOoo1`4007[mool10000Zj[Q?ag7hKlE5000XS800040001<0000
0000000000000000oooooooooom@0000@00006@0000H000030000000000U0000300000d0080X0000
30000040001B0000L0400040001eoooo0000000000000000T040000000000082@`1=04d0B@0g0000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
?`00?`@000020000@=IT0<S:600000006`0n07@1HP000000D05R05P3B`0004<08=9T0<1kI0000000
10000000001L0@010000020000000041E<TH08cS:GN<bQP0mG4^MoKo7@7nooooZSPZMj8d:WL00000
001T023BI02F7`ZL000001SBI02LbQP0RU=gM@00HP000000XEAgMN;9HgBF7`ZL8=9T0801fWD0QP@2
B01;0000B`1XbQP0UQl:W8C<6000L7UeKXP20OkooonQE7Me1A;FMB3BI03PAFD04AlQN0002P3PAFD0
e<XH05`ieWETMP08000002D0000<00000@0005@0001D00001`4006omool;0@00MOgoo`40002[Z^4o
7LOQ_hTD003Z<P000@0004`00000000000000000003ooooooooooe00002`0000D00001P0000<0000
000002D0000<00003@00P2P0000<00000@000580001`0@000@0003Woool0000000000000002@0@00
000000000P9304d0C@190340<0000000000000000000000000000000000000000000000000000000
000000000000000000000000000o000o100005C96010eV@0S<XH0?Ea;WLK03h0M05R0000001@0F80
F0=;0000I00PdV@0`7]T000000040000000005`100400000800000000@5DbAP0000008c:603eLBig
m_lM0OkooonZ>2YgXS@ZM`00000006@08=9T09HO2Yd000006=9T09c:602:DgMe001R0000002QE7Me
h/USM9HO2YdPdV@0P07JM@00001804/0001;06S:602F7`ZMQ<`H001`NGE^R081o_oooj5DMgD54]Ie
8=9T0>15I@0A7b5h000:0>15I@3DbQP0G3WFMFAf00P000009@0000`000010000E00005@0000<0@00
L?gooa81001joOoo0@000:^ZhClMan6ol1@00:8b00010000C00000000000000000000?oooooooooo
D00007D0001h00009P0001`0000200000000000000000000000002D0000<00000P0002L0000H0000
0`00000000000000000002D0000<00000`0001<0000<00000P0005/0000h00000@4007cmoolB0@00
O?goo`40000500001@0001@DD39R5E0bHQEH<Q@DF38D550b600000`000000000E00005@000020@00
OOgoo`P10027oOoo0@000:^ZhClMan6o:Q@009<a00010000C00000000000000000000?oooooooooo
D0000400001T0000600000`000000000E00005@000080@00OOgoo``10027oOoo0@000:^ZhClMan6o
Wa@009<a00010000C00000000000000000000?ooooooooooD00007@0001@0000600000`000000000
9@0000`0000=0020:00000`000010000DP00070100010000MOooo`00000000000000090100000000
00020T<0C@1=04T0=`00000000000000000000000000000000000000000000000000000000000000
0000000000000000000003l003l4000005]I043FI00@@0@2j00001/0?P1d0F8000000501HP1H0d/0
>0440R3BI01P3fD0000000@000000000G0400@00000P000000010EC960000000S<XH0?Ea;WOfoad1
o_ooojXh:WNR=2Yg00000000I00PdV@0UQl:WP00000HdV@0W<XH08YCMgD0068000000:5DMgGRbF=d
UQl:WR3BI0200MYe2P000>RM108000@2J<XH09HO2Yj4c1P0071iMFj80P7nooooXEAgM@DBeWDPdV@0
h4EU014O8GP000X0h4EU0=C:601L>MIeI7H02000000U000030000040001D0000E00000`1001noOoo
404008Cmool10000Zj[Q?ag7hKoW5000cC400040001<00000000000000000000oooooooooom@0000
/0000500000H000030000000000U0000300000d0080X000030000040001B0000L0400040000ioooo
0000000000000000T040000000000082@`1=0580<@0`000000000000000000000000000000000000
000000000000000000000000000000000000000000000000?`00?`@0001DbAP0@=IT08c:603eLBig
6`0n07@1HP000000D05R05P3B`0006@08=9T060?I@00000010000000001L0@010000020000000041
E<TH0000002<bQP0mG4^MoKo7@7nooooZSPZMj8d:WL00000001T023BI02F7`ZO000001SBI02LbQP0
RU=gM@00HP000000XEAgMN;9HgBF7`ZO8=9T0801fWD00000j9d40P00109XbQP0UQl:WhC<6000L7Ue
KXP20OkooonQE7Me1A;FMB3BI03PAFD04AlQN0002P3PAFD0e<XH05`ieWETMP08000002D0000<0000
0@0005@0001D00005P4007OmoolN0@00POgoo`40002[Z^4o7LOQ_k8E000L<P000@0004`000000000
00000000003ooooooooooe00000m0000X00001P0000<0000000002D0000<00003@00P2P0000<0000
0@000580001`0@000@0003Woool0000000000000002@0@00000000000P9304d0C@190340<0000000
000000000000000000000000000000000000000000000000000000000000000000000000000o000o
100005C96010eV@0S<XH0?Ea;WLK03h0M05R0000001@0F80F0=;0000I00PdV@0H0mU000000040000
000005`100400000800000000@5DbAP0000008c:603eLBigm_lM0OkooonZ>2YgXS@ZM`00000006@0
8=9T09HO2Z0000006=9T09c:602:DgMe001R0000002QE7Meh/USM9HO2Z0PdV@0P07JM@00003XW@@2
00040VS:602F7`ZPQ<`H001`NGE^R081o_oooj5DMgD54]Ie8=9T0>15I@0A7b5h000:0>15I@3DbQP0
G3WFMFAf00P000009@0000`000010000E00005@0000P0@00MogoobT10021oOoo0@000:^ZhClMan6o
Q1H001`b00010000C00000000000000000000?ooooooooooD00004/0002P0000600000`000000000
E00005@0000[0@00L?gooc41001joOoo0@000:^ZhClMan6oDaL00:8b00010000C000000000000000
00000?ooooooooooD0000400001T0000600000`0000000009@0000`0000=0020:00000`000010000
DP00070100010000MOooo`0000000000000009010000000000020T<0C@1B03L00000000000000000
0000000000000000000000000000000000000000000000000000000000000000000003l003l40000
E<TH043FI02<bQP0mG4^Ma/0?P1d0F8000000501HP1H0d/0001T023BI01P3fD0000000@000000000
G0400@00000P000000010EC960000000S<XH0?Ea;WOfoad1o_ooojXh:WNR=2Yg00000000I00PdV@0
UQl:X@00000HdV@0W<XH08YCMgD0068000000:5DMgGRbF=dUQl:XB3BI0200MYe00000>RM108000@2
J<XH09HO2Z64c1P0071iMFj80P7nooooXEAgM@DBeWDPdV@0h4EU014O8GP000X0h4EU0=C:601L>MIe
I7H02000000U000030000040001D0000E0000301001_oOoo=04007Gmool10000Zj[Q?ag7hKo85`00
jS800040001<00000000000000000000oooooooooom@0000<P000500000H000030000000000U0000
300000d0080X000030000040001B0000L0400040000ioooo0000000000000000T040000000000082
@`1=04d0B@0a03000000000000000000000000000000000000000000000000000000000000000000
0000000000000000?`00?`@0001DbAP0@=IT08c:603eLBig6`0n07@1HP000000D05R05P3B`0006@0
8=9T060?I@00000010000000001L0@010000020000000041E<TH0000002<bQP0mG4^MoKo7@7noooo
ZSPZMj8d:WL00000001T023BI02F7`ZR000001SBI02LbQP0RU=gM@00HP000000XEAgMN;9HgBF7`ZR
8=9T0801fWD00000j9d40P00109XbQP0UQl:XXC<6000L7UeKXP20OkooonQE7Me1A;FMB3BI03PAFD0
4AlQN0002P3PAFD0e<XH05`ieWETMP08000002D0000<00000@0005@0001D0000=@40073moolk0@00
N_goo`40002[Z^4o7LOQ_b8H002R<P000@0004`00000000000000000003ooooooooooe00001e0000
N00002D0000<00001`00P2P0000<00000P0002H0000L00000P0000000000000000000000000U0000
30000080000U000030000000080X0000300000<0000W0000600000<00000000000000000000U0000
300000<0000C000030000080001K0000>00002/1001loOoo>`4007cmool100001@0000D0001L5e0b
W1Q@<Y`HF39L5ePbG1M@<QP0000<0000000005@0001D0000:`4007gmoola0@00Qogoo`40002[Z^4o
7LOQ_e<G002C<@000@0004`00000000000000000003ooooooooooe0000100000I00001P0000<0000
000005@0001D0000<04007gmoolf0@00Qogoo`40002[Z^4o7LOQ_lPG002C<@000@0004`000000000
00000000003ooooooooooe00001h0000N00001P0000<0000000002D0000<00003@00P2P0000<0000
0@000580001`0@000@0007Goool0000000000000002@0@00000000000P9304d0DP0g000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000o000o
1000001KF@10eV@044040^P0000K03h0M05R0000001@0F80F0=;03P1108PdV@0H0mU000000040000
000005`100400000800000000@5DbAP0000008c:603eLBigm_lM0OkooonZ>2YgXS@ZM`00000006@0
8=9T09HO2Z<000006=9T09c:602:DgMe001R0000002QE7Meh/USM9HO2Z<PdV@0P07JM@X0003XW@@2
00040VS:602F7`ZSQ<`H001`NGE^R081o_oooj5DMgD54]Ie8=9T0>15I@0A7b5h000:0>15I@3DbQP0
G3WFMFAf00P000009@0000`000010000E00005@0000f0@00O_goocX10024oOoo0@000:^ZhClMan6o
>QP00<da00010000C00000000000000000000?ooooooooooD0000380001@0000600000`000000000
9@0000`0000=0020:00000`000010000DP00070100010000>Oooo`00000000000000090100000000
00020T<0C@1B0340<000000000000000000000000000000000000000000000000000000000000000
0000000000000000000003l003l40000E<TH043FI02<bQP0mG4^Ma/0?P1d0F8000000501HP1H0d/0
001T023BI01P3fD0000000@000000000G0400@00000P000000010EC960000000S<XH0?Ea;WOfoad1
o_ooojXh:WNR=2Yg00000000I00PdV@0UQl:Y000000HdV@0W<XH08YCMgD0068000000:5DMgGRbF=d
UQl:Y23BI0200MYe00000>RM108000@2J<XH09HO2ZB4c1P0071iMFj80P7nooooXEAgM@DBeWDPdV@0
h4EU014O8GP000X0h4EU0=C:601L>MIeI7H02000000U000030000040001D0000E00003h1001goOoo
AP40087mool10000Zj[Q?ag7hKoH600073800040001<00000000000000000000oooooooooom@0000
:`000:00000H000030000000000U0000300000d0080X000030000040001B0000L0400040000ioooo
0000000000000000T040000000000082@`1=04d0B@0a030000000000000000000000000000000000
000000000000000000000000000000000000000000000000?`00?`@0001DbAP0@=IT08c:603eLBig
6`0n07@1HP000000D05R05P3B`0006@08=9T060?I@00000010000000001L0@010000020000000041
E<TH0000002<bQP0mG4^MoKo7@7nooooZSPZMj8d:WL00000001T023BI02F7`ZU000001SBI02LbQP0
RU=gM@00HP000000XEAgMN;9HgBF7`ZU8=9T0801fWD00000j9d40P00109XbQP0UQl:YHC<6000L7Ue
KXP20OkooonQE7Me1A;FMB3BI03PAFD04AlQN0002P3PAFD0e<XH05`ieWETMP08000002D0000<0000
0@0005@0001D0000B04007Omoom>0@00POgoo`40002[Z^4o7LOQ_ilI000L<P000@0004`000000000
00000000003ooooooooooe00001V0000I00001P0000<0000000002D0000<00003@00P2P0000<0000
0@000580001`0@000@0003Woool0000000000000002@0@00000000000P9304d0DP0a030000000000
000000000000000000000000000000000000000000000000000000000000000000000000000o000o
100005C96010eV@0S<XH0?Ea;WLK03h0M05R0000001@0F80F0=;0000I00PdV@0H0mU000000040000
000005`100400000800000000@5DbAP0000008c:603eLBigm_lM0OkooonZ>2YgXS@ZM`00000006@0
8=9T09HO2ZH000006=9T09c:602:DgMe001R0000002QE7Meh/USM9HO2ZHPdV@0P07JM@00003XW@@2
00040VS:602F7`ZVQ<`H001`NGE^R081o_oooj5DMgD54]Ie8=9T0>15I@0A7b5h000:0>15I@3DbQP0
G3WFMFAf00P000009@0000`000010000E00005@0001>0@00Mogooe810021oOoo0@000:^ZhClMan6o
5QX001`b00010000C00000000000000000000?ooooooooooD00002P0001@0000600000`000000000
9@0000`0000=0020:00000`000010000DP00070100010000>Oooo`00000000000000090100000000
00020T<0C@1=04T0<@0`000000000000000000000000000000000000000000000000000000000000
0000000000000000000003l003l40000E<TH043FI02<bQP0mG4^Ma/0?P1d0F8000000501HP1H0d/0
001T023BI01P3fD0000000@000000000G0400@00000P000000010EC960000000S<XH0?Ea;WOfoad1
o_ooojXh:WNR=2Yg00000000I00PdV@0UQl:Y`00000HdV@0W<XH08YCMgD0068000000:5DMgGRbF=d
UQl:Yb3BI0200MYe00000>RM108000@2J<XH09HO2ZN4c1P0071iMFj80P7nooooXEAgM@DBeWDPdV@0
h4EU014O8GP000X0h4EU0=C:601L>MIeI7H02000000U000030000040001D0000E0000581001goOoo
F040087mool10000Zj[Q?ag7hKmT6P0073800040001<00000000000000000000oooooooooom@0000
N00007P0000H000030000000001D0000E00005P1001goOooF`40087mool10000Zj[Q?ag7hKoF6P00
73800040001<00000000000000000000oooooooooom@0000>`0003`0000H000030000000001D0000
E00005`1001goOooH040087mool10000Zj[Q?ag7hKl_6`0073800040001<00000000000000000000
oooooooooom@0000M0000500000H000030000000000U0000300000d0080X000030000040001B0000
L0400040000ioooo0000000000000000T040000000000082@`1=0580<@0`00000000000000000000
0000000000000000000000000000000000000000000000000000000000000000?`00?`@0001DbAP0
@=IT08c:603eLBig6`0n07@1HP000000D05R05P3B`0006@08=9T060?I@00000010000000001L0@01
0000020000000041E<TH0000002<bQP0mG4^MoKo7@7nooooZSPZMj8d:WL00000001T023BI02F7`ZX
000001SBI02LbQP0RU=gM@00HP000000XEAgMN;9HgBF7`ZX8=9T0801fWD00000j9d40P00109XbQP0
UQl:Z8C<6000L7UeKXP20OkooonQE7Me1A;FMB3BI03PAFD04AlQN0002P3PAFD0e<XH05`ieWETMP08
000002D0000<00000@0005@0001D0000H04007OmoomT0@00POgoo`40002[Z^4o7LOQ_gLK000L<P00
0@0004`00000000000000000003ooooooooooe00000Y0000D00002D0000<00001`00P2P0000<0000
0P0002D0000<00000000P2P0000<00000`0002D0000<00003@00P2P0000<00000@0000h0000D0000
00000100000D0000240122@0000H00000Q30f`400003000000000000000000006d000400000d0000
0@000080000]AX13H6<Ta4YJb4:?nlQ10`0002e6P4=PHbC4_ebb@f1S9<@]AX13Q1/Na24000080000
HP0000`0000100008@0000P0000Q0000200007<0000<0000000001`0000800009@0000`000000020
9@0000`0000700209@0000`0000>00206@0000`0003oool0600000`0000000004P0000`000020000
4`0000`000010000500000`0000=00005@0000`0000100005P0000`0000000003@00010000000000
000003X0000<00002P0001/0000@000000000000000S000080000?2C_d40000000000?jXa47lo;o5
=95lAR@0000T0000l9>o@@0000000000oZS4@Ocl_lDdTGa6100007<0000<0000000000d0000@0000
00000000001B0000L0400080000@00001`00000000000000_080000000070P8RD`1i07<0M01U06d0
000D0:3hooob0@00000003bm@P:0n?oo201HO__fool000000000022m@P:0n?ooool00000E0XHT7P0
0000P5c;=@3;c4`mT<`e0;SMPPLQ@kighQlQ5280RP4H00000000062F2PH80000cjTT@@00acf8Po46
00000<3Lk0J/b3D00000000000000000ooooob3<=@1<c3D0?=Le08DI`WNeLfH1o_ooohcS_GObh;eg
003c23Sl0002000000000200001lc3D0X<`e0>]HkgH007P0200D02IJkgHAZA=U0000062F2PKooooo
0`00000000000000000006S<=@2:MFMX[=<e001`lGKik]LCo_ooobIJkgIR4aEg8;]D2P40003Dc3D0
f<`e02l`5GMTMP08000002D0000<00000P0004H000280000O00004M4BD<200000@4006kmoomT0@00
Qogooc00001W06D0KP1U0780H@1d06D0I00P0680N@0P05L0C@1602l0A@1=04H0801R0640H`1[06D0
KP1T0200K`1V0200L01c07@0K`1U06@0J@1d0000J@1^0700M@1d0000000S0000800009=FVCl00000
00000?mCWKolo;o5=95lAR@0000T0000TeJI?`0000000000oe>M_ocl_lDdTGa6100002<0000P0000
TeJI?`0000000000oe>M_ocl_lDdTGa6900002@0002CEYTo00000000003oDifoo?boaCBAO4H40000
4P0000`0000100005P0000`0000H0000600000`000000000DP00070100030000>Oooo`0000000000
00000901000000001`020T<0C@1=04T0<@0`00000000000000000000000000000000000000000000
0000000000000000000000000000000010000<S:60000000200000L000000000SU<gMLS:600`bQP0
k;1300@000240000b<XH00000000000030000000000100008<XH000000240000X0l0008000030000
b<XH000000000000?<XH07nN@`3l2P@2P<XH0000@`040000S[E30;>6HgAXOP@28HQ6000000000000
00000040001<bQP002m:00c;603PW480HfPlM?koool004<0gKE306Qn1080000000040VQn10;8bQP0
0@0003P07P0;0000b<XH06Qn10810`00/7d40P40001POP@2I7H02000000U0000300000<0001D0000
E00000l0000`0000UP0002D100010000Zj[Q?ag7hKlE5000XS800040001<00000000000000000000
oooooooooom@0000@00006@0000H000030000000001B0000L04000@0000D00002@00000000000000
_080000000070P8RD`1i07<0M01U06d000000000003R0000000006a4NP:0n?oo0000000000000000
00000514NP:0n?oo^YH000005GNgI1EghQlQ5000000000000@00091[o@GHbcD0HF@EMn8O8A@00000
000005@000000000T6_m1E3<=@3NDAEghQlQ582Eo0D40000f5aO0e@0000000000@0003P07P0;0000
b<XH06Qn10810`00/7d40P40001POP@2000020000030g>`6[<Pe053<=@0_<1EgD<`e06H`5GN4fE/:
H9H:1RD0000000X022X008C==@0MnV=XhQlQ5000o0F@Jod510000=QLG`>b2VAXP0HIM`0000201QUg
P04IMiSIF`ZXc3D0;c0EMjS<=@1V<1Egi=UK2V2F2PITMP08000002D0000<0000100002P0000<0000
0`000580001`0@000`0007Goool0000000000000002@0@00000000L00P9304d0C@1903L000000000
000000000000000000000000000000000000000000000000000000000000000000000000000o000o
100000800010eV@0b<XH0000000K03h0M05R0000001@0F80F0=;0000@`0PdV@0`7]T000000040000
000005`100400000800000000@5DbAP0S><YMhc:603eLBigm_lM0OkooonZ>2YgXS@ZM`00000006@0
8=9T09HO2Y`000006=9T09c:602:DgMe001R0000002QE7Meh/USM9HO2Y`PdV@0P07JM@26109804/0
001;06S:602F7`ZLQ<`H001`NGE^R081o_oooj5DMgD54]Ie8=9T0>15I@0A7b5h000:0>15I@3DbQP0
G3WFMFAf00P000009@0000`000030000E00005@0002J00003`000001002j00000@000:^ZhClMan6o
RA@00>Xb00010000C00000000000000000000?ooooooooooD0000;00001@0000600000`000000000
9@0000`000040000:00000`000030000DP00070100030000>Oooo`00000000000000090100000000
1`020T<0C@1=04T0<@0`000000000000000000000000000000000000000000000000000000000000
0000000000000000000003l003l40000E<TH043FI02<bQP0mG4^Ma/0?P1d0F8000000501HP1H0d/0
001T023BI030Nf@0000000@000000000G0400@00000P000000010EC960000000S<XH0?Ea;WOfoad1
o_ooojXh:WNR=2Yg00000000I00PdV@0UQl:W@00000HdV@0W<XH08YCMgD0068000000:5DMgGRbF=d
UQl:WB3BI0200MYe000004P0B`0004/0J<XH09HO2Yf4c1P0071iMFj80P7nooooXEAgM@DBeWDPdV@0
h4EU014O8GP000X0h4EU0=C:601L>MIeI7H02000000U0000300000<0001D0000E00001D1000`0000
Y@4002D100010000Zj[Q?ag7hKo`5000XS800040001<00000000000000000000oooooooooom@0000
M@0007P0000V0000700000D00000000000000000000000009@0000`0000500009`0001P000060000
00000000000000009@0000`0000600004`0000`000020000F`0003P0000=0000@`4009h1001>0@00
0@0000D00005000051A@<V8ED39R5EPb51AH<Q@DD38H000030000000001D0000E00002P0001n0@00
[`0007<200010000Zj[Q?ag7hKlZ5000Tc400040001<00000000000000000000oooooooooom@0000
@00006@0000H000030000000001D0000E0000;@0001n0@00504007<200010000Zj[Q?ag7hKnO5000
Tc400040001<00000000000000000000oooooooooom@0000M0000500000H000030000000000U0000
300000@0000X0000300000<0001B0000L04000<0001eoooo0000000000000000T040000000070082
@`1=04d0B@0g00000000000000000000000000000000000000000000000000000000000000000000
0000000000000000?`00?`@00000FeT0@=IT011010;X00006`0n07@1HP000000D05R05P3B`0h0@@2
8=9T060?I@00000010000000001L0@010000020000000041E<TH0000002<bQP0mG4^MoKo7@7noooo
ZSPZMj8d:WL00000001T023BI02F7`ZN000001SBI02LbQP0RU=gM@00HP000000XEAgMN;9HgBF7`ZN
8=9T0801fWD:0000j9d40P00109XbQP0UQl:WXC<6000L7UeKXP20OkooonQE7Me1A;FMB3BI03PAFD0
4AlQN0002P3PAFD0e<XH05`ieWETMP08000002D0000<00000`0005@0001D00002`4006d1001a0@00
60800040002[Z^4o7LOQ_nLD003=<@000@0004`00000000000000000003ooooooooooe00002`0000
D00001P0000<0000000002D0000<0000100002P0000<00000`000580001`0@000`0003Woool00000
00000000002@0@00000000L00P9304d0DP0a03000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000o000o100005C96010eV@0S<XH0?Ea;WLK03h0
M05R0000001@0F80F0=;0000I00PdV@0H0mU000000040000000005`100400000800000000@5DbAP0
000008c:603eLBigm_lM0OkooonZ>2YgXS@ZM`00000006@08=9T09HO2Yl000006=9T09c:602:DgMe
001R0000002QE7Meh/USM9HO2YlPdV@0P07JM@00003XW@@200040VS:602F7`ZOQ<`H001`NGE^R081
o_oooj5DMgD54]Ie8=9T0>15I@0A7b5h000:0>15I@3DbQP0G3WFMFAf00P000009@0000`000030000
E00005@0003n0@00e@000;h2003:0@000@000:^ZhClMan6o/QD001`b00010000C000000000000000
00000?ooooooooooD00003d0002P0000600000`0000000009@0000`000040000:00000`000030000
DP00070100030000>Oooo`000000000000000901000000001`020T<0C@1=04T0<@0`000000000000
0000000000000000000000000000000000000000000000000000000000000000000003l003l40000
E<TH043FI02<bQP0mG4^Ma/0?P1d0F8000000501HP1H0d/0001T023BI01P3fD0000000@000000000
G0400@00000P000000010EC960000000S<XH0?Ea;WOfoad1o_ooojXh:WNR=2Yg00000000I00PdV@0
UQl:X000000HdV@0W<XH08YCMgD0068000000:5DMgGRbF=dUQl:X23BI0200MYe00000>RM108000@2
J<XH09HO2Z24c1P0071iMFj80P7nooooXEAgM@DBeWDPdV@0h4EU014O8GP000X0h4EU0=C:601L>MIe
I7H02000000U0000300000<0001D0000E0000?T2003E0000cP<00<X100010000Zj[Q?ag7hKn45P00
73800040001<00000000000000000000oooooooooom@0000B`000:00000H000030000000001D0000
E0000?43000`0000N0@002D100010000Zj[Q?ag7hKmC5`00XS800040001<00000000000000000000
oooooooooom@0000@00006@0000H000030000000000U0000300000@0000X0000300000<0001B0000
L04000<0001eoooo0000000000000000T040000000070082@`1=0580=`0000000000000000000000
0000000000000000000000000000000000000000000000000000000000000000?`00?`@0001DbAP0
@=IT08c:603eLBig6`0n07@1HP000000D05R05P3B`0006@08=9T060?I@00000010000000001L0@01
0000020000000041E<TH0000002<bQP0mG4^MoKo7@7nooooZSPZMj8d:WL00000001T023BI02F7`ZQ
000001SBI02LbQP0RU=gM@00HP000000XEAgMN;9HgBF7`ZQ8=9T0801fWD00000j9d40P00109XbQP0
UQl:XHC<6000L7UeKXP20OkooonQE7Me1A;FMB3BI03PAFD04AlQN0002P3PAFD0e<XH05`ieWETMP08
000002D0000<00000`0005@0001D0000OP@000l0003N1000^P000040002[Z^4o7LOQ_lPG003Z<P00
0@0004`00000000000000000003ooooooooooe00000b0000D00001P0000<0000000002D0000<0000
100002P0000<00000`000580001`0@000`0003Woool0000000000000002@0@00000000L00P9304d0
C@190340<00000000000000000000000000000000000000000000000000000000000000000000000
00000000000o000o100005C96010eV@0S<XH0?Ea;WLK03h0M05R0000001@0F80F0=;0000I00PdV@0
H0mU000000040000000005`100400000800000000@5DbAP0000008c:603eLBigm_lM0OkooonZ>2Yg
XS@ZM`00000006@08=9T09HO2Z8000006=9T09c:602:DgMe001R0000002QE7Meh/USM9HO2Z8PdV@0
P07JM@00003XW@@200040VS:602F7`ZRQ<`H001`NGE^R081o_oooj5DMgD54]Ie8=9T0>15I@0A7b5h
000:0>15I@3DbQP0G3WFMFAf00P000009@0000`000030000E00005@0003Y1000<00007T5000U0@00
0@000:^ZhClMan6o8QP00:8b00010000C00000000000000000000?ooooooooooD00007D0001h0000
9@0000`000070020:00000`0000500009P0001`0000500000000000000000000000002D0000<0000
1@0002D0000<00000000P2P0000<00001P0002L0000H00001P00000000000000000002D0000<0000
1P0001<0000<00000P0005/0000h0000o0<004<1001l1@00CP400040000500001@0005`GD3:L650b
W1QH<U`GF39L5e0b600000`000000000E00005@0003a0`00OP4007P4001c0P000@000:^ZhClMan6o
DaL009<a00010000C00000000000000000000?ooooooooooD0000400001T0000600000`000000000
E00005@0001n1000OP4000h5001c0P000@000:^ZhClMan6ob1L009<a00010000C000000000000000
00000?ooooooooooD00007P0001h0000600000`0000000009@0000`000040000:00000`000030000
DP00070100030000MOooo`000000000000000901000000001`020T<0C@1B03L00000000000000000
0000000000000000000000000000000000000000000000000000000000000000000003l003l40000
05]I043FI00@@0@2j00001/0?P1d0F8000000501HP1H0d/0>0440R3BI01P3fD0000000@000000000
G0400@00000P000000010EC960000000S<XH0?Ea;WOfoad1o_ooojXh:WNR=2Yg00000000I00PdV@0
UQl:X`00000HdV@0W<XH08YCMgD0068000000:5DMgGRbF=dUQl:Xb3BI0200MYe2P000>RM108000@2
J<XH09HO2Z>4c1P0071iMFj80P7nooooXEAgM@DBeWDPdV@0h4EU014O8GP000X0h4EU0=C:601L>MIe
I7H02000000U0000300000<0001D0000E00000H5001]0@00IPD001P200010000Zj[Q?ag7hKlj6000
cC400040001<00000000000000000000oooooooooom@0000<P000500000H000030000000000U0000
300000@0000X0000300000<0001B0000L04000<0000ioooo0000000000000000T040000000070082
@`1=0580<@0`00000000000000000000000000000000000000000000000000000000000000000000
0000000000000000?`00?`@0001DbAP0@=IT08c:603eLBig6`0n07@1HP000000D05R05P3B`0006@0
8=9T060?I@00000010000000001L0@010000020000000041E<TH0000002<bQP0mG4^MoKo7@7noooo
ZSPZMj8d:WL00000001T023BI02F7`ZT000001SBI02LbQP0RU=gM@00HP000000XEAgMN;9HgBF7`ZT
8=9T0801fWD00000j9d40P00109XbQP0UQl:Y8C<6000L7UeKXP20OkooonQE7Me1A;FMB3BI03PAFD0
4AlQN0002P3PAFD0e<XH05`ieWETMP08000002D0000<00000`0005@0001D0000``D00=D000231P00
bP400040002[Z^4o7LOQ_mPH000L<P000@0004`00000000000000000003ooooooooooe00000[0000
X00001P0000<0000000002D0000<0000100002P0000<00000`000580001`0@000`0003Woool00000
00000000002@0@00000000L00P9304d0C@190340<000000000000000000000000000000000000000
0000000000000000000000000000000000000000000o000o100005C96010eV@0S<XH0?Ea;WLK03h0
M05R0000001@0F80F0=;0000I00PdV@0H0mU000000040000000005`100400000800000000@5DbAP0
000008c:603eLBigm_lM0OkooonZ>2YgXS@ZM`00000006@08=9T09HO2ZD000006=9T09c:602:DgMe
001R0000002QE7Meh/USM9HO2ZDPdV@0P07JM@00003XW@@200040VS:602F7`ZUQ<`H001`NGE^R081
o_oooj5DMgD54]Ie8=9T0>15I@0A7b5h000:0>15I@3DbQP0G3WFMFAf00P000009@0000`000030000
E00005@0002b1P00e@0003H7003:0@000@000:^ZhClMan6oWaT001`b00010000C000000000000000
00000?ooooooooooD00006H0=@1T0000600000`0000000009@0000`000040000:00000`000030000
DP00070100030000>Oooo`000000000000000901000000001`020T<0C@1B0340<000000000000000
0000000000000000000000000000000000000000000000000000000000000000000003l003l40000
E<TH043FI02<bQP0mG4^Ma/0?P1d0F8000000501HP1H0d/0001T023BI01P3fD0000000@000000000
G0400@00000P000000010EC960000000S<XH0?Ea;WOfoad1o_ooojXh:WNR=2Yg00000000I00PdV@0
UQl:YP00000HdV@0W<XH08YCMgD0068000000:5DMgGRbF=dUQl:YR3BI0200MYe00000>RM108000@2
J<XH09HO2ZJ4c1P0071iMFj80P7nooooXEAgM@DBeWDPdV@0h4EU014O8GP000X0h4EU0=C:601L>MIe
I7H02000000U0000300000<0001D0000E0000407003E0000X0L00<X100010000Zj[Q?ag7hKlF6P00
73800040001<00000000000000000000oooooooooom@0000:0000500000H000030000000000U0000
300000@0000X0000300000<0001B0000L04000<0000ioooo0000000000000000T040000000070082
@`1=04d0B@0a03000000000000000000000000000000000000000000000000000000000000000000
0000000000000000?`00?`@0001DbAP0@=IT08c:603eLBig6`0n07@1HP000000D05R05P3B`0006@0
8=9T060?I@00000010000000001L0@010000020000000041E<TH0000002<bQP0mG4^MoKo7@7noooo
ZSPZMj8d:WL00000001T023BI02F7`ZW000001SBI02LbQP0RU=gM@00HP000000XEAgMN;9HgBF7`ZW
8=9T0801fWD00000j9d40P00109XbQP0UQl:YhC<6000L7UeKXP20OkooonQE7Me1A;FMB3BI03PAFD0
4AlQN0002P3PAFD0e<XH05`ieWETMP08000002D0000<00000`0005@0001D0000WPL00=D0000^2000
bP400040002[Z^4o7LOQ_f@J000L<P000@0004`00000000000000000003ooooooooooe00001h080o
N00001P0000<0000000005@0001D00009PP00=D0001^2000bP400040002[Z^4o7LOQ_mHJ000L<P00
0@0004`00000000000000000003ooooooooooe00000k04d0?00001P0000<0000000005@0001D0000
T@P00=D0003a2000bP400040002[Z^4o7LOQ_blK000L<P000@0004`00000000000000000003ooooo
oooooe00001d0020D00001P0000<0000000002D0000<0000100002P0000<00000`000580001`0@00
0`0003Woool0000000000000002@0@00000000L00P9304d0DP0a0300000000000000000000000000
00000000000000000000000000000000000000000000000000000000000o000o100005C96010eV@0
S<XH0?Ea;WLK03h0M05R0000001@0F80F0=;0000I00PdV@0H0mU000000040000000005`100400000
800000000@5DbAP0000008c:603eLBigm_lM0OkooonZ>2YgXS@ZM`00000006@08=9T09HO2ZP00000
6=9T09c:602:DgMe001R0000002QE7Meh/USM9HO2ZPPdV@0P07JM@00003XW@@200040VS:602F7`ZX
Q<`H001`NGE^R081o_oooj5DMgD54]Ie8=9T0>15I@0A7b5h000:0>15I@3DbQP0G3WFMFAf00P00000
9@0000`000030000E00005@0003W2000e@0004L9003:0@000@000:^ZhClMan6oMa/001`b00010000
C00000000000000000000?ooooooooooD00002T0001@00009@0000`000070020:00000`000050000
9@0000`000000020:00000`0000600009@0000`000040000:00000`000030000AP0001@000080000
AdA9@`<0000R000030000?oooolR000030000?oooolU0000300000d0080X000030000080000X0000
300000@0000R000030000?oooom60000`0400;@10015CDH[;40002@0000H00000020?`0000000000
0020?`0008000020:T0002@0000H0000d[jm@@0000000000TBJm@MTV_/E4k796940000`000000000
:T0002@0000H0000/08/>P0000000000/08/>P00eZL000VY:d0000`0000000007T0600`000000000
8D0500`000000000240211P0000<00000Q30f`000003000@=40200`0000000007T0900`000000000
:T0002@0000H0000/08/>P0000000000/08/>P00eZL000VY8D0700`000000000:T0002@0000H0000
/08/>P0000000000/08/>P00eZL000VY:d0000`000000000:d0000`0000000007T0600`000000000
8D0500`000000000240311P0000<00000Q30f`000003000@=40300`0000000007T0900`000000000
:T0002@0000H00000020?`00000000000020?`00000000008D0700`000000000C00006@000000000
000004L9001A0P000000000000182@00DP8002T0ZP00000000000000P3l0000000000000P3l00000
0000000000000000000000000000000000000280000<0000ooooodH0000L0000400004E=AR/2@000
30000000000>000050000000000@00005000
\>"], "Graphics",
  GeneratedCell->False,
  CellAutoOverwrite->False,
  ImageSize->{194.49473684210525`, 48.3165872576177},
  ImageMargins->{{36.800000000000004`, 0.}, {0., 43.66568421052633}}],
 "\t\nThe finite difference scheme is given by Eq. (10):\n",
 Cell[GraphicsData["Metafile", "\<\
CF5dJ6E]HGAYHf4PEfU^I6mgLb15CDHPAVmbKF5d0@0009G40@0006`0003oooooooooom`7003Q0000
0000000000118@00i@800215CDH00040a9D00141000500000000000000000000HA<006PK003B0000
:@400000000000000000050d0`0XR0@0AP0002`0000P0000ADe6:`500@0L00004000008@`=/00000
F08005P200160000O04007010015CDH[7T0500`0000000007d0300`000000000<402010000040000
0020?b501`0<000000000290100<0000000002Y0000T000060000000P3l0000000000000P3l00000
000002]0000<0000000001i01P0<0000000002501@0<0000000001i02@0<0000000002Y0000T0000
60000000P3l0000000000000P3l00000000002501`0<0000000002Y0000T000060000;02;3X00000
00000;02;3X0<2K5030CaB]0000<0000000002Y0000T000060000;02;3X0000000000;02;3X0<2K5
030CaB]0000<0000000002Y0000T000060000;02;3X0000000000;02;3X002JY000CZ@Y0080T0000
60000>7ohOl100000000000000309S]:0?R2B24000080000HP0000`000010000900002@00000080m
000000000000080m00000000000200009`0001P00001000000000>7oh@0000009@0000`000010000
9@0000`000080020EP000300003oooooooooom`7002`00001@000?Son?ohooP:^7gh2[Qmn?ohooSo
9@0000`0000700209@0000`000000020900002@00000081100000000000008110000000000020000
AP0008Q6001lAP00ADe6:b]0000<0000000001i01P0<0000000002501@0<0000000001i02@0<0000
000002Y0000T000060000;02;3X0000000000;02;3X002JY000CZB501`0<0000000002]0000<0000
000002Y0000T0000600006SX9440000000000?MU947WE0K5^M3BABA0100<0000000000Q000EhA@00
K4D0008@`=/200000`0005a500010000c0000=00001aoOooTP4008Cmooni7000QZGoogTg002oYooo
84E=AP000@1LA@00g0000080000`0000K000000000201`00>0@00:D2001m0@000000000000000000
eED:04S@1@1W06D0KP1U0780H@1d06D0I00P0680N@0P05L0C@1602l0A@1=04H0801R0640H`1[06D0
KP1T0200K`1V0200L01c07@0K`1U06@0J@1d0000J@1^0700M@1d0000000A0000300000H0000:0000
40000000000000004P0000`0000100005P0000`0000H0000600000`000000000DP00070100010000
>Oooo`0000000000000009010000000000020T<0C@1C05T0<@0`04l0DP1904L00000000000000000
00000000000000000000000000000000000000000000000010000<S:60000000200000L000000000
SU<gMLS:600`bQP0k;1300@000240000b<XH00000000000030000000000100008<XH000000240000
X0l0008000030000b<XH000000000000?<XH07nN@`3l2U`0P<XH0000@`040000S[E3005;:7aXOU`0
8HQ600000000000000000040001<bQP002m:00c;603PW480dJEgO?koool004<0gKE306QnG0000000
001L06QnG038bQP00@0003P07P0;0000b<XH06QnG0010`00/7eL0040001POU`0I7H02000000U0000
30000040001D0000E0000=00001coOoof00008Cmool10000Zj[Q?ag7hKm84000JS800040001<0000
0000000000000000oooooooooom@0000X@000:00000H000030000000000U0000300000d0080X0000
30000040001B0000L0400040000ioooo0000000000000000T040000000000082@`1=04d0B@0a0300
00000000000000000000000000000000000000000000000000000000000000000000000000000000
?`00?`@000020000@=IP0<S:600000006`0n07@1GP000000D05N05P3B`0004<08=9P0<1kH0000000
10000000001L0@010000020000000041E<TH08cS:GN<bQP0mG4^Mjj>1P7nooooZSPZMj8d:WL00000
001P023BH00X80Yk000001SBH02LbQP0RU=gM@00GP000000XEAgMK:8;W`X80Yk8=9P0801fWD0QU`0
B01;0000B`1XbQP0:20:NhC<6000L7Ue?/U?2OkooonQE7Me1A;FMB3BH03PAF40kQlQa0002P3PAF40
e<XH05`ieWETMP08000002D0000<00000@0005@0001D0000f00007?moooO0000OOgoo`40002[Z^4o
7LOQ_n8@001Z<P000@0004`00000000000000000003ooooooooooe00001C0000N00001P0000<0000
000002D0000<00003@00P2P0000<00000@000580001`0@000@0007Goool0000000000000002@0@00
000000000P9304d0C@1903L000000000000000000000000000000000000000000000000000000000
000000000000000000000000000o000o100005C96010eV00S<XH0?Ea;WLK03h0M05N0000001@0Eh0
F0=;0000H00PdV00`7]P000000040000000005`100400000800000000@5DbAP0000008c:603eLBig
[Xh60OkooonZ>2YgXS@ZM`00000006008=9P02PP2W`000006=9P09c:602:DgMe001N0000002QE7Me
/XP^O2PP2W`PdV00P07JM@00001804/0001;06S:600X80YlQ<`H001`NGDnbDl9o_oooj5DMgD54]Ie
8=9P0>15H@3^7b74000:0>15H@3DbQP0G3WFMFAf00P000009@0000`000010000E00005@0003N0000
Mogoon<0001moOoo0@000:^ZhClMan6oGA4004`b00010000C00000000000000000000?oooooooooo
D00006h0001T0000600000`0000000009@0000`0000=0020:00000`000010000DP00070100010000
>Oooo`0000000000000009010000000000020T<0C@1=04T0<@0`0000000000000000000000000000
000000000000000000000000000000000000000000000000000003l003l40000E<TH043FH02<bQP0
mG4^Ma/0?P1d0Eh000000501GP1H0d/0001P023BH030Nf00000000@000000000G0400@00000P0000
00010EC960000000S<XH0?Ea;WN^SPH1o_ooojXh:WNR=2Yg00000000H00PdV00:20:O@00000HdV00
W<XH08YCMgD005h000000:5DMgFbR2il:20:OB3BH0200MYe000004P0B`0004/0J<XH02PP2Wf4c1P0
071iMCk9C`WnooooXEAgM@DBeWDPdV00h4EQ0>hO8L@000X0h4EQ0=C:601L>MIeI7H02000000U0000
30000040001D0000E0000>D0001coOook@0007gmool10000Zj[Q?ag7hKoZ4@00JS800040001<0000
0000000000000000oooooooooom@0000E@0008`0000H000030000000000U0000300000d0080X0000
30000040001B0000L0400040001eoooo0000000000000000T040000000000082@`1=0580=`000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
?`00?`@0001DbAP0@=IP08c:603eLBig6`0n07@1GP000000D05N05P3B`0006008=9P0<1kH0000000
10000000001L0@010000020000000041E<TH0000002<bQP0mG4^Mjj>1P7nooooZSPZMj8d:WL00000
001P023BH00X80Yn000001SBH02LbQP0RU=gM@00GP000000XEAgMK:8;W`X80Yn8=9P0801fWD00000
B01;0000B`1XbQP0:20:OXC<6000L7Ue?/U?2OkooonQE7Me1A;FMB3BH03PAF40kQlQa0002P3PAF40
e<XH05`ieWETMP08000002D0000<00000@0005@0001D0000k@00077mooo`0000Mogoo`40002[Z^4o
7LOQ_hPB003A<P000@0004`00000000000000000003ooooooooooe00000X0000?00001P0000<0000
000002D0000<00003@00P2P0000<00000@000580001`0@000@0007Goool0000000000000002@0@00
000000000P9304d0C@1903L000000000000000000000000000000000000000000000000000000000
000000000000000000000000000o000o100005C96010eV00S<XH0?Ea;WLK03h0M05N0000001@0Eh0
F0=;0000H00PdV00`7]P000000040000000005`100400000800000000@5DbAP0000008c:603eLBig
[Xh60OkooonZ>2YgXS@ZM`00000006008=9P02PP2Wl000006=9P09c:602:DgMe001N0000002QE7Me
/XP^O2PP2WlPdV00P07JM@00001804/0001;06S:600X80YoQ<`H001`NGDnbDl9o_oooj5DMgD54]Ie
8=9P0>15H@3^7b74000:0>15H@3DbQP0G3WFMFAf00P000009@0000`000010000E00005@0003`0000
LOgoooD0001goOoo0@000:^ZhClMan6oaQ800=4b00010000C00000000000000000000?oooooooooo
D00006h0001T0000600000`0000000009@0000`0000=0020:00000`000010000DP00070100010000
MOooo`0000000000000009010000000000020T<0C@1B03L000000000000000000000000000000000
000000000000000000000000000000000000000000000000000003l003l40000E<TH043FH02<bQP0
mG4^Ma/0?P1d0Eh000000501GP1H0d/0001P023BH030Nf00000000@000000000G0400@00000P0000
00010EC960000000S<XH0?Ea;WN^SPH1o_ooojXh:WNR=2Yg00000000H00PdV00:20:P000000HdV00
W<XH08YCMgD005h000000:5DMgFbR2il:20:P23BH0200MYe000004P0B`0004/0J<XH02PP2X24c1P0
071iMCk9C`WnooooXEAgM@DBeWDPdV00h4EQ0>hO8L@000X0h4EQ0=C:601L>MIeI7H02000000U0000
30000040001D0000E0000?D0001aoOoon00007Omool10000Zj[Q?ag7hKlX4`00dC800040001<0000
0000000000000000oooooooooom@0000:@0003`0000H000030000000000U0000300000d0080X0000
30000040001B0000L0400040001eoooo0000000000000000T040000000000082@`1=04d0B@0g0000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
?`00?`@0001DbAP0@=IP08c:603eLBig6`0n07@1GP000000D05N05P3B`0006008=9P0<1kH0000000
10000000001L0@010000020000000041E<TH0000002<bQP0mG4^Mjj>1P7nooooZSPZMj8d:WL00000
001P023BH00X80Z1000001SBH02LbQP0RU=gM@00GP000000XEAgMK:8;W`X80Z18=9P0801fWD00000
B01;0000B`1XbQP0:20:PHC<6000L7Ue?/U?2OkooonQE7Me1A;FMB3BH03PAF40kQlQa0002P3PAF40
e<XH05`ieWETMP08000002D0000<00000@0005@0001D0000k00007Wmooo_0000Oogoo`40002[Z^4o
7LOQ_g8B000b<P000@0004`00000000000000000003ooooooooooe00001Z0000?00001P0000<0000
000002D0000<00003@00P2P0000<00000@000580001`0@000@0007Goool0000000000000002@0@00
000000000P9304d0DP0g000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000o000o100005C96010eV00S<XH0?Ea;WLK03h0M05N0000001@0Eh0
F0=;0000H00PdV00`7]P000000040000000005`100400000800000000@5DbAP0000008c:603eLBig
[Xh60OkooonZ>2YgXS@ZM`00000006008=9P02PP2X8000006=9P09c:602:DgMe001N0000002QE7Me
/XP^O2PP2X8PdV00P07JM@00001804/0001;06S:600X80Z2Q<`H001`NGDnbDl9o_oooj5DMgD54]Ie
8=9P0>15H@3^7b74000:0>15H@3DbQP0G3WFMFAf00P000009@0000`000010000E00005@0003`0000
NOgoooH0001ooOoo0@000:^ZhClMan6o_180038b00010000C00000000000000000000?oooooooooo
D00002/0001h0000600000`000000000E00005@0003f0000NOgoooX0001ooOoo0@000:^ZhClMan6o
=a<0038b00010000C00000000000000000000?ooooooooooD0000340001@0000600000`000000000
9@0000`0000=0020:00000`000010000DP00070100010000>Oooo`00000000000000090100000000
00020T<0C@1B0340<000000000000000000000000000000000000000000000000000000000000000
0000000000000000000003l003l40000E<TH043FH02<bQP0mG4^Ma/0?P1d0Eh000000501GP1H0d/0
001P023BH030Nf00000000@000000000G0400@00000P000000010EC960000000S<XH0?Ea;WN^SPH1
o_ooojXh:WNR=2Yg00000000H00PdV00:20:P`00000HdV00W<XH08YCMgD005h000000:5DMgFbR2il
:20:Pb3BH0200MYe000004P0B`0004/0J<XH02PP2X>4c1P0071iMCk9C`WnooooXEAgM@DBeWDPdV00
h4EQ0>hO8L@000X0h4EQ0=C:601L>MIeI7H02000000U000030000040001D0000E0000?d0001coOoo
1@4007gmool10000Zj[Q?ag7hKnl4`00JS800040001<00000000000000000000oooooooooom@0000
:`000:00000H000030000000001D0000E00000L1001coOoo2`4007gmool10000Zj[Q?ag7hKn35000
JS800040001<00000000000000000000oooooooooom@0000:0000500000H000030000000001D0000
E00000X1001coOoo3`4007gmool10000Zj[Q?ag7hKoA5000JS800040001<00000000000000000000
oooooooooom@0000<@0006@0000H000030000000001D0000E0000181001coOoo6P4007gmool10000
Zj[Q?ag7hKmQ5@00JS800040001<00000000000000000000oooooooooom@0000:`000:00000H0000
30000000001D0000E00001`1001coOoo8@4007gmool10000Zj[Q?ag7hKlX5P00JS800040001<0000
0000000000000000oooooooooom@0000<P0006@0000H000030000000000U0000300000d0080X0000
30000040001B0000L0400040000ioooo0000000000000000T040000000000082@`1=04d0B@0a0300
00000000000000000000000000000000000000000000000000000000000000000000000000000000
?`00?`@0001DbAP0@=IP08c:603eLBig6`0n07@1GP000000D05N05P3B`0006008=9P0<1kH0000000
10000000001L0@010000020000000041E<TH0000002<bQP0mG4^Mjj>1P7nooooZSPZMj8d:WL00000
001P023BH00X80Z4000001SBH02LbQP0RU=gM@00GP000000XEAgMK:8;W`X80Z48=9P0801fWD00000
B01;0000B`1XbQP0:20:Q8C<6000L7Ue?/U?2OkooonQE7Me1A;FMB3BH03PAF40kQlQa0002P3PAF40
e<XH05`ieWETMP08000002D0000<00000@0005@0001D00008@4007?moolX0@00OOgoo`40002[Z^4o
7LOQ_h`F001Z<P000@0004`00000000000000000003ooooooooooe00001C0000N00001P0000<0000
000002D0000<00003@00P2P0000<00000@000580001`0@000@0007Goool0000000000000002@0@00
000000000P9304d0C@1903L000000000000000000000000000000000000000000000000000000000
000000000000000000000000000o000o100005C96010eV00S<XH0?Ea;WLK03h0M05N0000001@0Eh0
F0=;0000H00PdV00`7]P000000040000000005`100400000800000000@5DbAP0000008c:603eLBig
[Xh60OkooonZ>2YgXS@ZM`00000006008=9P02PP2XD000006=9P09c:602:DgMe001N0000002QE7Me
/XP^O2PP2XDPdV00P07JM@00001804/0001;06S:600X80Z5Q<`H001`NGDnbDl9o_oooj5DMgD54]Ie
8=9P0>15H@3^7b74000:0>15H@3DbQP0G3WFMFAf00P000009@0000`000010000E00005@0000W0@00
Mogoob`1001moOoo0@000:^ZhClMan6o1QL004`b00010000C00000000000000000000?oooooooooo
D00006h0001T0000600000`0000000009@0000`0000=0020:00000`000010000DP00070100010000
>Oooo`0000000000000009010000000000020T<0C@1B0340<0000000000000000000000000000000
000000000000000000000000000000000000000000000000000003l003l40000E<TH043FH02<bQP0
mG4^Ma/0?P1d0Eh000000501GP1H0d/0001P023BH030Nf00000000@000000000G0400@00000P0000
00010EC960000000S<XH0?Ea;WN^SPH1o_ooojXh:WNR=2Yg00000000H00PdV00:20:QP00000HdV00
W<XH08YCMgD005h000000:5DMgFbR2il:20:QR3BH0200MYe000004P0B`0004/0J<XH02PP2XJ4c1P0
071iMCk9C`WnooooXEAgM@DBeWDPdV00h4EQ0>hO8L@000X0h4EQ0=C:601L>MIeI7H02000000U0000
30000040001D0000E00002`1001coOoo<04007gmool10000Zj[Q?ag7hKmb5`00JS800040001<0000
0000000000000000oooooooooom@0000:@000500000H000030000000000U0000300000d0080X0000
30000040001B0000L0400040000ioooo0000000000000000T040000000000082@`1=04d0B@0a0300
00000000000000000000000000000000000000000000000000000000000000000000000000000000
?`00?`@0001DbAP0@=IP08c:603eLBig6`0n07@1GP000000D05N05P3B`0006008=9P0<1kH0000000
10000000001L0@010000020000000041E<TH0000002<bQP0mG4^Mjj>1P7nooooZSPZMj8d:WL00000
001P023BH00X80Z7000001SBH02LbQP0RU=gM@00GP000000XEAgMK:8;W`X80Z78=9P0801fWD00000
B01;0000B`1XbQP0:20:QhC<6000L7Ue?/U?2OkooonQE7Me1A;FMB3BH03PAF40kQlQa0002P3PAF40
e<XH05`ieWETMP08000002D0000<00000@0005@0001D0000<04007?moolh0@00OOgoo`40002[Z^4o
7LOQ_l0G001Z<P000@0004`00000000000000000003ooooooooooe00001E0000S00001P0000<0000
000002D0000<00003@00P2P0000<00000@000580001`0@000@0007Goool0000000000000002@0@00
000000000P9304d0DP0g000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000o000o100005C96010eV00S<XH0?Ea;WLK03h0M05N0000001@0Eh0
F0=;0000H00PdV00`7]P000000040000000005`100400000800000000@5DbAP0000008c:603eLBig
[Xh60OkooonZ>2YgXS@ZM`00000006008=9P02PP2XP000006=9P09c:602:DgMe001N0000002QE7Me
/XP^O2PP2XPPdV00P07JMJ@l:WOC?2Yg000gMVS:600X80Z8Q<`H001`NGDnbDl9o_oooj5DMgD54]Ie
8=9P0>15H@3^7b74000:0>15H@3DbQP0G3WFMFAf00P000009@0000`000010000E00005@0000h0@00
LOgooc/1001goOoo0@000:^ZhClMan6oGQP00=4b00010000C00000000000000000000?oooooooooo
D00002P0000l0000600000`0000000009@0000`0000=0020:00000`000010000DP00070100010000
MOooo`0000000000000009010000000000020T<0C@1=04T0=`000000000000000000000000000000
000000000000000000000000000000000000000000000000000003l003l40000E<TH043FH02<bQP0
mG4^Ma/0?P1d0Eh000000501GP1H0d/0001P023BH030Nf00000000@000000000G0400@00000P0000
00010EC960000000S<XH0?Ea;WN^SPH1o_ooojXh:WNR=2Yg00000000H00PdV00:20:R@00000HdV00
W<XH08YCMgD005h000000:5DMgFbR2il:20:RB3BH0200MYe00000=<l:WL003MfJ<XH02PP2XV4c1P0
071iMCk9C`WnooooXEAgM@DBeWDPdV00h4EQ0>hO8L@000X0h4EQ0=C:601L>MIeI7H02000000U0000
30000040001D0000E00003/1001aoOoo@04007Omool10000Zj[Q?ag7hKnL6000dC800040001<0000
0000000000000000oooooooooom@0000KP0006@0000H000030000000000U0000300000d0080X0000
30000040001B0000L0400040001eoooo0000000000000000T040000000000082@`1=0580=`000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
?`00?`@0001DbAP0@=IP08c:603eLBig6`0n07@1GP000000D05N05P3B`0006008=9P0<1kH0000000
10000000001L0@010000020000000041E<TH0000002<bQP0mG4^Mjj>1P7nooooZSPZMj8d:WL00000
001P023BH00X80Z:000001SBH02LbQP0RU=gM@00GP000000XEAgMK:8;W`X80Z:8=9P0801fWD00000
dc`ZM`00=gIXbQP0:20:RXC<6000L7Ue?/U?2OkooonQE7Me1A;FMB3BH03PAF40kQlQa0002P3PAF40
e<XH05`ieWETMP08000002D0000<00000@0005@0001D0000@040077moom30@00Mogoo`40002[Z^4o
7LOQ_ohH003A<P000@0004`00000000000000000003ooooooooooe00000Y0000?00001P0000<0000
000002D0000<00003@00P2P0000<00000@000580001`0@000@0007Goool0000000000000002@0@00
000000000P9304d0C@1903L000000000000000000000000000000000000000000000000000000000
000000000000000000000000000o000o100005C96010eV00S<XH0?Ea;WLK03h0M05N0000001@0Eh0
F0=;0000H00PdV00`7]P000000040000000005`100400000800000000@5DbAP0000008c:603eLBig
[Xh60OkooonZ>2YgXS@ZM`00000006008=9P02PP2X/000006=9P09c:602:DgMe001N0000002QE7Me
/XP^O2PP2X/PdV00P07JM@00003C?2Yg000gMVS:600X80Z;Q<`H001`NGDnbDl9o_oooj5DMgD54]Ie
8=9P0>15H@3^7b74000:0>15H@3DbQP0G3WFMFAf00P000009@0000`000010000E00005@0000g0@00
NOgoocX1001ooOoo0@000:^ZhClMan6oB1P0038b00010000C00000000000000000000?oooooooooo
D00006X0000l0000600000`0000000009@0000`0000=0020:00000`000010000DP00070100010000
>Oooo`0000000000000009010000000000020T<0C@1C05T0<@0`04l0DP1904L00000000000000000
000000000000000000000000000000000000000000000000000003l003l40000E<TH043FH02<bQP0
mG4^Ma/0?P1d0Eh000000501GP1H0d/0001P023BH030Nf00000000@000000000G0400@00000P0000
00010EC960000000S<XH0?Ea;WN^SPH1o_ooojXh:WNR=2Yg00000000H00PdV00:20:S000000HdV00
W<XH08YCMgD005h000000:5DMgFbR2il:20:S23BH0200MYe00000=<l:WL003MfJ<XH02PP2Xb4c1P0
071iMCk9C`WnooooXEAgM@DBeWDPdV00h4EQ0>hO8L@000X0h4EQ0=C:601L>MIeI7H02000000U0000
30000040001D0000E00004H1001coOooCP4008Cmool10000Zj[Q?ag7hKmc6@00JS800040001<0000
0000000000000000oooooooooom@0000X@000:00000H000030000000000U0000300000d0080X0000
30000040001B0000L0400040000ioooo0000000000000000T040000000000082@`1=04d0B@0a0300
00000000000000000000000000000000000000000000000000000000000000000000000000000000
?`00?`@0001DbAP0@=IP08c:603eLBig6`0n07@1GP000000D05N05P3B`0006008=9P0<1kH0000000
10000000001L0@010000020000000041E<TH0000002<bQP0mG4^Mjj>1P7nooooZSPZMj8d:WL00000
001P023BH00X80Z=000001SBH02LbQP0RU=gM@00GP000000XEAgMK:8;W`X80Z=8=9P0801fWD00000
dc`ZM`00=gIXbQP0:20:SHC<6000L7Ue?/U?2OkooonQE7Me1A;FMB3BH03PAF40kQlQa0002P3PAF40
e<XH05`ieWETMP08000002D0000<00000@0005@0001D0000D04007?moomG0@00OOgoo`40002[Z^4o
7LOQ_cXJ001Z<P000@0004`00000000000000000003ooooooooooe00001C0000N00001P0000<0000
000002D0000<00003@00P2P0000<00000@000580001`0@000@0007Goool0000000000000002@0@00
000000000P9304d0C@1903L000000000000000000000000000000000000000000000000000000000
000000000000000000000000000o000o100005C96010eV00S<XH0?Ea;WLK03h0M05N0000001@0Eh0
F0=;0000H00PdV00`7]P000000040000000005`100400000800000000@5DbAP0000008c:603eLBig
[Xh60OkooonZ>2YgXS@ZM`00000006008=9P02PP2Xh000006=9P09c:602:DgMe001N0000002QE7Me
/XP^O2PP2XhPdV00P07JM@00003C?2Yg000gMVS:600X80Z>Q<`H001`NGDnbDl9o_oooj5DMgD54]Ie
8=9P0>15H@3^7b74000:0>15H@3DbQP0G3WFMFAf00P000009@0000`000010000E00005@0001F0@00
Mogooe/1001moOoo0@000:^ZhClMan6o]1X004`b00010000C00000000000000000000?oooooooooo
D00006h0001T0000600000`0000000009@0000`0000=0020:00000`000010000DP00070100010000
>Oooo`0000000000000009010000000000020T<0C@1=04T0<@0`0000000000000000000000000000
000000000000000000000000000000000000000000000000000003l003l40000E<TH043FH02<bQP0
mG4^Ma/0?P1d0Eh000000501GP1H0d/0001P023BH030Nf00000000@000000000G0400@00000P0000
00010EC960000000S<XH0?Ea;WN^SPH1o_ooojXh:WNR=2Yg00000000H00PdV00:20:S`00000HdV00
W<XH08YCMgD005h000000:5DMgFbR2il:20:Sb3BH0200MYe00000=<l:WL003MfJ<XH02PP2Xn4c1P0
071iMCk9C`WnooooXEAgM@DBeWDPdV00h4EQ0>hO8L@000X0h4EQ0=C:601L>MIeI7H02000000U0000
30000040001D0000E00005d1001coOooI@4007gmool10000Zj[Q?ag7hKm26`00JS800040001<0000
0000000000000000oooooooooom@0000E@0008`0000H000030000000000U0000300000d0080X0000
30000040001B0000L0400040001eoooo0000000000000000T040000000000082@`1=0580=`000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
?`00?`@0001DbAP0@=IP08c:603eLBig6`0n07@1GP000000D05N05P3B`0006008=9P0<1kH0000000
10000000001L0@010000020000000041E<TH0000002<bQP0mG4^Mjj>1P7nooooZSPZMj8d:WL00000
001P023BH00X80Z@000001SBH02LbQP0RU=gM@00GP000000XEAgMK:8;W`X80Z@8=9P0801fWD00000
dc`ZM`00=gIXbQP0:20:T8C<6000L7Ue?/U?2OkooonQE7Me1A;FMB3BH03PAF40kQlQa0002P3PAF40
e<XH05`ieWETMP08000002D0000<00000@0005@0001D0000I@40077moomX0@00Mogoo`40002[Z^4o
7LOQ_mlK003A<P000@0004`00000000000000000003ooooooooooe00000X0000?00001P0000<0000
000002D0000<00003@00P2P0000<00000@000580001`0@000@0007Goool0000000000000002@0@00
000000000P9304d0C@1903L000000000000000000000000000000000000000000000000000000000
000000000000000000000000000o000o100005C96010eV00S<XH0?Ea;WLK03h0M05N0000001@0Eh0
F0=;0000H00PdV00`7]P000000040000000005`100400000800000000@5DbAP0000008c:603eLBig
[Xh60OkooonZ>2YgXS@ZM`00000006008=9P02PP2Y4000006=9P09c:602:DgMe001N0000002QE7Me
/XP^O2PP2Y4PdV00P07JM@00003C?2Yg000gMVS:600X80ZAQ<`H001`NGDnbDl9o_oooj5DMgD54]Ie
8=9P0>15H@3^7b74000:0>15H@3DbQP0G3WFMFAf00P000009@0000`000010000E00005@0001X0@00
LOgoofd1001goOoo0@000:^ZhClMan6o7Q`00=4b00010000C00000000000000000000?oooooooooo
D00006h0001T0000600000`0000000009@0000`0000=0020:00000`000010000DP00070100010000
MOooo`0000000000000009010000000000020T<0C@1B03L000000000000000000000000000000000
000000000000000000000000000000000000000000000000000003l003l40000E<TH043FH02<bQP0
mG4^Ma/0?P1d0Eh000000501GP1H0d/0001P023BH030Nf00000000@000000000G0400@00000P0000
00010EC960000000S<XH0?Ea;WN^SPH1o_ooojXh:WNR=2Yg00000000H00PdV00:20:TP00000HdV00
W<XH08YCMgD005h000000:5DMgFbR2il:20:TR3BH0200MYe00000=<l:WL003MfJ<XH02PP2Y:4c1P0
071iMCk9C`WnooooXEAgM@DBeWDPdV00h4EQ0>hO8L@000X0h4EQ0=C:601L>MIeI7H02000000U0000
30000040001D0000E00006d1001aoOooL04007Omool10000Zj[Q?ag7hKn07000dC800040001<0000
0000000000000000oooooooooom@0000:@0003`0000H000030000000000U0000300000d0080X0000
30000040001B0000L0400040001eoooo0000000000000000T040000000000082@`1=04d0B@0g0000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
?`00?`@0001DbAP0@=IP08c:603eLBig6`0n07@1GP000000D05N05P3B`0006008=9P0<1kH0000000
10000000001L0@010000020000000041E<TH0000002<bQP0mG4^Mjj>1P7nooooZSPZMj8d:WL00000
001P023BH00X80ZC000001SBH02LbQP0RU=gM@00GP000000XEAgMK:8;W`X80ZC8=9P0801fWD00000
dc`ZM`00=gIXbQP0:20:ThC<6000L7Ue?/U?2OkooonQE7Me1A;FMB3BH03PAF40kQlQa0002P3PAF40
e<XH05`ieWETMP08000002D0000<00000@0005@0001D0000I04007WmoomW0@00Oogoo`40002[Z^4o
7LOQ_lXK000b<P000@0004`00000000000000000003ooooooooooe00001Z0000?00001P0000<0000
000002D0000<00003@00P2P0000<00000@000580001`0@000@0007Goool0000000000000002@0@00
000000000P9304d0D`1I03L000000000000000000000000000000000000000000000000000000000
000000000000000000000000000o000o100005C96010eV00S<XH0?Ea;WLK03h0M05N0000001@0Eh0
F0=;0000H00PdV00`7]P000000040000000005`100400000800000000@5DbAP0000008c:603eLBig
[Xh60OkooonZ>2YgXS@ZM`00000006008=9P02PP2Y@000006=9P09c:602:DgMe001N0000002QE7Me
/XP^O2PP2Y@PdV00P07JM@00003C?2Yg000gMVS:600X80ZDQ<`H001`NGDnbDl9o_oooj5DMgD54]Ie
8=9P0>15H@3^7b74000:0>15H@3DbQP0G3WFMFAf00P000009@0000`000010000E00005@0001W0@00
NOgoofd10024oOoo0@000:^ZhClMan6o51`0038b00010000C00000000000000000000?oooooooooo
D0000:40001h0000600000`0000000009@0000`0000=0020:00000`000010000DP00070100010000
MOooo`0000000000000009010000000000020T<0C@1B03L000000000000000000000000000000000
000000000000000000000000000000000000000000000000000003l003l40000E<TH043FH02<bQP0
mG4^Ma/0?P1d0Eh000000501GP1H0d/0001P023BH030Nf00000000@000000000G0400@00000P0000
00010EC960000000S<XH0?Ea;WN^SPH1o_ooojXh:WNR=2Yg00000000H00PdV00:20:U@00000HdV00
W<XH08YCMgD005h000000:5DMgFbR2il:20:UB3BH0200MYe00000=<l:WL003MfJ<XH02PP2YF4c1P0
071iMCk9C`WnooooXEAgM@DBeWDPdV00h4EQ0>hO8L@000X0h4EQ0=C:601L>MIeI7H02000000U0000
30000040001D0000E00006h1001ioOooLP4007omool10000Zj[Q?ag7hKn@7000<S800040001<0000
0000000000000000oooooooooom@0000<@000500000H000030000000000U0000300000d0080X0000
30000040001B0000L0400040000ioooo0000000000000000T040000000000082@`1=0580<@0`0000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
?`00?`@0001DbAP0@=IP08c:603eLBig6`0n07@1GP000000D05N05P3B`0006008=9P0<1kH0000000
10000000001L0@010000020000000041E<TH0000002<bQP0mG4^Mjj>1P7nooooZSPZMj8d:WL00000
001P023BH00X80ZF000001SBH02LbQP0RU=gM@00GP000000XEAgMK:8;W`X80ZF8=9P0801fWD00000
dc`ZM`00=gIXbQP0:20:UXC<6000L7Ue?/U?2OkooonQE7Me1A;FMB3BH03PAF40kQlQa0002P3PAF40
e<XH05`ieWETMP08000002D0000<00000@0005@0001D0000M@4007?moomm0@00OOgoo`40002[Z^4o
7LOQ_b8M001Z<P000@0004`00000000000000000003ooooooooooe00000m0000X00001P0000<0000
000002D0000<00003@00P2P0000<00000@000580001`0@000@0003Woool0000000000000002@0@00
000000000P9304d0C@190340<0000000000000000000000000000000000000000000000000000000
000000000000000000000000000o000o100005C96010eV00S<XH0?Ea;WLK03h0M05N0000001@0Eh0
F0=;0000H00PdV00`7]P000000040000000005`100400000800000000@5DbAP0000008c:603eLBig
[Xh60OkooonZ>2YgXS@ZM`00000006008=9P02PP2YL000006=9P09c:602:DgMe001N0000002QE7Me
/XP^O2PP2YLPdV00P07JM@00003C?2Yg000gMVS:600X80ZGQ<`H001`NGDnbDl9o_oooj5DMgD54]Ie
8=9P0>15H@3^7b74000:0>15H@3DbQP0G3WFMFAf00P000009@0000`000010000E00005@0001o0@00
LogoohL1001moOoo0@000:^ZhClMan6om1d006Xb00010000C00000000000000000000?oooooooooo
D00004L0002P0000600000`0000000009@0000`0000=0020:00000`000010000DP00070100010000
MOooo`0000000000000009010000000000020T<0C@1B03L000000000000000000000000000000000
000000000000000000000000000000000000000000000000000003l003l40000E<TH043FH02<bQP0
mG4^Ma/0?P1d0Eh000000501GP1H0d/0001P023BH030Nf00000000@000000000G0400@00000P0000
00010EC960000000S<XH0?Ea;WN^SPH1o_ooojXh:WNR=2Yg00000000H00PdV00:20:V000000HdV00
W<XH08YCMgD005h000000:5DMgFbR2il:20:V23BH0200MYe00000=<l:WL003MfJ<XH02PP2YR4c1P0
071iMCk9C`WnooooXEAgM@DBeWDPdV00h4EQ0>hO8L@000X0h4EQ0=C:601L>MIeI7H02000000U0000
30000040001D0000E00008L1001aoOooRP4007Omool10000Zj[Q?ag7hKnA7P00dC800040001<0000
0000000000000000oooooooooom@0000:00003`0000H000030000000000U0000300000d0080X0000
30000040001B0000L0400040001eoooo0000000000000000T040000000000082@`1=04d0B@0g0000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
?`00?`@0001DbAP0@=IP08c:603eLBig6`0n07@1GP000000D05N05P3B`0006008=9P0<1kH0000000
10000000001L0@010000020000000041E<TH0000002<bQP0mG4^Mjj>1P7nooooZSPZMj8d:WL00000
001P023BH00X80ZI000001SBH02LbQP0RU=gM@00GP000000XEAgMK:8;W`X80ZI8=9P0801fWD00000
dc`ZM`00=gIXbQP0:20:VHC<6000L7Ue?/U?2OkooonQE7Me1A;FMB3BH03PAF40kQlQa0002P3PAF40
e<XH05`ieWETMP08000002D0000<00000@0005@0001D0000RP40077moon?0@00Mogoo`40002[Z^4o
7LOQ_m0N003A<P000@0004`00000000000000000003ooooooooooe00001^0000I00001P0000<0000
000002D0000<00003@00P2P0000<00000@000580001`0@000@0007Goool0000000000000002@0@00
000000000P9304d0DP0g000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000o000o100005C96010eV00S<XH0?Ea;WLK03h0M05N0000001@0Eh0
F0=;0000H00PdV00`7]P000000040000000005`100400000800000000@5DbAP0000008c:603eLBig
[Xh60OkooonZ>2YgXS@ZM`00000006008=9P02PP2YX000006=9P09c:602:DgMe001N0000002QE7Me
/XP^O2PP2YXPdV00P07JM@00003C?2Yg000gMVS:600X80ZJQ<`H001`NGDnbDl9o_oooj5DMgD54]Ie
8=9P0>15H@3^7b74000:0>15H@3DbQP0G3WFMFAf00P000009@0000`000010000E00005@0002?0@00
LOgooi81001goOoo0@000:^ZhClMan6o<Ql00=4b00010000C00000000000000000000?oooooooooo
D00002T0000l0000600000`0000000009@0000`0000=0020:00000`000010000DP00070100010000
MOooo`0000000000000009010000000000020T<0C@1=04T0=`000000000000000000000000000000
000000000000000000000000000000000000000000000000000003l003l40000E<TH043FH02<bQP0
mG4^Ma/0?P1d0Eh000000501GP1H0d/0001P023BH030Nf00000000@000000000G0400@00000P0000
00010EC960000000S<XH0?Ea;WN^SPH1o_ooojXh:WNR=2Yg00000000H00PdV00:20:V`00000HdV00
W<XH08YCMgD005h000000:5DMgFbR2il:20:Vb3BH0200MYe00000=<l:WL003MfJ<XH02PP2Y^4c1P0
071iMCk9C`WnooooXEAgM@DBeWDPdV00h4EQ0>hO8L@000X0h4EQ0=C:601L>MIeI7H02000000U0000
30000040001D0000E00008L1001ioOooRP4007omool10000Zj[Q?ag7hKnA7P00<S800040001<0000
0000000000000000oooooooooom@0000JP0003`0000U0000300000d0080X000030000040000>0000
50000000000@0000500000Q00@PT00006000008@`=/100000`00000000000000000001]000100000
=000004000020000^HQ@@n4S9<A:=T=3MPR9@@<0002iR513hB<Ta87ObD?Q8bC4^HQ@@ikK7l@Q0000
20000680000<00000@000240000800008@0000P0001c000030000000000L0000200002D0000<0000
0000P2D0000<00001`00P2D0000<00003P00P1T0000<0000oooo01P0000<000000000180000<0000
0P0001<0000<00000@0001@0000<00003@0001D0000<00000@0001H0000<0000000000d0000@0000
00000000000j0000300000X0000K000040000000000000008`000200002][2E100000000001AVBe1
bo@6aAVMgTDT000090000:f/9D4000000000056I;D7;m0K56IgNA@@0001c000030000000000=0000
4000000000000000DP00070100020000400000L00000000000000;`2000000001`828U<0N@1c07@0
I@1]0000502Pn?oolP400000000l_D82P?Soo`P0F7kkm_oo00000000000P_D82P?Sooooo000005@:
691h0000081LbcD0bla<?I3<=@2hgH878D>nM`@>8OTR08X160000000001PUPX620000<nY94400<Lm
F8?a1P000030g>`6[<Pe00000000000000000?oooolPc3D0C<`e03cG=@256L9g]G=V0Okooon<hkeg
l^2mM`00l`P`o0000P000000000P0000O<`e0:3<=@3[F>mf001h00P0500VF^mf4JTCI@00001PUPX6
ooooo`<000000000P:mK2P00N03Pked:RWEWJ:cC=@00L?5f000000/X003Tc3D0CRjoMhR_G0Yo1`00
T:mL2]S<=@0_<1EgI7H02000000U00003000008000160000R00007`00017A4U30P000=40001_oOoo
T`40083mool`0000I`1U06h0I@1b0640M01U06@0801R07T0801G04d0AP0_04D0C@160200HP1Q06<0
J`1U06h0I00P06l0IP0P0700L`1d06l0I@1T06T0M00006T0KP1`07D0M00000008`000200003`VP@o
00000000000>h@Zobo@6aAVMgTDT000090000?2J13l00000000000kQ2[o;m0K56IgNA@@0000S0000
80000?2J13l00000000000kQ2[o;m0K56IgNAB@0000T0000l9X4?`00000000003^4:_l_d1/DIWMi5
10000180000<00000@0001H0000<0000600001P0000<000000000580001`0@000`0003Woool00000
00000000002@0@00000000L00P9304d0D`1I0340<01?0580B@170000000000000000000000000000
00000000000000000000000000000000000000@00038bQP0000000P000070000000008iC=gG8bQP0
<<XH0>b`@`040000Q0000<S:60000000000000`0000000000@00023:60000000Q0000:0?00020000
0`000<S:60000000000003c:601oWT<0o0YL083:600004<0100008je@`01BbQlJ7iL0268AP000000
0000000000010000C<XH000_BP0<baP0h9a20=6UMgcnoooo00130=fe@`1XOU`000000000G01XOU`0
b<XH0040000h01h02`000<S:601XOU`00@<00;1mG0010000H7iL06Af00P000009@0000`000030000
E00005@0000000009@0005<0003Q00000@000:^ZhClMan6oB10006Xb00010000C000000000000000
00000?ooooooooooD0000:40002P0000600000`000000000DP00070100040000500000T000000000
00000;`2000000001`828U<0N@1c07@0I@1]000000000000hP000000001/A7X2P?Soo`0000000000
00000000001@A7X2P?SookZF000001Eg]f@EM`@>8OT0000000000040000`m_d5f</e065T5GL43R7i
00000000001D00000000033fo@E@c3D0gU4EM`@>8OThh8L00P000=QLG`=D000000000040000h01h0
2`000<S:601XOU`00@<00;1mG0010000H7iL000000P00000`=c/1Zc8=@1@c3D0;c0EMe3<=@1V<1Eg
E?iK2V2F2PHU0000000:0=Q>0024cCD07OYSJ0@>8OT008L0<?Km1@80003HG5l3/PYTJ5`66GL00000
G0HIMh016GMXoU/:Z<`e02l`5GNXc3D0IS0EMkCnF`YPUPX6I7H02000000U0000300000@0000X0000
300000<0001B0000L04000<0000ioooo0000000000000000T040000000070082@`1=04d0B@0a0300
00000000000000000000000000000000000000000000000000000000000000000000000000000000
?`00?`@000020000@=IP0<S:600000006`0n07@1GP000000D05N05P3B`0004<08=9P0<1kH0000000
10000000001L0@010000020000000041E<TH08cS:GN<bQP0mG4^Mjj>1P7nooooZSPZMj8d:WL00000
001P023BH00X80Yk000001SBH02LbQP0RU=gM@00GP000000XEAgMK:8;W`X80Yk8=9P0801fWD0QU`0
B01;0000B`1XbQP0:20:NhC<6000L7Ue?/U?2OkooonQE7Me1A;FMB3BH03PAF40kQlQa0002P3PAF40
e<XH05`ieWETMP08000002D0000<00000`0005@0001D0000C`0002T0002B0000U0000040002[Z^4o
7LOQ_n8@001Z<P000@0004`00000000000000000003ooooooooooe00001C0000N00001P0000<0000
000002D0000<0000100002P0000<00000`000580001`0@000`0007Goool0000000000000002@0@00
000000L00P9304d0C@1903L000000000000000000000000000000000000000000000000000000000
000000000000000000000000000o000o100005C96010eV00S<XH0?Ea;WLK03h0M05N0000001@0Eh0
F0=;0000H00PdV00`7]P000000040000000005`100400000800000000@5DbAP0000008c:603eLBig
[Xh60OkooonZ>2YgXS@ZM`00000006008=9P02PP2W`000006=9P09c:602:DgMe001N0000002QE7Me
/XP^O2PP2W`PdV00P07JM@00001804/0001;06S:600X80YlQ<`H001`NGDnbDl9o_oooj5DMgD54]Ie
8=9P0>15H@3^7b74000:0>15H@3DbQP0G3WFMFAf00P000009@0000`000030000E00005@0002?0000
D@000<<0002L00000@000:^ZhClMan6oGA4004`b00010000C00000000000000000000?oooooooooo
D00006h0001T0000600000`0000000009@0000`000040000:00000`000030000DP00070100030000
>Oooo`000000000000000901000000001`020T<0C@1=04T0<@0`0000000000000000000000000000
000000000000000000000000000000000000000000000000000003l003l40000E<TH043FH02<bQP0
mG4^Ma/0?P1d0Eh000000501GP1H0d/0001P023BH030Nf00000000@000000000G0400@00000P0000
00010EC960000000S<XH0?Ea;WN^SPH1o_ooojXh:WNR=2Yg00000000H00PdV00:20:O@00000HdV00
W<XH08YCMgD005h000000:5DMgFbR2il:20:OB3BH0200MYe000004P0B`0004/0J<XH02PP2Wf4c1P0
071iMCk9C`WnooooXEAgM@DBeWDPdV00h4EQ0>hO8L@000X0h4EQ0=C:601L>MIeI7H02000000U0000
300000<0001D0000E0000=P0000Y00009P4009@000010000Zj[Q?ag7hKoZ4@00JS800040001<0000
0000000000000000oooooooooom@0000E@0008`0000H000030000000000U0000300000@0000X0000
300000<0001B0000L04000<0001eoooo0000000000000000T040000000070082@`1=0580=`000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
?`00?`@0001DbAP0@=IP08c:603eLBig6`0n07@1GP000000D05N05P3B`0006008=9P0<1kH0000000
10000000001L0@010000020000000041E<TH0000002<bQP0mG4^Mjj>1P7nooooZSPZMj8d:WL00000
001P023BH00X80Yn000001SBH02LbQP0RU=gM@00GP000000XEAgMK:8;W`X80Yn8=9P0801fWD00000
B01;0000B`1XbQP0:20:OXC<6000L7Ue?/U?2OkooonQE7Me1A;FMB3BH03PAF40kQlQa0002P3PAF40
e<XH05`ieWETMP08000002D0000<00000`0005@0001D0000:P4000T0001:0@00E0000040002[Z^4o
7LOQ_hPB003A<P000@0004`00000000000000000003ooooooooooe00000X0000?00001P0000<0000
000002D0000<0000100002P0000<00000`000580001`0@000`0007Goool0000000000000002@0@00
000000L00P9304d0C@1903L000000000000000000000000000000000000000000000000000000000
000000000000000000000000000o000o100005C96010eV00S<XH0?Ea;WLK03h0M05N0000001@0Eh0
F0=;0000H00PdV00`7]P000000040000000005`100400000800000000@5DbAP0000008c:603eLBig
[Xh60OkooonZ>2YgXS@ZM`00000006008=9P02PP2Wl000006=9P09c:602:DgMe001N0000002QE7Me
/XP^O2PP2WlPdV00P07JM@00001804/0001;06S:600X80YoQ<`H001`NGDnbDl9o_oooj5DMgD54]Ie
8=9P0>15H@3^7b74000:0>15H@3DbQP0G3WFMFAf00P000009@0000`000030000E00005@0001:0@00
2@0007h1001D00000@000:^ZhClMan6oaQ800=4b00010000C00000000000000000000?oooooooooo
D00006h0001T0000600000`0000000009@0000`000040000:00000`000030000DP00070100030000
MOooo`000000000000000901000000001`020T<0C@1B03L000000000000000000000000000000000
000000000000000000000000000000000000000000000000000003l003l40000E<TH043FH02<bQP0
mG4^Ma/0?P1d0Eh000000501GP1H0d/0001P023BH030Nf00000000@000000000G0400@00000P0000
00010EC960000000S<XH0?Ea;WN^SPH1o_ooojXh:WNR=2Yg00000000H00PdV00:20:P000000HdV00
W<XH08YCMgD005h000000:5DMgFbR2il:20:P23BH0200MYe000004P0B`0004/0J<XH02PP2X24c1P0
071iMCk9C`WnooooXEAgM@DBeWDPdV00h4EQ0>hO8L@000X0h4EQ0=C:601L>MIeI7H02000000U0000
300000<0001D0000E00007d100090000W@4005@000010000Zj[Q?ag7hKlX4`00dC800040001<0000
0000000000000000oooooooooom@0000:@0003`0000H000030000000000U0000300000@0000X0000
300000<0001B0000L04000<0001eoooo0000000000000000T040000000070082@`1=04d0B@0g0000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
?`00?`@0001DbAP0@=IP08c:603eLBig6`0n07@1GP000000D05N05P3B`0006008=9P0<1kH0000000
10000000001L0@010000020000000041E<TH0000002<bQP0mG4^Mjj>1P7nooooZSPZMj8d:WL00000
001P023BH00X80Z1000001SBH02LbQP0RU=gM@00GP000000XEAgMK:8;W`X80Z18=9P0801fWD00000
B01;0000B`1XbQP0:20:PHC<6000L7Ue?/U?2OkooonQE7Me1A;FMB3BH03PAF40kQlQa0002P3PAF40
e<XH05`ieWETMP08000002D0000<00000`0005@0001D00007`400600000o0@00Z`000040002[Z^4o
7LOQ_g8B000b<P000@0004`00000000000000000003ooooooooooe00001Z0000?00001P0000<0000
000002D0000<0000100002P0000<00000`000580001`0@000`0007Goool0000000000000002@0@00
000000L00P9304d0DP0g000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000o000o100005C96010eV00S<XH0?Ea;WLK03h0M05N0000001@0Eh0
F0=;0000H00PdV00`7]P000000040000000005`100400000800000000@5DbAP0000008c:603eLBig
[Xh60OkooonZ>2YgXS@ZM`00000006008=9P02PP2X8000006=9P09c:602:DgMe001N0000002QE7Me
/XP^O2PP2X8PdV00P07JM@00001804/0001;06S:600X80Z2Q<`H001`NGDnbDl9o_oooj5DMgD54]Ie
8=9P0>15H@3^7b74000:0>15H@3DbQP0G3WFMFAf00P000009@0000`000030000E00005@000150@00
H00008@1002[00000@000:^ZhClMan6o_180038b00010000C00000000000000000000?oooooooooo
D00002/0001h0000600000`000000000E00005@000250@00H0000:l1002[00000@000:^ZhClMan6o
=a<0038b00010000C00000000000000000000?ooooooooooD0000340001@0000600000`000000000
9@0000`000040000:00000`000030000DP00070100030000>Oooo`00000000000000090100000000
1`020T<0C@1B0340<000000000000000000000000000000000000000000000000000000000000000
0000000000000000000003l003l40000E<TH043FH02<bQP0mG4^Ma/0?P1d0Eh000000501GP1H0d/0
001P023BH030Nf00000000@000000000G0400@00000P000000010EC960000000S<XH0?Ea;WN^SPH1
o_ooojXh:WNR=2Yg00000000H00PdV00:20:P`00000HdV00W<XH08YCMgD005h000000:5DMgFbR2il
:20:Pb3BH0200MYe000004P0B`0004/0J<XH02PP2X>4c1P0071iMCk9C`WnooooXEAgM@DBeWDPdV00
h4EQ0>hO8L@000X0h4EQ0=C:601L>MIeI7H02000000U0000300000<0001D0000E0000<X1000Y0000
7@8009@000010000Zj[Q?ag7hKnl4`00JS800040001<00000000000000000000oooooooooom@0000
:`000:00000H000030000000001D0000E0000342000Y0000F`8009@000010000Zj[Q?ag7hKn35000
JS800040001<00000000000000000000oooooooooom@0000:0000500000H000030000000001D0000
E00005T2000Y0000S@8009@000010000Zj[Q?ag7hKoA5000JS800040001<00000000000000000000
oooooooooom@0000<@0006@0000H000030000000001D0000E0000:@2000Y0000m`8009@000010000
Zj[Q?ag7hKmQ5@00JS800040001<00000000000000000000oooooooooom@0000:`000:00000H0000
30000000001D0000E00000/3000Y0000?`<009@000010000Zj[Q?ag7hKlX5P00JS800040001<0000
0000000000000000oooooooooom@0000<P0006@0000H000030000000000U0000300000@0000X0000
300000<0001B0000L04000<0000ioooo0000000000000000T040000000070082@`1=04d0B@0a0300
00000000000000000000000000000000000000000000000000000000000000000000000000000000
?`00?`@0001DbAP0@=IP08c:603eLBig6`0n07@1GP000000D05N05P3B`0006008=9P0<1kH0000000
10000000001L0@010000020000000041E<TH0000002<bQP0mG4^Mjj>1P7nooooZSPZMj8d:WL00000
001P023BH00X80Z4000001SBH02LbQP0RU=gM@00GP000000XEAgMK:8;W`X80Z48=9P0801fWD00000
B01;0000B`1XbQP0:20:Q8C<6000L7Ue?/U?2OkooonQE7Me1A;FMB3BH03PAF40kQlQa0002P3PAF40
e<XH05`ieWETMP08000002D0000<00000`0005@0001D0000?`<002T000220`00U0000040002[Z^4o
7LOQ_h`F001Z<P000@0004`00000000000000000003ooooooooooe00001C0000N00001P0000<0000
000002D0000<0000100002P0000<00000`000580001`0@000`0007Goool0000000000000002@0@00
000000L00P9304d0C@1903L000000000000000000000000000000000000000000000000000000000
000000000000000000000000000o000o100005C96010eV00S<XH0?Ea;WLK03h0M05N0000001@0Eh0
F0=;0000H00PdV00`7]P000000040000000005`100400000800000000@5DbAP0000008c:603eLBig
[Xh60OkooonZ>2YgXS@ZM`00000006008=9P02PP2XD000006=9P09c:602:DgMe001N0000002QE7Me
/XP^O2PP2XDPdV00P07JM@00001804/0001;06S:600X80Z5Q<`H001`NGDnbDl9o_oooj5DMgD54]Ie
8=9P0>15H@3^7b74000:0>15H@3DbQP0G3WFMFAf00P000009@0000`000030000E00005@0001n0`00
D@000;83002L00000@000:^ZhClMan6o1QL004`b00010000C00000000000000000000?oooooooooo
D00006h0001T0000600000`0000000009@0000`000040000:00000`000030000DP00070100030000
>Oooo`000000000000000901000000001`020T<0C@1B0340<0000000000000000000000000000000
000000000000000000000000000000000000000000000000000003l003l40000E<TH043FH02<bQP0
mG4^Ma/0?P1d0Eh000000501GP1H0d/0001P023BH030Nf00000000@000000000G0400@00000P0000
00010EC960000000S<XH0?Ea;WN^SPH1o_ooojXh:WNR=2Yg00000000H00PdV00:20:QP00000HdV00
W<XH08YCMgD005h000000:5DMgFbR2il:20:QR3BH0200MYe000004P0B`0004/0J<XH02PP2XJ4c1P0
071iMCk9C`WnooooXEAgM@DBeWDPdV00h4EQ0>hO8L@000X0h4EQ0=C:601L>MIeI7H02000000U0000
300000<0001D0000E0000;H3000Y0000h0<009@000010000Zj[Q?ag7hKmb5`00JS800040001<0000
0000000000000000oooooooooom@0000:@000500000H000030000000000U0000300000@0000X0000
300000<0001B0000L04000<0000ioooo0000000000000000T040000000070082@`1=04d0B@0a0300
00000000000000000000000000000000000000000000000000000000000000000000000000000000
?`00?`@0001DbAP0@=IP08c:603eLBig6`0n07@1GP000000D05N05P3B`0006008=9P0<1kH0000000
10000000001L0@010000020000000041E<TH0000002<bQP0mG4^Mjj>1P7nooooZSPZMj8d:WL00000
001P023BH00X80Z7000001SBH02LbQP0RU=gM@00GP000000XEAgMK:8;W`X80Z78=9P0801fWD00000
B01;0000B`1XbQP0:20:QhC<6000L7Ue?/U?2OkooonQE7Me1A;FMB3BH03PAF40kQlQa0002P3PAF40
e<XH05`ieWETMP08000002D0000<00000`0005@0001D0000gP<002T0000/1000U0000040002[Z^4o
7LOQ_l0G001Z<P000@0004`00000000000000000003ooooooooooe00001E0000S00001P0000<0000
000002D0000<0000100002P0000<00000`000580001`0@000`0007Goool0000000000000002@0@00
000000L00P9304d0DP0g000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000o000o100005C96010eV00S<XH0?Ea;WLK03h0M05N0000001@0Eh0
F0=;0000H00PdV00`7]P000000040000000005`100400000800000000@5DbAP0000008c:603eLBig
[Xh60OkooonZ>2YgXS@ZM`00000006008=9P02PP2XP000006=9P09c:602:DgMe001N0000002QE7Me
/XP^O2PP2XPPdV00P07JMJ@l:WOC?2Yg000gMVS:600X80Z8Q<`H001`NGDnbDl9o_oooj5DMgD54]Ie
8=9P0>15H@3^7b74000:0>15H@3DbQP0G3WFMFAf00P000009@0000`000030000E00005@0000`1000
2@000504001D00000@000:^ZhClMan6oGQP00=4b00010000C00000000000000000000?oooooooooo
D00002P0000l0000600000`0000000009@0000`000040000:00000`000030000DP00070100030000
MOooo`000000000000000901000000001`020T<0C@1=04T0=`000000000000000000000000000000
000000000000000000000000000000000000000000000000000003l003l40000E<TH043FH02<bQP0
mG4^Ma/0?P1d0Eh000000501GP1H0d/0001P023BH030Nf00000000@000000000G0400@00000P0000
00010EC960000000S<XH0?Ea;WN^SPH1o_ooojXh:WNR=2Yg00000000H00PdV00:20:R@00000HdV00
W<XH08YCMgD005h000000:5DMgFbR2il:20:RB3BH0200MYe00000=<l:WL003MfJ<XH02PP2XV4c1P0
071iMCk9C`WnooooXEAgM@DBeWDPdV00h4EQ0>hO8L@000X0h4EQ0=C:601L>MIeI7H02000000U0000
300000<0001D0000E000050400090000Q0@005@000010000Zj[Q?ag7hKnL6000dC800040001<0000
0000000000000000oooooooooom@0000KP0006@0000H000030000000000U0000300000@0000X0000
300000<0001B0000L04000<0001eoooo0000000000000000T040000000070082@`1=0580=`000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
?`00?`@0001DbAP0@=IP08c:603eLBig6`0n07@1GP000000D05N05P3B`0006008=9P0<1kH0000000
10000000001L0@010000020000000041E<TH0000002<bQP0mG4^Mjj>1P7nooooZSPZMj8d:WL00000
001P023BH00X80Z:000001SBH02LbQP0RU=gM@00GP000000XEAgMK:8;W`X80Z:8=9P0801fWD00000
dc`ZM`00=gIXbQP0:20:RXC<6000L7Ue?/U?2OkooonQE7Me1A;FMB3BH03PAF40kQlQa0002P3PAF40
e<XH05`ieWETMP08000002D0000<00000`0005@0001D0000P`@000T0002S1000E0000040002[Z^4o
7LOQ_ohH003A<P000@0004`00000000000000000003ooooooooooe00000Y0000?00001P0000<0000
000002D0000<0000100002P0000<00000`000580001`0@000`0007Goool0000000000000002@0@00
000000L00P9304d0C@1903L000000000000000000000000000000000000000000000000000000000
000000000000000000000000000o000o100005C96010eV00S<XH0?Ea;WLK03h0M05N0000001@0Eh0
F0=;0000H00PdV00`7]P000000040000000005`100400000800000000@5DbAP0000008c:603eLBig
[Xh60OkooonZ>2YgXS@ZM`00000006008=9P02PP2X/000006=9P09c:602:DgMe001N0000002QE7Me
/XP^O2PP2X/PdV00P07JM@00003C?2Yg000gMVS:600X80Z;Q<`H001`NGDnbDl9o_oooj5DMgD54]Ie
8=9P0>15H@3^7b74000:0>15H@3DbQP0G3WFMFAf00P000009@0000`000030000E00005@0000U1000
H00004D4002[00000@000:^ZhClMan6oB1P0038b00010000C00000000000000000000?oooooooooo
D00006X0000l0000600000`0000000009@0000`000040000:00000`000030000DP00070100030000
>Oooo`000000000000000901000000001`020T<0C@1C05T0<@0`04l0DP1904L00000000000000000
000000000000000000000000000000000000000000000000000003l003l40000E<TH043FH02<bQP0
mG4^Ma/0?P1d0Eh000000501GP1H0d/0001P023BH030Nf00000000@000000000G0400@00000P0000
00010EC960000000S<XH0?Ea;WN^SPH1o_ooojXh:WNR=2Yg00000000H00PdV00:20:S000000HdV00
W<XH08YCMgD005h000000:5DMgFbR2il:20:S23BH0200MYe00000=<l:WL003MfJ<XH02PP2Xb4c1P0
071iMCk9C`WnooooXEAgM@DBeWDPdV00h4EQ0>hO8L@000X0h4EQ0=C:601L>MIeI7H02000000U0000
300000<0001D0000E0000;l4000U00004PD00>4000010000Zj[Q?ag7hKmc6@00JS800040001<0000
0000000000000000oooooooooom@0000X@000:00000H000030000000000U0000300000@0000X0000
300000<0001B0000L04000<0000ioooo0000000000000000T040000000070082@`1=04d0B@0a0300
00000000000000000000000000000000000000000000000000000000000000000000000000000000
?`00?`@0001DbAP0@=IP08c:603eLBig6`0n07@1GP000000D05N05P3B`0006008=9P0<1kH0000000
10000000001L0@010000020000000041E<TH0000002<bQP0mG4^Mjj>1P7nooooZSPZMj8d:WL00000
001P023BH00X80Z=000001SBH02LbQP0RU=gM@00GP000000XEAgMK:8;W`X80Z=8=9P0801fWD00000
dc`ZM`00=gIXbQP0:20:SHC<6000L7Ue?/U?2OkooonQE7Me1A;FMB3BH03PAF40kQlQa0002P3PAF40
e<XH05`ieWETMP08000002D0000<00000`0005@0001D00009PD002T0001Y1@00U0000040002[Z^4o
7LOQ_cXJ001Z<P000@0004`00000000000000000003ooooooooooe00001C0000N00001P0000<0000
000002D0000<0000100002P0000<00000`000580001`0@000`0007Goool0000000000000002@0@00
000000L00P9304d0C@1903L000000000000000000000000000000000000000000000000000000000
000000000000000000000000000o000o100005C96010eV00S<XH0?Ea;WLK03h0M05N0000001@0Eh0
F0=;0000H00PdV00`7]P000000040000000005`100400000800000000@5DbAP0000008c:603eLBig
[Xh60OkooonZ>2YgXS@ZM`00000006008=9P02PP2Xh000006=9P09c:602:DgMe001N0000002QE7Me
/XP^O2PP2XhPdV00P07JM@00003C?2Yg000gMVS:600X80Z>Q<`H001`NGDnbDl9o_oooj5DMgD54]Ie
8=9P0>15H@3^7b74000:0>15H@3DbQP0G3WFMFAf00P000009@0000`000030000E00005@0001V1@00
D@0009X5002L00000@000:^ZhClMan6o]1X004`b00010000C00000000000000000000?oooooooooo
D00006h0001T0000600000`0000000009@0000`000040000:00000`000030000DP00070100030000
>Oooo`000000000000000901000000001`020T<0C@1=04T0<@0`0000000000000000000000000000
000000000000000000000000000000000000000000000000000003l003l40000E<TH043FH02<bQP0
mG4^Ma/0?P1d0Eh000000501GP1H0d/0001P023BH030Nf00000000@000000000G0400@00000P0000
00010EC960000000S<XH0?Ea;WN^SPH1o_ooojXh:WNR=2Yg00000000H00PdV00:20:S`00000HdV00
W<XH08YCMgD005h000000:5DMgFbR2il:20:Sb3BH0200MYe00000=<l:WL003MfJ<XH02PP2Xn4c1P0
071iMCk9C`WnooooXEAgM@DBeWDPdV00h4EQ0>hO8L@000X0h4EQ0=C:601L>MIeI7H02000000U0000
300000<0001D0000E0000:l5000Y0000o@D009@000010000Zj[Q?ag7hKm26`00JS800040001<0000
0000000000000000oooooooooom@0000E@0008`0000H000030000000000U0000300000@0000X0000
300000<0001B0000L04000<0001eoooo0000000000000000T040000000070082@`1=0580=`000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
?`00?`@0001DbAP0@=IP08c:603eLBig6`0n07@1GP000000D05N05P3B`0006008=9P0<1kH0000000
10000000001L0@010000020000000041E<TH0000002<bQP0mG4^Mjj>1P7nooooZSPZMj8d:WL00000
001P023BH00X80Z@000001SBH02LbQP0RU=gM@00GP000000XEAgMK:8;W`X80Z@8=9P0801fWD00000
dc`ZM`00=gIXbQP0:20:T8C<6000L7Ue?/U?2OkooonQE7Me1A;FMB3BH03PAF40kQlQa0002P3PAF40
e<XH05`ieWETMP08000002D0000<00000`0005@0001D00000@H000T0000Q1P00E0000040002[Z^4o
7LOQ_mlK003A<P000@0004`00000000000000000003ooooooooooe00000X0000?00001P0000<0000
000002D0000<0000100002P0000<00000`000580001`0@000`0007Goool0000000000000002@0@00
000000L00P9304d0C@1903L000000000000000000000000000000000000000000000000000000000
000000000000000000000000000o000o100005C96010eV00S<XH0?Ea;WLK03h0M05N0000001@0Eh0
F0=;0000H00PdV00`7]P000000040000000005`100400000800000000@5DbAP0000008c:603eLBig
[Xh60OkooonZ>2YgXS@ZM`00000006008=9P02PP2Y4000006=9P09c:602:DgMe001N0000002QE7Me
/XP^O2PP2Y4PdV00P07JM@00003C?2Yg000gMVS:600X80ZAQ<`H001`NGDnbDl9o_oooj5DMgD54]Ie
8=9P0>15H@3^7b74000:0>15H@3DbQP0G3WFMFAf00P000009@0000`000030000E00005@0000Q1P00
2@0005D6001D00000@000:^ZhClMan6o7Q`00=4b00010000C00000000000000000000?oooooooooo
D00006h0001T0000600000`0000000009@0000`000040000:00000`000030000DP00070100030000
MOooo`000000000000000901000000001`020T<0C@1B03L000000000000000000000000000000000
000000000000000000000000000000000000000000000000000003l003l40000E<TH043FH02<bQP0
mG4^Ma/0?P1d0Eh000000501GP1H0d/0001P023BH030Nf00000000@000000000G0400@00000P0000
00010EC960000000S<XH0?Ea;WN^SPH1o_ooojXh:WNR=2Yg00000000H00PdV00:20:TP00000HdV00
W<XH08YCMgD005h000000:5DMgFbR2il:20:TR3BH0200MYe00000=<l:WL003MfJ<XH02PP2Y:4c1P0
071iMCk9C`WnooooXEAgM@DBeWDPdV00h4EQ0>hO8L@000X0h4EQ0=C:601L>MIeI7H02000000U0000
300000<0001D0000E00005@600090000M0H005@000010000Zj[Q?ag7hKn07000dC800040001<0000
0000000000000000oooooooooom@0000:@0003`0000H000030000000000U0000300000@0000X0000
300000<0001B0000L04000<0001eoooo0000000000000000T040000000070082@`1=04d0B@0g0000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
?`00?`@0001DbAP0@=IP08c:603eLBig6`0n07@1GP000000D05N05P3B`0006008=9P0<1kH0000000
10000000001L0@010000020000000041E<TH0000002<bQP0mG4^Mjj>1P7nooooZSPZMj8d:WL00000
001P023BH00X80ZC000001SBH02LbQP0RU=gM@00GP000000XEAgMK:8;W`X80ZC8=9P0801fWD00000
dc`ZM`00=gIXbQP0:20:ThC<6000L7Ue?/U?2OkooonQE7Me1A;FMB3BH03PAF40kQlQa0002P3PAF40
e<XH05`ieWETMP08000002D0000<00000`0005@0001D0000mPD00600000F1P00Z`000040002[Z^4o
7LOQ_lXK000b<P000@0004`00000000000000000003ooooooooooe00001Z0000?00001P0000<0000
000002D0000<0000100002P0000<00000`000580001`0@000`0007Goool0000000000000002@0@00
000000L00P9304d0D`1I03L000000000000000000000000000000000000000000000000000000000
000000000000000000000000000o000o100005C96010eV00S<XH0?Ea;WLK03h0M05N0000001@0Eh0
F0=;0000H00PdV00`7]P000000040000000005`100400000800000000@5DbAP0000008c:603eLBig
[Xh60OkooonZ>2YgXS@ZM`00000006008=9P02PP2Y@000006=9P09c:602:DgMe001N0000002QE7Me
/XP^O2PP2Y@PdV00P07JM@00003C?2Yg000gMVS:600X80ZDQ<`H001`NGDnbDl9o_oooj5DMgD54]Ie
8=9P0>15H@3^7b74000:0>15H@3DbQP0G3WFMFAf00P000009@0000`000030000E00005@0000L1P00
GP0005/6003P00000@000:^ZhClMan6o51`0038b00010000C00000000000000000000?oooooooooo
D0000:40001h0000600000`0000000009@0000`000040000:00000`000030000DP00070100030000
MOooo`000000000000000901000000001`020T<0C@1B03L000000000000000000000000000000000
000000000000000000000000000000000000000000000000000003l003l40000E<TH043FH02<bQP0
mG4^Ma/0?P1d0Eh000000501GP1H0d/0001P023BH030Nf00000000@000000000G0400@00000P0000
00010EC960000000S<XH0?Ea;WN^SPH1o_ooojXh:WNR=2Yg00000000H00PdV00:20:U@00000HdV00
W<XH08YCMgD005h000000:5DMgFbR2il:20:UB3BH0200MYe00000=<l:WL003MfJ<XH02PP2YF4c1P0
071iMCk9C`WnooooXEAgM@DBeWDPdV00h4EQ0>hO8L@000X0h4EQ0=C:601L>MIeI7H02000000U0000
300000<0001D0000E00005`6001P0000QPH00:/000010000Zj[Q?ag7hKn@7000<S800040001<0000
0000000000000000oooooooooom@0000<@000500000H000030000000000U0000300000@0000X0000
300000<0001B0000L04000<0000ioooo0000000000000000T040000000070082@`1=0580<@0`0000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
?`00?`@0001DbAP0@=IP08c:603eLBig6`0n07@1GP000000D05N05P3B`0006008=9P0<1kH0000000
10000000001L0@010000020000000041E<TH0000002<bQP0mG4^Mjj>1P7nooooZSPZMj8d:WL00000
001P023BH00X80ZF000001SBH02LbQP0RU=gM@00GP000000XEAgMK:8;W`X80ZF8=9P0801fWD00000
dc`ZM`00=gIXbQP0:20:UXC<6000L7Ue?/U?2OkooonQE7Me1A;FMB3BH03PAF40kQlQa0002P3PAF40
e<XH05`ieWETMP08000002D0000<00000`0005@0001D0000Z0H002T0003k1P00U0000040002[Z^4o
7LOQ_b8M001Z<P000@0004`00000000000000000003ooooooooooe00000m0000X00001P0000<0000
000002D0000<0000100002P0000<00000`000580001`0@000`0003Woool0000000000000002@0@00
000000L00P9304d0C@190340<0000000000000000000000000000000000000000000000000000000
000000000000000000000000000o000o100005C96010eV00S<XH0?Ea;WLK03h0M05N0000001@0Eh0
F0=;0000H00PdV00`7]P000000040000000005`100400000800000000@5DbAP0000008c:603eLBig
[Xh60OkooonZ>2YgXS@ZM`00000006008=9P02PP2YL000006=9P09c:602:DgMe001N0000002QE7Me
/XP^O2PP2YLPdV00P07JM@00003C?2Yg000gMVS:600X80ZGQ<`H001`NGDnbDl9o_oooj5DMgD54]Ie
8=9P0>15H@3^7b74000:0>15H@3DbQP0G3WFMFAf00P000009@0000`000030000E00005@0000E1`00
:@0006P7002D00000@000:^ZhClMan6om1d006Xb00010000C00000000000000000000?oooooooooo
D00004L0002P0000600000`0000000009@0000`000040000:00000`000030000DP00070100030000
MOooo`000000000000000901000000001`020T<0C@1B03L000000000000000000000000000000000
000000000000000000000000000000000000000000000000000003l003l40000E<TH043FH02<bQP0
mG4^Ma/0?P1d0Eh000000501GP1H0d/0001P023BH030Nf00000000@000000000G0400@00000P0000
00010EC960000000S<XH0?Ea;WN^SPH1o_ooojXh:WNR=2Yg00000000H00PdV00:20:V000000HdV00
W<XH08YCMgD005h000000:5DMgFbR2il:20:V23BH0200MYe00000=<l:WL003MfJ<XH02PP2YR4c1P0
071iMCk9C`WnooooXEAgM@DBeWDPdV00h4EQ0>hO8L@000X0h4EQ0=C:601L>MIeI7H02000000U0000
300000<0001D0000E00006H700090000QPL005@000010000Zj[Q?ag7hKnA7P00dC800040001<0000
0000000000000000oooooooooom@0000:00003`0000H000030000000000U0000300000@0000X0000
300000<0001B0000L04000<0001eoooo0000000000000000T040000000070082@`1=04d0B@0g0000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
?`00?`@0001DbAP0@=IP08c:603eLBig6`0n07@1GP000000D05N05P3B`0006008=9P0<1kH0000000
10000000001L0@010000020000000041E<TH0000002<bQP0mG4^Mjj>1P7nooooZSPZMj8d:WL00000
001P023BH00X80ZI000001SBH02LbQP0RU=gM@00GP000000XEAgMK:8;W`X80ZI8=9P0801fWD00000
dc`ZM`00=gIXbQP0:20:VHC<6000L7Ue?/U?2OkooonQE7Me1A;FMB3BH03PAF40kQlQa0002P3PAF40
e<XH05`ieWETMP08000002D0000<00000`0005@0001D0000Q`L000T0002k1`00E0000040002[Z^4o
7LOQ_m0N003A<P000@0004`00000000000000000003ooooooooooe00001^0000I00001P0000<0000
000002D0000<0000100002P0000<00000`000580001`0@000`0007Goool0000000000000002@0@00
000000L00P9304d0DP0g000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000o000o100005C96010eV00S<XH0?Ea;WLK03h0M05N0000001@0Eh0
F0=;0000H00PdV00`7]P000000040000000005`100400000800000000@5DbAP0000008c:603eLBig
[Xh60OkooonZ>2YgXS@ZM`00000006008=9P02PP2YX000006=9P09c:602:DgMe001N0000002QE7Me
/XP^O2PP2YXPdV00P07JM@00003C?2Yg000gMVS:600X80ZJQ<`H001`NGDnbDl9o_oooj5DMgD54]Ie
8=9P0>15H@3^7b74000:0>15H@3DbQP0G3WFMFAf00P000009@0000`000030000E00005@0002i1`00
2@000=T7001D00000@000:^ZhClMan6o<Ql00=4b00010000C00000000000000000000?oooooooooo
D00002T0000l0000600000`0000000009@0000`000040000:00000`000030000DP00070100030000
MOooo`000000000000000901000000001`020T<0C@1=04T0=`000000000000000000000000000000
000000000000000000000000000000000000000000000000000003l003l40000E<TH043FH02<bQP0
mG4^Ma/0?P1d0Eh000000501GP1H0d/0001P023BH030Nf00000000@000000000G0400@00000P0000
00010EC960000000S<XH0?Ea;WN^SPH1o_ooojXh:WNR=2Yg00000000H00PdV00:20:V`00000HdV00
W<XH08YCMgD005h000000:5DMgFbR2il:20:Vb3BH0200MYe00000=<l:WL003MfJ<XH02PP2Y^4c1P0
071iMCk9C`WnooooXEAgM@DBeWDPdV00h4EQ0>hO8L@000X0h4EQ0=C:601L>MIeI7H02000000U0000
300000<0001D0000E00006H7001P0000QPL00:/000010000Zj[Q?ag7hKnA7P00<S800040001<0000
0000000000000000oooooooooom@0000JP0003`0000U0000300000@0000X0000300000<000160000
500000P00017A4U30`000280000<0000ooooob80000<0000ooooobD0000<00003@00P2P0000<0000
0P0002P0000<000010000280000<0000ooooodH000300@00]04004E=AR//@000900001P00000080o
000000000000080o0000P000080Z@000900001P0001Xj2A100000000003gIBA1ie@6aKW@dTDT@000
30000000000Z@000900001P0002`0R`j00000000002`0R`j000VZ@004jT[@00030000000000N@0H0
30000000000Q@0D0300000000008@084600000`000024<3K000000<0010d@08030000000000N@0T0
30000000000Z@000900001P0002`0R`j00000000002`0R`j000VZ@004jTQ@0L030000000000Z@000
900001P0002`0R`j00000000002`0R`j000VZ@004jT[@00030000000000[@00030000000000N@0H0
30000000000Q@0D0300000000008@0<4600000`000024<3K000000<0010d@0<030000000000N@0T0
30000000000Z@000900001P00000080o000000000000080o00000000000Q@0L030000000001<0000
I000000000000000f`L00:l00000000000000=`7002`0000:@2Z0000000000000020?`0000000000
0020?`0000000000000000000000000000000000000000008P0000`0003oooooAP0001`0000@0000
ADe6:`90000<0000000000h0000D000000000100000D0000
\>"], "Graphics",
  GeneratedCell->False,
  CellAutoOverwrite->False,
  ImageSize->{304.6105263157894, 26.5208169677926},
  ImageMargins->{{30., 0.}, {0., 26.36904948939514}}],
 "\n where \n",
 Cell[GraphicsData["Metafile", "\<\
CF5dJ6E]HGAYHf4PEfU^I6mgLb15CDHPAVmbKF5d0@000;fD0@0006`0003ooooon_ooo`D9002C0@00
00000000000Z9P00L@D00215CDH00040U;d004l1000500000000000000000000HA<006PK003B0000
:@400000000000000000050d0`0XR0@0AP0002`0000P0000ADe6:`500@0L00004000008@`=/00000
F08005P200160000O04007010015CDH[7T0500`0000000007d0300`000000000<402010000040000
0020?b501`0<000000000290100<0000000002Y0000T000060000000P3l0000000000000P3l00000
000002]0000<0000000001i01P0<0000000002501@0<0000000001i02@0<0000000002Y0000T0000
60000000P3l0000000000000P3l00000000002501`0<0000000002Y0000T000060000;02;3X00000
00000;02;3X042?5021IaB]0000<0000000002Y0000T000060000;02;3X0000000000;02;3X042?5
021IaB]0000<0000000002Y0000T000060000;02;3X0000000000;02;3X002>Y001IZ@Y0080T0000
60000>7ohOl1000000000000000@aeI:097eB24000080000HP0000`000010000900002@00000000n
000000000000000n00000000000200009`0001P00001000000000>7oh@0000009@0000`000010000
9@0000`000080020EP000300003oooooooooo`D9001:0@001@000?coo?olod`:94Q<2RA8o?olooco
9@0000`0000700209@0000`000000020900002@00000001100000000000000110000000000020000
AP00071J001TFP00ADe6:b]0000<0000000001i01P0<0000000002501@0<0000000001i02@0<0000
000002Y0000T000060000;02;3X0000000000;02;3X002>Y001IZB501`0<0000000002]0000<0000
000002Y0000T0000600000jn94400000000005<g945B3?W4jiCBABA0100<0000000000Q000EPF@00
E5T0008@`=/200000`0004AI00010000c0000<80001_oOooX04009GmoonW6P00QZGoofLi003AZOoo
84E=AP000@14F@006P400080000`0000K000000000201`00>0@00:D2001m0@000000000000000000
eED:04S@1@1W06D0KP1U0780H@1d06D0I00P0680N@0P05L0C@1602l0A@1=04H0801R0640H`1[06D0
KP1T0200K`1V0200L01c07@0K`1U06@0J@1d0000J@1^0700M@1d0000000A0000300000H0000:0000
40000000000000004P0000`0000100005P0000`0000H0000600000`000000000DP00070100010000
>Oooo`0000000000000009010000000000020T<0C@1=04T0<@0`0000000000000000000000000000
00000000000000000000000000000000000000000000000010000<S:60000000200000L000000000
SU<gMLS:600`bQP0k;1300@000240000b<XH00000000000030000000000100008<XH000000240000
X0l0008000030000b<XH000000000000?<XH07nN@`3l2Wl0P<XH0000@`040000S[E30639c5=XOWl0
8HQ600000000000000000040001<bQP002m:00c;603PW480/2NCDokoool004<0gKE306QnO`000000
001o06QnO`38bQP00@0003P07P0;0000b<XH06QnO`010`00/7eo0040001POWl0I7H02000000U0000
30000040001D0000E0000<80001joOoobP0008Cmool10000Zj[Q?ag7hKl`3`00gS400040001<0000
0000000000000000oooooooooom@0000A`000:00000H000030000000000U0000300000d0080X0000
30000040001B0000L0400040001eoooo0000000000000000T040000000000082@`1=0580=`000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
?`00?`@000020000@=JA0<S:600000006`0n07@1S`000000D06?05P3g`4004<08=:A0<1kT@000000
10000000001L0@010000020000000041E<TH08cS:GN<bQP0mG4^Mm@M1P7nooooZSPZMj8d:WL00000
002A023BT@0n80XK000001SBT@2LbQP0RU=gM@00S`000000XEAgMILKdU<n80XK8=:A0801fWD0QWl0
B03O0@00g`5XbQP0?R0:6hC<6000L7Ue6eZc9_kooonQE7Me1A;FMB3BT@3PAI80I20Q2@002P3PAI80
e<XH05`ieWETMP08000002D0000<00000@0005@0001D0000bP0007Smooo=0000O_goo`40002[Z^4o
7LOQ_ld?0016<P000@0004`00000000000000000003ooooooooooe00000X0000?00001P0000<0000
000002D0000<00003@00P2P0000<00000@000580001`0@000@0007Goool0000000000000002@0@00
000000000P9304d0C@1903L000000000000000000000000000000000000000000000000000000000
000000000000000000000000000o000o100005C96010eY40S<XH0?Ea;WLK03h0M06?0000001@0Hl0
F0?O0@00T@0PdY40`7^A000000040000000005`100400000800000000@5DbAP0000008c:603eLBig
e1d60OkooonZ>2YgXS@ZM`00000009408=:A03hP2Q`000006=:A09c:602:DgMe002?0000002QE7Me
Ua_BDchP2Q`PdY40P07JM@0000180=l1003O0FS:600n80XLQ<`H001`NGDKF[<Vo_oooj5DMgD54]Ie
8=:A0>15TP1T8249000:0>15TP3DbQP0G3WFMFAf00P000009@0000`000010000E00005@0003=0000
N?goom80001noOoo0@000:^ZhClMan6o310004Hb00010000C00000000000000000000?oooooooooo
D00006h0001T0000600000`0000000009@0000`0000=0020:00000`000010000DP00070100010000
MOooo`0000000000000009010000000000020T<0C@1B03L000000000000000000000000000000000
000000000000000000000000000000000000000000000000000003l003l40000E<TH043FT@2<bQP0
mG4^Ma/0?P1d0Hl000000501S`1H0ml1002A023BT@30Ni40000000@000000000G0400@00000P0000
00010EC960000000S<XH0?Ea;WOD7@H1o_ooojXh:WNR=2Yg00000000T@0PdY40?R0:7@00000HdY40
W<XH08YCMgD008l000000:5DMgFG6m9C?R0:7B3BT@200MYe000004P0g`400=l1J<XH03hP2Qf4c1P0
071iMA]J/bKnooooXEAgM@DBeWDPdY40h4FB06@P8@T000X0h4FB0=C:601L>MIeI7H02000000U0000
30000040001D0000E0000=80001hoOooe@0007kmool10000Zj[Q?ag7hKm^4000AS800040001<0000
0000000000000000oooooooooom@0000:@0003`0000H000030000000000U0000300000d0080X0000
30000040001B0000L0400040001eoooo0000000000000000T040000000000082@`1=04d0B@0g0000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
?`00?`@0001DbAP0@=JA08c:603eLBig6`0n07@1S`000000D06?05P3g`4009408=:A0<1kT@000000
10000000001L0@010000020000000041E<TH0000002<bQP0mG4^Mm@M1P7nooooZSPZMj8d:WL00000
002A023BT@0n80XN000001SBT@2LbQP0RU=gM@00S`000000XEAgMILKdU<n80XN8=:A0801fWD00000
B03O0@00g`5XbQP0?R0:7XC<6000L7Ue6eZc9_kooonQE7Me1A;FMB3BT@3PAI80I20Q2@002P3PAI80
e<XH05`ieWETMP08000002D0000<00000@0005@0001D0000bP00083mooo=0000Q_goo`40002[Z^4o
7LOQ_ld?002V<@000@0004`00000000000000000003ooooooooooe00001Z0000?00001P0000<0000
000002D0000<00003@00P2P0000<00000@000580001`0@000@0003Woool0000000000000002@0@00
000000000P9304d0D`1I0340<01?0580B@1700000000000000000000000000000000000000000000
000000000000000000000000000o000o100005C96010eY40S<XH0?Ea;WLK03h0M06?0000001@0Hl0
F0?O0@00T@0PdY40`7^A000000040000000005`100400000800000000@5DbAP0000008c:603eLBig
e1d60OkooonZ>2YgXS@ZM`00000009408=:A03hP2Ql000006=:A09c:602:DgMe002?0000002QE7Me
Ua_BDchP2QlPdY40P07JM@0000180=l1003O0FS:600n80XOQ<`H001`NGDKF[<Vo_oooj5DMgD54]Ie
8=:A0>15TP1T8249000:0>15TP3DbQP0G3WFMFAf00P000009@0000`000010000E00005@0003I0000
N_goon40002;oOoo0@000:^ZhClMan6ok1000=ha00010000C00000000000000000000?oooooooooo
D0000;@0002P0000600000`0000000009@0000`0000=0020:00000`000010000DP00070100010000
>Oooo`0000000000000009010000000000020T<0C@1=04T0<@0`0000000000000000000000000000
000000000000000000000000000000000000000000000000000003l003l40000E<TH043FT@2<bQP0
mG4^Ma/0?P1d0Hl000000501S`1H0ml1002A023BT@30Ni40000000@000000000G0400@00000P0000
00010EC960000000S<XH0?Ea;WOD7@H1o_ooojXh:WNR=2Yg00000000T@0PdY40?R0:8000000HdY40
W<XH08YCMgD008l000000:5DMgFG6m9C?R0:823BT@200MYe000004P0g`400=l1J<XH03hP2R24c1P0
071iMA]J/bKnooooXEAgM@DBeWDPdY40h4FB06@P8@T000X0h4FB0=C:601L>MIeI7H02000000U0000
30000040001D0000E0000><0001joOooj`0008Cmool10000Zj[Q?ag7hKno4@00gS400040001<0000
0000000000000000oooooooooom@0000E@0008`0000H000030000000000U0000300000d0080X0000
30000040001B0000L0400040001eoooo0000000000000000T040000000000082@`1=0580=`000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
?`00?`@0001DbAP0@=JA08c:603eLBig6`0n07@1S`000000D06?05P3g`4009408=:A0<1kT@000000
10000000001L0@010000020000000041E<TH0000002<bQP0mG4^Mm@M1P7nooooZSPZMj8d:WL00000
002A023BT@0n80XQ000001SBT@2LbQP0RU=gM@00S`000000XEAgMILKdU<n80XQ8=:A0801fWD00000
B03O0@00g`5XbQP0?R0:8HC<6000L7Ue6eZc9_kooonQE7Me1A;FMB3BT@3PAI80I20Q2@002P3PAI80
e<XH05`ieWETMP08000002D0000<00000@0005@0001D0000j`0007Smooo^0000O_goo`40002[Z^4o
7LOQ_e`B0016<P000@0004`00000000000000000003ooooooooooe00000X0000?00001P0000<0000
000002D0000<00003@00P2P0000<00000@000580001`0@000@0007Goool0000000000000002@0@00
000000000P9304d0C@1903L000000000000000000000000000000000000000000000000000000000
000000000000000000000000000o000o100005C96010eY40S<XH0?Ea;WLK03h0M06?0000001@0Hl0
F0?O0@00T@0PdY40`7^A000000040000000005`100400000800000000@5DbAP0000008c:603eLBig
e1d60OkooonZ>2YgXS@ZM`00000009408=:A03hP2R8000006=:A09c:602:DgMe002?0000002QE7Me
Ua_BDchP2R8PdY40P07JM@0000180=l1003O0FS:600n80XRQ<`H001`NGDKF[<Vo_oooj5DMgD54]Ie
8=:A0>15TP1T8249000:0>15TP3DbQP0G3WFMFAf00P000009@0000`000010000E00005@0003^0000
N?gooo<0001noOoo0@000:^ZhClMan6oVa8004Hb00010000C00000000000000000000?oooooooooo
D00006h0001T0000600000`0000000009@0000`0000=0020:00000`000010000DP00070100010000
MOooo`0000000000000009010000000000020T<0C@1C05T0=`000000000000000000000000000000
000000000000000000000000000000000000000000000000000003l003l40000E<TH043FT@2<bQP0
mG4^Ma/0?P1d0Hl000000501S`1H0ml1002A023BT@30Ni40000000@000000000G0400@00000P0000
00010EC960000000S<XH0?Ea;WOD7@H1o_ooojXh:WNR=2Yg00000000T@0PdY40?R0:8`00000HdY40
W<XH08YCMgD008l000000:5DMgFG6m9C?R0:8b3BT@200MYe000004P0g`400=l1J<XH03hP2R>4c1P0
071iMA]J/bKnooooXEAgM@DBeWDPdY40h4FB06@P8@T000X0h4FB0=C:601L>MIeI7H02000000U0000
30000040001D0000E0000?<0001hoOoon@0008?mool10000Zj[Q?ag7hKom4P00AS800040001<0000
0000000000000000oooooooooom@0000X@0007P0000H000030000000000U0000300000d0080X0000
30000040001B0000L0400040001eoooo0000000000000000T040000000000082@`1=0580=`000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
?`00?`@0001DbAP0@=JA08c:603eLBig6`0n07@1S`000000D06?05P3g`4009408=:A0<1kT@000000
10000000001L0@010000020000000041E<TH0000002<bQP0mG4^Mm@M1P7nooooZSPZMj8d:WL00000
002A023BT@0n80XT000001SBT@2LbQP0RU=gM@00S`000000XEAgMILKdU<n80XT8=:A0801fWD00000
B03O0@00g`5XbQP0?R0:98C<6000L7Ue6eZc9_kooonQE7Me1A;FMB3BT@3PAI80I20Q2@002P3PAI80
e<XH05`ieWETMP08000002D0000<00000@0005@0001D0000n@0007Smooom0000O_goo`40002[Z^4o
7LOQ_gTC0016<P000@0004`00000000000000000003ooooooooooe00000a0000D00001P0000<0000
000005@0001D0000o@0007Smool00@00O_goo`40002[Z^4o7LOQ_lTC0016<P000@0004`000000000
00000000003ooooooooooe00000Y0000?00001P0000<0000000002D0000<00003@00P2P0000<0000
0@000580001`0@000@0007Goool0000000000000002@0@00000000000P9304d0C@1903L000000000
000000000000000000000000000000000000000000000000000000000000000000000000000o000o
100005C96010eY40S<XH0?Ea;WLK03h0M06?0000001@0Hl0F0?O0@00T@0PdY40`7^A000000040000
000005`100400000800000000@5DbAP0000008c:603eLBige1d60OkooonZ>2YgXS@ZM`0000000940
8=:A03hP2RD000006=:A09c:602:DgMe002?0000002QE7MeUa_BDchP2RDPdY40P07JM@0000180=l1
003O0FS:600n80XUQ<`H001`NGDKF[<Vo_oooj5DMgD54]Ie8=:A0>15TP1T8249000:0>15TP3DbQP0
G3WFMFAf00P000009@0000`000010000E00005@0003Z0000P?goond00026oOoo0@000:^ZhClMan6o
Aa800:Ha00010000C00000000000000000000?ooooooooooD00006X0000l0000600000`000000000
9@0000`0000=0020:00000`000010000DP00070100010000>Oooo`00000000000000090100000000
00020T<0C@1C05T0<@0`04l0DP1904L0000000000000000000000000000000000000000000000000
0000000000000000000003l003l40000E<TH043FT@2<bQP0mG4^Ma/0?P1d0Hl000000501S`1H0ml1
002A023BT@30Ni40000000@000000000G0400@00000P000000010EC960000000S<XH0?Ea;WOD7@H1
o_ooojXh:WNR=2Yg00000000T@0PdY40?R0:9P00000HdY40W<XH08YCMgD008l000000:5DMgFG6m9C
?R0:9R3BT@200MYe000004P0g`400=l1J<XH03hP2RJ4c1P0071iMA]J/bKnooooXEAgM@DBeWDPdY40
h4FB06@P8@T000X0h4FB0=C:601L>MIeI7H02000000U000030000040001D0000E00000<1001joOoo
2`4008_mool10000Zj[Q?ag7hKln5000gS400040001<00000000000000000000oooooooooom@0000
X@000:00000H000030000000000U0000300000d0080X000030000040001B0000L0400040001eoooo
0000000000000000T040000000000082@`1=04d0B@0g000000000000000000000000000000000000
000000000000000000000000000000000000000000000000?`00?`@0001DbAP0@=JA08c:603eLBig
6`0n07@1S`000000D06?05P3g`4009408=:A0<1kT@00000010000000001L0@010000020000000041
E<TH0000002<bQP0mG4^Mm@M1P7nooooZSPZMj8d:WL00000002A023BT@0n80XW000001SBT@2LbQP0
RU=gM@00S`000000XEAgMILKdU<n80XW8=:A0801fWD00000B03O0@00g`5XbQP0?R0:9hC<6000L7Ue
6eZc9_kooonQE7Me1A;FMB3BT@3PAI80I20Q2@002P3PAI80e<XH05`ieWETMP08000002D0000<0000
0@0005@0001D00003P40073moolC0@00M_goo`40002[Z^4o7LOQ_aTE003G<P000@0004`000000000
00000000003ooooooooooe00001^0000I00001P0000<0000000002D0000<00003@00P2P0000<0000
0@000580001`0@000@0007Goool0000000000000002@0@00000000000P9304d0D`1I03L000000000
000000000000000000000000000000000000000000000000000000000000000000000000000o000o
100005C96010eY40S<XH0?Ea;WLK03h0M06?0000001@0Hl0F0?O0@00T@0PdY40`7^A000000040000
000005`100400000800000000@5DbAP0000008c:603eLBige1d60OkooonZ>2YgXS@ZM`0000000940
8=:A03hP2RP000006=:A09c:602:DgMe002?0000002QE7MeUa_BDchP2RPPdY40P07JM@0000180=l1
003O0FS:600n80XXQ<`H001`NGDKF[<Vo_oooj5DMgD54]Ie8=:A0>15TP1T8249000:0>15TP3DbQP0
G3WFMFAf00P000009@0000`000010000E00005@0000C0@00L?gooaT1001koOoo0@000:^ZhClMan6o
O1D00=Lb00010000C00000000000000000000?ooooooooooD0000:40001h0000600000`000000000
9@0000`0000=0020:00000`000010000DP00070100010000MOooo`00000000000000090100000000
00020T<0C@1B03L00000000000000000000000000000000000000000000000000000000000000000
0000000000000000000003l003l40000E<TH043FT@2<bQP0mG4^Ma/0?P1d0Hl000000501S`1H0ml1
002A023BT@30Ni40000000@000000000G0400@00000P000000010EC960000000S<XH0?Ea;WOD7@H1
o_ooojXh:WNR=2Yg00000000T@0PdY40?R0::@00000HdY40W<XH08YCMgD008l000000:5DMgFG6m9C
?R0::B3BT@200MYe000004P0g`400=l1J<XH03hP2RV4c1P0071iMA]J/bKnooooXEAgM@DBeWDPdY40
h4FB06@P8@T000X0h4FB0=C:601L>MIeI7H02000000U000030000040001D0000E00001T1001`oOoo
7@4007Kmool10000Zj[Q?ag7hKoh5@00ec800040001<00000000000000000000oooooooooom@0000
<P000500000H000030000000000U0000300000d0080X000030000040001B0000L0400040000ioooo
0000000000000000T040000000000082@`1=04D0F00a030000000000000000000000000000000000
000000000000000000000000000000000000000000000000?`00?`@0001DbAP0@=JA08c:603eLBig
6`0n07@1S`000000D06?05P3g`4009408=:A0<1kT@00000010000000001L0@010000020000000041
E<TH0000002<bQP0mG4^Mm@M1P7nooooZSPZMj8d:WL00000002A023BT@0n80XZ000001SBT@2LbQP0
RU=gM@00S`000000XEAgMILKdU<n80XZ8=:A0801fWD00000B03O0@00g`5XbQP0?R0::XC<6000L7Ue
6eZc9_kooonQE7Me1A;FMB3BT@3PAI80I20Q2@002P3PAI80e<XH05`ieWETMP08000002D0000<0000
0@0005@0001D00003P40073moolL0@00UOgoo`40002[Z^4o7LOQ_b0E002K<P000@0004`000000000
00000000003ooooooooooe00001H0000604001P0000<0000000002D0000<00003@00P2P0000<0000
0@000580001`0@000@0007Goool0000000000000002@0@00000000000P9304d0C@1903L000000000
000000000000000000000000000000000000000000000000000000000000000000000000000o000o
100005C96010eY40S<XH0?Ea;WLK03h0M06?0000001@0Hl0F0?O0@00T@0PdY40`7^A000000040000
000005`100400000800000000@5DbAP0000008c:603eLBige1d60OkooonZ>2YgXS@ZM`0000000940
8=:A03hP2R/000006=:A09c:602:DgMe002?0000002QE7MeUa_BDchP2R/PdY40P07JM@0000180=l1
003O0FS:600n80X[Q<`H001`NGDKF[<Vo_oooj5DMgD54]Ie8=:A0>15TP1T8249000:0>15TP3DbQP0
G3WFMFAf00P000009@0000`000010000E00005@0000=0@00R?gooa@1002>oOoo0@000:^ZhClMan6o
1AD00?D`00010000C00000000000000000000?ooooooooooD00006d0002<0000600000`000000000
9@0000`0000=0020:00000`000010000DP00070100010000MOooo`00000000000000090100000000
00020T<0C@1B03L00000000000000000000000000000000000000000000000000000000000000000
0000000000000000000003l003l40000E<TH043FT@2<bQP0mG4^Ma/0?P1d0Hl000000501S`1H0ml1
002A023BT@30Ni40000000@000000000G0400@00000P000000010EC960000000S<XH0?Ea;WOD7@H1
o_ooojXh:WNR=2Yg00000000T@0PdY40?R0:;000000HdY40W<XH08YCMgD008l000000:5DMgFG6m9C
?R0:;23BT@200MYe000004P0g`400=l1J<XH03hP2Rb4c1P0071iMA]J/bKnooooXEAgM@DBeWDPdY40
h4FB06@P8@T000X0h4FB0=C:601L>MIeI7H02000000U000030000040001D0000E00001@10028oOoo
6P4008kmool10000Zj[Q?ag7hKnB5@00mC000040001<00000000000000000000oooooooooom@0000
?@0007P0000H000030000000001D0000E00001X10028oOoo7P4008kmool10000Zj[Q?ag7hKl=5P00
mC000040001<00000000000000000000oooooooooom@0000<0000500000H000030000000000U0000
300000d0080X000030000040001B0000L0400040000ioooo0000000000000000T040000000000082
@`1=0580<@0`00000000000000000000000000000000000000000000000000000000000000000000
0000000000000000?`00?`@0001DbAP0@=JA08c:603eLBig6`0n07@1S`000000D06?05P3g`400940
8=:A0<1kT@00000010000000001L0@010000020000000041E<TH0000002<bQP0mG4^Mm@M1P7noooo
ZSPZMj8d:WL00000002A023BT@0n80X]000001SBT@2LbQP0RU=gM@00S`000000XEAgMILKdU<n80X]
8=:A0801fWD00000B03O0@00g`5XbQP0?R0:;HC<6000L7Ue6eZc9_kooonQE7Me1A;FMB3BT@3PAI80
I20Q2@002P3PAI80e<XH05`ieWETMP08000002D0000<00000@0005@0001D00008P4007OmoolW0@00
POgoo`40002[Z^4o7LOQ_j@F000@<P000@0004`00000000000000000003ooooooooooe00001n0000
I00001P0000<0000000002D0000<00003@00P2P0000<00000@000580001`0@000@0003Woool00000
00000000002@0@00000000000P9304d0C@190340<000000000000000000000000000000000000000
0000000000000000000000000000000000000000000o000o100005C96010eY40S<XH0?Ea;WLK03h0
M06?0000001@0Hl0F0?O0@00T@0PdY40`7^A000000040000000005`100400000800000000@5DbAP0
000008c:603eLBige1d60OkooonZ>2YgXS@ZM`00000009408=:A03hP2Rh000006=:A09c:602:DgMe
002?0000002QE7MeUa_BDchP2RhPdY40P07JM@0000180=l1003O0FS:600n80X^Q<`H001`NGDKF[<V
o_oooj5DMgD54]Ie8=:A0>15TP1T8249000:0>15TP3DbQP0G3WFMFAf00P000009@0000`000010000
E00005@0000P0@00N_goobL10024oOoo0@000:^ZhClMan6oOQH00=ha00010000C000000000000000
00000?ooooooooooD00005@0001h0000600000`0000000009@0000`0000=0020:00000`000010000
DP00070100010000MOooo`0000000000000009010000000000020T<0C@1B03L00000000000000000
0000000000000000000000000000000000000000000000000000000000000000000003l003l40000
E<TH043FT@2<bQP0mG4^Ma/0?P1d0Hl000000501S`1H0ml1002A023BT@30Ni40000000@000000000
G0400@00000P000000010EC960000000S<XH0?Ea;WOD7@H1o_ooojXh:WNR=2Yg00000000T@0PdY40
?R0:;`00000HdY40W<XH08YCMgD008l000000:5DMgFG6m9C?R0:;b3BT@200MYe000004P0g`400=l1
J<XH03hP2Rn4c1P0071iMA]J/bKnooooXEAgM@DBeWDPdY40h4FB06@P8@T000X0h4FB0=C:601L>MIe
I7H02000000U000030000040001D0000E00002L1001ioOoo:P4007omool10000Zj[Q?ag7hKl>5`00
<3800040001<00000000000000000000oooooooooom@0000:00003`0000H000030000000000U0000
300000d0080X000030000040001B0000L0400040001eoooo0000000000000000T040000000000082
@`1=04d0B@0g00000000000000000000000000000000000000000000000000000000000000000000
0000000000000000?`00?`@0001DbAP0@=JA08c:603eLBig6`0n07@1S`000000D06?05P3g`400940
8=:A0<1kT@00000010000000001L0@010000020000000041E<TH0000002<bQP0mG4^Mm@M1P7noooo
ZSPZMj8d:WL00000002A023BT@0n80X`000001SBT@2LbQP0RU=gM@00S`000000XEAgMILKdU<n80X`
8=:A0801fWD00000B03O0@00g`5XbQP0?R0:<8C<6000L7Ue6eZc9_kooonQE7Me1A;FMB3BT@3PAI80
I20Q2@002P3PAI80e<XH05`ieWETMP08000002D0000<00000@0005@0001D0000:P4007Wmool^0@00
Oogoo`40002[Z^4o7LOQ_d`G000`<P000@0004`00000000000000000003ooooooooooe00002`0000
D00001P0000<0000000002D0000<00003@00P2P0000<00000@000580001`0@000@0007Goool00000
00000000002@0@00000000000P9304d0DP0g00000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000o000o100005C96010eY40S<XH0?Ea;WLK03h0
M06?0000001@0Hl0F0?O0@00T@0PdY40`7^A000000040000000005`100400000800000000@5DbAP0
000008c:603eLBige1d60OkooonZ>2YgXS@ZM`00000009408=:A03hP2S4000006=:A09c:602:DgMe
002?0000002QE7MeUa_BDchP2S4PdY40P07JM@0000180=l1003O0FS:600n80XaQ<`H001`NGDKF[<V
o_oooj5DMgD54]Ie8=:A0>15TP1T8249000:0>15TP3DbQP0G3WFMFAf00P000009@0000`000010000
E00005@0000_0@00NOgooc81001ooOoo0@000:^ZhClMan6oZ1L0030b00010000C000000000000000
00000?ooooooooooD00002T0000l0000600000`0000000009@0000`0000=0020:00000`000010000
DP00070100010000MOooo`0000000000000009010000000000020T<0C@1=04T0=`00000000000000
0000000000000000000000000000000000000000000000000000000000000000000003l003l40000
E<TH043FT@2<bQP0mG4^Ma/0?P1d0Hl000000501S`1H0ml1002A023BT@30Ni40000000@000000000
G0400@00000P000000010EC960000000S<XH0?Ea;WOD7@H1o_ooojXh:WNR=2Yg00000000T@0PdY40
?R0:<P00000HdY40W<XH08YCMgD008l000000:5DMgFG6m9C?R0:<R3BT@200MYe000004P0g`400=l1
J<XH03hP2S:4c1P0071iMA]J/bKnooooXEAgM@DBeWDPdY40h4FB06@P8@T000X0h4FB0=C:601L>MIe
I7H02000000U000030000040001D0000E00002H1001ooOoo;@4008Gmool10000Zj[Q?ag7hKob5P00
[3400040001<00000000000000000000oooooooooom@0000K@0008`0000H000030000000001D0000
E00002`1001ooOoo;`4008Gmool10000Zj[Q?ag7hKn05`00[3400040001<00000000000000000000
oooooooooom@0000>`0002P0000H000030000000001D0000E00002l1001ooOoo=04008Gmool10000
Zj[Q?ag7hKn^5`00[3400040001<00000000000000000000oooooooooom@0000KP0006@0000H0000
30000000000U0000300000d0080X000030000040001B0000L0400040000ioooo0000000000000000
T040000000000082@`1=04D0F00a0300000000000000000000000000000000000000000000000000
00000000000000000000000000000000?`00?`@0001DbAP0@=JA08c:603eLBig6`0n07@1S`000000
D06?05P3g`4009408=:A0<1kT@00000010000000001L0@010000020000000041E<TH0000002<bQP0
mG4^Mm@M1P7nooooZSPZMj8d:WL00000002A023BT@0n80Xc000001SBT@2LbQP0RU=gM@00S`000000
XEAgMILKdU<n80Xc8=:A0801fWD00000B03O0@00g`5XbQP0?R0:<hC<6000L7Ue6eZc9_kooonQE7Me
1A;FMB3BT@3PAI80I20Q2@002P3PAI80e<XH05`ieWETMP08000002D0000<00000@0005@0001D0000
=P4006omoolk0@00U?goo`40002[Z^4o7LOQ_c`H002l<P000@0004`00000000000000000003ooooo
oooooe00001X0000I00001P0000<0000000002D0000<00003@00P2P0000<00000@000580001`0@00
0@0003Woool0000000000000002@0@00000000000P9304d0C@190340<00000000000000000000000
00000000000000000000000000000000000000000000000000000000000o000o100005C96010eY40
S<XH0?Ea;WLK03h0M06?0000001@0Hl0F0?O0@00T@0PdY40`7^A000000040000000005`100400000
800000000@5DbAP0000008c:603eLBige1d60OkooonZ>2YgXS@ZM`00000009408=:A03hP2S@00000
6=:A09c:602:DgMe002?0000002QE7MeUa_BDchP2S@PdY40P07JM@0000180=l1003O0FS:600n80Xd
Q<`H001`NGDKF[<Vo_oooj5DMgD54]Ie8=:A0>15TP1T8249000:0>15TP3DbQP0G3WFMFAf00P00000
9@0000`000010000E00005@0000k0@00N_good<10024oOoo0@000:^ZhClMan6oVaP00=ha00010000
C00000000000000000000?ooooooooooD00005D0002<0000600000`0000000009@0000`0000=0020
:00000`000010000DP00070100010000MOooo`0000000000000009010000000000020T<0C@1B03L0
00000000000000000000000000000000000000000000000000000000000000000000000000000000
000003l003l40000E<TH043FT@2<bQP0mG4^Ma/0?P1d0Hl000000501S`1H0ml1002A023BT@30Ni40
000000@000000000G0400@00000P000000010EC960000000S<XH0?Ea;WOD7@H1o_ooojXh:WNR=2Yg
00000000T@0PdY40?R0:=@00000HdY40W<XH08YCMgD008l000000:5DMgFG6m9C?R0:=B3BT@200MYe
000004P0g`400=l1J<XH03hP2SF4c1P0071iMA]J/bKnooooXEAgM@DBeWDPdY40h4FB06@P8@T000X0
h4FB0=C:601L>MIeI7H02000000U000030000040001D0000E00004<1001hoOooAP4007kmool10000
Zj[Q?ag7hKlh6@00AS800040001<00000000000000000000oooooooooom@0000:00003`0000H0000
30000000000U0000300000d0080X000030000040001B0000L0400040001eoooo0000000000000000
T040000000000082@`1=04d0B@0g0000000000000000000000000000000000000000000000000000
00000000000000000000000000000000?`00?`@0001DbAP0@=JA08c:603eLBig6`0n07@1S`000000
D06?05P3g`4009408=:A0<1kT@00000010000000001L0@010000020000000041E<TH0000002<bQP0
mG4^Mm@M1P7nooooZSPZMj8d:WL00000002A023BT@0n80Xf000001SBT@2LbQP0RU=gM@00S`000000
XEAgMILKdU<n80Xf8=:A0801fWD00000B03O0@00g`5XbQP0?R0:=XC<6000L7Ue6eZc9_kooonQE7Me
1A;FMB3BT@3PAI80I20Q2@002P3PAI80e<XH05`ieWETMP08000002D0000<00000@0005@0001D0000
AP4007Smoom=0@00O_goo`40002[Z^4o7LOQ_gHI0016<P000@0004`00000000000000000003ooooo
oooooe00001]0000S00001P0000<0000000002D0000<00003@00P2P0000<00000@000580001`0@00
0@0007Goool0000000000000002@0@00000000000P9304d0DP0g0000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000o000o100005C96010eY40
S<XH0?Ea;WLK03h0M06?0000001@0Hl0F0?O0@00T@0PdY40`7^A000000040000000005`100400000
800000000@5DbAP0000008c:603eLBige1d60OkooonZ>2YgXS@ZM`00000009408=:A03hP2SL00000
6=:A09c:602:DgMe002?0000002QE7MeUa_BDchP2SLPdY40P07JM@0000180=l1003O0FS:600n80Xg
Q<`H001`NGDKF[<Vo_oooj5DMgD54]Ie8=:A0>15TP1T8249000:0>15TP3DbQP0G3WFMFAf00P00000
9@0000`000010000E00005@0001=0@00N?gooe<1001noOoo0@000:^ZhClMan6o11X004Hb00010000
C00000000000000000000?ooooooooooD00002/0001h0000600000`000000000E00005@0001C0@00
N?gooeL1001noOoo0@000:^ZhClMan6oOQX004Hb00010000C00000000000000000000?oooooooooo
D0000340001@0000600000`000000000E00005@0001G0@00N?gooeX1001noOoo0@000:^ZhClMan6o
cAX004Hb00010000C00000000000000000000?ooooooooooD00002T0000l0000600000`000000000
9@0000`0000=0020:00000`000010000DP00070100010000MOooo`00000000000000090100000000
00020T<0C@1=04T0=`00000000000000000000000000000000000000000000000000000000000000
0000000000000000000003l003l40000E<TH043FT@2<bQP0mG4^Ma/0?P1d0Hl000000501S`1H0ml1
002A023BT@30Ni40000000@000000000G0400@00000P000000010EC960000000S<XH0?Ea;WOD7@H1
o_ooojXh:WNR=2Yg00000000T@0PdY40?R0:>000000HdY40W<XH08YCMgD008l000000:5DMgFG6m9C
?R0:>23BT@200MYe000004P0g`400=l1J<XH03hP2SR4c1P0071iMA]J/bKnooooXEAgM@DBeWDPdY40
h4FB06@P8@T000X0h4FB0=C:601L>MIeI7H02000000U000030000040001D0000E00004810020oOoo
A@4008Kmool10000Zj[Q?ag7hKlR6@00YS400040001<00000000000000000000oooooooooom@0000
JP0003`0000H000030000000000U0000300000d0080X000030000040001B0000L0400040000ioooo
0000000000000000T040000000000082@`1=05<0F@0a0300C`1B04T0A`0000000000000000000000
000000000000000000000000000000000000000000000000?`00?`@0001DbAP0@=JA08c:603eLBig
6`0n07@1S`000000D06?05P3g`4009408=:A0<1kT@00000010000000001L0@010000020000000041
E<TH0000002<bQP0mG4^Mm@M1P7nooooZSPZMj8d:WL00000002A023BT@0n80Xi000001SBT@2LbQP0
RU=gM@00S`000000XEAgMILKdU<n80Xi8=:A0801fWD00000B03O0@00g`5XbQP0?R0:>HC<6000L7Ue
6eZc9_kooonQE7Me1A;FMB3BT@3PAI80I20Q2@002P3PAI80e<XH05`ieWETMP08000002D0000<0000
0@0005@0001D0000G@4007[moomU0@00Rogoo`40002[Z^4o7LOQ_d8K003N<@000@0004`000000000
00000000003ooooooooooe00002Q0000X00001P0000<0000000002D0000<00003@00P2P0000<0000
0@000580001`0@000@0003Woool0000000000000002@0@00000000000P9304d0C@190340<0000000
000000000000000000000000000000000000000000000000000000000000000000000000000o000o
100005C96010eY40S<XH0?Ea;WLK03h0M06?0000001@0Hl0F0?O0@00T@0PdY40`7^A000000040000
000005`100400000800000000@5DbAP0000008c:603eLBige1d60OkooonZ>2YgXS@ZM`0000000940
8=:A03hP2SX000006=:A09c:602:DgMe002?0000002QE7MeUa_BDchP2SXPdY40P07JM@0000180=l1
003O0FS:600n80XjQ<`H001`NGDKF[<Vo_oooj5DMgD54]Ie8=:A0>15TP1T8249000:0>15TP3DbQP0
G3WFMFAf00P000009@0000`000010000E00005@0001W0@00N_goofl10024oOoo0@000:^ZhClMan6o
2A`00=ha00010000C00000000000000000000?ooooooooooD00005D0002<0000600000`000000000
9@0000`0000=0020:00000`000010000DP00070100010000MOooo`00000000000000090100000000
00020T<0C@1B03L00000000000000000000000000000000000000000000000000000000000000000
0000000000000000000003l003l40000E<TH043FT@2<bQP0mG4^Ma/0?P1d0Hl000000501S`1H0ml1
002A023BT@30Ni40000000@000000000G0400@00000P000000010EC960000000S<XH0?Ea;WOD7@H1
o_ooojXh:WNR=2Yg00000000T@0PdY40?R0:>`00000HdY40W<XH08YCMgD008l000000:5DMgFG6m9C
?R0:>b3BT@200MYe000004P0g`400=l1J<XH03hP2S^4c1P0071iMA]J/bKnooooXEAgM@DBeWDPdY40
h4FB06@P8@T000X0h4FB0=C:601L>MIeI7H02000000U000030000040001D0000E00006l1001hoOoo
LP4007kmool10000Zj[Q?ag7hKnV7000AS800040001<00000000000000000000oooooooooom@0000
:00003`0000H000030000000000U0000300000d0080X000030000040001B0000L0400040001eoooo
0000000000000000T040000000000082@`1=04d0B@0g000000000000000000000000000000000000
000000000000000000000000000000000000000000000000?`00?`@0001DbAP0@=JA08c:603eLBig
6`0n07@1S`000000D06?05P3g`4009408=:A0<1kT@00000010000000001L0@010000020000000041
E<TH0000002<bQP0mG4^Mm@M1P7nooooZSPZMj8d:WL00000002A023BT@0n80Xl000001SBT@2LbQP0
RU=gM@00S`000000XEAgMILKdU<n80Xl8=:A0801fWD00000B03O0@00g`5XbQP0?R0:?8C<6000L7Ue
6eZc9_kooonQE7Me1A;FMB3BT@3PAI80I20Q2@002P3PAI80e<XH05`ieWETMP08000002D0000<0000
0@0005@0001D0000LP4007Smoomi0@00O_goo`40002[Z^4o7LOQ_nDL0016<P000@0004`000000000
00000000003ooooooooooe00001]0000S00001P0000<0000000002D0000<00003@00P2P0000<0000
0@000580001`0@000@0007Goool0000000000000002@0@00000000000P9304d0DP0g000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000o000o
100005C96010eY40S<XH0?Ea;WLK03h0M06?0000001@0Hl0F0?O0@00T@0PdY40`7^A000000040000
000005`100400000800000000@5DbAP0000008c:603eLBige1d60OkooonZ>2YgXS@ZM`0000000940
8=:A03hP2Sd000006=:A09c:602:DgMe002?0000002QE7MeUa_BDchP2SdPdY40P07JM@0000180=l1
003O0FS:600n80XmQ<`H001`NGDKF[<Vo_oooj5DMgD54]Ie8=:A0>15TP1T8249000:0>15TP3DbQP0
G3WFMFAf00P000009@0000`000010000E00005@0001i0@00N?goog`1001noOoo0@000:^ZhClMan6o
LQd004Hb00010000C00000000000000000000?ooooooooooD00002T0000l0000600000`000000000
9@0000`0000=0020:00000`000010000DP00070100010000MOooo`00000000000000090100000000
00020T<0C@1=04T0=`00000000000000000000000000000000000000000000000000000000000000
0000000000000000000003l003l40000E<TH043FT@2<bQP0mG4^Ma/0?P1d0Hl000000501S`1H0ml1
002A023BT@30Ni40000000@000000000G0400@00000P000000010EC960000000S<XH0?Ea;WOD7@H1
o_ooojXh:WNR=2Yg00000000T@0PdY40?R0:?P00000HdY40W<XH08YCMgD008l000000:5DMgFG6m9C
?R0:?R3BT@200MYe000004P0g`400=l1J<XH03hP2Sj4c1P0071iMA]J/bKnooooXEAgM@DBeWDPdY40
h4FB06@P8@T000X0h4FB0=C:601L>MIeI7H02000000U000030000040001D0000E00006h10020oOoo
L@4008Kmool10000Zj[Q?ag7hKnA7000YS400040001<00000000000000000000oooooooooom@0000
JP0003`0000H000030000000000U0000300000d0080X000030000040001B0000L0400040000ioooo
0000000000000000T040000000000082@`1=04D0F00a030000000000000000000000000000000000
000000000000000000000000000000000000000000000000?`00?`@0001DbAP0@=JA08c:603eLBig
6`0n07@1S`000000D06?05P3g`4009408=:A0<1kT@00000010000000001L0@010000020000000041
E<TH0000002<bQP0mG4^Mm@M1P7nooooZSPZMj8d:WL00000002A023BT@0n80Xo000001SBT@2LbQP0
RU=gM@00S`000000XEAgMILKdU<n80Xo8=:A0801fWD00000B03O0@00g`5XbQP0?R0:?hC<6000L7Ue
6eZc9_kooonQE7Me1A;FMB3BT@3PAI80I20Q2@002P3PAI80e<XH05`ieWETMP08000002D0000<0000
0@0005@0001D0000O@4006omoon20@00U?goo`40002[Z^4o7LOQ_kXM002l<P000@0004`000000000
00000000003ooooooooooe00001Y0000I00001P0000<0000000002D0000<00003@00P2P0000<0000
0@000580001`0@000@0003Woool0000000000000002@0@00000000000P9304d0DP0a030000000000
000000000000000000000000000000000000000000000000000000000000000000000000000o000o
100005C96010eY40S<XH0?Ea;WLK03h0M06?0000001@0Hl0F0?O0@00T@0PdY40`7^A000000040000
000005`100400000800000000@5DbAP0000008c:603eLBige1d60OkooonZ>2YgXS@ZM`0000000940
8=:A03hP2T0000006=:A09c:602:DgMe002?0000002QE7MeUa_BDchP2T0PdY40P07JM@0000180=l1
003O0FS:600n80Y0Q<`H001`NGDKF[<Vo_oooj5DMgD54]Ie8=:A0>15TP1T8249000:0>15TP3DbQP0
G3WFMFAf00P000009@0000`000010000E00005@000240@00N_gooh`10024oOoo0@000:^ZhClMan6o
AQh00=ha00010000C00000000000000000000?ooooooooooD00002/0002P0000600000`000000000
9@0000`0000=0020:00000`000010000DP00070100010000>Oooo`00000000000000090100000000
00020T<0C@1=04T0<@0`000000000000000000000000000000000000000000000000000000000000
0000000000000000000003l003l40000E<TH043FT@2<bQP0mG4^Ma/0?P1d0Hl000000501S`1H0ml1
002A023BT@30Ni40000000@000000000G0400@00000P000000010EC960000000S<XH0?Ea;WOD7@H1
o_ooojXh:WNR=2Yg00000000T@0PdY40?R0:@@00000HdY40W<XH08YCMgD008l000000:5DMgFG6m9C
?R0:@B3BT@200MYe000004P0g`400=l1J<XH03hP2T64c1P0071iMA]J/bKnooooXEAgM@DBeWDPdY40
h4FB06@P8@T000X0h4FB0=C:601L>MIeI7H02000000U000030000040001D0000E00008d1001joOoo
T`4008Cmool10000Zj[Q?ag7hKl=7`00gS400040001<00000000000000000000oooooooooom@0000
AP0007P0000H000030000000000U0000300000d0080X000030000040001B0000L0400040001eoooo
0000000000000000T040000000000082@`1=0580=`00000000000000000000000000000000000000
000000000000000000000000000000000000000000000000?`00?`@0001DbAP0@=JA08c:603eLBig
6`0n07@1S`000000D06?05P3g`4009408=:A0<1kT@00000010000000001L0@010000020000000041
E<TH0000002<bQP0mG4^Mm@M1P7nooooZSPZMj8d:WL00000002A023BT@0n80Y2000001SBT@2LbQP0
RU=gM@00S`000000XEAgMILKdU<n80Y28=:A0801fWD00000B03O0@00g`5XbQP0?R0:@XC<6000L7Ue
6eZc9_kooonQE7Me1A;FMB3BT@3PAI80I20Q2@002P3PAI80e<XH05`ieWETMP08000002D0000<0000
0@0005@0001D0000U@4007SmoonH0@00O_goo`40002[Z^4o7LOQ_jTO0016<P000@0004`000000000
00000000003ooooooooooe00000X0000?00001P0000<0000000002D0000<00003@00P2P0000<0000
0@000580001`0@000@0007Goool0000000000000002@0@00000000000P9304d0C@1903L000000000
000000000000000000000000000000000000000000000000000000000000000000000000000o000o
100005C96010eY40S<XH0?Ea;WLK03h0M06?0000001@0Hl0F0?O0@00T@0PdY40`7^A000000040000
000005`100400000800000000@5DbAP0000008c:603eLBige1d60OkooonZ>2YgXS@ZM`0000000940
8=:A03hP2T<000006=:A09c:602:DgMe002?0000002QE7MeUa_BDchP2T<PdY40P07JM@0000180=l1
003O0FS:600n80Y3Q<`H001`NGDKF[<Vo_oooj5DMgD54]Ie8=:A0>15TP1T8249000:0>15TP3DbQP0
G3WFMFAf00P000009@0000`000010000E00005@0002H0@00N?gooid1001noOoo0@000:^ZhClMan6o
ial004Hb00010000C00000000000000000000?ooooooooooD00006h0001T0000600000`000000000
9@0000`0000=0020:00000`000010000DP00070100010000MOooo`00000000000000090100000000
00020T<0C@1B03L00000000000000000000000000000000000000000000000000000000000000000
0000000000000000000003l003l40000E<TH043FT@2<bQP0mG4^Ma/0?P1d0Hl000000501S`1H0ml1
002A023BT@30Ni40000000@000000000G0400@00000P000000010EC960000000S<XH0?Ea;WOD7@H1
o_ooojXh:WNR=2Yg00000000T@0PdY40?R0:A000000HdY40W<XH08YCMgD008l000000:5DMgFG6m9C
?R0:A23BT@200MYe000004P0g`400=l1J<XH03hP2TB4c1P0071iMA]J/bKnooooXEAgM@DBeWDPdY40
h4FB06@P8@T000X0h4FB0=C:601L>MIeI7H02000000U000030000040001D0000E00009d1001hoOoo
X04007kmool10000Zj[Q?ag7hKm98000AS800040001<00000000000000000000oooooooooom@0000
:@0003`0000H000030000000000U0000300000d0080X000030000040001B0000L0400040001eoooo
0000000000000000T040000000000082@`1=04d0B@0g000000000000000000000000000000000000
000000000000000000000000000000000000000000000000?`00?`@0001DbAP0@=JA08c:603eLBig
6`0n07@1S`000000D06?05P3g`4009408=:A0<1kT@00000010000000001L0@010000020000000041
E<TH0000002<bQP0mG4^Mm@M1P7nooooZSPZMj8d:WL00000002A023BT@0n80Y5000001SBT@2LbQP0
RU=gM@00S`000000XEAgMILKdU<n80Y58=:A0801fWD00000B03O0@00g`5XbQP0?R0:AHC<6000L7Ue
6eZc9_kooonQE7Me1A;FMB3BT@3PAI80I20Q2@002P3PAI80e<XH05`ieWETMP08000002D0000<0000
0@0005@0001D0000U040083moonG0@00Q_goo`40002[Z^4o7LOQ_hdO002V<@000@0004`000000000
00000000003ooooooooooe00001Z0000?00002D0000<00003@00P2P0000<00000@0000h0000D0000
00000100000D0000240122@0000H00000Q30f`400003000000000000000000006d000400000d0000
0@0000800039P453hB<Ta<e0H4=[W0120`000<V0@D?Q8bC4bn3@@n4S9<C9P4536aXLa24000080000
HP0000`0000100008@0000P0000Q0000200007<0000<0000000001`0000800009@0000`000000020
9@0000`0000700209@0000`0000>00206@0000`0003oool0600000`0000000004P0000`000020000
4`0000`000010000500000`0000=00005@0000`0000100005P0000`0000000003@00010000000000
000003X0000<00002P0001/0000@000000000000000S0000800009YX9D400000000004_i:44Y3_[4
aZkHAB@0000T0000VVPU@@0000000000BoTX@BT>n/C6[]Q5100007<0000<0000000000d0000@0000
00000000001B0000L0400080000@00001`00000000000000_080000000070P8RD`1i07<0M01U06d0
000D0:3hooob0@00000003bm@P:0n?oo201HO__fool000000000022m@P:0n?ooool00000E0XHT7P0
0000P5c;=@3;c4`mT<`e0;SMPPLQ@kig1R0QVb80RP4H00000000062F2PH80000cjTT@@00aceHPo46
00000<3Lk0J/b3D00000000000000000ooooob3<=@1<c3D0?=Le08DI`WNeLfH1o_ooohcS_GObh;eg
003c23Sl0002000000000200001lc3D0X<`e0>]HkgH007P0200D02IJkgHAZA=U0000062F2PKooooo
0`0000000020[e/:001h0>3_G@Z:MFMX[=<e001`lGH000002bP00>C<=@1>;[mgR:mL2Wl7002@[e`:
f<`e02l`5GMTMP08000002D0000<00000P0004H000280000O00004M4BD<20000`P0006omoonQ0@00
Sogooc00001W06D0KP1U0780H@1d06D0I00P0680N@0P05L0C@1602l0A@1=04H0801R0640H`1[06D0
KP1T0200K`1V0200L01c07@0K`1U06@0J@1d0000J@1^0700M@1d0000000S0000800007=T13l00000
00000=H]1klY3_[4aZkHAB@0000T0000Lf@4?`0000000000eRd7_bT>n/C6[]Q5100002<0000P0000
Lf@4?`0000000000eRd7_bT>n/C6[]Q5900002@0001cI0@o00000000003F;@No:@kja<J^f4D40000
4P0000`0000100005P0000`0000H0000600000`000000000DP00070100030000>Oooo`0000000000
00000901000000001`020T<0C@1=04T0<@0`00000000000000000000000000000000000000000000
0000000000000000000000000000000010000<S:60000000200000L000000000SU<gMLS:600`bQP0
k;1300@000240000b<XH00000000000030000000000100008<XH000000240000X0l0008000030000
b<XH000000000000?<XH07nN@`3l2Wl0P<XH0000@`040000S[E30639c5=XOWl08HQ6000000000000
00000040001<bQP002m:00c;603PW480/2NCDokoool004<0gKE306QnO`000000001o06QnO`38bQP0
0@0003P07P0;0000b<XH06QnO`010`00/7eo0040001POWl0I7H02000000U0000300000<0001D0000
E00000X0001b0000G@000=/000010000Zj[Q?ag7hKl`3`00gS400040001<00000000000000000000
oooooooooom@0000A`000:00000H000030000000001B0000L04000@0000D00002@00000000000000
_080000000070P8RD`1i07<0M01U06d000000000003R0000000006a4NP:0n?oo0000000000000000
00000514NP:0n?oo^YH000005GNgI1Eg1R0QV`00000000000@000?2DoPGHbcD0HF@EM`HP8I/00000
000005@000000000l9Cn1E3<=@3NDAEg1R0QVhSOQ`020000f5aO0e@0000000000@0003P07P0;0000
b<XH06QnO`010`00/7eo0040001POWl0000020000030g>`6[<Pe053<=@0_<1EgD<`e06H`5GLl4U`:
H9H:1RD0000000X0`68008C==@0MnV=X1R0QV`00Q`3`U?h50P000=QLG`>b2VAXH0HIM`00001P1QUg
P04IMe0BG0ZXc3D0;c0EMjS<=@1V<1EgW19L2V2F2PITMP08000002D0000<0000100002P0000<0000
0`000580001`0@000`0007Goool0000000000000002@0@00000000L00P9304d0DP0g000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000o000o
100000800010eY40b<XH0000000K03h0M06?0000001@0Hl0F0?O0@00@`0PdY40`7^A000000040000
000005`100400000800000000@5DbAP0S><YMhc:603eLBige1d60OkooonZ>2YgXS@ZM`0000000940
8=:A03hP2Q/000006=:A09c:602:DgMe002?0000002QE7MeUa_BDchP2Q/PdY40P07JM@26O`180=l1
003O0FS:600n80XKQ<`H001`NGDKF[<Vo_oooj5DMgD54]Ie8=:A0>15TP1T8249000:0>15TP3DbQP0
G3WFMFAf00P000009@0000`000030000E00005@0001K0000D`0007X0002L00000@000:^ZhClMan6o
c@l004Hb00010000C00000000000000000000?ooooooooooD00002P0000l0000600000`000000000
9@0000`000040000:00000`000030000DP00070100030000MOooo`00000000000000090100000000
1`020T<0C@1=04T0=`00000000000000000000000000000000000000000000000000000000000000
0000000000000000000003l003l40000E<TH043FT@2<bQP0mG4^Ma/0?P1d0Hl000000501S`1H0ml1
002A023BT@30Ni40000000@000000000G0400@00000P000000010EC960000000S<XH0?Ea;WOD7@H1
o_ooojXh:WNR=2Yg00000000T@0PdY40?R0:7000000HdY40W<XH08YCMgD008l000000:5DMgFG6m9C
?R0:723BT@200MYe000004P0g`400=l1J<XH03hP2Qb4c1P0071iMA]J/bKnooooXEAgM@DBeWDPdY40
h4FB06@P8@T000X0h4FB0=C:601L>MIeI7H02000000U0000300000<0001D0000E00007`0001C0000
/00009`000010000Zj[Q?ag7hKl<4000AS800040001<00000000000000000000oooooooooom@0000
KP0006@0000H000030000000000U0000300000@0000X0000300000<0001B0000L04000<0001eoooo
0000000000000000T040000000070082@`1=0580=`00000000000000000000000000000000000000
000000000000000000000000000000000000000000000000?`00?`@0001DbAP0@=JA08c:603eLBig
6`0n07@1S`000000D06?05P3g`4009408=:A0<1kT@00000010000000001L0@010000020000000041
E<TH0000002<bQP0mG4^Mm@M1P7nooooZSPZMj8d:WL00000002A023BT@0n80XM000001SBT@2LbQP0
RU=gM@00S`000000XEAgMILKdU<n80XM8=:A0801fWD00000B03O0@00g`5XbQP0?R0:7HC<6000L7Ue
6eZc9_kooonQE7Me1A;FMB3BT@3PAI80I20Q2@002P3PAI80e<XH05`ieWETMP08000002D0000<0000
0`0005@0001D0000[`0005<0003>0000W0000040002[Z^4o7LOQ_fh@0016<P000@0004`000000000
00000000003ooooooooooe00000Y0000?00001P0000<0000000002D0000<0000100002P0000<0000
0`000580001`0@000`0007Goool0000000000000002@0@00000000L00P9304d0C@1903L000000000
000000000000000000000000000000000000000000000000000000000000000000000000000o000o
100005C96010eY40S<XH0?Ea;WLK03h0M06?0000001@0Hl0F0?O0@00T@0PdY40`7^A000000040000
000005`100400000800000000@5DbAP0000008c:603eLBige1d60OkooonZ>2YgXS@ZM`0000000940
8=:A03hP2Qh000006=:A09c:602:DgMe002?0000002QE7MeUa_BDchP2QhPdY40P07JM@0000180=l1
003O0FS:600n80XNQ<`H001`NGDKF[<Vo_oooj5DMgD54]Ie8=:A0>15TP1T8249000:0>15TP3DbQP0
G3WFMFAf00P000009@0000`000030000E00005@0001K0000Y`0007X0003`00000@000:^ZhClMan6o
c@l00:Ha00010000C00000000000000000000?ooooooooooD00006X0000l0000600000`000000000
9@0000`000040000:00000`000030000DP00070100030000>Oooo`00000000000000090100000000
1`020T<0C@1C05T0<@0`04l0DP1904L0000000000000000000000000000000000000000000000000
0000000000000000000003l003l40000E<TH043FT@2<bQP0mG4^Ma/0?P1d0Hl000000501S`1H0ml1
002A023BT@30Ni40000000@000000000G0400@00000P000000010EC960000000S<XH0?Ea;WOD7@H1
o_ooojXh:WNR=2Yg00000000T@0PdY40?R0:7`00000HdY40W<XH08YCMgD008l000000:5DMgFG6m9C
?R0:7b3BT@200MYe000004P0g`400=l1J<XH03hP2Qn4c1P0071iMA]J/bKnooooXEAgM@DBeWDPdY40
h4FB06@P8@T000X0h4FB0=C:601L>MIeI7H02000000U0000300000<0001D0000E0000?00001_0000
@`4002D100010000Zj[Q?ag7hKo/4000gS400040001<00000000000000000000oooooooooom@0000
]0000:00000H000030000000000U0000300000@0000X0000300000<0001B0000L04000<0000ioooo
0000000000000000T040000000070082@`1=04d0B@0a030000000000000000000000000000000000
000000000000000000000000000000000000000000000000?`00?`@0001DbAP0@=JA08c:603eLBig
6`0n07@1S`000000D06?05P3g`4009408=:A0<1kT@00000010000000001L0@010000020000000041
E<TH0000002<bQP0mG4^Mm@M1P7nooooZSPZMj8d:WL00000002A023BT@0n80XP000001SBT@2LbQP0
RU=gM@00S`000000XEAgMILKdU<n80XP8=:A0801fWD00000B03O0@00g`5XbQP0?R0:88C<6000L7Ue
6eZc9_kooonQE7Me1A;FMB3BT@3PAI80I20Q2@002P3PAI80e<XH05`ieWETMP08000002D0000<0000
0`0005@0001D0000G@400780002[0@00f`000040002[Z^4o7LOQ_klA003N<@000@0004`000000000
00000000003ooooooooooe00001E0000S00001P0000<0000000002D0000<0000100002P0000<0000
0`000580001`0@000`0007Goool0000000000000002@0@00000000L00P9304d0DP0g000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000o000o
100005C96010eY40S<XH0?Ea;WLK03h0M06?0000001@0Hl0F0?O0@00T@0PdY40`7^A000000040000
000005`100400000800000000@5DbAP0000008c:603eLBige1d60OkooonZ>2YgXS@ZM`0000000940
8=:A03hP2R4000006=:A09c:602:DgMe002?0000002QE7MeUa_BDchP2R4PdY40P07JM@0000180=l1
003O0FS:600n80XQQ<`H001`NGDKF[<Vo_oooj5DMgD54]Ie8=:A0>15TP1T8249000:0>15TP3DbQP0
G3WFMFAf00P000009@0000`000030000E00005@0002^0@00D`000<d1002L00000@000:^ZhClMan6o
G18004Hb00010000C00000000000000000000?ooooooooooD00002P0000l0000600000`000000000
9@0000`000040000:00000`000030000DP00070100030000MOooo`00000000000000090100000000
1`020T<0C@1=04T0=`00000000000000000000000000000000000000000000000000000000000000
0000000000000000000003l003l40000E<TH043FT@2<bQP0mG4^Ma/0?P1d0Hl000000501S`1H0ml1
002A023BT@30Ni40000000@000000000G0400@00000P000000010EC960000000S<XH0?Ea;WOD7@H1
o_ooojXh:WNR=2Yg00000000T@0PdY40?R0:8P00000HdY40W<XH08YCMgD008l000000:5DMgFG6m9C
?R0:8R3BT@200MYe000004P0g`400=l1J<XH03hP2R:4c1P0071iMA]J/bKnooooXEAgM@DBeWDPdY40
h4FB06@P8@T000X0h4FB0=C:601L>MIeI7H02000000U0000300000<0001D0000E0000<l1001C0000
0`8009`000010000Zj[Q?ag7hKnK4P00AS800040001<00000000000000000000oooooooooom@0000
KP0006@0000H000030000000000U0000300000@0000X0000300000<0001B0000L04000<0001eoooo
0000000000000000T040000000070082@`1=05<0F@0g000000000000000000000000000000000000
000000000000000000000000000000000000000000000000?`00?`@0001DbAP0@=JA08c:603eLBig
6`0n07@1S`000000D06?05P3g`4009408=:A0<1kT@00000010000000001L0@010000020000000041
E<TH0000002<bQP0mG4^Mm@M1P7nooooZSPZMj8d:WL00000002A023BT@0n80XS000001SBT@2LbQP0
RU=gM@00S`000000XEAgMILKdU<n80XS8=:A0801fWD00000B03O0@00g`5XbQP0?R0:8hC<6000L7Ue
6eZc9_kooonQE7Me1A;FMB3BT@3PAI80I20Q2@002P3PAI80e<XH05`ieWETMP08000002D0000<0000
0`0005@0001D00000@80050000100P00c`000040002[Z^4o7LOQ_odB0016<P000@0004`000000000
00000000003ooooooooooe00002Q0000N00001P0000<0000000002D0000<0000100002P0000<0000
0`000580001`0@000`0007Goool0000000000000002@0@00000000L00P9304d0DP0g000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000o000o
100005C96010eY40S<XH0?Ea;WLK03h0M06?0000001@0Hl0F0?O0@00T@0PdY40`7^A000000040000
000005`100400000800000000@5DbAP0000008c:603eLBige1d60OkooonZ>2YgXS@ZM`0000000940
8=:A03hP2R@000006=:A09c:602:DgMe002?0000002QE7MeUa_BDchP2R@PdY40P07JM@0000180=l1
003O0FS:600n80XTQ<`H001`NGDKF[<Vo_oooj5DMgD54]Ie8=:A0>15TP1T8249000:0>15TP3DbQP0
G3WFMFAf00P000009@0000`000030000E00005@000120P00D`0006`2002L00000@000:^ZhClMan6o
NA<004Hb00010000C00000000000000000000?ooooooooooD0000340001@0000600000`000000000
E00005@0001[0P00D`0008X2002L00000@000:^ZhClMan6obA<004Hb00010000C000000000000000
00000?ooooooooooD00002T0000l0000600000`0000000009@0000`000040000:00000`000030000
DP00070100030000MOooo`000000000000000901000000001`020T<0C@1=04T0=`00000000000000
0000000000000000000000000000000000000000000000000000000000000000000003l003l40000
E<TH043FT@2<bQP0mG4^Ma/0?P1d0Hl000000501S`1H0ml1002A023BT@30Ni40000000@000000000
G0400@00000P000000010EC960000000S<XH0?Ea;WOD7@H1o_ooojXh:WNR=2Yg00000000T@0PdY40
?R0:9@00000HdY40W<XH08YCMgD008l000000:5DMgFG6m9C?R0:9B3BT@200MYe000004P0g`400=l1
J<XH03hP2RF4c1P0071iMA]J/bKnooooXEAgM@DBeWDPdY40h4FB06@P8@T000X0h4FB0=C:601L>MIe
I7H02000000U0000300000<0001D0000E0000:<1002W0000`P400?0000010000Zj[Q?ag7hKm74P00
YS400040001<00000000000000000000oooooooooom@0000JP0003`0000H000030000000000U0000
300000@0000X0000300000<0001B0000L04000<0000ioooo0000000000000000T040000000070082
@`1=05<0F@0a0300C`1B04T0A`000000000000000000000000000000000000000000000000000000
0000000000000000?`00?`@0001DbAP0@=JA08c:603eLBig6`0n07@1S`000000D06?05P3g`400940
8=:A0<1kT@00000010000000001L0@010000020000000041E<TH0000002<bQP0mG4^Mm@M1P7noooo
ZSPZMj8d:WL00000002A023BT@0n80XV000001SBT@2LbQP0RU=gM@00S`000000XEAgMILKdU<n80XV
8=:A0801fWD00000B03O0@00g`5XbQP0?R0:9XC<6000L7Ue6eZc9_kooonQE7Me1A;FMB3BT@3PAI80
I20Q2@002P3PAI80e<XH05`ieWETMP08000002D0000<00000`0005@0001D0000Z08006l0003k0P00
9@400040002[Z^4o7LOQ_chD003N<@000@0004`00000000000000000003ooooooooooe00002Q0000
X00001P0000<0000000002D0000<0000100002P0000<00000`000580001`0@000`0007Goool00000
00000000002@0@00000000L00P9304d0C@1903L00000000000000000000000000000000000000000
0000000000000000000000000000000000000000000o000o100005C96010eY40S<XH0?Ea;WLK03h0
M06?0000001@0Hl0F0?O0@00T@0PdY40`7^A000000040000000005`100400000800000000@5DbAP0
000008c:603eLBige1d60OkooonZ>2YgXS@ZM`00000009408=:A03hP2RL000006=:A09c:602:DgMe
002?0000002QE7MeUa_BDchP2RLPdY40P07JM@0000180=l1003O0FS:600n80XWQ<`H001`NGDKF[<V
o_oooj5DMgD54]Ie8=:A0>15TP1T8249000:0>15TP3DbQP0G3WFMFAf00P000009@0000`000030000
E00005@0000I0`001P0004d3001?00000@000:^ZhClMan6o6AD00=Lb00010000C000000000000000
00000?ooooooooooD00006h0001T0000600000`0000000009@0000`000040000:00000`000030000
DP00070100030000MOooo`000000000000000901000000001`020T<0C@1C05T0=`00000000000000
0000000000000000000000000000000000000000000000000000000000000000000003l003l40000
E<TH043FT@2<bQP0mG4^Ma/0?P1d0Hl000000501S`1H0ml1002A023BT@30Ni40000000@000000000
G0400@00000P000000010EC960000000S<XH0?Ea;WOD7@H1o_ooojXh:WNR=2Yg00000000T@0PdY40
?R0::000000HdY40W<XH08YCMgD008l000000:5DMgFG6m9C?R0::23BT@200MYe000004P0g`400=l1
J<XH03hP2RR4c1P0071iMA]J/bKnooooXEAgM@DBeWDPdY40h4FB06@P8@T000X0h4FB0=C:601L>MIe
I7H02000000U0000300000<0001D0000E00004`300030000R`<0088000010000Zj[Q?ag7hKml5@00
ec800040001<00000000000000000000oooooooooom@0000X@0007P0000H000030000000000U0000
300000@0000X0000300000<0001B0000L04000<0001eoooo0000000000000000T040000000070082
@`1=0580=`0000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000?`00?`@0001DbAP0@=JA08c:603eLBig6`0n07@1S`000000D06?05P3g`400940
8=:A0<1kT@00000010000000001L0@010000020000000041E<TH0000002<bQP0mG4^Mm@M1P7noooo
ZSPZMj8d:WL00000002A023BT@0n80XY000001SBT@2LbQP0RU=gM@00S`000000XEAgMILKdU<n80XY
8=:A0801fWD00000B03O0@00g`5XbQP0?R0::HC<6000L7Ue6eZc9_kooonQE7Me1A;FMB3BT@3PAI80
I20Q2@002P3PAI80e<XH05`ieWETMP08000002D0000<00000`0005@0001D0000S0<000H0002f0`00
C`000040002[Z^4o7LOQ_oPE003G<P000@0004`00000000000000000003ooooooooooe00000b0000
D00001P0000<0000000002D0000<0000100002P0000<00000`000580001`0@000`0003Woool00000
00000000002@0@00000000L00P9304d0A@1H0340<000000000000000000000000000000000000000
0000000000000000000000000000000000000000000o000o100005C96010eY40S<XH0?Ea;WLK03h0
M06?0000001@0Hl0F0?O0@00T@0PdY40`7^A000000040000000005`100400000800000000@5DbAP0
000008c:603eLBige1d60OkooonZ>2YgXS@ZM`00000009408=:A03hP2RX000006=:A09c:602:DgMe
002?0000002QE7MeUa_BDchP2RXPdY40P07JM@0000180=l1003O0FS:600n80XZQ<`H001`NGDKF[<V
o_oooj5DMgD54]Ie8=:A0>15TP1T8249000:0>15TP3DbQP0G3WFMFAf00P000009@0000`000030000
E00005@0000L0`002`000:d3002C0@000@000:^ZhClMan6o81D009/b00010000C000000000000000
00000?ooooooooooD00005P0000H0@00600000`0000000009@0000`000040000:00000`000030000
DP00070100030000MOooo`000000000000000901000000001`020T<0C@1=04T0=`00000000000000
0000000000000000000000000000000000000000000000000000000000000000000003l003l40000
E<TH043FT@2<bQP0mG4^Ma/0?P1d0Hl000000501S`1H0ml1002A023BT@30Ni40000000@000000000
G0400@00000P000000010EC960000000S<XH0?Ea;WOD7@H1o_ooojXh:WNR=2Yg00000000T@0PdY40
?R0::`00000HdY40W<XH08YCMgD008l000000:5DMgFG6m9C?R0::b3BT@200MYe000004P0g`400=l1
J<XH03hP2R^4c1P0071iMA]J/bKnooooXEAgM@DBeWDPdY40h4FB06@P8@T000X0h4FB0=C:601L>MIe
I7H02000000U0000300000<0001D0000E00000h300050@00E`<004h100010000Zj[Q?ag7hKl55@00
mC000040001<00000000000000000000oooooooooom@0000K@0008`0000H000030000000000U0000
300000@0000X0000300000<0001B0000L04000<0001eoooo0000000000000000T040000000070082
@`1=0580=`0000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000?`00?`@0001DbAP0@=JA08c:603eLBig6`0n07@1S`000000D06?05P3g`400940
8=:A0<1kT@00000010000000001L0@010000020000000041E<TH0000002<bQP0mG4^Mm@M1P7noooo
ZSPZMj8d:WL00000002A023BT@0n80X/000001SBT@2LbQP0RU=gM@00S`000000XEAgMILKdU<n80X/
8=:A0801fWD00000B03O0@00g`5XbQP0?R0:;8C<6000L7Ue6eZc9_kooonQE7Me1A;FMB3BT@3PAI80
I20Q2@002P3PAI80e<XH05`ieWETMP08000002D0000<00000`0005@0001D0000E`<000D1002F0`00
CP400040002[Z^4o7LOQ_i8E003e<0000@0004`00000000000000000003ooooooooooe00000m0000
N00001P0000<0000000005@0001D0000U`<000D100310`00CP400040002[Z^4o7LOQ_`dF003e<000
0@0004`00000000000000000003ooooooooooe00000`0000D00001P0000<0000000002D0000<0000
100002P0000<00000`000580001`0@000`0003Woool0000000000000002@0@00000000L00P9304d0
DP0a0300000000000000000000000000000000000000000000000000000000000000000000000000
00000000000o000o100005C96010eY40S<XH0?Ea;WLK03h0M06?0000001@0Hl0F0?O0@00T@0PdY40
`7^A000000040000000005`100400000800000000@5DbAP0000008c:603eLBige1d60OkooonZ>2Yg
XS@ZM`00000009408=:A03hP2Rd000006=:A09c:602:DgMe002?0000002QE7MeUa_BDchP2RdPdY40
P07JM@0000180=l1003O0FS:600n80X]Q<`H001`NGDKF[<Vo_oooj5DMgD54]Ie8=:A0>15TP1T8249
000:0>15TP3DbQP0G3WFMFAf00P000009@0000`000030000E00005@0003U0`00F00001T400310000
0@000:^ZhClMan6oY1H0010b00010000C00000000000000000000?ooooooooooD00007h0001T0000
600000`0000000009@0000`000040000:00000`000030000DP00070100030000>Oooo`0000000000
00000901000000001`020T<0C@1=04T0<@0`00000000000000000000000000000000000000000000
00000000000000000000000000000000000003l003l40000E<TH043FT@2<bQP0mG4^Ma/0?P1d0Hl0
00000501S`1H0ml1002A023BT@30Ni40000000@000000000G0400@00000P000000010EC960000000
S<XH0?Ea;WOD7@H1o_ooojXh:WNR=2Yg00000000T@0PdY40?R0:;P00000HdY40W<XH08YCMgD008l0
00000:5DMgFG6m9C?R0:;R3BT@200MYe000004P0g`400=l1J<XH03hP2Rj4c1P0071iMA]J/bKnoooo
XEAgM@DBeWDPdY40h4FB06@P8@T000X0h4FB0=C:601L>MIeI7H02000000U0000300000<0001D0000
E0000=43001b00006P@00=/000010000Zj[Q?ag7hKmn5P00gS400040001<00000000000000000000
oooooooooom@0000E00007P0000H000030000000000U0000300000@0000X0000300000<0001B0000
L04000<0001eoooo0000000000000000T040000000070082@`1=0580=`0000000000000000000000
0000000000000000000000000000000000000000000000000000000000000000?`00?`@0001DbAP0
@=JA08c:603eLBig6`0n07@1S`000000D06?05P3g`4009408=:A0<1kT@00000010000000001L0@01
0000020000000041E<TH0000002<bQP0mG4^Mm@M1P7nooooZSPZMj8d:WL00000002A023BT@0n80X_
000001SBT@2LbQP0RU=gM@00S`000000XEAgMILKdU<n80X_8=:A0801fWD00000B03O0@00g`5XbQP0
?R0:;hC<6000L7Ue6eZc9_kooonQE7Me1A;FMB3BT@3PAI80I20Q2@002P3PAI80e<XH05`ieWETMP08
000002D0000<00000`0005@0001D000070@005l0000k1000Z0000040002[Z^4o7LOQ_`hG000`<P00
0@0004`00000000000000000003ooooooooooe00000X0000?00001P0000<0000000002D0000<0000
100002P0000<00000`000580001`0@000`0007Goool0000000000000002@0@00000000L00P9304d0
C@1903L0000000000000000000000000000000000000000000000000000000000000000000000000
00000000000o000o100005C96010eY40S<XH0?Ea;WLK03h0M06?0000001@0Hl0F0?O0@00T@0PdY40
`7^A000000040000000005`100400000800000000@5DbAP0000008c:603eLBige1d60OkooonZ>2Yg
XS@ZM`00000009408=:A03hP2S0000006=:A09c:602:DgMe002?0000002QE7MeUa_BDchP2S0PdY40
P07JM@0000180=l1003O0FS:600n80X`Q<`H001`NGDKF[<Vo_oooj5DMgD54]Ie8=:A0>15TP1T8249
000:0>15TP3DbQP0G3WFMFAf00P000009@0000`000030000E00005@0000l1000G`0006P4002X0000
0@000:^ZhClMan6oC1L0030b00010000C00000000000000000000?ooooooooooD0000;00001@0000
600000`0000000009@0000`000040000:00000`000030000DP00070100030000MOooo`0000000000
00000901000000001`020T<0C@1B03L0000000000000000000000000000000000000000000000000
00000000000000000000000000000000000003l003l40000E<TH043FT@2<bQP0mG4^Ma/0?P1d0Hl0
00000501S`1H0ml1002A023BT@30Ni40000000@000000000G0400@00000P000000010EC960000000
S<XH0?Ea;WOD7@H1o_ooojXh:WNR=2Yg00000000T@0PdY40?R0:<@00000HdY40W<XH08YCMgD008l0
00000:5DMgFG6m9C?R0:<B3BT@200MYe000004P0g`400=l1J<XH03hP2S64c1P0071iMA]J/bKnoooo
XEAgM@DBeWDPdY40h4FB06@P8@T000X0h4FB0=C:601L>MIeI7H02000000U0000300000<0001D0000
E00006`4001O0000R`@00:P000010000Zj[Q?ag7hKnX5`00<3800040001<00000000000000000000
oooooooooom@0000:@0003`0000H000030000000000U0000300000@0000X0000300000<0001B0000
L04000<0001eoooo0000000000000000T040000000070082@`1=04d0B@0g00000000000000000000
0000000000000000000000000000000000000000000000000000000000000000?`00?`@0001DbAP0
@=JA08c:603eLBig6`0n07@1S`000000D06?05P3g`4009408=:A0<1kT@00000010000000001L0@01
0000020000000041E<TH0000002<bQP0mG4^Mm@M1P7nooooZSPZMj8d:WL00000002A023BT@0n80Xb
000001SBT@2LbQP0RU=gM@00S`000000XEAgMILKdU<n80Xb8=:A0801fWD00000B03O0@00g`5XbQP0
?R0:<XC<6000L7Ue6eZc9_kooonQE7Me1A;FMB3BT@3PAI80I20Q2@002P3PAI80e<XH05`ieWETMP08
000002D0000<00000`0005@0001D00003@@00:@0001F1000k@000040002[Z^4o7LOQ_o8F002/<@00
0@0004`00000000000000000003ooooooooooe00001]0<3KS00001P0000<0000000005@0001D0000
E`@00:@0001/1000k@000040002[Z^4o7LOQ_h0G002/<@000@0004`00000000000000000003ooooo
oooooe00000k02`j:00001P0000<0000000005@0001D0000K`@00:@0002S1000k@000040002[Z^4o
7LOQ_jhG002/<@000@0004`00000000000000000003ooooooooooe00001^00<0I00001P0000<0000
000002D0000<0000100002P0000<00000`000580001`0@000`0003Woool0000000000000002@0@00
000000L00P9304d0A@1H0340<0000000000000000000000000000000000000000000000000000000
000000000000000000000000000o000o100005C96010eY40S<XH0?Ea;WLK03h0M06?0000001@0Hl0
F0?O0@00T@0PdY40`7^A000000040000000005`100400000800000000@5DbAP0000008c:603eLBig
e1d60OkooonZ>2YgXS@ZM`00000009408=:A03hP2S<000006=:A09c:602:DgMe002?0000002QE7Me
Ua_BDchP2S<PdY40P07JM@0000180=l1003O0FS:600n80XcQ<`H001`NGDKF[<Vo_oooj5DMgD54]Ie
8=:A0>15TP1T8249000:0>15TP3DbQP0G3WFMFAf00P000009@0000`000030000E00005@0002h1000
n_ooon`400220@000@000:^ZhClMan6o?1P00;`b00010000C00000000000000000000?oooooooooo
D00006P0001T0000600000`0000000009@0000`000040000:00000`000030000DP00070100030000
>Oooo`000000000000000901000000001`020T<0C@1=04T0<@0`0000000000000000000000000000
000000000000000000000000000000000000000000000000000003l003l40000E<TH043FT@2<bQP0
mG4^Ma/0?P1d0Hl000000501S`1H0ml1002A023BT@30Ni40000000@000000000G0400@00000P0000
00010EC960000000S<XH0?Ea;WOD7@H1o_ooojXh:WNR=2Yg00000000T@0PdY40?R0:=000000HdY40
W<XH08YCMgD008l000000:5DMgFG6m9C?R0:=23BT@200MYe000004P0g`400=l1J<XH03hP2SB4c1P0
071iMA]J/bKnooooXEAgM@DBeWDPdY40h4FB06@P8@T000X0h4FB0=C:601L>MIeI7H02000000U0000
300000<0001D0000E0000>T4001b0000=`D00=/000010000Zj[Q?ag7hKnK6000gS400040001<0000
0000000000000000oooooooooom@0000E@0008`0000H000030000000000U0000300000@0000X0000
300000<0001B0000L04000<0001eoooo0000000000000000T040000000070082@`1=0580=`000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
?`00?`@0001DbAP0@=JA08c:603eLBig6`0n07@1S`000000D06?05P3g`4009408=:A0<1kT@000000
10000000001L0@010000020000000041E<TH0000002<bQP0mG4^Mm@M1P7nooooZSPZMj8d:WL00000
002A023BT@0n80Xe000001SBT@2LbQP0RU=gM@00S`000000XEAgMILKdU<n80Xe8=:A0801fWD00000
B03O0@00g`5XbQP0?R0:=HC<6000L7Ue6eZc9_kooonQE7Me1A;FMB3BT@3PAI80I20Q2@002P3PAI80
e<XH05`ieWETMP08000002D0000<00000`0005@0001D0000>PD005<0001I1@00W0000040002[Z^4o
7LOQ_cPI0016<P000@0004`00000000000000000003ooooooooooe00000X0000?00001P0000<0000
000002D0000<0000100002P0000<00000`000580001`0@000`0007Goool0000000000000002@0@00
000000L00P9304d0C@1903L000000000000000000000000000000000000000000000000000000000
000000000000000000000000000o000o100005C96010eY40S<XH0?Ea;WLK03h0M06?0000001@0Hl0
F0?O0@00T@0PdY40`7^A000000040000000005`100400000800000000@5DbAP0000008c:603eLBig
e1d60OkooonZ>2YgXS@ZM`00000009408=:A03hP2SH000006=:A09c:602:DgMe002?0000002QE7Me
Ua_BDchP2SHPdY40P07JM@0000180=l1003O0FS:600n80XfQ<`H001`NGDKF[<Vo_oooj5DMgD54]Ie
8=:A0>15TP1T8249000:0>15TP3DbQP0G3WFMFAf00P000009@0000`000030000E00005@0001J1@00
D`000:<5002L00000@000:^ZhClMan6oMQT004Hb00010000C00000000000000000000?oooooooooo
D00006d0002<0000600000`0000000009@0000`000040000:00000`000030000DP00070100030000
MOooo`000000000000000901000000001`020T<0C@1B03L000000000000000000000000000000000
000000000000000000000000000000000000000000000000000003l003l40000E<TH043FT@2<bQP0
mG4^Ma/0?P1d0Hl000000501S`1H0ml1002A023BT@30Ni40000000@000000000G0400@00000P0000
00010EC960000000S<XH0?Ea;WOD7@H1o_ooojXh:WNR=2Yg00000000T@0PdY40?R0:=`00000HdY40
W<XH08YCMgD008l000000:5DMgFG6m9C?R0:=b3BT@200MYe000004P0g`400=l1J<XH03hP2SN4c1P0
071iMA]J/bKnooooXEAgM@DBeWDPdY40h4FB06@P8@T000X0h4FB0=C:601L>MIeI7H02000000U0000
300000<0001D0000E0000:@5001C0000h`D009`000010000Zj[Q?ag7hKl46P00AS800040001<0000
0000000000000000oooooooooom@0000:`0007P0000H000030000000001D0000E0000><5001C0000
3@H009`000010000Zj[Q?ag7hKmn6P00AS800040001<00000000000000000000oooooooooom@0000
<@000500000H000030000000001D0000E00000`6001C0000:`H009`000010000Zj[Q?ag7hKo=6P00
AS800040001<00000000000000000000oooooooooom@0000:@0003`0000H000030000000000U0000
300000@0000X0000300000<0001B0000L04000<0001eoooo0000000000000000T040000000070082
@`1=04d0B@0g00000000000000000000000000000000000000000000000000000000000000000000
0000000000000000?`00?`@0001DbAP0@=JA08c:603eLBig6`0n07@1S`000000D06?05P3g`400940
8=:A0<1kT@00000010000000001L0@010000020000000041E<TH0000002<bQP0mG4^Mm@M1P7noooo
ZSPZMj8d:WL00000002A023BT@0n80Xh000001SBT@2LbQP0RU=gM@00S`000000XEAgMILKdU<n80Xh
8=:A0801fWD00000B03O0@00g`5XbQP0?R0:>8C<6000L7Ue6eZc9_kooonQE7Me1A;FMB3BT@3PAI80
I20Q2@002P3PAI80e<XH05`ieWETMP08000002D0000<00000`0005@0001D0000;`D00:L0001>1@00
l0000040002[Z^4o7LOQ_b8I002V<@000@0004`00000000000000000003ooooooooooe00001Z0000
?00001P0000<0000000002D0000<0000100002P0000<00000`000580001`0@000`0003Woool00000
00000000002@0@00000000L00P9304d0D`1I0340<01?0580B@170000000000000000000000000000
0000000000000000000000000000000000000000000o000o100005C96010eY40S<XH0?Ea;WLK03h0
M06?0000001@0Hl0F0?O0@00T@0PdY40`7^A000000040000000005`100400000800000000@5DbAP0
000008c:603eLBige1d60OkooonZ>2YgXS@ZM`00000009408=:A03hP2ST000006=:A09c:602:DgMe
002?0000002QE7MeUa_BDchP2STPdY40P07JM@0000180=l1003O0FS:600n80XiQ<`H001`NGDKF[<V
o_oooj5DMgD54]Ie8=:A0>15TP1T8249000:0>15TP3DbQP0G3WFMFAf00P000009@0000`000030000
E00005@000181P00K`0009/6000U0@000@000:^ZhClMan6o@Q/00=ha00010000C000000000000000
00000?ooooooooooD0000:40002P0000600000`0000000009@0000`000040000:00000`000030000
DP00070100030000>Oooo`000000000000000901000000001`020T<0C@1=04T0<@0`000000000000
0000000000000000000000000000000000000000000000000000000000000000000003l003l40000
E<TH043FT@2<bQP0mG4^Ma/0?P1d0Hl000000501S`1H0ml1002A023BT@30Ni40000000@000000000
G0400@00000P000000010EC960000000S<XH0?Ea;WOD7@H1o_ooojXh:WNR=2Yg00000000T@0PdY40
?R0:>P00000HdY40W<XH08YCMgD008l000000:5DMgFG6m9C?R0:>R3BT@200MYe000004P0g`400=l1
J<XH03hP2SZ4c1P0071iMA]J/bKnooooXEAgM@DBeWDPdY40h4FB06@P8@T000X0h4FB0=C:601L>MIe
I7H02000000U0000300000<0001D0000E0000:l6001b0000o@H00=/000010000Zj[Q?ag7hKl97000
gS400040001<00000000000000000000oooooooooom@0000E@0008`0000H000030000000000U0000
300000@0000X0000300000<0001B0000L04000<0001eoooo0000000000000000T040000000070082
@`1=0580=`0000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000?`00?`@0001DbAP0@=JA08c:603eLBig6`0n07@1S`000000D06?05P3g`400940
8=:A0<1kT@00000010000000001L0@010000020000000041E<TH0000002<bQP0mG4^Mm@M1P7noooo
ZSPZMj8d:WL00000002A023BT@0n80Xk000001SBT@2LbQP0RU=gM@00S`000000XEAgMILKdU<n80Xk
8=:A0801fWD00000B03O0@00g`5XbQP0?R0:>hC<6000L7Ue6eZc9_kooonQE7Me1A;FMB3BT@3PAI80
I20Q2@002P3PAI80e<XH05`ieWETMP08000002D0000<00000`0005@0001D000000L005<0000O1`00
W0000040002[Z^4o7LOQ_jHL0016<P000@0004`00000000000000000003ooooooooooe00000X0000
?00001P0000<0000000002D0000<0000100002P0000<00000`000580001`0@000`0007Goool00000
00000000002@0@00000000L00P9304d0C@1903L00000000000000000000000000000000000000000
0000000000000000000000000000000000000000000o000o100005C96010eY40S<XH0?Ea;WLK03h0
M06?0000001@0Hl0F0?O0@00T@0PdY40`7^A000000040000000005`100400000800000000@5DbAP0
000008c:603eLBige1d60OkooonZ>2YgXS@ZM`00000009408=:A03hP2S`000006=:A09c:602:DgMe
002?0000002QE7MeUa_BDchP2S`PdY40P07JM@0000180=l1003O0FS:600n80XlQ<`H001`NGDKF[<V
o_oooj5DMgD54]Ie8=:A0>15TP1T8249000:0>15TP3DbQP0G3WFMFAf00P000009@0000`000030000
E00005@0000Q1`00D`0006X7002L00000@000:^ZhClMan6oiA`004Hb00010000C000000000000000
00000?ooooooooooD00006d0002<0000600000`0000000009@0000`000040000:00000`000030000
DP00070100030000MOooo`000000000000000901000000001`020T<0C@1B03L00000000000000000
0000000000000000000000000000000000000000000000000000000000000000000003l003l40000
E<TH043FT@2<bQP0mG4^Ma/0?P1d0Hl000000501S`1H0ml1002A023BT@30Ni40000000@000000000
G0400@00000P000000010EC960000000S<XH0?Ea;WOD7@H1o_ooojXh:WNR=2Yg00000000T@0PdY40
?R0:?@00000HdY40W<XH08YCMgD008l000000:5DMgFG6m9C?R0:?B3BT@200MYe000004P0g`400=l1
J<XH03hP2Sf4c1P0071iMA]J/bKnooooXEAgM@DBeWDPdY40h4FB06@P8@T000X0h4FB0=C:601L>MIe
I7H02000000U0000300000<0001D0000E00006X7001C0000R@L009`000010000Zj[Q?ag7hKmb7@00
AS800040001<00000000000000000000oooooooooom@0000:@0003`0000H000030000000000U0000
300000@0000X0000300000<0001B0000L04000<0001eoooo0000000000000000T040000000070082
@`1=04d0B@0g00000000000000000000000000000000000000000000000000000000000000000000
0000000000000000?`00?`@0001DbAP0@=JA08c:603eLBig6`0n07@1S`000000D06?05P3g`400940
8=:A0<1kT@00000010000000001L0@010000020000000041E<TH0000002<bQP0mG4^Mm@M1P7noooo
ZSPZMj8d:WL00000002A023BT@0n80Xn000001SBT@2LbQP0RU=gM@00S`000000XEAgMILKdU<n80Xn
8=:A0801fWD00000B03O0@00g`5XbQP0?R0:?XC<6000L7Ue6eZc9_kooonQE7Me1A;FMB3BT@3PAI80
I20Q2@002P3PAI80e<XH05`ieWETMP08000002D0000<00000`0005@0001D0000mPH00:L0000E1`00
l0000040002[Z^4o7LOQ_i4L002V<@000@0004`00000000000000000003ooooooooooe00001Z0000
?00001P0000<0000000002D0000<0000100002P0000<00000`000580001`0@000`0003Woool00000
00000000002@0@00000000L00P9304d0A@1H0340<000000000000000000000000000000000000000
0000000000000000000000000000000000000000000o000o100005C96010eY40S<XH0?Ea;WLK03h0
M06?0000001@0Hl0F0?O0@00T@0PdY40`7^A000000040000000005`100400000800000000@5DbAP0
000008c:603eLBige1d60OkooonZ>2YgXS@ZM`00000009408=:A03hP2Sl000006=:A09c:602:DgMe
002?0000002QE7MeUa_BDchP2SlPdY40P07JM@0000180=l1003O0FS:600n80XoQ<`H001`NGDKF[<V
o_oooj5DMgD54]Ie8=:A0>15TP1T8249000:0>15TP3DbQP0G3WFMFAf00P000009@0000`000030000
E00005@0002?1`00n_oool<700220@000@000:^ZhClMan6o^Qd00;`b00010000C000000000000000
00000?ooooooooooD00006T0001T0000600000`0000000009@0000`000040000:00000`000030000
DP00070100030000>Oooo`000000000000000901000000001`020T<0C@1B0340<000000000000000
0000000000000000000000000000000000000000000000000000000000000000000003l003l40000
E<TH043FT@2<bQP0mG4^Ma/0?P1d0Hl000000501S`1H0ml1002A023BT@30Ni40000000@000000000
G0400@00000P000000010EC960000000S<XH0?Ea;WOD7@H1o_ooojXh:WNR=2Yg00000000T@0PdY40
?R0:@000000HdY40W<XH08YCMgD008l000000:5DMgFG6m9C?R0:@23BT@200MYe000004P0g`400=l1
J<XH03hP2T24c1P0071iMA]J/bKnooooXEAgM@DBeWDPdY40h4FB06@P8@T000X0h4FB0=C:601L>MIe
I7H02000000U0000300000<0001D0000E0000=P7001b0000:`P00=/000010000Zj[Q?ag7hKm67P00
gS400040001<00000000000000000000oooooooooom@0000:`000:00000H000030000000000U0000
300000@0000X0000300000<0001B0000L04000<0000ioooo0000000000000000T040000000070082
@`1=04d0B@0a03000000000000000000000000000000000000000000000000000000000000000000
0000000000000000?`00?`@0001DbAP0@=JA08c:603eLBig6`0n07@1S`000000D06?05P3g`400940
8=:A0<1kT@00000010000000001L0@010000020000000041E<TH0000002<bQP0mG4^Mm@M1P7noooo
ZSPZMj8d:WL00000002A023BT@0n80Y1000001SBT@2LbQP0RU=gM@00S`000000XEAgMILKdU<n80Y1
8=:A0801fWD00000B03O0@00g`5XbQP0?R0:@HC<6000L7Ue6eZc9_kooonQE7Me1A;FMB3BT@3PAI80
I20Q2@002P3PAI80e<XH05`ieWETMP08000002D0000<00000`0005@0001D0000?PP00780002;2000
f`000040002[Z^4o7LOQ_`dO003N<@000@0004`00000000000000000003ooooooooooe0000160000
N00001P0000<0000000002D0000<0000100002P0000<00000`000580001`0@000`0007Goool00000
00000000002@0@00000000L00P9304d0DP0g00000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000o000o100005C96010eY40S<XH0?Ea;WLK03h0
M06?0000001@0Hl0F0?O0@00T@0PdY40`7^A000000040000000005`100400000800000000@5DbAP0
000008c:603eLBige1d60OkooonZ>2YgXS@ZM`00000009408=:A03hP2T8000006=:A09c:602:DgMe
002?0000002QE7MeUa_BDchP2T8PdY40P07JM@0000180=l1003O0FS:600n80Y2Q<`H001`NGDKF[<V
o_oooj5DMgD54]Ie8=:A0>15TP1T8249000:0>15TP3DbQP0G3WFMFAf00P000009@0000`000030000
E00005@0002?2000D`000:h8002L00000@000:^ZhClMan6oZAl004Hb00010000C000000000000000
00000?ooooooooooD00002P0000l0000600000`0000000009@0000`000040000:00000`000030000
DP00070100030000MOooo`000000000000000901000000001`020T<0C@1=04T0=`00000000000000
0000000000000000000000000000000000000000000000000000000000000000000003l003l40000
E<TH043FT@2<bQP0mG4^Ma/0?P1d0Hl000000501S`1H0ml1002A023BT@30Ni40000000@000000000
G0400@00000P000000010EC960000000S<XH0?Ea;WOD7@H1o_ooojXh:WNR=2Yg00000000T@0PdY40
?R0:@`00000HdY40W<XH08YCMgD008l000000:5DMgFG6m9C?R0:@b3BT@200MYe000004P0g`400=l1
J<XH03hP2T>4c1P0071iMA]J/bKnooooXEAgM@DBeWDPdY40h4FB06@P8@T000X0h4FB0=C:601L>MIe
I7H02000000U0000300000<0001D0000E0000:l8001C0000h`P009`000010000Zj[Q?ag7hKoW7`00
AS800040001<00000000000000000000oooooooooom@0000KP0006@0000H000030000000000U0000
300000@0000X0000300000<0001B0000L04000<0001eoooo0000000000000000T040000000070082
@`1=0580=`0000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000?`00?`@0001DbAP0@=JA08c:603eLBig6`0n07@1S`000000D06?05P3g`400940
8=:A0<1kT@00000010000000001L0@010000020000000041E<TH0000002<bQP0mG4^Mm@M1P7noooo
ZSPZMj8d:WL00000002A023BT@0n80Y4000001SBT@2LbQP0RU=gM@00S`000000XEAgMILKdU<n80Y4
8=:A0801fWD00000B03O0@00g`5XbQP0?R0:A8C<6000L7Ue6eZc9_kooonQE7Me1A;FMB3BT@3PAI80
I20Q2@002P3PAI80e<XH05`ieWETMP08000002D0000<00000`0005@0001D0000hPP005<000012@00
W0000040002[Z^4o7LOQ_dTP0016<P000@0004`00000000000000000003ooooooooooe00000Y0000
?00001P0000<0000000002D0000<0000100002P0000<00000`000580001`0@000`0007Goool00000
00000000002@0@00000000L00P9304d0C@1903L00000000000000000000000000000000000000000
0000000000000000000000000000000000000000000o000o100005C96010eY40S<XH0?Ea;WLK03h0
M06?0000001@0Hl0F0?O0@00T@0PdY40`7^A000000040000000005`100400000800000000@5DbAP0
000008c:603eLBige1d60OkooonZ>2YgXS@ZM`00000009408=:A03hP2TD000006=:A09c:602:DgMe
002?0000002QE7MeUa_BDchP2TDPdY40P07JM@0000180=l1003O0FS:600n80Y5Q<`H001`NGDKF[<V
o_oooj5DMgD54]Ie8=:A0>15TP1T8249000:0>15TP3DbQP0G3WFMFAf00P000009@0000`000030000
E00005@000212000Y`000:08003`00000@000:^ZhClMan6oSAl00:Ha00010000C000000000000000
00000?ooooooooooD00006X0000l00009@0000`000040000:00000`000030000AP0001@000080000
AdA9@`<0000R000030000?oooolR000030000?oooolU0000300000d0080X000030000080000X0000
300000@0000R000030000?oooom60000`0400;@10015CDH[;40002@0000H00000020?`0000000000
0020?`0008000020:T0002@0000H00003[hT@@0000000000DcLT@E8<nLC[U=95940000`000000000
:T0002@0000H0000/08/>P0000000000/08/>P008jT005VY:d0000`0000000007T0600`000000000
8D0500`000000000240211P0000<00000Q30f`000003000@=40200`0000000007T0900`000000000
:T0002@0000H0000/08/>P0000000000/08/>P008jT005VY8D0700`000000000:T0002@0000H0000
/08/>P0000000000/08/>P008jT005VY:d0000`000000000:d0000`0000000007T0600`000000000
8D0500`000000000240311P0000<00000Q30f`000003000@=40300`0000000007T0900`000000000
:T0002@0000H00000020?`00000000000020?`00000000008D0700`000000000C00006@000000000
000000@900190@000000000000052@00BP4002T0ZP00000000000000P3l0000000000000P3l00000
0000000000000000000000000000000000000280000<0000ooooodH0000L0000400004E=AR/2@000
30000000000>000050000000000@00005000
\>"], "Graphics",
  GeneratedCell->False,
  CellAutoOverwrite->False,
  ImageSize->{310.22105263157886`, 43.740495490352785`},
  ImageMargins->{{27.599999999999998`, 0.}, {0., 26.046854663774422`}}],
 "\n or, in matrix-vector form, by Eq. (11):\n ",
 Cell[GraphicsData["Metafile", "\<\
CF5dJ6E]HGAYHf4PEfU^I6mgLb15CDHPAVmbKF5d0@0007b40@0006`0003ooooo^_ooolh800190@00
00000000000>9@00TP<00215CDH00040Q7`00?40000500000000000000000000HA<006PK003B0000
:@400000000000000000050d0`0XR0@0AP0002`0000P0000ADe6:`500@0L00004000008@`=/00000
F08005P200160000O04007010015CDH[7T0500`0000000007d0300`000000000<402010000040000
0020?b501`0<000000000290100<0000000002Y0000T000060000000P3l0000000000000P3l00000
000002]0000<0000000001i01P0<0000000002501@0<0000000001i02@0<0000000002Y0000T0000
60000000P3l0000000000000P3l00000000002501`0<0000000002Y0000T000060000;02;3X00000
00000;02;3X0P;k3080maB]0000<0000000002Y0000T000060000;02;3X0000000000;02;3X0P;k3
080maB]0000<0000000002Y0000T000060000;02;3X0000000000;02;3X00;jW000nZ@Y0080T0000
60000>7ohOl1000000000000002PRe1:P7ZQB24000080000HP0000`000010000900002@00000000n
000000000000000n00000000000200009`0001P00001000000000>7oh@0000009@0000`000010000
9@0000`000080020EP000300003ooooooooool88003I00001@000?coo?olol@634K41Pa6o?olooco
9@0000`0000700209@0000`000000020900002@00000001100000000000000110000000000020000
AP000>Pi003L>@00ADe6:b]0000<0000000001i01P0<0000000002501@0<0000000001i02@0<0000
000002Y0000T000060000;02;3X0000000000;02;3X00;jW000nZB501`0<0000000002]0000<0000
000002Y0000T000060000;HN9D40000000000>mH944dOog4Ra7CABA0100<0000000000Q000GH>000
c3P0008@`=/200000`000;`h00010000c0000<H0001XoOooWP4008gmoolA6`00HjGoomXh000YZ?oo
84E=AP000@2l>000_0000080000`0000K000000000201`00>0@00:D2001m0@000000000000000000
eED:04S@1@1W06D0KP1U0780H@1d06D0I00P0680N@0P05L0C@1602l0A@1=04H0801R0640H`1[06D0
KP1T0200K`1V0200L01c07@0K`1U06@0J@1d0000J@1^0700M@1d0000000A0000300000H0000:0000
40000000000000004P0000`0000100005P0000`0000H0000600000`000000000DP00070100010000
>Oooo`0000000000000009010000000000020T<0C@1=04T0<@0`0000000000000000000000000000
00000000000000000000000000000000000000000000000010000<S:60000000200000L000000000
SU<gMLS:600`bQP0k;1300@000240000b<XH00000000000030000000000100008<XH000000240000
X0l0008000030000b<XH000000000000?<XH07nN@`3l2]`1P<XH0000@`040000S[E30=bV8BiXO]`1
8HQ600000000000000000040001<bQP002m:00c;603PW48034Qn;_koool004<0gKE306Qng0400000
003L0FQng078bQP00@0003P07P0;0000b<XH06Qng0410`00/7gL0@40001PO]`1I7H02000000U0000
30000040001D0000E0000<H0001coOoocP0007gmool10000Zj[Q?ag7hKma3`00JS800040001<0000
0000000000000000oooooooooom@0000@@000:00000H000030000000001D0000E0000<l0001coOoo
e`0007gmool10000Zj[Q?ag7hKlX4000JS800040001<00000000000000000000oooooooooom@0000
E@0008`0000H000030000000000U0000300000d0080X000030000040001B0000L0400040001eoooo
0000000000000000T040000000000082@`1=0580=`00000000000000000000000000000000000000
000000000000000000000000000000000000000000000000?`00?`@000020000@=IV0<S:60000000
6`0n07@1I0000000D05T05P3g@4004<08=9V0<1kIP00000010000000001L0@010000020000000041
E<TH0000002<bQP0mG4^Mo3_F`7nooooZSPZMj8d:WL00000001V023BIP3@8@X@000001SBIP2LbQP0
RU=gM@00I0000000XEAgMJJI8bk@8@X@8=9V0801fWD0Q]`1B03M0@00g@5XbQP0d24:48C<6000L7Ue
:]Q2FokooonQE7Me1A;FMB3BIP3PAFL0ca8QQ@002P3PAFL0e<XH05`ieWETMP08000002D0000<0000
0@0005@0001D0000e`0007;moooJ0000N?goo`40002[Z^4o7LOQ_lH@002l<P000@0004`000000000
00000000003ooooooooooe00000X0000?00001P0000<0000000002D0000<00003@00P2P0000<0000
0@000580001`0@000@0007Goool0000000000000002@0@00000000000P9304d0C@1903L000000000
000000000000000000000000000000000000000000000000000000000000000000000000000o000o
100005C96010eVH0S<XH0?Ea;WLK03h0M05T0000001@0F@0F0?M0@00IP0PdVH0`7]V000000040000
000005`100400000800000000@5DbAP0000008c:603eLBigl>mK0OkooonZ>2YgXS@ZM`00000006H0
8=9V0=0Q2Q4000006=9V09c:602:DgMe001T0000002QE7MeYYTS;]0Q2Q4PdVH0P07JM@0000180=d1
003M0FS:603@8@XAQ<`H001`NGDZf49Ko_oooj5DMgD54]Ie8=9V0>15I`3?4R65000:0>15I`3DbQP0
G3WFMFAf00P000009@0000`000010000E00005@0003J0000L_goon40001hoOoo0@000:^ZhClMan6o
11400;`b00010000C00000000000000000000?ooooooooooD00006d0002<0000600000`000000000
9@0000`0000=0020:00000`000010000DP00070100010000MOooo`00000000000000090100000000
00020T<0C@1B03L00000000000000000000000000000000000000000000000000000000000000000
0000000000000000000003l003l40000E<TH043FIP2<bQP0mG4^Ma/0?P1d0F@000000501I01H0md1
001V023BIP30NfH0000000@000000000G0400@00000P000000010EC960000000S<XH0?Ea;WO`ke/1
o_ooojXh:WNR=2Yg00000000IP0PdVH0d24:4P00000HdVH0W<XH08YCMgD006@000000:5DMgFVVB<^
d24:4R3BIP200MYe000004P0g@400=d1J<XH0=0Q2Q:4c1P0071iMB[H@U_nooooXEAgM@DBeWDPdVH0
h4EW0<lB8HD000X0h4EW0=C:601L>MIeI7H02000000U000030000040001D0000E0000>40001boOoo
i00007Smool10000Zj[Q?ag7hKnB4@00_3800040001<00000000000000000000oooooooooom@0000
:@0003`0000H000030000000000U0000300000d0080X000030000040001B0000L0400040000ioooo
0000000000000000T040000000000082@`1=0580<@0`000000000000000000000000000000000000
000000000000000000000000000000000000000000000000?`00?`@0001DbAP0@=IV08c:603eLBig
6`0n07@1I0000000D05T05P3g@4006H08=9V0<1kIP00000010000000001L0@010000020000000041
E<TH0000002<bQP0mG4^Mo3_F`7nooooZSPZMj8d:WL00000001V023BIP3@8@XC000001SBIP2LbQP0
RU=gM@00I0000000XEAgMJJI8bk@8@XC8=9V0801fWD00000B03M0@00g@5XbQP0d24:4hC<6000L7Ue
:]Q2FokooonQE7Me1A;FMB3BIP3PAFL0ca8QQ@002P3PAFL0e<XH05`ieWETMP08000002D0000<0000
0@0005@0001D0000i`0007?mooo_0000OOgoo`40002[Z^4o7LOQ_a0B001Z<P000@0004`000000000
00000000003ooooooooooe00000m0000X00001P0000<0000000002D0000<00003@00P2P0000<0000
0@000580001`0@000@0003Woool0000000000000002@0@00000000000P9304d0C@190340<0000000
000000000000000000000000000000000000000000000000000000000000000000000000000o000o
100005C96010eVH0S<XH0?Ea;WLK03h0M05T0000001@0F@0F0?M0@00IP0PdVH0`7]V000000040000
000005`100400000800000000@5DbAP0000008c:603eLBigl>mK0OkooonZ>2YgXS@ZM`00000006H0
8=9V0=0Q2Q@000006=9V09c:602:DgMe001T0000002QE7MeYYTS;]0Q2Q@PdVH0P07JM@0000180=d1
003M0FS:603@8@XDQ<`H001`NGDZf49Ko_oooj5DMgD54]Ie8=9V0>15I`3?4R65000:0>15I`3DbQP0
G3WFMFAf00P000009@0000`000010000E00005@0003b0000LogoooX0001moOoo0@000:^ZhClMan6o
ha8006Xb00010000C00000000000000000000?ooooooooooD00004L0002P0000600000`000000000
9@0000`0000=0020:00000`000010000DP00070100010000>Oooo`00000000000000090100000000
00020T<0C@1505P0<@0`000000000000000000000000000000000000000000000000000000000000
0000000000000000000003l003l40000E<TH043FIP2<bQP0mG4^Ma/0?P1d0F@000000501I01H0md1
001V023BIP30NfH0000000@000000000G0400@00000P000000010EC960000000S<XH0?Ea;WO`ke/1
o_ooojXh:WNR=2Yg00000000IP0PdVH0d24:5@00000HdVH0W<XH08YCMgD006@000000:5DMgFVVB<^
d24:5B3BIP200MYe000004P0g@400=d1J<XH0=0Q2QF4c1P0071iMB[H@U_nooooXEAgM@DBeWDPdVH0
h4EW0<lB8HD000X0h4EW0=C:601L>MIeI7H02000000U000030000040001D0000E0000?/0001XoOoo
0@4008gmool10000Zj[Q?ag7hKnR4`00Ac<00040001<00000000000000000000oooooooooom@0000
/`0007P0000H000030000000000U0000300000d0080X000030000040001B0000L0400040000ioooo
0000000000000000T040000000000082@`1=04d0B@0a030000000000000000000000000000000000
000000000000000000000000000000000000000000000000?`00?`@0001DbAP0@=IV08c:603eLBig
6`0n07@1I0000000D05T05P3g@4006H08=9V0<1kIP00000010000000001L0@010000020000000041
E<TH0000002<bQP0mG4^Mo3_F`7nooooZSPZMj8d:WL00000001V023BIP3@8@XF000001SBIP2LbQP0
RU=gM@00I0000000XEAgMJJI8bk@8@XF8=9V0801fWD00000B03M0@00g@5XbQP0d24:5XC<6000L7Ue
:]Q2FokooonQE7Me1A;FMB3BIP3PAFL0ca8QQ@002P3PAFL0e<XH05`ieWETMP08000002D0000<0000
0@0005@0001D00000@4007?mool90@00OOgoo`40002[Z^4o7LOQ_aLD001Z<P000@0004`000000000
00000000003ooooooooooe00001E0000S00001P0000<0000000002D0000<00003@00P2P0000<0000
0@000580001`0@000@0007Goool0000000000000002@0@00000000000P9304d0DP0g000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000o000o
100005C96010eVH0S<XH0?Ea;WLK03h0M05T0000001@0F@0F0?M0@00IP0PdVH0`7]V000000040000
000005`100400000800000000@5DbAP0000008c:603eLBigl>mK0OkooonZ>2YgXS@ZM`00000006H0
8=9V0=0Q2QL000006=9V09c:602:DgMe001T0000002QE7MeYYTS;]0Q2QLPdVH0P07JM@0000180=d1
003M0FS:603@8@XGQ<`H001`NGDZf49Ko_oooj5DMgD54]Ie8=9V0>15I`3?4R65000:0>15I`3DbQP0
G3WFMFAf00P000009@0000`000010000E00005@000090@00L_goo``1001hoOoo0@000:^ZhClMan6o
]1@00;`b00010000C00000000000000000000?ooooooooooD00002P0000l0000600000`000000000
9@0000`0000=0020:00000`000010000DP00070100010000MOooo`00000000000000090100000000
00020T<0C@1=04T0=`00000000000000000000000000000000000000000000000000000000000000
0000000000000000000003l003l40000E<TH043FIP2<bQP0mG4^Ma/0?P1d0F@000000501I01H0md1
001V023BIP30NfH0000000@000000000G0400@00000P000000010EC960000000S<XH0?Ea;WO`ke/1
o_ooojXh:WNR=2Yg00000000IP0PdVH0d24:6000000HdVH0W<XH08YCMgD006@000000:5DMgFVVB<^
d24:623BIP200MYe000004P0g@400=d1J<XH0=0Q2QR4c1P0071iMB[H@U_nooooXEAgM@DBeWDPdVH0
h4EW0<lB8HD000X0h4EW0=C:601L>MIeI7H02000000U000030000040001D0000E00000`1001boOoo
4`4007Smool10000Zj[Q?ag7hKoc5000_3800040001<00000000000000000000oooooooooom@0000
K@0008`0000H000030000000000U0000300000d0080X000030000040001B0000L0400040001eoooo
0000000000000000T040000000000082@`1=05<0F@0g000000000000000000000000000000000000
000000000000000000000000000000000000000000000000?`00?`@0001DbAP0@=IV08c:603eLBig
6`0n07@1I0000000D05T05P3g@4006H08=9V0<1kIP00000010000000001L0@010000020000000041
E<TH0000002<bQP0mG4^Mo3_F`7nooooZSPZMj8d:WL00000001V023BIP3@8@XI000001SBIP2LbQP0
RU=gM@00I0000000XEAgMJJI8bk@8@XI8=9V0801fWD00000B03M0@00g@5XbQP0d24:6HC<6000L7Ue
:]Q2FokooonQE7Me1A;FMB3BIP3PAFL0ca8QQ@002P3PAFL0e<XH05`ieWETMP08000002D0000<0000
0@0005@0001D00004`4007;moolI0@00OOgoo`40002[Z^4o7LOQ_h0E002l<P000@0004`000000000
00000000003ooooooooooe00002Q0000N00001P0000<0000000002D0000<00003@00P2P0000<0000
0@000580001`0@000@0007Goool0000000000000002@0@00000000000P9304d0DP0g000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000o000o
100005C96010eVH0S<XH0?Ea;WLK03h0M05T0000001@0F@0F0?M0@00IP0PdVH0`7]V000000040000
000005`100400000800000000@5DbAP0000008c:603eLBigl>mK0OkooonZ>2YgXS@ZM`00000006H0
8=9V0=0Q2QX000006=9V09c:602:DgMe001T0000002QE7MeYYTS;]0Q2QXPdVH0P07JM@0000180=d1
003M0FS:603@8@XJQ<`H001`NGDZf49Ko_oooj5DMgD54]Ie8=9V0>15I`3?4R65000:0>15I`3DbQP0
G3WFMFAf00P000009@0000`000010000E00005@0000I0@00L_gooad1001hoOoo0@000:^ZhClMan6o
oAD00;`b00010000C00000000000000000000?ooooooooooD0000340001@0000600000`000000000
E00005@0000M0@00L_goob01001hoOoo0@000:^ZhClMan6oC1H00;`b00010000C000000000000000
00000?ooooooooooD00002T0000l0000600000`0000000009@0000`0000=0020:00000`000010000
DP00070100010000>Oooo`0000000000000009010000000000020T<0C@1=04T0<@0`000000000000
0000000000000000000000000000000000000000000000000000000000000000000003l003l40000
E<TH043FIP2<bQP0mG4^Ma/0?P1d0F@000000501I01H0md1001V023BIP30NfH0000000@000000000
G0400@00000P000000010EC960000000S<XH0?Ea;WO`ke/1o_ooojXh:WNR=2Yg00000000IP0PdVH0
d24:6`00000HdVH0W<XH08YCMgD006@000000:5DMgFVVB<^d24:6b3BIP200MYe000004P0g@400=d1
J<XH0=0Q2Q^4c1P0071iMB[H@U_nooooXEAgM@DBeWDPdVH0h4EW0<lB8HD000X0h4EW0=C:601L>MIe
I7H02000000U000030000040001D0000E0000241001coOoo904007gmool10000Zj[Q?ag7hKnD5P00
JS800040001<00000000000000000000oooooooooom@0000>`0003`0000H000030000000001D0000
E00002D1001coOoo;@4007gmool10000Zj[Q?ag7hKo]5P00JS800040001<00000000000000000000
oooooooooom@0000E@0008`0000H000030000000000U0000300000d0080X000030000040001B0000
L0400040001eoooo0000000000000000T040000000000082@`1=0580=`0000000000000000000000
0000000000000000000000000000000000000000000000000000000000000000?`00?`@0001DbAP0
@=IV08c:603eLBig6`0n07@1I0000000D05T05P3g@4006H08=9V0<1kIP00000010000000001L0@01
0000020000000041E<TH0000002<bQP0mG4^Mo3_F`7nooooZSPZMj8d:WL00000001V023BIP3@8@XL
000001SBIP2LbQP0RU=gM@00I0000000XEAgMJJI8bk@8@XL8=9V0801fWD00000B03M0@00g@5XbQP0
d24:78C<6000L7Ue:]Q2FokooonQE7Me1A;FMB3BIP3PAFL0ca8QQ@002P3PAFL0e<XH05`ieWETMP08
000002D0000<00000@0005@0001D0000;@4007;mool`0@00N?goo`40002[Z^4o7LOQ_hXG002l<P00
0@0004`00000000000000000003ooooooooooe00000X0000?00001P0000<0000000002D0000<0000
3@00P2P0000<00000@000580001`0@000@0007Goool0000000000000002@0@00000000000P9304d0
C@1903L0000000000000000000000000000000000000000000000000000000000000000000000000
00000000000o000o100005C96010eVH0S<XH0?Ea;WLK03h0M05T0000001@0F@0F0?M0@00IP0PdVH0
`7]V000000040000000005`100400000800000000@5DbAP0000008c:603eLBigl>mK0OkooonZ>2Yg
XS@ZM`00000006H08=9V0=0Q2Qd000006=9V09c:602:DgMe001T0000002QE7MeYYTS;]0Q2QdPdVH0
P07JM@0000180=d1003M0FS:603@8@XMQ<`H001`NGDZf49Ko_oooj5DMgD54]Ie8=9V0>15I`3?4R65
000:0>15I`3DbQP0G3WFMFAf00P000009@0000`000010000E00005@0000`0@00L_goocL1001hoOoo
0@000:^ZhClMan6obAL00;`b00010000C00000000000000000000?ooooooooooD00006d0002<0000
600000`0000000009@0000`0000=0020:00000`000010000DP00070100010000MOooo`0000000000
000009010000000000020T<0C@1C05T0=`0000000000000000000000000000000000000000000000
00000000000000000000000000000000000003l003l40000E<TH043FIP2<bQP0mG4^Ma/0?P1d0F@0
00000501I01H0md1001V023BIP30NfH0000000@000000000G0400@00000P000000010EC960000000
S<XH0?Ea;WO`ke/1o_ooojXh:WNR=2Yg00000000IP0PdVH0d24:7P00000HdVH0W<XH08YCMgD006@0
00000:5DMgFVVB<^d24:7R3BIP200MYe000004P0g@400=d1J<XH0=0Q2Qj4c1P0071iMB[H@U_noooo
XEAgM@DBeWDPdVH0h4EW0<lB8HD000X0h4EW0=C:601L>MIeI7H02000000U000030000040001D0000
E00003P1001boOoo?P4007gmool10000Zj[Q?ag7hKmF6000_3800040001<00000000000000000000
oooooooooom@0000X@0007P0000H000030000000000U0000300000d0080X000030000040001B0000
L0400040001eoooo0000000000000000T040000000000082@`1=0580=`0000000000000000000000
0000000000000000000000000000000000000000000000000000000000000000?`00?`@0001DbAP0
@=IV08c:603eLBig6`0n07@1I0000000D05T05P3g@4006H08=9V0<1kIP00000010000000001L0@01
0000020000000041E<TH0000002<bQP0mG4^Mo3_F`7nooooZSPZMj8d:WL00000001V023BIP3@8@XO
000001SBIP2LbQP0RU=gM@00I0000000XEAgMJJI8bk@8@XO8=9V0801fWFT?2Ygdc`ZM`00JWIXbQP0
d24:7hC<6000L7Ue:]Q2FokooonQE7Me1A;FMB3BIP3PAFL0ca8QQ@002P3PAFL0e<XH05`ieWETMP08
000002D0000<00000@0005@0001D0000?P4007;moom20@00N?goo`40002[Z^4o7LOQ_m<H002l<P00
0@0004`00000000000000000003ooooooooooe00000b0000D00001P0000<0000000005@0001D0000
@P4007;moom50@00N?goo`40002[Z^4o7LOQ_b8I002l<P000@0004`00000000000000000003ooooo
oooooe00000Y0000?00001P0000<0000000002D0000<00003@00P2P0000<00000@000580001`0@00
0@0003Woool0000000000000002@0@00000000000P9304d0C@190340<00000000000000000000000
00000000000000000000000000000000000000000000000000000000000o000o100005C96010eVH0
S<XH0?Ea;WLK03h0M05T0000001@0F@0F0?M0@00IP0PdVH0`7]V000000040000000005`100400000
800000000@5DbAP0000008c:603eLBigl>mK0OkooonZ>2YgXS@ZM`00000006H08=9V0=0Q2R000000
6=9V09c:602:DgMe001T0000002QE7MeYYTS;]0Q2R0PdVH0P07JM@00003C?2Yg001ZMVS:603@8@XP
Q<`H001`NGDZf49Ko_oooj5DMgD54]Ie8=9V0>15I`3?4R65000:0>15I`3DbQP0G3WFMFAf00P00000
9@0000`000010000E00005@000150@00LogoodP1001moOoo0@000:^ZhClMan6oK1T006Xb00010000
C00000000000000000000?ooooooooooD00003/0000l0000600000`000000000E00005@0001:0@00
Logoodd1001moOoo0@000:^ZhClMan6oa1T006Xb00010000C00000000000000000000?oooooooooo
D00003X0000l0000600000`000000000E00005@0001>0@00Logooe41001moOoo0@000:^ZhClMan6o
7AX006Xb00010000C00000000000000000000?ooooooooooD00003X0000l0000600000`000000000
E00005@0001C0@00LogooeH1001moOoo0@000:^ZhClMan6oMQX006Xb00010000C000000000000000
00000?ooooooooooD00003X0000l0000600000`000000000E00005@0001G0@00LogooeX1001moOoo
0@000:^ZhClMan6ocAX006Xb00010000C00000000000000000000?ooooooooooD00003/0000l0000
600000`000000000E00005@0001L0@00Logoof@1001moOoo0@000:^ZhClMan6o9Q/006Xb00010000
C00000000000000000000?ooooooooooD00005D0002<0000600000`0000000009@0000`0000=0020
:00000`000010000DP00070100010000MOooo`0000000000000009010000000000020T<0C@1B03L0
00000000000000000000000000000000000000000000000000000000000000000000000000000000
000003l003l40000E<TH043FIP2<bQP0mG4^Ma/0?P1d0F@000000501I01H0md1001V023BIP30NfH0
000000@000000000G0400@00000P000000010EC960000000S<XH0?Ea;WO`ke/1o_ooojXh:WNR=2Yg
00000000IP0PdVH0d24:8@00000HdVH0W<XH08YCMgD006@000000:5DMgFVVB<^d24:8B3BIP200MYe
00000=<l:WL006YfJ<XH0=0Q2R64c1P0071iMB[H@U_nooooXEAgM@DBeWDPdVH0h4EW0<lB8HD000X0
h4EW0=C:601L>MIeI7H02000000U000030000040001D0000E00006<1001boOooIP4007Smool10000
Zj[Q?ag7hKo46`00_3800040001<00000000000000000000oooooooooom@0000:00003`0000H0000
30000000001D0000E00006L1001boOooJ`4007Smool10000Zj[Q?ag7hKl27000_3800040001<0000
0000000000000000oooooooooom@0000<0000500000H000030000000001D0000E00006X1001boOoo
K@4007Smool10000Zj[Q?ag7hKmA7000_3800040001<00000000000000000000oooooooooom@0000
:@0003`0000H000030000000000U0000300000d0080X000030000040001B0000L0400040000ioooo
0000000000000000T040000000000082@`1=04d0B@0a030000000000000000000000000000000000
000000000000000000000000000000000000000000000000?`00?`@0001DbAP0@=IV08c:603eLBig
6`0n07@1I0000000D05T05P3g@4006H08=9V0<1kIP00000010000000001L0@010000020000000041
E<TH0000002<bQP0mG4^Mo3_F`7nooooZSPZMj8d:WL00000001V023BIP3@8@XR000001SBIP2LbQP0
RU=gM@00I0000000XEAgMJJI8bk@8@XR8=9V0801fWD00000dc`ZM`00JWIXbQP0d24:8XC<6000L7Ue
:]Q2FokooonQE7Me1A;FMB3BIP3PAFL0ca8QQ@002P3PAFL0e<XH05`ieWETMP08000002D0000<0000
0@0005@0001D0000KP4007?mooma0@00OOgoo`40002[Z^4o7LOQ_iTL001Z<P000@0004`000000000
00000000003ooooooooooe00000k0000?00001P0000<0000000005@0001D0000L`4007?moomi0@00
OOgoo`40002[Z^4o7LOQ_o8L001Z<P000@0004`00000000000000000003ooooooooooe0000160000
N00001P0000<0000000002D0000<00003@00P2P0000<00000@000580001`0@000@0007Goool00000
00000000002@0@00000000000P9304d0DP0g00000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000o000o100005C96010eVH0S<XH0?Ea;WLK03h0
M05T0000001@0F@0F0?M0@00IP0PdVH0`7]V000000040000000005`100400000800000000@5DbAP0
000008c:603eLBigl>mK0OkooonZ>2YgXS@ZM`00000006H08=9V0=0Q2R<000006=9V09c:602:DgMe
001T0000002QE7MeYYTS;]0Q2R<PdVH0P07JM@00003C?2Yg001ZMVS:603@8@XSQ<`H001`NGDZf49K
o_oooj5DMgD54]Ie8=9V0>15I`3?4R65000:0>15I`3DbQP0G3WFMFAf00P000009@0000`000010000
E00005@0001j0@00L_googd1001hoOoo0@000:^ZhClMan6oSQd00;`b00010000C000000000000000
00000?ooooooooooD00002P0000l0000600000`0000000009@0000`0000=0020:00000`000010000
DP00070100010000MOooo`0000000000000009010000000000020T<0C@1=04T0=`00000000000000
0000000000000000000000000000000000000000000000000000000000000000000003l003l40000
E<TH043FIP2<bQP0mG4^Ma/0?P1d0F@000000501I01H0md1001V023BIP30NfH0000000@000000000
G0400@00000P000000010EC960000000S<XH0?Ea;WO`ke/1o_ooojXh:WNR=2Yg00000000IP0PdVH0
d24:9000000HdVH0W<XH08YCMgD006@000000:5DMgFVVB<^d24:923BIP200MYe00000=<l:WL006Yf
J<XH0=0Q2RB4c1P0071iMB[H@U_nooooXEAgM@DBeWDPdVH0h4EW0<lB8HD000X0h4EW0=C:601L>MIe
I7H02000000U000030000040001D0000E00007d1001boOooQ04007Smool10000Zj[Q?ag7hKo<7@00
_3800040001<00000000000000000000oooooooooom@0000K@0008`0000H000030000000000U0000
300000d0080X000030000040001B0000L0400040001eoooo0000000000000000T040000000000082
@`1=0580=`0000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000?`00?`@0001DbAP0@=IV08c:603eLBig6`0n07@1I0000000D05T05P3g@4006H0
8=9V0<1kIP00000010000000001L0@010000020000000041E<TH0000002<bQP0mG4^Mo3_F`7noooo
ZSPZMj8d:WL00000001V023BIP3@8@XU000001SBIP2LbQP0RU=gM@00I0000000XEAgMJJI8bk@8@XU
8=9V0801fWD00000dc`ZM`00JWIXbQP0d24:9HC<6000L7Ue:]Q2FokooonQE7Me1A;FMB3BIP3PAFL0
ca8QQ@002P3PAFL0e<XH05`ieWETMP08000002D0000<00000@0005@0001D0000Q@4007;moon80@00
N?goo`40002[Z^4o7LOQ_eXN002l<P000@0004`00000000000000000003ooooooooooe00000Y0000
?00001P0000<0000000002D0000<00003@00P2P0000<00000@000580001`0@000@0003Woool00000
00000000002@0@00000000000P9304d0C@190340<000000000000000000000000000000000000000
0000000000000000000000000000000000000000000o000o100005C96010eVH0S<XH0?Ea;WLK03h0
M05T0000001@0F@0F0?M0@00IP0PdVH0`7]V000000040000000005`100400000800000000@5DbAP0
000008c:603eLBigl>mK0OkooonZ>2YgXS@ZM`00000006H08=9V0=0Q2RH000006=9V09c:602:DgMe
001T0000002QE7MeYYTS;]0Q2RHPdVH0P07JM@00003C?2Yg001ZMVS:603@8@XVQ<`H001`NGDZf49K
o_oooj5DMgD54]Ie8=9V0>15I`3?4R65000:0>15I`3DbQP0G3WFMFAf00P000009@0000`000010000
E00005@000280@00Logooh/1001moOoo0@000:^ZhClMan6oXQh006Xb00010000C000000000000000
00000?ooooooooooD00003/0000l0000600000`000000000E00005@0002=0@00Logooi41001moOoo
0@000:^ZhClMan6onah006Xb00010000C00000000000000000000?ooooooooooD00007@0001@0000
600000`0000000009@0000`0000=0020:00000`000010000DP00070100010000MOooo`0000000000
000009010000000000020T<0C@1=04T0=`0000000000000000000000000000000000000000000000
00000000000000000000000000000000000003l003l40000E<TH043FIP2<bQP0mG4^Ma/0?P1d0F@0
00000501I01H0md1001V023BIP30NfH0000000@000000000G0400@00000P000000010EC960000000
S<XH0?Ea;WO`ke/1o_ooojXh:WNR=2Yg00000000IP0PdVH0d24:9`00000HdVH0W<XH08YCMgD006@0
00000:5DMgFVVB<^d24:9b3BIP200MYe00000=<l:WL006YfJ<XH0=0Q2RN4c1P0071iMB[H@U_noooo
XEAgM@DBeWDPdVH0h4EW0<lB8HD000X0h4EW0=C:601L>MIeI7H02000000U000030000040001D0000
E0000901001goOooU`4007gmool10000Zj[Q?ag7hKm37`00C3800040001<00000000000000000000
oooooooooom@0000K@0008`0000H000030000000000U0000300000d0080X000030000040001B0000
L0400040000ioooo0000000000000000T040000000000082@`1=04D0F00a03000000000000000000
0000000000000000000000000000000000000000000000000000000000000000?`00?`@0001DbAP0
@=IV08c:603eLBig6`0n07@1I0000000D05T05P3g@4006H08=9V0<1kIP00000010000000001L0@01
0000020000000041E<TH0000002<bQP0mG4^Mo3_F`7nooooZSPZMj8d:WL00000001V023BIP3@8@XX
000001SBIP2LbQP0RU=gM@00I0000000XEAgMJJI8bk@8@XX8=9V0801fWD00000dc`ZM`00JWIXbQP0
d24::8C<6000L7Ue:]Q2FokooonQE7Me1A;FMB3BIP3PAFL0ca8QQ@002P3PAFL0e<XH05`ieWETMP08
000002D0000<00000@0005@0001D0000V04006SmoonN0@00SOgoo`40002[Z^4o7LOQ_mXO0017<`00
0@0004`00000000000000000003ooooooooooe00002d0000N00002D0000<00003@00P2P0000<0000
0@0000h0000D000000000100000D0000240122@0000H00000Q30f`40000300000000000000000000
6d000400000d00000@000080001OPTA3H6<Ta8@oFD<20ZU10`0005n2A4=PHbC4lN3>@f1S9<AOPTA3
D1/Oa24000080000HP0000`0000100008@0000P0000Q0000200007<0000<0000000001`000080000
9@0000`0000000209@0000`0000700209@0000`0000>00206@0000`0003oool0600000`000000000
4P0000`0000200004`0000`000010000500000`0000=00005@0000`0000100005P0000`000000000
3@00010000000000000003X0000<00002P0001/0000@000000000000000S0000800003_?9D400000
00000>:g:d4iS_k4jhSLAB@0000T0000>llU@@0000000000h[L[@CV>o/C[R=a5100007<0000<0000
000000d0000@000000000000001B0000L0400080000@00001`00000000000000_080000000070P8R
D`1i07<0M01U06d0000D0:3hooob0@00000003bm@P:0n?oo201HO__fool000000000022m@P:0n?oo
ool00000E0XHT7P00000P5c;=@3;c4`mT<`e0;SMPPLQ@kignAhQhB80RP4H00000000062F2PH80000
cjTT@@00aceHPo4600000<3Lk0J/b3D00000000000000000ooooob3<=@1<c3D0?=Le08DI`WNeLfH1
o_ooohcS_GObh;eg003f23Sl0002000000000200001lc3D0X<`e0>]HkgH007P0200D02IJkgHAZA=U
0000062F2PKooooo0`00000000000000000006S<=@2:MFMX[=<e001`lGKik]LCo_ooobIJkgIR4aEg
X;YD2P40003Dc3D0f<`e02l`5GMTMP08000002D0000<00000P0004H000280000O00004M4BD<20000
a@0006kmoonM0@00Pogooc00001W06D0KP1U0780H@1d06D0I00P0680N@0P05L0C@1602l0A@1=04H0
801R0640H`1[06D0KP1T0200K`1V0200L01c07@0K`1U06@0J@1d0000J@1^0700M@1d0000000S0000
800009Rf13l0000000000>QO2KliS_k4jhSLAB@0000T0000V;H4?`0000000000j5l9_cV>o/C[R=a5
100002<0000P0000V;H4?`0000000000j5l9_cV>o/C[R=a5900002@0002H]P@o00000000003XG`Vo
>Hkna>^8g4D400004P0000`0000100005P0000`0000H0000600000`000000000DP00070100030000
>Oooo`000000000000000901000000001`020T<0C@1=04T0<@0`0000000000000000000000000000
00000000000000000000000000000000000000000000000010000<S:60000000200000L000000000
SU<gMLS:600`bQP0k;1300@000240000b<XH00000000000030000000000100008<XH000000240000
X0l0008000030000b<XH000000000000?<XH07nN@`3l2]`1P<XH0000@`040000S[E30=bV8BiXO]`1
8HQ600000000000000000040001<bQP002m:00c;603PW48034Qn;_koool004<0gKE306Qng0400000
003L0FQng078bQP00@0003P07P0;0000b<XH06Qng0410`00/7gL0@40001PO]`1I7H02000000U0000
300000<0001D0000E00000d0000c0000H00009h000010000Zj[Q?ag7hKma3`00JS800040001<0000
0000000000000000oooooooooom@0000@@3ooj00000H000030000000001D0000E00006`0000c0000
^`0009h000010000Zj[Q?ag7hKlX4000JS800040001<00000000000000000000oooooooooom@0000
E@0e08`0000H000030000000001B0000L04000@0000D00002@00000000000000_080000000070P8R
D`1i07<0M01U06d000000000003R0000000006a4NP:0n?oo000000000000000000000514NP:0n?oo
^YH000005GNgI1EgnAhQh@00000000000@000<Rmo@GHbcD0HF@EMoTN8N400000000005@000000000
b;gm1E3<=@3NDAEgnAhQhDSPQ`020000f5aO0e@0000000000@0003P07P0;0000b<XH06Qng0410`00
/7gL0@40001PO]`100002000001PUPX6H9H:1U3<=@0_<1EgD<`e06H`5GNdlE/:H9H:1RD0000000X0
>48008C==@0MnV=XnAhQh@00Q`38_Od50P000=QLG`>b2VAXD0HIM`00001@1QUgP04IMbSbF`ZXc3D0
;c0EMjS<=@1V<1EgM?9K2V2F2PITMP08000002D0000<0000100002P0000<00000`000580001`0@00
0`0007Goool0000000000000002@0@00000000L00P9304d0DP0g0000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000o000o100000800010eVH0
b<XH0000000K03h0M05T0000001@0F@0F0?M0@00@`0PdVH0`7]V000000040000000005`100400000
800000000@5DbAP0000008c:603eLBigl>mK0OkooonZ>2YgXS@ZM`00000006H08=9V0=0Q2Q000000
6=9V09c:602:DgMe001T0000002QE7MeYYTS;]0Q2Q0PdVH0P07JM@26g0580=d1003M0FS:603@8@X@
Q<`H001`NGDZf49Ko_oooj5DMgD54]Ie8=9V0>15I`3?4R65000:0>15I`3DbQP0G3WFMFAf00P00000
9@0000`000030000E00005@0002n00007`000=h0001Z00000@000:^ZhClMan6oaQ000;`b00010000
C00000000000000000000?ooooooooooD00002P00`0l0000600000`0000000009@0000`000040000
:00000`000030000DP00070100030000MOooo`000000000000000901000000001`020T<0C@1=04T0
=`000000000000000000000000000000000000000000000000000000000000000000000000000000
000003l003l40000E<TH043FIP2<bQP0mG4^Ma/0?P1d0F@000000501I01H0md1001V023BIP30NfH0
000000@000000000G0400@00000P000000010EC960000000S<XH0?Ea;WO`ke/1o_ooojXh:WNR=2Yg
00000000IP0PdVH0d24:4@00000HdVH0W<XH08YCMgD006@000000:5DMgFVVB<^d24:4B3BIP200MYe
000004P0g@400=d1J<XH0=0Q2Q64c1P0071iMB[H@U_nooooXEAgM@DBeWDPdVH0h4EW0<lB8HD000X0
h4EW0=C:601L>MIeI7H02000000U0000300000<0001D0000E0000=h0000O00009`4006X000010000
Zj[Q?ag7hKl44@00_3800040001<00000000000000000000oooooooooom@0000K@0H08`0000H0000
30000000000U0000300000@0000X0000300000<0001B0000L04000<0001eoooo0000000000000000
T040000000070082@`1=0580=`000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000?`00?`@0001DbAP0@=IV08c:603eLBig6`0n07@1I0000000
D05T05P3g@4006H08=9V0<1kIP00000010000000001L0@010000020000000041E<TH0000002<bQP0
mG4^Mo3_F`7nooooZSPZMj8d:WL00000001V023BIP3@8@XB000001SBIP2LbQP0RU=gM@00I0000000
XEAgMJJI8bk@8@XB8=9V0801fWD00000B03M0@00g@5XbQP0d24:4XC<6000L7Ue:]Q2FokooonQE7Me
1A;FMB3BIP3PAFL0ca8QQ@002P3PAFL0e<XH05`ieWETMP08000002D0000<00000`0005@0001D0000
9`4001l000170@00JP000040002[Z^4o7LOQ_i8A002l<P000@0004`00000000000000000003ooooo
oooooe00000Y01P0?00001P0000<0000000002D0000<0000100002P0000<00000`000580001`0@00
0`0003Woool0000000000000002@0@00000000L00P9304d0DP0a0300000000000000000000000000
00000000000000000000000000000000000000000000000000000000000o000o100005C96010eVH0
S<XH0?Ea;WLK03h0M05T0000001@0F@0F0?M0@00IP0PdVH0`7]V000000040000000005`100400000
800000000@5DbAP0000008c:603eLBigl>mK0OkooonZ>2YgXS@ZM`00000006H08=9V0=0Q2Q<00000
6=9V09c:602:DgMe001T0000002QE7MeYYTS;]0Q2Q<PdVH0P07JM@0000180=d1003M0FS:603@8@XC
Q<`H001`NGDZf49Ko_oooj5DMgD54]Ie8=9V0>15I`3?4R65000:0>15I`3DbQP0G3WFMFAf00P00000
9@0000`000030000E00005@0001Y0@00<`000;`1002N00000@000:^ZhClMan6o418006Xb00010000
C00000000000000000000?ooooooooooD00003d0602P0000600000`0000000009@0000`000040000
:00000`000030000DP00070100030000>Oooo`000000000000000901000000001`020T<0C@1=04T0
<@0`0000000000000000000000000000000000000000000000000000000000000000000000000000
000003l003l40000E<TH043FIP2<bQP0mG4^Ma/0?P1d0F@000000501I01H0md1001V023BIP30NfH0
000000@000000000G0400@00000P000000010EC960000000S<XH0?Ea;WO`ke/1o_ooojXh:WNR=2Yg
00000000IP0PdVH0d24:5000000HdVH0W<XH08YCMgD006@000000:5DMgFVVB<^d24:523BIP200MYe
000004P0g@400=d1J<XH0=0Q2QB4c1P0071iMB[H@U_nooooXEAgM@DBeWDPdVH0h4EW0<lB8HD000X0
h4EW0=C:601L>MIeI7H02000000U0000300000<0001D0000E0000=H1000c0000:@8009h000010000
Zj[Q?ag7hKoS4P00JS800040001<00000000000000000000oooooooooom@0000A`0H0:00000H0000
30000000000U0000300000@0000X0000300000<0001B0000L04000<0000ioooo0000000000000000
T040000000070082@`1=04D0F00a0300000000000000000000000000000000000000000000000000
00000000000000000000000000000000?`00?`@0001DbAP0@=IV08c:603eLBig6`0n07@1I0000000
D05T05P3g@4006H08=9V0<1kIP00000010000000001L0@010000020000000041E<TH0000002<bQP0
mG4^Mo3_F`7nooooZSPZMj8d:WL00000001V023BIP3@8@XE000001SBIP2LbQP0RU=gM@00I0000000
XEAgMJJI8bk@8@XE8=9V0801fWD00000B03M0@00g@5XbQP0d24:5HC<6000L7Ue:]Q2FokooonQE7Me
1A;FMB3BIP3PAFL0ca8QQ@002P3PAFL0e<XH05`ieWETMP08000002D0000<00000`0005@0001D0000
>@800;[ooomh0P00B@400040002[Z^4o7LOQ_j8C0017<`000@0004`00000000000000000003ooooo
oooooe00002c01P0N00001P0000<0000000002D0000<0000100002P0000<00000`000580001`0@00
0`0003Woool0000000000000002@0@00000000L00P9304d0C@190340<00000000000000000000000
00000000000000000000000000000000000000000000000000000000000o000o100005C96010eVH0
S<XH0?Ea;WLK03h0M05T0000001@0F@0F0?M0@00IP0PdVH0`7]V000000040000000005`100400000
800000000@5DbAP0000008c:603eLBigl>mK0OkooonZ>2YgXS@ZM`00000006H08=9V0=0Q2QH00000
6=9V09c:602:DgMe001T0000002QE7MeYYTS;]0Q2QHPdVH0P07JM@0000180=d1003M0FS:603@8@XF
Q<`H001`NGDZf49Ko_oooj5DMgD54]Ie8=9V0>15I`3?4R65000:0>15I`3DbQP0G3WFMFAf00P00000
9@0000`000030000E00005@0001f0P00<`000<D2002N00000@000:^ZhClMan6o5a@006Xb00010000
C00000000000000000000?ooooooooooD00005D0602<0000600000`0000000009@0000`000040000
:00000`000030000DP00070100030000MOooo`000000000000000901000000001`020T<0C@1B03L0
00000000000000000000000000000000000000000000000000000000000000000000000000000000
000003l003l40000E<TH043FIP2<bQP0mG4^Ma/0?P1d0F@000000501I01H0md1001V023BIP30NfH0
000000@000000000G0400@00000P000000010EC960000000S<XH0?Ea;WO`ke/1o_ooojXh:WNR=2Yg
00000000IP0PdVH0d24:5`00000HdVH0W<XH08YCMgD006@000000:5DMgFVVB<^d24:5b3BIP200MYe
000004P0g@400=d1J<XH0=0Q2QN4c1P0071iMB[H@U_nooooXEAgM@DBeWDPdVH0h4EW0<lB8HD000X0
h4EW0=C:601L>MIeI7H02000000U0000300000<0001D0000E0000<L2000O0000i`8006X000010000
Zj[Q?ag7hKnd5000_3800040001<00000000000000000000oooooooooom@0000:00H03`0000H0000
30000000000U0000300000@0000X0000300000<0001B0000L04000<0001eoooo0000000000000000
T040000000070082@`1=04d0B@0g0000000000000000000000000000000000000000000000000000
00000000000000000000000000000000?`00?`@0001DbAP0@=IV08c:603eLBig6`0n07@1I0000000
D05T05P3g@4006H08=9V0<1kIP00000010000000001L0@010000020000000041E<TH0000002<bQP0
mG4^Mo3_F`7nooooZSPZMj8d:WL00000001V023BIP3@8@XH000001SBIP2LbQP0RU=gM@00I0000000
XEAgMJJI8bk@8@XH8=9V0801fWD00000B03M0@00g@5XbQP0d24:68C<6000L7Ue:]Q2FokooonQE7Me
1A;FMB3BIP3PAFL0ca8QQ@002P3PAFL0e<XH05`ieWETMP08000002D0000<00000`0005@0001D0000
j08001l0000a0`00JP000040002[Z^4o7LOQ_o<D002l<P000@0004`00000000000000000003ooooo
oooooe00001]01P0S00001P0000<0000000002D0000<0000100002P0000<00000`000580001`0@00
0`0007Goool0000000000000002@0@00000000L00P9304d0D`1I03L0000000000000000000000000
00000000000000000000000000000000000000000000000000000000000o000o100005C96010eVH0
S<XH0?Ea;WLK03h0M05T0000001@0F@0F0?M0@00IP0PdVH0`7]V000000040000000005`100400000
800000000@5DbAP0000008c:603eLBigl>mK0OkooonZ>2YgXS@ZM`00000006H08=9V0=0Q2QT00000
6=9V09c:602:DgMe001T0000002QE7MeYYTS;]0Q2QTPdVH0P07JM@0000180=d1003M0FS:603@8@XI
Q<`H001`NGDZf49Ko_oooj5DMgD54]Ie8=9V0>15I`3?4R65000:0>15I`3DbQP0G3WFMFAf00P00000
9@0000`000030000E00005@0000a0`007@000703002O00000@000:^ZhClMan6oP1D00;`b00010000
C00000000000000000000?ooooooooooD0000:40601h0000600000`0000000009@0000`000040000
:00000`000030000DP00070100030000MOooo`000000000000000901000000001`020T<0C@1B03L0
00000000000000000000000000000000000000000000000000000000000000000000000000000000
000003l003l40000E<TH043FIP2<bQP0mG4^Ma/0?P1d0F@000000501I01H0md1001V023BIP30NfH0
000000@000000000G0400@00000P000000010EC960000000S<XH0?Ea;WO`ke/1o_ooojXh:WNR=2Yg
00000000IP0PdVH0d24:6P00000HdVH0W<XH08YCMgD006@000000:5DMgFVVB<^d24:6R3BIP200MYe
000004P0g@400=d1J<XH0=0Q2QZ4c1P0071iMB[H@U_nooooXEAgM@DBeWDPdVH0h4EW0<lB8HD000X0
h4EW0=C:601L>MIeI7H02000000U0000300000<0001D0000E0000783000O0000W0<006X000010000
Zj[Q?ag7hKom5@00_3800040001<00000000000000000000oooooooooom@0000<@0H0500000H0000
30000000001D0000E00009/3000O0000^`<006X000010000Zj[Q?ag7hKm<5P00_3800040001<0000
0000000000000000oooooooooom@0000:@0H03`0000H000030000000000U0000300000@0000X0000
300000<0001B0000L04000<0000ioooo0000000000000000T040000000070082@`1=04d0B@0a0300
00000000000000000000000000000000000000000000000000000000000000000000000000000000
?`00?`@0001DbAP0@=IV08c:603eLBig6`0n07@1I0000000D05T05P3g@4006H08=9V0<1kIP000000
10000000001L0@010000020000000041E<TH0000002<bQP0mG4^Mo3_F`7nooooZSPZMj8d:WL00000
001V023BIP3@8@XK000001SBIP2LbQP0RU=gM@00I0000000XEAgMJJI8bk@8@XK8=9V0801fWD00000
B03M0@00g@5XbQP0d24:6hC<6000L7Ue:]Q2FokooonQE7Me1A;FMB3BIP3PAFL0ca8QQ@002P3PAFL0
e<XH05`ieWETMP08000002D0000<00000`0005@0001D0000`0<003<0003P0`00WP000040002[Z^4o
7LOQ_i@F001Z<P000@0004`00000000000000000003ooooooooooe00000k01P0?00001P0000<0000
000005@0001D0000kP<003<0000m1000WP000040002[Z^4o7LOQ_ndF001Z<P000@0004`000000000
00000000003ooooooooooe00001E0000S00001P0000<0000000002D0000<0000100002P0000<0000
0`000580001`0@000`0007Goool0000000000000002@0@00000000L00P9304d0DP0g000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000o000o
100005C96010eVH0S<XH0?Ea;WLK03h0M05T0000001@0F@0F0?M0@00IP0PdVH0`7]V000000040000
000005`100400000800000000@5DbAP0000008c:603eLBigl>mK0OkooonZ>2YgXS@ZM`00000006H0
8=9V0=0Q2Q`000006=9V09c:602:DgMe001T0000002QE7MeYYTS;]0Q2Q`PdVH0P07JM@0000180=d1
003M0FS:603@8@XLQ<`H001`NGDZf49Ko_oooj5DMgD54]Ie8=9V0>15I`3?4R65000:0>15I`3DbQP0
G3WFMFAf00P000009@0000`000030000E00005@0001010007`000604001Z00000@000:^ZhClMan6o
RQL00;`b00010000C00000000000000000000?ooooooooooD00002P0000l0000600000`000000000
9@0000`000040000:00000`000030000DP00070100030000MOooo`00000000000000090100000000
1`020T<0C@1=04T0=`00000000000000000000000000000000000000000000000000000000000000
0000000000000000000003l003l40000E<TH043FIP2<bQP0mG4^Ma/0?P1d0F@000000501I01H0md1
001V023BIP30NfH0000000@000000000G0400@00000P000000010EC960000000S<XH0?Ea;WO`ke/1
o_ooojXh:WNR=2Yg00000000IP0PdVH0d24:7@00000HdVH0W<XH08YCMgD006@000000:5DMgFVVB<^
d24:7B3BIP200MYe000004P0g@400=d1J<XH0=0Q2Qf4c1P0071iMB[H@U_nooooXEAgM@DBeWDPdVH0
h4EW0<lB8HD000X0h4EW0=C:601L>MIeI7H02000000U0000300000<0001D0000E0000604000O0000
Z@@006X000010000Zj[Q?ag7hKo95`00_3800040001<00000000000000000000oooooooooom@0000
K@1T08`0000H000030000000000U0000300000@0000X0000300000<0001B0000L04000<0001eoooo
0000000000000000T040000000070082@`1=05<0F@0g000000000000000000000000000000000000
000000000000000000000000000000000000000000000000?`00?`@0001DbAP0@=IV08c:603eLBig
6`0n07@1I0000000D05T05P3g@4006H08=9V0<1kIP00000010000000001L0@010000020000000041
E<TH0000002<bQP0mG4^Mo3_F`7nooooZSPZMj8d:WL00000001V023BIP3@8@XN000001SBIP2LbQP0
RU=gM@00I0000000XEAgMJJI8bk@8@XN8=9V0801fWD00000B03M0@00g@5XbQP0d24:7XC<6000L7Ue
:]Q2FokooonQE7Me1A;FMB3BIP3PAFL0ca8QQ@002P3PAFL0e<XH05`ieWETMP08000002D0000<0000
0`0005@0001D0000Z@@001d0003X1000W`000040002[Z^4o7LOQ_eHH002l<P000@0004`000000000
00000000003ooooooooooe00002Q0480N00001P0000<0000000002D0000<0000100002P0000<0000
0`000580001`0@000`0007Goool0000000000000002@0@00000000L00P9304d0DP0g000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000o000o
100005C96010eVH0S<XH0?Ea;WLK03h0M05T0000001@0F@0F0?M0@00IP0PdVH0`7]V000000040000
000005`100400000800000000@5DbAP0000008c:603eLBigl>mK0OkooonZ>2YgXS@ZM`00000006H0
8=9V0=0Q2Ql000006=9V09c:602:DgMe001T0000002QE7MeYYTS;]0Q2QlPdVH0P07JMJ@l:WOC?2Yg
001ZMVS:603@8@XOQ<`H001`NGDZf49Ko_oooj5DMgD54]Ie8=9V0>15I`3?4R65000:0>15I`3DbQP0
G3WFMFAf00P000009@0000`000030000E00005@0003Z10007`0001@5001Z00000@000:^ZhClMan6o
daP00;`b00010000C00000000000000000000?ooooooooooD0000380G`=@0000600000`000000000
E00005@0000C1@007`0003<5001Z00000@000:^ZhClMan6o8QT00;`b00010000C000000000000000
00000?ooooooooooD00002T0ooll0000600000`0000000009@0000`000040000:00000`000030000
DP00070100030000>Oooo`000000000000000901000000001`020T<0C@1=04T0<@0`000000000000
0000000000000000000000000000000000000000000000000000000000000000000003l003l40000
E<TH043FIP2<bQP0mG4^Ma/0?P1d0F@000000501I01H0md1001V023BIP30NfH0000000@000000000
G0400@00000P000000010EC960000000S<XH0?Ea;WO`ke/1o_ooojXh:WNR=2Yg00000000IP0PdVH0
d24:8000000HdVH0W<XH08YCMgD006@000000:5DMgFVVB<^d24:823BIP200MYe00000=<l:WL006Yf
J<XH0=0Q2R24c1P0071iMB[H@U_nooooXEAgM@DBeWDPdVH0h4EW0<lB8HD000X0h4EW0=C:601L>MIe
I7H02000000U0000300000<0001D0000E00003T5000c0000F@D009h000010000Zj[Q?ag7hKm/6@00
JS800040001<00000000000000000000oooooooooom@0000>`3ooc`0000H000030000000001D0000
E00006L5000c0000Q`D009h000010000Zj[Q?ag7hKo46@00JS800040001<00000000000000000000
oooooooooom@0000>P0003`0000H000030000000001D0000E00009D5000c0000]@D009h000010000
Zj[Q?ag7hKlM6P00JS800040001<00000000000000000000oooooooooom@0000>P0H03`0000H0000
30000000001D0000E0000<<5000c0000h`D009h000010000Zj[Q?ag7hKmf6P00JS800040001<0000
0000000000000000oooooooooom@0000>P0H03`0000H000030000000001D0000E0000?05000c0000
40H009h000010000Zj[Q?ag7hKo=6P00JS800040001<00000000000000000000oooooooooom@0000
>`0003`0000H000030000000001D0000E00001l6000c0000KPH009h000010000Zj[Q?ag7hKlV6`00
JS800040001<00000000000000000000oooooooooom@0000E@0008`0000H000030000000000U0000
300000@0000X0000300000<0001B0000L04000<0001eoooo0000000000000000T040000000070082
@`1=0580=`0000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000?`00?`@0001DbAP0@=IV08c:603eLBig6`0n07@1I0000000D05T05P3g@4006H0
8=9V0<1kIP00000010000000001L0@010000020000000041E<TH0000002<bQP0mG4^Mo3_F`7noooo
ZSPZMj8d:WL00000001V023BIP3@8@XQ000001SBIP2LbQP0RU=gM@00I0000000XEAgMJJI8bk@8@XQ
8=9V0801fWD00000dc`ZM`00JWIXbQP0d24:8HC<6000L7Ue:]Q2FokooonQE7Me1A;FMB3BIP3PAFL0
ca8QQ@002P3PAFL0e<XH05`ieWETMP08000002D0000<00000`0005@0001D0000L0H001l0002@1P00
JP000040002[Z^4o7LOQ_l@K002l<P000@0004`00000000000000000003ooooooooooe00000X0000
?00001P0000<0000000005@0001D0000T@H001l0002k1P00JP000040002[Z^4o7LOQ_`8L002l<P00
0@0004`00000000000000000003ooooooooooe00000`0000D00001P0000<0000000005@0001D0000
^PH001l0003J1P00JP000040002[Z^4o7LOQ_e4L002l<P000@0004`00000000000000000003ooooo
oooooe00000Y0000?00001P0000<0000000002D0000<0000100002P0000<00000`000580001`0@00
0`0003Woool0000000000000002@0@00000000L00P9304d0C@190340<00000000000000000000000
00000000000000000000000000000000000000000000000000000000000o000o100005C96010eVH0
S<XH0?Ea;WLK03h0M05T0000001@0F@0F0?M0@00IP0PdVH0`7]V000000040000000005`100400000
800000000@5DbAP0000008c:603eLBigl>mK0OkooonZ>2YgXS@ZM`00000006H08=9V0=0Q2R800000
6=9V09c:602:DgMe001T0000002QE7MeYYTS;]0Q2R8PdVH0P07JM@00003C?2Yg001ZMVS:603@8@XR
Q<`H001`NGDZf49Ko_oooj5DMgD54]Ie8=9V0>15I`3?4R65000:0>15I`3DbQP0G3WFMFAf00P00000
9@0000`000030000E00005@0003O1P00<`000?l6002N00000@000:^ZhClMan6oVA`006Xb00010000
C00000000000000000000?ooooooooooD00003/0000l0000600000`000000000E00005@0000=1`00
<`0005/7002N00000@000:^ZhClMan6olQ`006Xb00010000C00000000000000000000?oooooooooo
D00004H0T@1h0000600000`0000000009@0000`000040000:00000`000030000DP00070100030000
MOooo`000000000000000901000000001`020T<0C@1B03L000000000000000000000000000000000
000000000000000000000000000000000000000000000000000003l003l40000E<TH043FIP2<bQP0
mG4^Ma/0?P1d0F@000000501I01H0md1001V023BIP30NfH0000000@000000000G0400@00000P0000
00010EC960000000S<XH0?Ea;WO`ke/1o_ooojXh:WNR=2Yg00000000IP0PdVH0d24:8`00000HdVH0
W<XH08YCMgD006@000000:5DMgFVVB<^d24:8b3BIP200MYe00000=<l:WL006YfJ<XH0=0Q2R>4c1P0
071iMB[H@U_nooooXEAgM@DBeWDPdVH0h4EW0<lB8HD000X0h4EW0=C:601L>MIeI7H02000000U0000
300000<0001D0000E00005h7000O0000OPL006X000010000Zj[Q?ag7hKn>7@00_3800040001<0000
0000000000000000oooooooooom@0000:02A03`0000H000030000000000U0000300000@0000X0000
300000<0001B0000L04000<0001eoooo0000000000000000T040000000070082@`1=04d0B@0g0000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
?`00?`@0001DbAP0@=IV08c:603eLBig6`0n07@1I0000000D05T05P3g@4006H08=9V0<1kIP000000
10000000001L0@010000020000000041E<TH0000002<bQP0mG4^Mo3_F`7nooooZSPZMj8d:WL00000
001V023BIP3@8@XT000001SBIP2LbQP0RU=gM@00I0000000XEAgMJJI8bk@8@XT8=9V0801fWD00000
dc`ZM`00JWIXbQP0d24:98C<6000L7Ue:]Q2FokooonQE7Me1A;FMB3BIP3PAFL0ca8QQ@002P3PAFL0
e<XH05`ieWETMP08000002D0000<00000`0005@0001D0000OPL001l000371`00JP000040002[Z^4o
7LOQ_l`M002l<P000@0004`00000000000000000003ooooooooooe00001]0940S00001P0000<0000
000002D0000<0000100002P0000<00000`000580001`0@000`0007Goool0000000000000002@0@00
000000L00P9304d0DP0g000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000o000o100005C96010eVH0S<XH0?Ea;WLK03h0M05T0000001@0F@0
F0?M0@00IP0PdVH0`7]V000000040000000005`100400000800000000@5DbAP0000008c:603eLBig
l>mK0OkooonZ>2YgXS@ZM`00000006H08=9V0=0Q2RD000006=9V09c:602:DgMe001T0000002QE7Me
YYTS;]0Q2RDPdVH0P07JM@00003C?2Yg001ZMVS:603@8@XUQ<`H001`NGDZf49Ko_oooj5DMgD54]Ie
8=9V0>15I`3?4R65000:0>15I`3DbQP0G3WFMFAf00P000009@0000`000030000E00005@000381`00
7`000>P7001Z00000@000:^ZhClMan6oFQh00;`b00010000C00000000000000000000?oooooooooo
D00002T0T@0l0000600000`0000000009@0000`000040000:00000`000030000DP00070100030000
>Oooo`000000000000000901000000001`020T<0C@1=04T0<@0`0000000000000000000000000000
000000000000000000000000000000000000000000000000000003l003l40000E<TH043FIP2<bQP0
mG4^Ma/0?P1d0F@000000501I01H0md1001V023BIP30NfH0000000@000000000G0400@00000P0000
00010EC960000000S<XH0?Ea;WO`ke/1o_ooojXh:WNR=2Yg00000000IP0PdVH0d24:9P00000HdVH0
W<XH08YCMgD006@000000:5DMgFVVB<^d24:9R3BIP200MYe00000=<l:WL006YfJ<XH0=0Q2RJ4c1P0
071iMB[H@U_nooooXEAgM@DBeWDPdVH0h4EW0<lB8HD000X0h4EW0=C:601L>MIeI7H02000000U0000
300000<0001D0000E0000>d7000c00003@P009h000010000Zj[Q?ag7hKnR7P00JS800040001<0000
0000000000000000oooooooooom@0000>`2A03`0000H000030000000001D0000E00001/8000c0000
A@P009h000010000Zj[Q?ag7hKok7P00JS800040001<00000000000000000000oooooooooom@0000
M0000500000H000030000000000U0000300000@0000X0000300000<0001B0000L04000<0001eoooo
0000000000000000T040000000070082@`1=04d0B@0g000000000000000000000000000000000000
000000000000000000000000000000000000000000000000?`00?`@0001DbAP0@=IV08c:603eLBig
6`0n07@1I0000000D05T05P3g@4006H08=9V0<1kIP00000010000000001L0@010000020000000041
E<TH0000002<bQP0mG4^Mo3_F`7nooooZSPZMj8d:WL00000001V023BIP3@8@XW000001SBIP2LbQP0
RU=gM@00I0000000XEAgMJJI8bk@8@XW8=9V0801fWD00000dc`ZM`00JWIXbQP0d24:9hC<6000L7Ue
:]Q2FokooonQE7Me1A;FMB3BIP3PAFL0ca8QQ@002P3PAFL0e<XH05`ieWETMP08000002D0000<0000
0`0005@0001D0000@0P005/000292000YP000040002[Z^4o7LOQ_d<O001<<P000@0004`000000000
00000000003ooooooooooe00001]0000S00001P0000<0000000002D0000<0000100002P0000<0000
0`000580001`0@000`0003Woool0000000000000002@0@00000000L00P9304d0A@1H0340<0000000
000000000000000000000000000000000000000000000000000000000000000000000000000o000o
100005C96010eVH0S<XH0?Ea;WLK03h0M05T0000001@0F@0F0?M0@00IP0PdVH0`7]V000000040000
000005`100400000800000000@5DbAP0000008c:603eLBigl>mK0OkooonZ>2YgXS@ZM`00000006H0
8=9V0=0Q2RP000006=9V09c:602:DgMe001T0000002QE7MeYYTS;]0Q2RPPdVH0P07JM@00003C?2Yg
001ZMVS:603@8@XXQ<`H001`NGDZf49Ko_oooj5DMgD54]Ie8=9V0>15I`3?4R65000:0>15I`3DbQP0
G3WFMFAf00P000009@0000`000030000E00005@0002?2000^_ooolh800190@000@000:^ZhClMan6o
fQl004Lc00010000C00000000000000000000?ooooooooooD0000;@0T@1h00009@0000`000040000
:00000`000030000AP0001@000080000AdA9@`<0000R000030000?oooolR000030000?oooolU0000
300000d0080X000030000080000X0000300000@0000R000030000?oooom60000`0400;@10015CDH[
;40002@0000H00000020?`00000000000020?`0008000020:T0002@0000H0000]QhU@@0000000000
kePT@CAooLB;4M=5940000`000000000:T0002@0000H0000/08/>P0000000000/08/>P00_ZL003jY
:d0000`0000000007T0600`0000000008D0500`000000000240211P0000<00000Q30f`000003000@
=40200`0000000007T0900`000000000:T0002@0000H0000/08/>P0000000000/08/>P00_ZL003jY
8D0700`000000000:T0002@0000H0000/08/>P0000000000/08/>P00_ZL003jY:d0000`000000000
:d0000`0000000007T0600`0000000008D0500`000000000240311P0000<00000Q30f`000003000@
=40300`0000000007T0900`000000000:T0002@0000H00000020?`00000000000020?`0000000000
8D0700`000000000C00006@00000000000000<48003H00000000000000322000f@0002T0ZP000000
00000000P3l0000000000000P3l000000000000000000000000000000000000000000280000<0000
ooooodH0000L0000400004E=AR/2@00030000000000>000050000000000@00005000
\>"], "Graphics",
  GeneratedCell->False,
  CellAutoOverwrite->False,
  ImageSize->{295.70526315789476`, 28.382424812030145`},
  ImageMargins->{{26., 0.}, {0., 11.95789473684212}}]
}], "Subsubsection",
 CellChangeTimes->{{3.6371525629871335`*^9, 3.6371525929703865`*^9}, {
   3.637152667304517*^9, 3.6371526814225416`*^9}, {3.637153075690236*^9, 
   3.6371531499473667`*^9}, {3.63715320875947*^9, 3.637153235201516*^9}, {
   3.637153278085992*^9, 3.6371533175072613`*^9}, 3.637153382652975*^9, {
   3.63715382933156*^9, 3.6371538649464226`*^9}, {3.6371539028544893`*^9, 
   3.6371539154935117`*^9}, {3.6371539575385857`*^9, 
   3.6371539644025974`*^9}, {3.6371543757359204`*^9, 
   3.6371543757359204`*^9}, {3.6371544718496895`*^9, 3.637154530957593*^9}, {
   3.6371550729091454`*^9, 3.6371550729091454`*^9}, {3.6371551802941337`*^9, 
   3.637155180309734*^9}, {3.6381741717156*^9, 3.6381742638926*^9}, {
   3.6386008620846*^9, 3.6386008694406*^9}, {3.6386009149046*^9, 
   3.6386009197486*^9}, {3.6386018244596*^9, 3.6386018265466003`*^9}, {
   3.6386019518276*^9, 3.6386019570095997`*^9}, {3.6386020484105997`*^9, 
   3.6386020554636*^9}},
 Background->RGBColor[0.88, 1, 0.88]],

Cell[CellGroupData[{

Cell[TextData[{
 "The coefficients  ",
 Cell[GraphicsData["Metafile", "\<\
CF5dJ6E]HGAYHf4PEfU^I6mgLb15CDHPAVmbKF5d0@0002HT0@0006`0003oooooooooond0002U0000
00000000003W0`00]P800215CDH0004092H006<0000500000000000000000000HA<006PK003B0000
:@400000000000000000050d0`0XR0@0AP0002`0000P0000ADe6:`500@0L00004000008@`=/00000
F08005P200160000O04007010015CDH[7T0500`0000000007d0300`000000000<402010000040000
0020?b501`0<000000000290100<0000000002Y0000T000060000000P3l0000000000000P3l00000
000002]0000<0000000001i01P0<0000000002501@0<0000000001i02@0<0000000002Y0000T0000
60000000P3l0000000000000P3l00000000002501`0<0000000002Y0000T000060000;02;3X00000
00000;02;3X0j8k5040kaB]0000<0000000002Y0000T000060000;02;3X0000000000;02;3X0j8k5
040kaB]0000<0000000002Y0000T000060000;02;3X0000000000;02;3X008nY000kZ@Y0080T0000
60000>7ohOl10000000000000020G;18095eB24000080000HP0000`000010000900002@00000080m
000000000000080m00000000000200009`0001P00001000000000>7oh@0000009@0000`000010000
9@0000`000080020EP000300003oooooooooond0002U00001@000?Son?ohodP:b0i82/P>n?ohooSo
9@0000`0000700209@0000`000000020900002@00000081100000000000008110000000000020000
AP000;P>002/3P00ADe6:b]0000<0000000001i01P0<0000000002501@0<0000000001i02@0<0000
000002Y0000T000060000;02;3X0000000000;02;3X008nY000kZB501`0<0000000002]0000<0000
000002Y0000T0000600001?>8d400000000001?S8d7cN3c5@=GAABA0100<0000000000Q000FX3@00
W0d0008@`=/200000`0008`=00010000c00002L1001`oOoo?04007kmoonB:000ZZGooil[002oYooo
84E=AP000@2<3@00;P000080000`0000K000000000201`00>0@00:D2001m0@000000000000000000
eED:04S@1@1W06D0KP1U0780H@1d06D0I00P0680N@0P05L0C@1602l0A@1=04H0801R0640H`1[06D0
KP1T0200K`1V0200L01c07@0K`1U06@0J@1d0000J@1^0700M@1d0000000A0000300000H0000:0000
40000000000000004P0000`0000100005P0000`0000H0000600000`000000000DP00070100010000
>Oooo`0000000000000009010000000000020T<0C@1B0340<0000000000000000000000000000000
00000000000000000000000000000000000000000000000010000<S:60000000200000L000000000
SU<gMLS:600`bQP0k;1300@000240000b<XH00000000000030000000000100008<XH000000240000
X0l0008000030000b<XH000000000000?<XH07nN@`3l2Th0P<XH0000@`040000S[E301N=aRAXOTh0
8HQ600000000000000000040001<bQP002m:00c;603PW480af>I9?koool004<0gKE306QnCP000000
001>06QnCP38bQP00@0003P07P0;0000b<XH06QnCP010`00/7e>0040001POTh0I7H02000000U0000
30000040001D0000E00002T1001`oOoo;P4007[mool10000Zj[Q?ag7hKli5`00W3800040001<0000
0000000000000000oooooooooom@0000OP0006@0000H000030000000000U0000300000d0080X0000
30000040001B0000L0400040000ioooo0000000000000000T040000000000082@`1=04d0B@0a0300
00000000000000000000000000000000000000000000000000000000000000000000000000000000
?`00?`@000020000@=H[0<S:600000006`0n07@1:@000000D04Y05P3d04004<08=8[0<1k:`000000
10000000001L0@010000020000000041E<TH08cS:GN<bQP0mG4^Mg2L2P7nooooZSPZMj8d:WL00000
000[023B:`3H7`XP000001SB:`2LbQP0RU=gM@00:@000000XEAgMK^/aRCH7`XP8=8[0801fWD0QTh0
B03@0@00d05XbQP0f1l:88C<6000L7Ue=nfWDOkooonQE7Me1A;FMB3B:`3PAB`0_QlQD@002P3PAB`0
e<XH05`ieWETMP08000002D0000<00000@0005@0001D00009`4007?mool^0@00OOgoo`40002[Z^4o
7LOQ_a4G001Z<P000@0004`00000000000000000003ooooooooooe00001D0000N00001P0000<0000
000002D0000<00003@00P2P0000<00000@000580001`0@000@0007Goool0000000000000002@0@00
000000000P9304d0DP0g000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000o000o100005C96010eR/0S<XH0?Ea;WLK03h0M04Y0000001@0BT0
F0?@0@00:`0PdR/0`7/[000000040000000005`100400000800000000@5DbAP0000008c:603eLBig
L9`:0OkooonZ>2YgXS@ZM`00000002/08=8[0=PO2R4000006=8[09c:602:DgMe000Y0000002QE7Me
^jc69=PO2R4PdR/0P07JM@0000180=01003@0FS:603H7`XQQ<`H001`NGDgkJMAo_oooj5DMgD54]Ie
8=8[0>15;02n7b5A000:0>15;03DbQP0G3WFMFAf00P000009@0000`000010000E00005@0000^0@00
L_gooc41001hoOoo0@000:^ZhClMan6oXAL00;`b00010000C00000000000000000000?oooooooooo
D00002P0000l0000600000`0000000009@0000`0000=0020:00000`000010000DP00070100010000
MOooo`0000000000000009010000000000020T<0C@1=04T0=`000000000000000000000000000000
000000000000000000000000000000000000000000000000000003l003l40000E<TH043F:`2<bQP0
mG4^Ma/0?P1d0BT000000501:@1H0m01000[023B:`30Nb/0000000@000000000G0400@00000P0000
00010EC960000000S<XH0?Ea;WM`W0X1o_ooojXh:WNR=2Yg00000000:`0PdR/0f1l:8P00000HdR/0
W<XH08YCMgD002T000000:5DMgFk[<HTf1l:8R3B:`200MYe000004P0d0400=01J<XH0=PO2R:4c1P0
071iMCO]Ye7nooooXEAgM@DBeWDPdR/0h4D/0;hO8E4000X0h4D/0=C:601L>MIeI7H02000000U0000
30000040001D0000E0000381001boOoo=P4007Smool10000Zj[Q?ag7hKoP5`00_3800040001<0000
0000000000000000oooooooooom@0000/0000500000H000030000000000U0000300000d0080X0000
30000040001B0000L0400040001eoooo0000000000000000T040000000000082@`1=0580=`000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
?`00?`@0001DbAP0@=H[08c:603eLBig6`0n07@1:@000000D04Y05P3d04002/08=8[0<1k:`000000
10000000001L0@010000020000000041E<TH0000002<bQP0mG4^Mg2L2P7nooooZSPZMj8d:WL00000
000[023B:`3H7`XS000001SB:`2LbQP0RU=gM@00:@000000XEAgMK^/aRCH7`XS8=8[0801fWD00000
B03@0@00d05XbQP0f1l:8hC<6000L7Ue=nfWDOkooonQE7Me1A;FMB3B:`3PAB`0_QlQD@002P3PAB`0
e<XH05`ieWETMP08000002D0000<00000@0005@0001D0000=P4007;mooli0@00N?goo`40002[Z^4o
7LOQ_c`H002l<P000@0004`00000000000000000003ooooooooooe00000Y0000?00001P0000<0000
000002D0000<00003@00P2P0000<00000@000580001`0@000@0007Goool0000000000000002@0@00
000000000P9304d0C@1903L000000000000000000000000000000000000000000000000000000000
000000000000000000000000000o000o100005C96010eR/0S<XH0?Ea;WLK03h0M04Y0000001@0BT0
F0?@0@00:`0PdR/0`7/[000000040000000005`100400000800000000@5DbAP0000008c:603eLBig
L9`:0OkooonZ>2YgXS@ZM`00000002/08=8[0=PO2R@000006=8[09c:602:DgMe000Y0000002QE7Me
^jc69=PO2R@PdR/0P07JM@0000180=01003@0FS:603H7`XTQ<`H001`NGDgkJMAo_oooj5DMgD54]Ie
8=8[0>15;02n7b5A000:0>15;03DbQP0G3WFMFAf00P000009@0000`000010000E00005@0000]0@00
N?gooc@1001noOoo0@000:^ZhClMan6oQQL003Tb00010000C00000000000000000000?oooooooooo
D00006d0002<0000600000`000000000E00005@0000c0@00N?goocH1001noOoo0@000:^ZhClMan6o
4aP003Tb00010000C00000000000000000000?ooooooooooD00003/0000X0000600000`000000000
E00005@0000g0@00N?gooc`1001noOoo0@000:^ZhClMan6o@QP003Tb00010000C000000000000000
00000?ooooooooooD00006h0001T00009@0000`0000=0020:00000`0000100003P0001@000000000
400001@00008@048900001P000024<3K0@0000<00000000000000000000K@000@00003@000010000
0P0008e6Td>AhR?48S:i@HWNP4430000SDJC@i7R8lB_fIi3TN8Sa8e6Td>Mfao48@0000P0001R0000
30000040000Q00002000024000080000L`0000`000000000700000P0000U000030000000080U0000
300000L0080U0000300000h0080I000030000?ooo`0H000030000000000B000030000080000C0000
30000040000D0000300000d0000E000030000040000F000030000000000=00004000000000000000
>P0000`0000:00006`00010000000000000002<0000P0000GgXZ@@0000000000fZ`]@H@VA<F8GMi5
900002@0001ONRY100000000003J[2e1Q2I4aHQMgTD40000L`0000`0000000003@00010000000000
00000580001`0@000P0001000007000000000000002l0P00000000L20R9C07T0L`1d06D0K@0001@0
X?Sooo8100000000?;e20X3hool805QnnoKoo`00000000008;e20X3hooooo`00001D2QR@N0000020
G</e0<_<C3f@c3D0^=f21b53_WNQ724X8P2:0AP000000000H9H:1PP0003?ZBA10037?ER3l@H00000
`=c/1Zc8=@00000000000000003ooooo8<`e04c<=@0lecD0QAW2MkEcIP7nooooS>>mMo;P_GL00?H8
>?`0008000000000800007c<=@2Pc3D0jeS_MP00N00801@09U[_MQ6Y4fD00000H9H:1_ooool30000
0000000000000000J<`e08YeIfR/dcD0073aM_W^ea?noooo9U[_MV8C5GNP^U@:0@000=C<=@3Hc3D0
;c0EMfAf00P000009@0000`000020000AP0008P0001l0000AdA9@`80000W0@00L?goocd10020oOoo
<00006L0I@1^06D0LP1Q07@0I@1T0200HP1i0200E`1=04H0;`1504d0AP0P0680H@1S06/0I@1^06@0
801_06H0801`07<0M01_06D0I01Y07@0001Y06h0L01e07@0000002<0000P0000;W<8?`0000000000
[o0:_h@VA<F8GMi5900002@0000^L`Po00000000002_l0ZoQ2I4aHQMgTD400008`000200000^L`Po
00000000002_l0ZoQ2I4aHQMgTDT0000900002ic23l0000000000:o`2[n49TC5R5gNA@@0000B0000
30000040000F0000300001P0000H000030000000001B0000L04000<0000ioooo0000000000000000
T040000000070082@`1=0580<@0`0000000000000000000000000000000000000000000000000000
00000000000000000000000000040000b<XH0000000800001`000000002>DcMeb<XH033:603//4<0
100008@00038bQP000000000000<000000000040000PbQP0000008@0002P3`000P0000<00038bQP0
00000000000lbQP0Oii30?`:CP20bQP0001300@0002>]D<05hg696QnCP0QR4H00000000000000000
0@0004c:6000;dX03</H0>2L@P37HiTTo_ooo`00@`3M]D<0J7i>0000000004h0J7i>0<S:60010000
>00N00/00038bQP0J7i>0043002`ODh00@00061nCP1TMP08000002D0000<00000`0005@0001D0000
7P0000<0001D0000KP000040002[Z^4o7LOQ_cTG002L<P000@0004`00000000000000000003ooooo
oooooe00001n06H0I00001P0000<000000000580001`0@00100001@00009000000000000002l0P00
000000L20R9C07T0L`1d06D0K@00000000000>8000000000K4Aj0X3hool000000000000000000000
D4Aj0X3hoonjUP00000EMkMT5GNQ724X0000000000010000F3gm1MS;=@1QI1EgXA`Q:00000000000
E0000000001H?Od5D<`e0=iA5GNQ724Xn=n70080003HG5l3E000000000010000>00N00/00038bQP0
J7i>0043002`ODh00@00061nCP00000800000<3Lk0J/b3D0D<`e02l`5GM@c3D0IS0EMhC6F`YPUPX6
9@0000002P085`00Q<de01gjHfRQ724X002705Pmo@D20000f5aO0k8:I6Q81QUg000004P66GN00AUg
V<IK2ZS<=@0_<1EgZ<`e06H`5GOTaU/:H9H:1VAf00P000009@0000`000040000:00000`000030000
DP00070100030000>Oooo`000000000000000901000000001`020T<0C@1=04T0<@0`000000000000
0000000000000000000000000000000000000000000000000000000000000000000003l003l40000
0P00043F:`38bQP0000001/0?P1d0BT000000501:@1H0m010013023B:`30Nb/0000000@000000000
G0400@00000P000000010EC9602<hbUgS<XH0?Ea;WM`W0X1o_ooojXh:WNR=2Yg00000000:`0PdR/0
f1l:8000000HdR/0W<XH08YCMgD002T000000:5DMgFk[<HTf1l:823B:`200MYe08I>04P0d0400=01
J<XH0=PO2R24c1P0071iMCO]Ye7nooooXEAgM@DBeWDPdR/0h4D/0;hO8E4000X0h4D/0=C:601L>MIe
I7H02000000U0000300000<0001D0000E00000T0000N0000E00008T000010000Zj[Q?ag7hKlA5`00
JS800040001<00000000000000000000oooooooooom@0000E00007P0000H000030000000000U0000
300000@0000X0000300000<0001B0000L04000<0001eoooo0000000000000000T040000000070082
@`1=0580=`0000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000?`00?`@0001DbAP0@=H[08c:603eLBig6`0n07@1:@000000D04Y05P3d04002/0
8=8[0<1k:`00000010000000001L0@010000020000000041E<TH0000002<bQP0mG4^Mg2L2P7noooo
ZSPZMj8d:WL00000000[023B:`3H7`XQ000001SB:`2LbQP0RU=gM@00:@000000XEAgMK^/aRCH7`XQ
8=8[0801fWD00000B03@0@00d05XbQP0f1l:8HC<6000L7Ue=nfWDOkooonQE7Me1A;FMB3B:`3PAB`0
_QlQD@002P3PAB`0e<XH05`ieWETMP08000002D0000<00000`0005@0001D0000EP0000X0001f0000
E@000040002[Z^4o7LOQ_j4G002l<P000@0004`00000000000000000003ooooooooooe00000X0000
?00001P0000<0000000002D0000<0000100002P0000<00000`000580001`0@000`0007Goool00000
00000000002@0@00000000L00P9304d0C@1903L00000000000000000000000000000000000000000
0000000000000000000000000000000000000000000o000o100005C96010eR/0S<XH0?Ea;WLK03h0
M04Y0000001@0BT0F0?@0@00:`0PdR/0`7/[000000040000000005`100400000800000000@5DbAP0
000008c:603eLBigL9`:0OkooonZ>2YgXS@ZM`00000002/08=8[0=PO2R8000006=8[09c:602:DgMe
000Y0000002QE7Me^jc69=PO2R8PdR/0P07JM@0000180=01003@0FS:603H7`XRQ<`H001`NGDgkJMA
o_oooj5DMgD54]Ie8=8[0>15;02n7b5A000:0>15;03DbQP0G3WFMFAf00P000009@0000`000030000
E00005@0001g00002P000:D0001E00000@000:^ZhClMan6oh1L00;`b00010000C000000000000000
00000?ooooooooooD0000;00001@0000600000`0000000009@0000`000040000:00000`000030000
DP00070100030000MOooo`000000000000000901000000001`020T<0C@1B03L00000000000000000
0000000000000000000000000000000000000000000000000000000000000000000003l003l40000
E<TH043F:`2<bQP0mG4^Ma/0?P1d0BT000000501:@1H0m01000[023B:`30Nb/0000000@000000000
G0400@00000P000000010EC960000000S<XH0?Ea;WM`W0X1o_ooojXh:WNR=2Yg00000000:`0PdR/0
f1l:8`00000HdR/0W<XH08YCMgD002T000000:5DMgFk[<HTf1l:8b3B:`200MYe000004P0d0400=01
J<XH0=PO2R>4c1P0071iMCO]Ye7nooooXEAgM@DBeWDPdR/0h4D/0;hO8E4000X0h4D/0=C:601L>MIe
I7H02000000U0000300000<0001D0000E0000:P0000:0000b00005D000010000Zj[Q?ag7hKll6000
_3800040001<00000000000000000000oooooooooom@0000:@0QQC`0000H000030000000000U0000
300000@0000X0000300000<0001B0000L04000<0001eoooo0000000000000000T040000000070082
@`1=04d0B@0g00000000000000000000000000000000000000000000000000000000000000000000
0000000000000000?`00?`@0001DbAP0@=H[08c:603eLBig6`0n07@1:@000000D04Y05P3d04002/0
8=8[0<1k:`00000010000000001L0@010000020000000041E<TH0000002<bQP0mG4^Mg2L2P7noooo
ZSPZMj8d:WL00000000[023B:`3H7`XT000001SB:`2LbQP0RU=gM@00:@000000XEAgMK^/aRCH7`XT
8=8[0801fWD00000B03@0@00d05XbQP0f1l:98C<6000L7Ue=nfWDOkooonQE7Me1A;FMB3B:`3PAB`0
_QlQD@002P3PAB`0e<XH05`ieWETMP08000002D0000<00000`0005@0001D0000A`000540002B0000
W0000040002[Z^4o7LOQ_hHG000i<P000@0004`00000000000000000003ooooooooooe00001]0265
S00001P0000<0000000005@0001D0000T`000540002Y0000W0000040002[Z^4o7LOQ_a<H000i<P00
0@0004`00000000000000000003ooooooooooe00000k0000:00001P0000<0000000005@0001D0000
[0000540003R0000W0000040002[Z^4o7LOQ_d8H000i<P000@0004`00000000000000000003ooooo
oooooe00001^0000I00002D0000<0000100002P0000<00000`0004H0000D0000200004M4BD<30000
8P0000`0003ooooo8P0000`0003ooooo9@0000`0000=0020:00000`000020000:00000`000040000
8P0000`0003oooooAP000<01002d0@00ADe6:ba0000T000060000000P3l0000000000000P3l00020
0000P2Y0000T0000600001?>8d400000000001?S8d7cN3c5@=GAABA0000<0000000002Y0000T0000
60000;02;3X0000000000;02;3X008nY000kZB]0000<0000000001i01P0<0000000002501@0<0000
000000Q00P@H00003000008@`=/000000`0043A00P0<0000000001i02@0<0000000002Y0000T0000
60000;02;3X0000000000;02;3X008nY000kZB501`0<0000000002Y0000T000060000;02;3X00000
00000;02;3X008nY000kZB]0000<0000000002]0000<0000000001i01P0<0000000002501@0<0000
000000Q00`@H00003000008@`=/000000`0043A00`0<0000000001i02@0<0000000002Y0000T0000
60000000P3l0000000000000P3l00000000002501`0<0000000004`0001T000000000000003/0000
Y000000000000000k@000:D0000Y0:X0000000000000080o000000000000080o0000000000000000
000000000000000000000000000R000030000?oooom60000700001000015CDH[0T0000`000000000
3P0001@000000000400001@0
\>"], "Graphics",
  GeneratedCell->False,
  CellAutoOverwrite->False,
  ImageSize->{31.800000000000008`, 21.651063829787272`},
  ImageMargins->{{1.7263157894736698`, 0.}, {0., 6.800000000000008}}],
 "   of the paper are given here by the function TT[m,n,\[Gamma]]",
 StyleBox["  ",
  FontSlant->"Italic"],
 "where  ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["t", "n"], TraditionalForm]]],
 "=tt[n]"
}], "Text",
 CellChangeTimes->{{3.636977241041491*^9, 3.636977288861226*^9}, {
  3.6371540193780947`*^9, 3.637154134615897*^9}, {3.6371541746923676`*^9, 
  3.637154286800164*^9}, {3.637154738875758*^9, 3.6371547440861673`*^9}, {
  3.6371553197739787`*^9, 3.63715540584133*^9}, {3.6381742718185997`*^9, 
  3.6381742799796*^9}, {3.6386009291646*^9, 3.6386009306046*^9}, {
  3.6386019595875998`*^9, 3.6386019595875998`*^9}},
 Background->RGBColor[0.88, 1, 0.88]],

Cell[BoxData[
 RowBox[{
  RowBox[{"TT", "[", 
   RowBox[{"m_", ",", "n_", ",", "gamma_"}], "]"}], ":=", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"tt", "[", "n", " ", "]"}], "-", 
        RowBox[{"tt", "[", "m", "]"}]}], ")"}], "^", 
      RowBox[{"(", 
       RowBox[{"1", "-", "gamma"}], ")"}]}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"tt", "[", "n", " ", "]"}], "-", 
        RowBox[{"tt", "[", 
         RowBox[{"m", "+", "1"}], "]"}]}], ")"}], "^", 
      RowBox[{"(", 
       RowBox[{"1", "-", "gamma"}], ")"}]}]}], ")"}], "/", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"tt", "[", 
      RowBox[{"m", "+", "1"}], "]"}], "-", 
     RowBox[{"tt", "[", "m", "]"}]}], ")"}]}]}]], "Input",
 Background->RGBColor[0.88, 1, 0.88]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 "The coefficient\n  ",
 Cell[GraphicsData["Metafile", "\<\
CF5dJ6E]HGAYHf4PEfU^I6mgLb15CDHPAVmbKF5d0@000;fD0@0006`0003ooooon_ooo`D9002C0@00
00000000000Z9P00L@D00215CDH00040U;d004l1000500000000000000000000HA<006PK003B0000
:@400000000000000000050d0`0XR0@0AP0002`0000P0000ADe6:`500@0L00004000008@`=/00000
F08005P200160000O04007010015CDH[7T0500`0000000007d0300`000000000<402010000040000
0020?b501`0<000000000290100<0000000002Y0000T000060000000P3l0000000000000P3l00000
000002]0000<0000000001i01P0<0000000002501@0<0000000001i02@0<0000000002Y0000T0000
60000000P3l0000000000000P3l00000000002501`0<0000000002Y0000T000060000;02;3X00000
00000;02;3X042?5021IaB]0000<0000000002Y0000T000060000;02;3X0000000000;02;3X042?5
021IaB]0000<0000000002Y0000T000060000;02;3X0000000000;02;3X002>Y001IZ@Y0080T0000
60000>7ohOl1000000000000000@aeI:097eB24000080000HP0000`000010000900002@00000000n
000000000000000n00000000000200009`0001P00001000000000>7oh@0000009@0000`000010000
9@0000`000080020EP000300003oooooooooo`D9001:0@001@000?coo?olod`:94Q<2RA8o?olooco
9@0000`0000700209@0000`000000020900002@00000001100000000000000110000000000020000
AP00071J001TFP00ADe6:b]0000<0000000001i01P0<0000000002501@0<0000000001i02@0<0000
000002Y0000T000060000;02;3X0000000000;02;3X002>Y001IZB501`0<0000000002]0000<0000
000002Y0000T0000600000jn94400000000005<g945B3?W4jiCBABA0100<0000000000Q000EPF@00
E5T0008@`=/200000`0004AI00010000c0000<80001_oOooX04009GmoonW6P00QZGoofLi003AZOoo
84E=AP000@14F@006P400080000`0000K000000000201`00>0@00:D2001m0@000000000000000000
eED:04S@1@1W06D0KP1U0780H@1d06D0I00P0680N@0P05L0C@1602l0A@1=04H0801R0640H`1[06D0
KP1T0200K`1V0200L01c07@0K`1U06@0J@1d0000J@1^0700M@1d0000000A0000300000H0000:0000
40000000000000004P0000`0000100005P0000`0000H0000600000`000000000DP00070100010000
>Oooo`0000000000000009010000000000020T<0C@1=04T0<@0`0000000000000000000000000000
00000000000000000000000000000000000000000000000010000<S:60000000200000L000000000
SU<gMLS:600`bQP0k;1300@000240000b<XH00000000000030000000000100008<XH000000240000
X0l0008000030000b<XH000000000000?<XH07nN@`3l2Wl0P<XH0000@`040000S[E30639c5=XOWl0
8HQ600000000000000000040001<bQP002m:00c;603PW480/2NCDokoool004<0gKE306QnO`000000
001o06QnO`38bQP00@0003P07P0;0000b<XH06QnO`010`00/7eo0040001POWl0I7H02000000U0000
30000040001D0000E0000<80001joOoobP0008Cmool10000Zj[Q?ag7hKl`3`00gS400040001<0000
0000000000000000oooooooooom@0000A`000:00000H000030000000000U0000300000d0080X0000
30000040001B0000L0400040001eoooo0000000000000000T040000000000082@`1=0580=`000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
?`00?`@000020000@=JA0<S:600000006`0n07@1S`000000D06?05P3g`4004<08=:A0<1kT@000000
10000000001L0@010000020000000041E<TH08cS:GN<bQP0mG4^Mm@M1P7nooooZSPZMj8d:WL00000
002A023BT@0n80XK000001SBT@2LbQP0RU=gM@00S`000000XEAgMILKdU<n80XK8=:A0801fWD0QWl0
B03O0@00g`5XbQP0?R0:6hC<6000L7Ue6eZc9_kooonQE7Me1A;FMB3BT@3PAI80I20Q2@002P3PAI80
e<XH05`ieWETMP08000002D0000<00000@0005@0001D0000bP0007Smooo=0000O_goo`40002[Z^4o
7LOQ_ld?0016<P000@0004`00000000000000000003ooooooooooe00000X0000?00001P0000<0000
000002D0000<00003@00P2P0000<00000@000580001`0@000@0007Goool0000000000000002@0@00
000000000P9304d0C@1903L000000000000000000000000000000000000000000000000000000000
000000000000000000000000000o000o100005C96010eY40S<XH0?Ea;WLK03h0M06?0000001@0Hl0
F0?O0@00T@0PdY40`7^A000000040000000005`100400000800000000@5DbAP0000008c:603eLBig
e1d60OkooonZ>2YgXS@ZM`00000009408=:A03hP2Q`000006=:A09c:602:DgMe002?0000002QE7Me
Ua_BDchP2Q`PdY40P07JM@0000180=l1003O0FS:600n80XLQ<`H001`NGDKF[<Vo_oooj5DMgD54]Ie
8=:A0>15TP1T8249000:0>15TP3DbQP0G3WFMFAf00P000009@0000`000010000E00005@0003=0000
N?goom80001noOoo0@000:^ZhClMan6o310004Hb00010000C00000000000000000000?oooooooooo
D00006h0001T0000600000`0000000009@0000`0000=0020:00000`000010000DP00070100010000
MOooo`0000000000000009010000000000020T<0C@1B03L000000000000000000000000000000000
000000000000000000000000000000000000000000000000000003l003l40000E<TH043FT@2<bQP0
mG4^Ma/0?P1d0Hl000000501S`1H0ml1002A023BT@30Ni40000000@000000000G0400@00000P0000
00010EC960000000S<XH0?Ea;WOD7@H1o_ooojXh:WNR=2Yg00000000T@0PdY40?R0:7@00000HdY40
W<XH08YCMgD008l000000:5DMgFG6m9C?R0:7B3BT@200MYe000004P0g`400=l1J<XH03hP2Qf4c1P0
071iMA]J/bKnooooXEAgM@DBeWDPdY40h4FB06@P8@T000X0h4FB0=C:601L>MIeI7H02000000U0000
30000040001D0000E0000=80001hoOooe@0007kmool10000Zj[Q?ag7hKm^4000AS800040001<0000
0000000000000000oooooooooom@0000:@0003`0000H000030000000000U0000300000d0080X0000
30000040001B0000L0400040001eoooo0000000000000000T040000000000082@`1=04d0B@0g0000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
?`00?`@0001DbAP0@=JA08c:603eLBig6`0n07@1S`000000D06?05P3g`4009408=:A0<1kT@000000
10000000001L0@010000020000000041E<TH0000002<bQP0mG4^Mm@M1P7nooooZSPZMj8d:WL00000
002A023BT@0n80XN000001SBT@2LbQP0RU=gM@00S`000000XEAgMILKdU<n80XN8=:A0801fWD00000
B03O0@00g`5XbQP0?R0:7XC<6000L7Ue6eZc9_kooonQE7Me1A;FMB3BT@3PAI80I20Q2@002P3PAI80
e<XH05`ieWETMP08000002D0000<00000@0005@0001D0000bP00083mooo=0000Q_goo`40002[Z^4o
7LOQ_ld?002V<@000@0004`00000000000000000003ooooooooooe00001Z0000?00001P0000<0000
000002D0000<00003@00P2P0000<00000@000580001`0@000@0003Woool0000000000000002@0@00
000000000P9304d0D`1I0340<01?0580B@1700000000000000000000000000000000000000000000
000000000000000000000000000o000o100005C96010eY40S<XH0?Ea;WLK03h0M06?0000001@0Hl0
F0?O0@00T@0PdY40`7^A000000040000000005`100400000800000000@5DbAP0000008c:603eLBig
e1d60OkooonZ>2YgXS@ZM`00000009408=:A03hP2Ql000006=:A09c:602:DgMe002?0000002QE7Me
Ua_BDchP2QlPdY40P07JM@0000180=l1003O0FS:600n80XOQ<`H001`NGDKF[<Vo_oooj5DMgD54]Ie
8=:A0>15TP1T8249000:0>15TP3DbQP0G3WFMFAf00P000009@0000`000010000E00005@0003I0000
N_goon40002;oOoo0@000:^ZhClMan6ok1000=ha00010000C00000000000000000000?oooooooooo
D0000;@0002P0000600000`0000000009@0000`0000=0020:00000`000010000DP00070100010000
>Oooo`0000000000000009010000000000020T<0C@1=04T0<@0`0000000000000000000000000000
000000000000000000000000000000000000000000000000000003l003l40000E<TH043FT@2<bQP0
mG4^Ma/0?P1d0Hl000000501S`1H0ml1002A023BT@30Ni40000000@000000000G0400@00000P0000
00010EC960000000S<XH0?Ea;WOD7@H1o_ooojXh:WNR=2Yg00000000T@0PdY40?R0:8000000HdY40
W<XH08YCMgD008l000000:5DMgFG6m9C?R0:823BT@200MYe000004P0g`400=l1J<XH03hP2R24c1P0
071iMA]J/bKnooooXEAgM@DBeWDPdY40h4FB06@P8@T000X0h4FB0=C:601L>MIeI7H02000000U0000
30000040001D0000E0000><0001joOooj`0008Cmool10000Zj[Q?ag7hKno4@00gS400040001<0000
0000000000000000oooooooooom@0000E@0008`0000H000030000000000U0000300000d0080X0000
30000040001B0000L0400040001eoooo0000000000000000T040000000000082@`1=0580=`000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
?`00?`@0001DbAP0@=JA08c:603eLBig6`0n07@1S`000000D06?05P3g`4009408=:A0<1kT@000000
10000000001L0@010000020000000041E<TH0000002<bQP0mG4^Mm@M1P7nooooZSPZMj8d:WL00000
002A023BT@0n80XQ000001SBT@2LbQP0RU=gM@00S`000000XEAgMILKdU<n80XQ8=:A0801fWD00000
B03O0@00g`5XbQP0?R0:8HC<6000L7Ue6eZc9_kooonQE7Me1A;FMB3BT@3PAI80I20Q2@002P3PAI80
e<XH05`ieWETMP08000002D0000<00000@0005@0001D0000j`0007Smooo^0000O_goo`40002[Z^4o
7LOQ_e`B0016<P000@0004`00000000000000000003ooooooooooe00000X0000?00001P0000<0000
000002D0000<00003@00P2P0000<00000@000580001`0@000@0007Goool0000000000000002@0@00
000000000P9304d0C@1903L000000000000000000000000000000000000000000000000000000000
000000000000000000000000000o000o100005C96010eY40S<XH0?Ea;WLK03h0M06?0000001@0Hl0
F0?O0@00T@0PdY40`7^A000000040000000005`100400000800000000@5DbAP0000008c:603eLBig
e1d60OkooonZ>2YgXS@ZM`00000009408=:A03hP2R8000006=:A09c:602:DgMe002?0000002QE7Me
Ua_BDchP2R8PdY40P07JM@0000180=l1003O0FS:600n80XRQ<`H001`NGDKF[<Vo_oooj5DMgD54]Ie
8=:A0>15TP1T8249000:0>15TP3DbQP0G3WFMFAf00P000009@0000`000010000E00005@0003^0000
N?gooo<0001noOoo0@000:^ZhClMan6oVa8004Hb00010000C00000000000000000000?oooooooooo
D00006h0001T0000600000`0000000009@0000`0000=0020:00000`000010000DP00070100010000
MOooo`0000000000000009010000000000020T<0C@1C05T0=`000000000000000000000000000000
000000000000000000000000000000000000000000000000000003l003l40000E<TH043FT@2<bQP0
mG4^Ma/0?P1d0Hl000000501S`1H0ml1002A023BT@30Ni40000000@000000000G0400@00000P0000
00010EC960000000S<XH0?Ea;WOD7@H1o_ooojXh:WNR=2Yg00000000T@0PdY40?R0:8`00000HdY40
W<XH08YCMgD008l000000:5DMgFG6m9C?R0:8b3BT@200MYe000004P0g`400=l1J<XH03hP2R>4c1P0
071iMA]J/bKnooooXEAgM@DBeWDPdY40h4FB06@P8@T000X0h4FB0=C:601L>MIeI7H02000000U0000
30000040001D0000E0000?<0001hoOoon@0008?mool10000Zj[Q?ag7hKom4P00AS800040001<0000
0000000000000000oooooooooom@0000X@0007P0000H000030000000000U0000300000d0080X0000
30000040001B0000L0400040001eoooo0000000000000000T040000000000082@`1=0580=`000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
?`00?`@0001DbAP0@=JA08c:603eLBig6`0n07@1S`000000D06?05P3g`4009408=:A0<1kT@000000
10000000001L0@010000020000000041E<TH0000002<bQP0mG4^Mm@M1P7nooooZSPZMj8d:WL00000
002A023BT@0n80XT000001SBT@2LbQP0RU=gM@00S`000000XEAgMILKdU<n80XT8=:A0801fWD00000
B03O0@00g`5XbQP0?R0:98C<6000L7Ue6eZc9_kooonQE7Me1A;FMB3BT@3PAI80I20Q2@002P3PAI80
e<XH05`ieWETMP08000002D0000<00000@0005@0001D0000n@0007Smooom0000O_goo`40002[Z^4o
7LOQ_gTC0016<P000@0004`00000000000000000003ooooooooooe00000a0000D00001P0000<0000
000005@0001D0000o@0007Smool00@00O_goo`40002[Z^4o7LOQ_lTC0016<P000@0004`000000000
00000000003ooooooooooe00000Y0000?00001P0000<0000000002D0000<00003@00P2P0000<0000
0@000580001`0@000@0007Goool0000000000000002@0@00000000000P9304d0C@1903L000000000
000000000000000000000000000000000000000000000000000000000000000000000000000o000o
100005C96010eY40S<XH0?Ea;WLK03h0M06?0000001@0Hl0F0?O0@00T@0PdY40`7^A000000040000
000005`100400000800000000@5DbAP0000008c:603eLBige1d60OkooonZ>2YgXS@ZM`0000000940
8=:A03hP2RD000006=:A09c:602:DgMe002?0000002QE7MeUa_BDchP2RDPdY40P07JM@0000180=l1
003O0FS:600n80XUQ<`H001`NGDKF[<Vo_oooj5DMgD54]Ie8=:A0>15TP1T8249000:0>15TP3DbQP0
G3WFMFAf00P000009@0000`000010000E00005@0003Z0000P?goond00026oOoo0@000:^ZhClMan6o
Aa800:Ha00010000C00000000000000000000?ooooooooooD00006X0000l0000600000`000000000
9@0000`0000=0020:00000`000010000DP00070100010000>Oooo`00000000000000090100000000
00020T<0C@1C05T0<@0`04l0DP1904L0000000000000000000000000000000000000000000000000
0000000000000000000003l003l40000E<TH043FT@2<bQP0mG4^Ma/0?P1d0Hl000000501S`1H0ml1
002A023BT@30Ni40000000@000000000G0400@00000P000000010EC960000000S<XH0?Ea;WOD7@H1
o_ooojXh:WNR=2Yg00000000T@0PdY40?R0:9P00000HdY40W<XH08YCMgD008l000000:5DMgFG6m9C
?R0:9R3BT@200MYe000004P0g`400=l1J<XH03hP2RJ4c1P0071iMA]J/bKnooooXEAgM@DBeWDPdY40
h4FB06@P8@T000X0h4FB0=C:601L>MIeI7H02000000U000030000040001D0000E00000<1001joOoo
2`4008_mool10000Zj[Q?ag7hKln5000gS400040001<00000000000000000000oooooooooom@0000
X@000:00000H000030000000000U0000300000d0080X000030000040001B0000L0400040001eoooo
0000000000000000T040000000000082@`1=04d0B@0g000000000000000000000000000000000000
000000000000000000000000000000000000000000000000?`00?`@0001DbAP0@=JA08c:603eLBig
6`0n07@1S`000000D06?05P3g`4009408=:A0<1kT@00000010000000001L0@010000020000000041
E<TH0000002<bQP0mG4^Mm@M1P7nooooZSPZMj8d:WL00000002A023BT@0n80XW000001SBT@2LbQP0
RU=gM@00S`000000XEAgMILKdU<n80XW8=:A0801fWD00000B03O0@00g`5XbQP0?R0:9hC<6000L7Ue
6eZc9_kooonQE7Me1A;FMB3BT@3PAI80I20Q2@002P3PAI80e<XH05`ieWETMP08000002D0000<0000
0@0005@0001D00003P40073moolC0@00M_goo`40002[Z^4o7LOQ_aTE003G<P000@0004`000000000
00000000003ooooooooooe00001^0000I00001P0000<0000000002D0000<00003@00P2P0000<0000
0@000580001`0@000@0007Goool0000000000000002@0@00000000000P9304d0D`1I03L000000000
000000000000000000000000000000000000000000000000000000000000000000000000000o000o
100005C96010eY40S<XH0?Ea;WLK03h0M06?0000001@0Hl0F0?O0@00T@0PdY40`7^A000000040000
000005`100400000800000000@5DbAP0000008c:603eLBige1d60OkooonZ>2YgXS@ZM`0000000940
8=:A03hP2RP000006=:A09c:602:DgMe002?0000002QE7MeUa_BDchP2RPPdY40P07JM@0000180=l1
003O0FS:600n80XXQ<`H001`NGDKF[<Vo_oooj5DMgD54]Ie8=:A0>15TP1T8249000:0>15TP3DbQP0
G3WFMFAf00P000009@0000`000010000E00005@0000C0@00L?gooaT1001koOoo0@000:^ZhClMan6o
O1D00=Lb00010000C00000000000000000000?ooooooooooD0000:40001h0000600000`000000000
9@0000`0000=0020:00000`000010000DP00070100010000MOooo`00000000000000090100000000
00020T<0C@1B03L00000000000000000000000000000000000000000000000000000000000000000
0000000000000000000003l003l40000E<TH043FT@2<bQP0mG4^Ma/0?P1d0Hl000000501S`1H0ml1
002A023BT@30Ni40000000@000000000G0400@00000P000000010EC960000000S<XH0?Ea;WOD7@H1
o_ooojXh:WNR=2Yg00000000T@0PdY40?R0::@00000HdY40W<XH08YCMgD008l000000:5DMgFG6m9C
?R0::B3BT@200MYe000004P0g`400=l1J<XH03hP2RV4c1P0071iMA]J/bKnooooXEAgM@DBeWDPdY40
h4FB06@P8@T000X0h4FB0=C:601L>MIeI7H02000000U000030000040001D0000E00001T1001`oOoo
7@4007Kmool10000Zj[Q?ag7hKoh5@00ec800040001<00000000000000000000oooooooooom@0000
<P000500000H000030000000000U0000300000d0080X000030000040001B0000L0400040000ioooo
0000000000000000T040000000000082@`1=04D0F00a030000000000000000000000000000000000
000000000000000000000000000000000000000000000000?`00?`@0001DbAP0@=JA08c:603eLBig
6`0n07@1S`000000D06?05P3g`4009408=:A0<1kT@00000010000000001L0@010000020000000041
E<TH0000002<bQP0mG4^Mm@M1P7nooooZSPZMj8d:WL00000002A023BT@0n80XZ000001SBT@2LbQP0
RU=gM@00S`000000XEAgMILKdU<n80XZ8=:A0801fWD00000B03O0@00g`5XbQP0?R0::XC<6000L7Ue
6eZc9_kooonQE7Me1A;FMB3BT@3PAI80I20Q2@002P3PAI80e<XH05`ieWETMP08000002D0000<0000
0@0005@0001D00003P40073moolL0@00UOgoo`40002[Z^4o7LOQ_b0E002K<P000@0004`000000000
00000000003ooooooooooe00001H0000604001P0000<0000000002D0000<00003@00P2P0000<0000
0@000580001`0@000@0007Goool0000000000000002@0@00000000000P9304d0C@1903L000000000
000000000000000000000000000000000000000000000000000000000000000000000000000o000o
100005C96010eY40S<XH0?Ea;WLK03h0M06?0000001@0Hl0F0?O0@00T@0PdY40`7^A000000040000
000005`100400000800000000@5DbAP0000008c:603eLBige1d60OkooonZ>2YgXS@ZM`0000000940
8=:A03hP2R/000006=:A09c:602:DgMe002?0000002QE7MeUa_BDchP2R/PdY40P07JM@0000180=l1
003O0FS:600n80X[Q<`H001`NGDKF[<Vo_oooj5DMgD54]Ie8=:A0>15TP1T8249000:0>15TP3DbQP0
G3WFMFAf00P000009@0000`000010000E00005@0000=0@00R?gooa@1002>oOoo0@000:^ZhClMan6o
1AD00?D`00010000C00000000000000000000?ooooooooooD00006d0002<0000600000`000000000
9@0000`0000=0020:00000`000010000DP00070100010000MOooo`00000000000000090100000000
00020T<0C@1B03L00000000000000000000000000000000000000000000000000000000000000000
0000000000000000000003l003l40000E<TH043FT@2<bQP0mG4^Ma/0?P1d0Hl000000501S`1H0ml1
002A023BT@30Ni40000000@000000000G0400@00000P000000010EC960000000S<XH0?Ea;WOD7@H1
o_ooojXh:WNR=2Yg00000000T@0PdY40?R0:;000000HdY40W<XH08YCMgD008l000000:5DMgFG6m9C
?R0:;23BT@200MYe000004P0g`400=l1J<XH03hP2Rb4c1P0071iMA]J/bKnooooXEAgM@DBeWDPdY40
h4FB06@P8@T000X0h4FB0=C:601L>MIeI7H02000000U000030000040001D0000E00001@10028oOoo
6P4008kmool10000Zj[Q?ag7hKnB5@00mC000040001<00000000000000000000oooooooooom@0000
?@0007P0000H000030000000001D0000E00001X10028oOoo7P4008kmool10000Zj[Q?ag7hKl=5P00
mC000040001<00000000000000000000oooooooooom@0000<0000500000H000030000000000U0000
300000d0080X000030000040001B0000L0400040000ioooo0000000000000000T040000000000082
@`1=0580<@0`00000000000000000000000000000000000000000000000000000000000000000000
0000000000000000?`00?`@0001DbAP0@=JA08c:603eLBig6`0n07@1S`000000D06?05P3g`400940
8=:A0<1kT@00000010000000001L0@010000020000000041E<TH0000002<bQP0mG4^Mm@M1P7noooo
ZSPZMj8d:WL00000002A023BT@0n80X]000001SBT@2LbQP0RU=gM@00S`000000XEAgMILKdU<n80X]
8=:A0801fWD00000B03O0@00g`5XbQP0?R0:;HC<6000L7Ue6eZc9_kooonQE7Me1A;FMB3BT@3PAI80
I20Q2@002P3PAI80e<XH05`ieWETMP08000002D0000<00000@0005@0001D00008P4007OmoolW0@00
POgoo`40002[Z^4o7LOQ_j@F000@<P000@0004`00000000000000000003ooooooooooe00001n0000
I00001P0000<0000000002D0000<00003@00P2P0000<00000@000580001`0@000@0003Woool00000
00000000002@0@00000000000P9304d0C@190340<000000000000000000000000000000000000000
0000000000000000000000000000000000000000000o000o100005C96010eY40S<XH0?Ea;WLK03h0
M06?0000001@0Hl0F0?O0@00T@0PdY40`7^A000000040000000005`100400000800000000@5DbAP0
000008c:603eLBige1d60OkooonZ>2YgXS@ZM`00000009408=:A03hP2Rh000006=:A09c:602:DgMe
002?0000002QE7MeUa_BDchP2RhPdY40P07JM@0000180=l1003O0FS:600n80X^Q<`H001`NGDKF[<V
o_oooj5DMgD54]Ie8=:A0>15TP1T8249000:0>15TP3DbQP0G3WFMFAf00P000009@0000`000010000
E00005@0000P0@00N_goobL10024oOoo0@000:^ZhClMan6oOQH00=ha00010000C000000000000000
00000?ooooooooooD00005@0001h0000600000`0000000009@0000`0000=0020:00000`000010000
DP00070100010000MOooo`0000000000000009010000000000020T<0C@1B03L00000000000000000
0000000000000000000000000000000000000000000000000000000000000000000003l003l40000
E<TH043FT@2<bQP0mG4^Ma/0?P1d0Hl000000501S`1H0ml1002A023BT@30Ni40000000@000000000
G0400@00000P000000010EC960000000S<XH0?Ea;WOD7@H1o_ooojXh:WNR=2Yg00000000T@0PdY40
?R0:;`00000HdY40W<XH08YCMgD008l000000:5DMgFG6m9C?R0:;b3BT@200MYe000004P0g`400=l1
J<XH03hP2Rn4c1P0071iMA]J/bKnooooXEAgM@DBeWDPdY40h4FB06@P8@T000X0h4FB0=C:601L>MIe
I7H02000000U000030000040001D0000E00002L1001ioOoo:P4007omool10000Zj[Q?ag7hKl>5`00
<3800040001<00000000000000000000oooooooooom@0000:00003`0000H000030000000000U0000
300000d0080X000030000040001B0000L0400040001eoooo0000000000000000T040000000000082
@`1=04d0B@0g00000000000000000000000000000000000000000000000000000000000000000000
0000000000000000?`00?`@0001DbAP0@=JA08c:603eLBig6`0n07@1S`000000D06?05P3g`400940
8=:A0<1kT@00000010000000001L0@010000020000000041E<TH0000002<bQP0mG4^Mm@M1P7noooo
ZSPZMj8d:WL00000002A023BT@0n80X`000001SBT@2LbQP0RU=gM@00S`000000XEAgMILKdU<n80X`
8=:A0801fWD00000B03O0@00g`5XbQP0?R0:<8C<6000L7Ue6eZc9_kooonQE7Me1A;FMB3BT@3PAI80
I20Q2@002P3PAI80e<XH05`ieWETMP08000002D0000<00000@0005@0001D0000:P4007Wmool^0@00
Oogoo`40002[Z^4o7LOQ_d`G000`<P000@0004`00000000000000000003ooooooooooe00002`0000
D00001P0000<0000000002D0000<00003@00P2P0000<00000@000580001`0@000@0007Goool00000
00000000002@0@00000000000P9304d0DP0g00000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000o000o100005C96010eY40S<XH0?Ea;WLK03h0
M06?0000001@0Hl0F0?O0@00T@0PdY40`7^A000000040000000005`100400000800000000@5DbAP0
000008c:603eLBige1d60OkooonZ>2YgXS@ZM`00000009408=:A03hP2S4000006=:A09c:602:DgMe
002?0000002QE7MeUa_BDchP2S4PdY40P07JM@0000180=l1003O0FS:600n80XaQ<`H001`NGDKF[<V
o_oooj5DMgD54]Ie8=:A0>15TP1T8249000:0>15TP3DbQP0G3WFMFAf00P000009@0000`000010000
E00005@0000_0@00NOgooc81001ooOoo0@000:^ZhClMan6oZ1L0030b00010000C000000000000000
00000?ooooooooooD00002T0000l0000600000`0000000009@0000`0000=0020:00000`000010000
DP00070100010000MOooo`0000000000000009010000000000020T<0C@1=04T0=`00000000000000
0000000000000000000000000000000000000000000000000000000000000000000003l003l40000
E<TH043FT@2<bQP0mG4^Ma/0?P1d0Hl000000501S`1H0ml1002A023BT@30Ni40000000@000000000
G0400@00000P000000010EC960000000S<XH0?Ea;WOD7@H1o_ooojXh:WNR=2Yg00000000T@0PdY40
?R0:<P00000HdY40W<XH08YCMgD008l000000:5DMgFG6m9C?R0:<R3BT@200MYe000004P0g`400=l1
J<XH03hP2S:4c1P0071iMA]J/bKnooooXEAgM@DBeWDPdY40h4FB06@P8@T000X0h4FB0=C:601L>MIe
I7H02000000U000030000040001D0000E00002H1001ooOoo;@4008Gmool10000Zj[Q?ag7hKob5P00
[3400040001<00000000000000000000oooooooooom@0000K@0008`0000H000030000000001D0000
E00002`1001ooOoo;`4008Gmool10000Zj[Q?ag7hKn05`00[3400040001<00000000000000000000
oooooooooom@0000>`0002P0000H000030000000001D0000E00002l1001ooOoo=04008Gmool10000
Zj[Q?ag7hKn^5`00[3400040001<00000000000000000000oooooooooom@0000KP0006@0000H0000
30000000000U0000300000d0080X000030000040001B0000L0400040000ioooo0000000000000000
T040000000000082@`1=04D0F00a0300000000000000000000000000000000000000000000000000
00000000000000000000000000000000?`00?`@0001DbAP0@=JA08c:603eLBig6`0n07@1S`000000
D06?05P3g`4009408=:A0<1kT@00000010000000001L0@010000020000000041E<TH0000002<bQP0
mG4^Mm@M1P7nooooZSPZMj8d:WL00000002A023BT@0n80Xc000001SBT@2LbQP0RU=gM@00S`000000
XEAgMILKdU<n80Xc8=:A0801fWD00000B03O0@00g`5XbQP0?R0:<hC<6000L7Ue6eZc9_kooonQE7Me
1A;FMB3BT@3PAI80I20Q2@002P3PAI80e<XH05`ieWETMP08000002D0000<00000@0005@0001D0000
=P4006omoolk0@00U?goo`40002[Z^4o7LOQ_c`H002l<P000@0004`00000000000000000003ooooo
oooooe00001X0000I00001P0000<0000000002D0000<00003@00P2P0000<00000@000580001`0@00
0@0003Woool0000000000000002@0@00000000000P9304d0C@190340<00000000000000000000000
00000000000000000000000000000000000000000000000000000000000o000o100005C96010eY40
S<XH0?Ea;WLK03h0M06?0000001@0Hl0F0?O0@00T@0PdY40`7^A000000040000000005`100400000
800000000@5DbAP0000008c:603eLBige1d60OkooonZ>2YgXS@ZM`00000009408=:A03hP2S@00000
6=:A09c:602:DgMe002?0000002QE7MeUa_BDchP2S@PdY40P07JM@0000180=l1003O0FS:600n80Xd
Q<`H001`NGDKF[<Vo_oooj5DMgD54]Ie8=:A0>15TP1T8249000:0>15TP3DbQP0G3WFMFAf00P00000
9@0000`000010000E00005@0000k0@00N_good<10024oOoo0@000:^ZhClMan6oVaP00=ha00010000
C00000000000000000000?ooooooooooD00005D0002<0000600000`0000000009@0000`0000=0020
:00000`000010000DP00070100010000MOooo`0000000000000009010000000000020T<0C@1B03L0
00000000000000000000000000000000000000000000000000000000000000000000000000000000
000003l003l40000E<TH043FT@2<bQP0mG4^Ma/0?P1d0Hl000000501S`1H0ml1002A023BT@30Ni40
000000@000000000G0400@00000P000000010EC960000000S<XH0?Ea;WOD7@H1o_ooojXh:WNR=2Yg
00000000T@0PdY40?R0:=@00000HdY40W<XH08YCMgD008l000000:5DMgFG6m9C?R0:=B3BT@200MYe
000004P0g`400=l1J<XH03hP2SF4c1P0071iMA]J/bKnooooXEAgM@DBeWDPdY40h4FB06@P8@T000X0
h4FB0=C:601L>MIeI7H02000000U000030000040001D0000E00004<1001hoOooAP4007kmool10000
Zj[Q?ag7hKlh6@00AS800040001<00000000000000000000oooooooooom@0000:00003`0000H0000
30000000000U0000300000d0080X000030000040001B0000L0400040001eoooo0000000000000000
T040000000000082@`1=04d0B@0g0000000000000000000000000000000000000000000000000000
00000000000000000000000000000000?`00?`@0001DbAP0@=JA08c:603eLBig6`0n07@1S`000000
D06?05P3g`4009408=:A0<1kT@00000010000000001L0@010000020000000041E<TH0000002<bQP0
mG4^Mm@M1P7nooooZSPZMj8d:WL00000002A023BT@0n80Xf000001SBT@2LbQP0RU=gM@00S`000000
XEAgMILKdU<n80Xf8=:A0801fWD00000B03O0@00g`5XbQP0?R0:=XC<6000L7Ue6eZc9_kooonQE7Me
1A;FMB3BT@3PAI80I20Q2@002P3PAI80e<XH05`ieWETMP08000002D0000<00000@0005@0001D0000
AP4007Smoom=0@00O_goo`40002[Z^4o7LOQ_gHI0016<P000@0004`00000000000000000003ooooo
oooooe00001]0000S00001P0000<0000000002D0000<00003@00P2P0000<00000@000580001`0@00
0@0007Goool0000000000000002@0@00000000000P9304d0DP0g0000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000o000o100005C96010eY40
S<XH0?Ea;WLK03h0M06?0000001@0Hl0F0?O0@00T@0PdY40`7^A000000040000000005`100400000
800000000@5DbAP0000008c:603eLBige1d60OkooonZ>2YgXS@ZM`00000009408=:A03hP2SL00000
6=:A09c:602:DgMe002?0000002QE7MeUa_BDchP2SLPdY40P07JM@0000180=l1003O0FS:600n80Xg
Q<`H001`NGDKF[<Vo_oooj5DMgD54]Ie8=:A0>15TP1T8249000:0>15TP3DbQP0G3WFMFAf00P00000
9@0000`000010000E00005@0001=0@00N?gooe<1001noOoo0@000:^ZhClMan6o11X004Hb00010000
C00000000000000000000?ooooooooooD00002/0001h0000600000`000000000E00005@0001C0@00
N?gooeL1001noOoo0@000:^ZhClMan6oOQX004Hb00010000C00000000000000000000?oooooooooo
D0000340001@0000600000`000000000E00005@0001G0@00N?gooeX1001noOoo0@000:^ZhClMan6o
cAX004Hb00010000C00000000000000000000?ooooooooooD00002T0000l0000600000`000000000
9@0000`0000=0020:00000`000010000DP00070100010000MOooo`00000000000000090100000000
00020T<0C@1=04T0=`00000000000000000000000000000000000000000000000000000000000000
0000000000000000000003l003l40000E<TH043FT@2<bQP0mG4^Ma/0?P1d0Hl000000501S`1H0ml1
002A023BT@30Ni40000000@000000000G0400@00000P000000010EC960000000S<XH0?Ea;WOD7@H1
o_ooojXh:WNR=2Yg00000000T@0PdY40?R0:>000000HdY40W<XH08YCMgD008l000000:5DMgFG6m9C
?R0:>23BT@200MYe000004P0g`400=l1J<XH03hP2SR4c1P0071iMA]J/bKnooooXEAgM@DBeWDPdY40
h4FB06@P8@T000X0h4FB0=C:601L>MIeI7H02000000U000030000040001D0000E00004810020oOoo
A@4008Kmool10000Zj[Q?ag7hKlR6@00YS400040001<00000000000000000000oooooooooom@0000
JP0003`0000H000030000000000U0000300000d0080X000030000040001B0000L0400040000ioooo
0000000000000000T040000000000082@`1=05<0F@0a0300C`1B04T0A`0000000000000000000000
000000000000000000000000000000000000000000000000?`00?`@0001DbAP0@=JA08c:603eLBig
6`0n07@1S`000000D06?05P3g`4009408=:A0<1kT@00000010000000001L0@010000020000000041
E<TH0000002<bQP0mG4^Mm@M1P7nooooZSPZMj8d:WL00000002A023BT@0n80Xi000001SBT@2LbQP0
RU=gM@00S`000000XEAgMILKdU<n80Xi8=:A0801fWD00000B03O0@00g`5XbQP0?R0:>HC<6000L7Ue
6eZc9_kooonQE7Me1A;FMB3BT@3PAI80I20Q2@002P3PAI80e<XH05`ieWETMP08000002D0000<0000
0@0005@0001D0000G@4007[moomU0@00Rogoo`40002[Z^4o7LOQ_d8K003N<@000@0004`000000000
00000000003ooooooooooe00002Q0000X00001P0000<0000000002D0000<00003@00P2P0000<0000
0@000580001`0@000@0003Woool0000000000000002@0@00000000000P9304d0C@190340<0000000
000000000000000000000000000000000000000000000000000000000000000000000000000o000o
100005C96010eY40S<XH0?Ea;WLK03h0M06?0000001@0Hl0F0?O0@00T@0PdY40`7^A000000040000
000005`100400000800000000@5DbAP0000008c:603eLBige1d60OkooonZ>2YgXS@ZM`0000000940
8=:A03hP2SX000006=:A09c:602:DgMe002?0000002QE7MeUa_BDchP2SXPdY40P07JM@0000180=l1
003O0FS:600n80XjQ<`H001`NGDKF[<Vo_oooj5DMgD54]Ie8=:A0>15TP1T8249000:0>15TP3DbQP0
G3WFMFAf00P000009@0000`000010000E00005@0001W0@00N_goofl10024oOoo0@000:^ZhClMan6o
2A`00=ha00010000C00000000000000000000?ooooooooooD00005D0002<0000600000`000000000
9@0000`0000=0020:00000`000010000DP00070100010000MOooo`00000000000000090100000000
00020T<0C@1B03L00000000000000000000000000000000000000000000000000000000000000000
0000000000000000000003l003l40000E<TH043FT@2<bQP0mG4^Ma/0?P1d0Hl000000501S`1H0ml1
002A023BT@30Ni40000000@000000000G0400@00000P000000010EC960000000S<XH0?Ea;WOD7@H1
o_ooojXh:WNR=2Yg00000000T@0PdY40?R0:>`00000HdY40W<XH08YCMgD008l000000:5DMgFG6m9C
?R0:>b3BT@200MYe000004P0g`400=l1J<XH03hP2S^4c1P0071iMA]J/bKnooooXEAgM@DBeWDPdY40
h4FB06@P8@T000X0h4FB0=C:601L>MIeI7H02000000U000030000040001D0000E00006l1001hoOoo
LP4007kmool10000Zj[Q?ag7hKnV7000AS800040001<00000000000000000000oooooooooom@0000
:00003`0000H000030000000000U0000300000d0080X000030000040001B0000L0400040001eoooo
0000000000000000T040000000000082@`1=04d0B@0g000000000000000000000000000000000000
000000000000000000000000000000000000000000000000?`00?`@0001DbAP0@=JA08c:603eLBig
6`0n07@1S`000000D06?05P3g`4009408=:A0<1kT@00000010000000001L0@010000020000000041
E<TH0000002<bQP0mG4^Mm@M1P7nooooZSPZMj8d:WL00000002A023BT@0n80Xl000001SBT@2LbQP0
RU=gM@00S`000000XEAgMILKdU<n80Xl8=:A0801fWD00000B03O0@00g`5XbQP0?R0:?8C<6000L7Ue
6eZc9_kooonQE7Me1A;FMB3BT@3PAI80I20Q2@002P3PAI80e<XH05`ieWETMP08000002D0000<0000
0@0005@0001D0000LP4007Smoomi0@00O_goo`40002[Z^4o7LOQ_nDL0016<P000@0004`000000000
00000000003ooooooooooe00001]0000S00001P0000<0000000002D0000<00003@00P2P0000<0000
0@000580001`0@000@0007Goool0000000000000002@0@00000000000P9304d0DP0g000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000o000o
100005C96010eY40S<XH0?Ea;WLK03h0M06?0000001@0Hl0F0?O0@00T@0PdY40`7^A000000040000
000005`100400000800000000@5DbAP0000008c:603eLBige1d60OkooonZ>2YgXS@ZM`0000000940
8=:A03hP2Sd000006=:A09c:602:DgMe002?0000002QE7MeUa_BDchP2SdPdY40P07JM@0000180=l1
003O0FS:600n80XmQ<`H001`NGDKF[<Vo_oooj5DMgD54]Ie8=:A0>15TP1T8249000:0>15TP3DbQP0
G3WFMFAf00P000009@0000`000010000E00005@0001i0@00N?goog`1001noOoo0@000:^ZhClMan6o
LQd004Hb00010000C00000000000000000000?ooooooooooD00002T0000l0000600000`000000000
9@0000`0000=0020:00000`000010000DP00070100010000MOooo`00000000000000090100000000
00020T<0C@1=04T0=`00000000000000000000000000000000000000000000000000000000000000
0000000000000000000003l003l40000E<TH043FT@2<bQP0mG4^Ma/0?P1d0Hl000000501S`1H0ml1
002A023BT@30Ni40000000@000000000G0400@00000P000000010EC960000000S<XH0?Ea;WOD7@H1
o_ooojXh:WNR=2Yg00000000T@0PdY40?R0:?P00000HdY40W<XH08YCMgD008l000000:5DMgFG6m9C
?R0:?R3BT@200MYe000004P0g`400=l1J<XH03hP2Sj4c1P0071iMA]J/bKnooooXEAgM@DBeWDPdY40
h4FB06@P8@T000X0h4FB0=C:601L>MIeI7H02000000U000030000040001D0000E00006h10020oOoo
L@4008Kmool10000Zj[Q?ag7hKnA7000YS400040001<00000000000000000000oooooooooom@0000
JP0003`0000H000030000000000U0000300000d0080X000030000040001B0000L0400040000ioooo
0000000000000000T040000000000082@`1=04D0F00a030000000000000000000000000000000000
000000000000000000000000000000000000000000000000?`00?`@0001DbAP0@=JA08c:603eLBig
6`0n07@1S`000000D06?05P3g`4009408=:A0<1kT@00000010000000001L0@010000020000000041
E<TH0000002<bQP0mG4^Mm@M1P7nooooZSPZMj8d:WL00000002A023BT@0n80Xo000001SBT@2LbQP0
RU=gM@00S`000000XEAgMILKdU<n80Xo8=:A0801fWD00000B03O0@00g`5XbQP0?R0:?hC<6000L7Ue
6eZc9_kooonQE7Me1A;FMB3BT@3PAI80I20Q2@002P3PAI80e<XH05`ieWETMP08000002D0000<0000
0@0005@0001D0000O@4006omoon20@00U?goo`40002[Z^4o7LOQ_kXM002l<P000@0004`000000000
00000000003ooooooooooe00001Y0000I00001P0000<0000000002D0000<00003@00P2P0000<0000
0@000580001`0@000@0003Woool0000000000000002@0@00000000000P9304d0DP0a030000000000
000000000000000000000000000000000000000000000000000000000000000000000000000o000o
100005C96010eY40S<XH0?Ea;WLK03h0M06?0000001@0Hl0F0?O0@00T@0PdY40`7^A000000040000
000005`100400000800000000@5DbAP0000008c:603eLBige1d60OkooonZ>2YgXS@ZM`0000000940
8=:A03hP2T0000006=:A09c:602:DgMe002?0000002QE7MeUa_BDchP2T0PdY40P07JM@0000180=l1
003O0FS:600n80Y0Q<`H001`NGDKF[<Vo_oooj5DMgD54]Ie8=:A0>15TP1T8249000:0>15TP3DbQP0
G3WFMFAf00P000009@0000`000010000E00005@000240@00N_gooh`10024oOoo0@000:^ZhClMan6o
AQh00=ha00010000C00000000000000000000?ooooooooooD00002/0002P0000600000`000000000
9@0000`0000=0020:00000`000010000DP00070100010000>Oooo`00000000000000090100000000
00020T<0C@1=04T0<@0`000000000000000000000000000000000000000000000000000000000000
0000000000000000000003l003l40000E<TH043FT@2<bQP0mG4^Ma/0?P1d0Hl000000501S`1H0ml1
002A023BT@30Ni40000000@000000000G0400@00000P000000010EC960000000S<XH0?Ea;WOD7@H1
o_ooojXh:WNR=2Yg00000000T@0PdY40?R0:@@00000HdY40W<XH08YCMgD008l000000:5DMgFG6m9C
?R0:@B3BT@200MYe000004P0g`400=l1J<XH03hP2T64c1P0071iMA]J/bKnooooXEAgM@DBeWDPdY40
h4FB06@P8@T000X0h4FB0=C:601L>MIeI7H02000000U000030000040001D0000E00008d1001joOoo
T`4008Cmool10000Zj[Q?ag7hKl=7`00gS400040001<00000000000000000000oooooooooom@0000
AP0007P0000H000030000000000U0000300000d0080X000030000040001B0000L0400040001eoooo
0000000000000000T040000000000082@`1=0580=`00000000000000000000000000000000000000
000000000000000000000000000000000000000000000000?`00?`@0001DbAP0@=JA08c:603eLBig
6`0n07@1S`000000D06?05P3g`4009408=:A0<1kT@00000010000000001L0@010000020000000041
E<TH0000002<bQP0mG4^Mm@M1P7nooooZSPZMj8d:WL00000002A023BT@0n80Y2000001SBT@2LbQP0
RU=gM@00S`000000XEAgMILKdU<n80Y28=:A0801fWD00000B03O0@00g`5XbQP0?R0:@XC<6000L7Ue
6eZc9_kooonQE7Me1A;FMB3BT@3PAI80I20Q2@002P3PAI80e<XH05`ieWETMP08000002D0000<0000
0@0005@0001D0000U@4007SmoonH0@00O_goo`40002[Z^4o7LOQ_jTO0016<P000@0004`000000000
00000000003ooooooooooe00000X0000?00001P0000<0000000002D0000<00003@00P2P0000<0000
0@000580001`0@000@0007Goool0000000000000002@0@00000000000P9304d0C@1903L000000000
000000000000000000000000000000000000000000000000000000000000000000000000000o000o
100005C96010eY40S<XH0?Ea;WLK03h0M06?0000001@0Hl0F0?O0@00T@0PdY40`7^A000000040000
000005`100400000800000000@5DbAP0000008c:603eLBige1d60OkooonZ>2YgXS@ZM`0000000940
8=:A03hP2T<000006=:A09c:602:DgMe002?0000002QE7MeUa_BDchP2T<PdY40P07JM@0000180=l1
003O0FS:600n80Y3Q<`H001`NGDKF[<Vo_oooj5DMgD54]Ie8=:A0>15TP1T8249000:0>15TP3DbQP0
G3WFMFAf00P000009@0000`000010000E00005@0002H0@00N?gooid1001noOoo0@000:^ZhClMan6o
ial004Hb00010000C00000000000000000000?ooooooooooD00006h0001T0000600000`000000000
9@0000`0000=0020:00000`000010000DP00070100010000MOooo`00000000000000090100000000
00020T<0C@1B03L00000000000000000000000000000000000000000000000000000000000000000
0000000000000000000003l003l40000E<TH043FT@2<bQP0mG4^Ma/0?P1d0Hl000000501S`1H0ml1
002A023BT@30Ni40000000@000000000G0400@00000P000000010EC960000000S<XH0?Ea;WOD7@H1
o_ooojXh:WNR=2Yg00000000T@0PdY40?R0:A000000HdY40W<XH08YCMgD008l000000:5DMgFG6m9C
?R0:A23BT@200MYe000004P0g`400=l1J<XH03hP2TB4c1P0071iMA]J/bKnooooXEAgM@DBeWDPdY40
h4FB06@P8@T000X0h4FB0=C:601L>MIeI7H02000000U000030000040001D0000E00009d1001hoOoo
X04007kmool10000Zj[Q?ag7hKm98000AS800040001<00000000000000000000oooooooooom@0000
:@0003`0000H000030000000000U0000300000d0080X000030000040001B0000L0400040001eoooo
0000000000000000T040000000000082@`1=04d0B@0g000000000000000000000000000000000000
000000000000000000000000000000000000000000000000?`00?`@0001DbAP0@=JA08c:603eLBig
6`0n07@1S`000000D06?05P3g`4009408=:A0<1kT@00000010000000001L0@010000020000000041
E<TH0000002<bQP0mG4^Mm@M1P7nooooZSPZMj8d:WL00000002A023BT@0n80Y5000001SBT@2LbQP0
RU=gM@00S`000000XEAgMILKdU<n80Y58=:A0801fWD00000B03O0@00g`5XbQP0?R0:AHC<6000L7Ue
6eZc9_kooonQE7Me1A;FMB3BT@3PAI80I20Q2@002P3PAI80e<XH05`ieWETMP08000002D0000<0000
0@0005@0001D0000U040083moonG0@00Q_goo`40002[Z^4o7LOQ_hdO002V<@000@0004`000000000
00000000003ooooooooooe00001Z0000?00002D0000<00003@00P2P0000<00000@0000h0000D0000
00000100000D0000240122@0000H00000Q30f`400003000000000000000000006d000400000d0000
0@0000800039P453hB<Ta<e0H4=[W0120`000<V0@D?Q8bC4bn3@@n4S9<C9P4536aXLa24000080000
HP0000`0000100008@0000P0000Q0000200007<0000<0000000001`0000800009@0000`000000020
9@0000`0000700209@0000`0000>00206@0000`0003oool0600000`0000000004P0000`000020000
4`0000`000010000500000`0000=00005@0000`0000100005P0000`0000000003@00010000000000
000003X0000<00002P0001/0000@000000000000000S0000800009YX9D400000000004_i:44Y3_[4
aZkHAB@0000T0000VVPU@@0000000000BoTX@BT>n/C6[]Q5100007<0000<0000000000d0000@0000
00000000001B0000L0400080000@00001`00000000000000_080000000070P8RD`1i07<0M01U06d0
000D0:3hooob0@00000003bm@P:0n?oo201HO__fool000000000022m@P:0n?ooool00000E0XHT7P0
0000P5c;=@3;c4`mT<`e0;SMPPLQ@kig8Q<QL280RP4H00000000062F2PH80000cjTT@@00aceHPo46
00000<3Lk0J/b3D00000000000000000ooooob3<=@1<c3D0?=Le08DI`WNeLfH1o_ooohcS_GObh;eg
003f23Sl0002000000000200001lc3D0X<`e0>]HkgH007P0200D02IJkgHAZA=U0000062F2PKooooo
0`0000000020[e/:001h0>3_G@Z:MFMX[=<e001`lGH000002bP00>C<=@1>;[mgR:mL2Wl7002@[e`:
f<`e02l`5GMTMP08000002D0000<00000P0004H000280000O00004M4BD<20000`P0006omoonQ0@00
Sogooc00001W06D0KP1U0780H@1d06D0I00P0680N@0P05L0C@1602l0A@1=04H0801R0640H`1[06D0
KP1T0200K`1V0200L01c07@0K`1U06@0J@1d0000J@1^0700M@1d0000000S0000800007=T13l00000
00000=H]1klY3_[4aZkHAB@0000T0000Lf@4?`0000000000eRd7_bT>n/C6[]Q5100002<0000P0000
Lf@4?`0000000000eRd7_bT>n/C6[]Q5900002@0001cI0@o00000000003F;@No:@kja<J^f4D40000
4P0000`0000100005P0000`0000H0000600000`000000000DP00070100030000>Oooo`0000000000
00000901000000001`020T<0C@1=04T0<@0`00000000000000000000000000000000000000000000
0000000000000000000000000000000010000<S:60000000200000L000000000SU<gMLS:600`bQP0
k;1300@000240000b<XH00000000000030000000000100008<XH000000240000X0l0008000030000
b<XH000000000000?<XH07nN@`3l2Wl0P<XH0000@`040000S[E30639c5=XOWl08HQ6000000000000
00000040001<bQP002m:00c;603PW480/2NCDokoool004<0gKE306QnO`000000001o06QnO`38bQP0
0@0003P07P0;0000b<XH06QnO`010`00/7eo0040001POWl0I7H02000000U0000300000<0001D0000
E00000X0001b0000G@000=/000010000Zj[Q?ag7hKl`3`00gS400040001<00000000000000000000
oooooooooom@0000A`0H0:00000H000030000000001B0000L04000@0000D00002@00000000000000
_080000000070P8RD`1i07<0M01U06d000000000003R0000000006a4NP:0n?oo0000000000000000
00000514NP:0n?oo^YH000005GNgI1Eg8Q<QL000000000000@000?2DoPGHbcD0HF@EMb8C8G000000
000005@000000000l9Cn1E3<=@3NDAEg8Q<QL8SOQ`020000f5aO0e@0000000000@0003P07P0;0000
b<XH06QnO`010`00/7eo0040001POWl0000020000030g>`6[<Pe053<=@0_<1EgD<`e06H`5GLl4U`:
H9H:1RD0000000X0`68008C==@0MnV=X8Q<QL000Q`3`U?h50P000=QLG`>b2VAXH0HIM`00001P1QUg
P04IMe0BG0ZXc3D0;c0EMjS<=@1V<1EgW19L2V2F2PITMP08000002D0000<0000100002P0000<0000
0`000580001`0@000`0007Goool0000000000000002@0@00000000L00P9304d0DP0g000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000o000o
100000800010eY40b<XH0000000K03h0M06?0000001@0Hl0F0?O0@00@`0PdY40`7^A000000040000
000005`100400000800000000@5DbAP0S><YMhc:603eLBige1d60OkooonZ>2YgXS@ZM`0000000940
8=:A03hP2Q/000006=:A09c:602:DgMe002?0000002QE7MeUa_BDchP2Q/PdY40P07JM@26O`180=l1
003O0FS:600n80XKQ<`H001`NGDKF[<Vo_oooj5DMgD54]Ie8=:A0>15TP1T8249000:0>15TP3DbQP0
G3WFMFAf00P000009@0000`000030000E00005@0001K0000D`0007X0002L00000@000:^ZhClMan6o
c@l004Hb00010000C00000000000000000000?ooooooooooD00002P0000l0000600000`000000000
9@0000`000040000:00000`000030000DP00070100030000MOooo`00000000000000090100000000
1`020T<0C@1=04T0=`00000000000000000000000000000000000000000000000000000000000000
0000000000000000000003l003l40000E<TH043FT@2<bQP0mG4^Ma/0?P1d0Hl000000501S`1H0ml1
002A023BT@30Ni40000000@000000000G0400@00000P000000010EC960000000S<XH0?Ea;WOD7@H1
o_ooojXh:WNR=2Yg00000000T@0PdY40?R0:7000000HdY40W<XH08YCMgD008l000000:5DMgFG6m9C
?R0:723BT@200MYe000004P0g`400=l1J<XH03hP2Qb4c1P0071iMA]J/bKnooooXEAgM@DBeWDPdY40
h4FB06@P8@T000X0h4FB0=C:601L>MIeI7H02000000U0000300000<0001D0000E00007`0001C0000
/00009`000010000Zj[Q?ag7hKl<4000AS800040001<00000000000000000000oooooooooom@0000
KP0006@0000H000030000000000U0000300000@0000X0000300000<0001B0000L04000<0001eoooo
0000000000000000T040000000070082@`1=0580=`00000000000000000000000000000000000000
000000000000000000000000000000000000000000000000?`00?`@0001DbAP0@=JA08c:603eLBig
6`0n07@1S`000000D06?05P3g`4009408=:A0<1kT@00000010000000001L0@010000020000000041
E<TH0000002<bQP0mG4^Mm@M1P7nooooZSPZMj8d:WL00000002A023BT@0n80XM000001SBT@2LbQP0
RU=gM@00S`000000XEAgMILKdU<n80XM8=:A0801fWD00000B03O0@00g`5XbQP0?R0:7HC<6000L7Ue
6eZc9_kooonQE7Me1A;FMB3BT@3PAI80I20Q2@002P3PAI80e<XH05`ieWETMP08000002D0000<0000
0`0005@0001D0000[`0005<0003>0000W0000040002[Z^4o7LOQ_fh@0016<P000@0004`000000000
00000000003ooooooooooe00000Y0000?00001P0000<0000000002D0000<0000100002P0000<0000
0`000580001`0@000`0007Goool0000000000000002@0@00000000L00P9304d0C@1903L000000000
000000000000000000000000000000000000000000000000000000000000000000000000000o000o
100005C96010eY40S<XH0?Ea;WLK03h0M06?0000001@0Hl0F0?O0@00T@0PdY40`7^A000000040000
000005`100400000800000000@5DbAP0000008c:603eLBige1d60OkooonZ>2YgXS@ZM`0000000940
8=:A03hP2Qh000006=:A09c:602:DgMe002?0000002QE7MeUa_BDchP2QhPdY40P07JM@0000180=l1
003O0FS:600n80XNQ<`H001`NGDKF[<Vo_oooj5DMgD54]Ie8=:A0>15TP1T8249000:0>15TP3DbQP0
G3WFMFAf00P000009@0000`000030000E00005@0001K0000Y`0007X0003`00000@000:^ZhClMan6o
c@l00:Ha00010000C00000000000000000000?ooooooooooD00006X0000l0000600000`000000000
9@0000`000040000:00000`000030000DP00070100030000>Oooo`00000000000000090100000000
1`020T<0C@1C05T0<@0`04l0DP1904L0000000000000000000000000000000000000000000000000
0000000000000000000003l003l40000E<TH043FT@2<bQP0mG4^Ma/0?P1d0Hl000000501S`1H0ml1
002A023BT@30Ni40000000@000000000G0400@00000P000000010EC960000000S<XH0?Ea;WOD7@H1
o_ooojXh:WNR=2Yg00000000T@0PdY40?R0:7`00000HdY40W<XH08YCMgD008l000000:5DMgFG6m9C
?R0:7b3BT@200MYe000004P0g`400=l1J<XH03hP2Qn4c1P0071iMA]J/bKnooooXEAgM@DBeWDPdY40
h4FB06@P8@T000X0h4FB0=C:601L>MIeI7H02000000U0000300000<0001D0000E0000?00001_0000
@`4002D100010000Zj[Q?ag7hKo/4000gS400040001<00000000000000000000oooooooooom@0000
]00^Mj00000H000030000000000U0000300000@0000X0000300000<0001B0000L04000<0000ioooo
0000000000000000T040000000070082@`1=04d0B@0a030000000000000000000000000000000000
000000000000000000000000000000000000000000000000?`00?`@0001DbAP0@=JA08c:603eLBig
6`0n07@1S`000000D06?05P3g`4009408=:A0<1kT@00000010000000001L0@010000020000000041
E<TH0000002<bQP0mG4^Mm@M1P7nooooZSPZMj8d:WL00000002A023BT@0n80XP000001SBT@2LbQP0
RU=gM@00S`000000XEAgMILKdU<n80XP8=:A0801fWD00000B03O0@00g`5XbQP0?R0:88C<6000L7Ue
6eZc9_kooonQE7Me1A;FMB3BT@3PAI80I20Q2@002P3PAI80e<XH05`ieWETMP08000002D0000<0000
0`0005@0001D0000G@400780002[0@00f`000040002[Z^4o7LOQ_klA003N<@000@0004`000000000
00000000003ooooooooooe00001E02igS00001P0000<0000000002D0000<0000100002P0000<0000
0`000580001`0@000`0007Goool0000000000000002@0@00000000L00P9304d0DP0g000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000o000o
100005C96010eY40S<XH0?Ea;WLK03h0M06?0000001@0Hl0F0?O0@00T@0PdY40`7^A000000040000
000005`100400000800000000@5DbAP0000008c:603eLBige1d60OkooonZ>2YgXS@ZM`0000000940
8=:A03hP2R4000006=:A09c:602:DgMe002?0000002QE7MeUa_BDchP2R4PdY40P07JM@0000180=l1
003O0FS:600n80XQQ<`H001`NGDKF[<Vo_oooj5DMgD54]Ie8=:A0>15TP1T8249000:0>15TP3DbQP0
G3WFMFAf00P000009@0000`000030000E00005@0002^0@00D`000<d1002L00000@000:^ZhClMan6o
G18004Hb00010000C00000000000000000000?ooooooooooD00002P0;WLl0000600000`000000000
9@0000`000040000:00000`000030000DP00070100030000MOooo`00000000000000090100000000
1`020T<0C@1=04T0=`00000000000000000000000000000000000000000000000000000000000000
0000000000000000000003l003l40000E<TH043FT@2<bQP0mG4^Ma/0?P1d0Hl000000501S`1H0ml1
002A023BT@30Ni40000000@000000000G0400@00000P000000010EC960000000S<XH0?Ea;WOD7@H1
o_ooojXh:WNR=2Yg00000000T@0PdY40?R0:8P00000HdY40W<XH08YCMgD008l000000:5DMgFG6m9C
?R0:8R3BT@200MYe000004P0g`400=l1J<XH03hP2R:4c1P0071iMA]J/bKnooooXEAgM@DBeWDPdY40
h4FB06@P8@T000X0h4FB0=C:601L>MIeI7H02000000U0000300000<0001D0000E0000<l1001C0000
0`8009`000010000Zj[Q?ag7hKnK4P00AS800040001<00000000000000000000oooooooooom@0000
KP0^Mf@0000H000030000000000U0000300000@0000X0000300000<0001B0000L04000<0001eoooo
0000000000000000T040000000070082@`1=05<0F@0g000000000000000000000000000000000000
000000000000000000000000000000000000000000000000?`00?`@0001DbAP0@=JA08c:603eLBig
6`0n07@1S`000000D06?05P3g`4009408=:A0<1kT@00000010000000001L0@010000020000000041
E<TH0000002<bQP0mG4^Mm@M1P7nooooZSPZMj8d:WL00000002A023BT@0n80XS000001SBT@2LbQP0
RU=gM@00S`000000XEAgMILKdU<n80XS8=:A0801fWD00000B03O0@00g`5XbQP0?R0:8hC<6000L7Ue
6eZc9_kooonQE7Me1A;FMB3BT@3PAI80I20Q2@002P3PAI80e<XH05`ieWETMP08000002D0000<0000
0`0005@0001D00000@80050000100P00c`000040002[Z^4o7LOQ_odB0016<P000@0004`000000000
00000000003ooooooooooe00002Q0082N00001P0000<0000000002D0000<0000100002P0000<0000
0`000580001`0@000`0007Goool0000000000000002@0@00000000L00P9304d0DP0g000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000o000o
100005C96010eY40S<XH0?Ea;WLK03h0M06?0000001@0Hl0F0?O0@00T@0PdY40`7^A000000040000
000005`100400000800000000@5DbAP0000008c:603eLBige1d60OkooonZ>2YgXS@ZM`0000000940
8=:A03hP2R@000006=:A09c:602:DgMe002?0000002QE7MeUa_BDchP2R@PdY40P07JM@0000180=l1
003O0FS:600n80XTQ<`H001`NGDKF[<Vo_oooj5DMgD54]Ie8=:A0>15TP1T8249000:0>15TP3DbQP0
G3WFMFAf00P000009@0000`000030000E00005@000120P00D`0006`2002L00000@000:^ZhClMan6o
NA<004Hb00010000C00000000000000000000?ooooooooooD00003400P9@0000600000`000000000
E00005@0001[0P00D`0008X2002L00000@000:^ZhClMan6obA<004Hb00010000C000000000000000
00000?ooooooooooD00002T0;WLl0000600000`0000000009@0000`000040000:00000`000030000
DP00070100030000MOooo`000000000000000901000000001`020T<0C@1=04T0=`00000000000000
0000000000000000000000000000000000000000000000000000000000000000000003l003l40000
E<TH043FT@2<bQP0mG4^Ma/0?P1d0Hl000000501S`1H0ml1002A023BT@30Ni40000000@000000000
G0400@00000P000000010EC960000000S<XH0?Ea;WOD7@H1o_ooojXh:WNR=2Yg00000000T@0PdY40
?R0:9@00000HdY40W<XH08YCMgD008l000000:5DMgFG6m9C?R0:9B3BT@200MYe000004P0g`400=l1
J<XH03hP2RF4c1P0071iMA]J/bKnooooXEAgM@DBeWDPdY40h4FB06@P8@T000X0h4FB0=C:601L>MIe
I7H02000000U0000300000<0001D0000E0000:<1002W0000`P400?0000010000Zj[Q?ag7hKm74P00
YS400040001<00000000000000000000oooooooooom@0000JP0003`0000H000030000000000U0000
300000@0000X0000300000<0001B0000L04000<0000ioooo0000000000000000T040000000070082
@`1=05<0F@0a0300C`1B04T0A`000000000000000000000000000000000000000000000000000000
0000000000000000?`00?`@0001DbAP0@=JA08c:603eLBig6`0n07@1S`000000D06?05P3g`400940
8=:A0<1kT@00000010000000001L0@010000020000000041E<TH0000002<bQP0mG4^Mm@M1P7noooo
ZSPZMj8d:WL00000002A023BT@0n80XV000001SBT@2LbQP0RU=gM@00S`000000XEAgMILKdU<n80XV
8=:A0801fWD00000B03O0@00g`5XbQP0?R0:9XC<6000L7Ue6eZc9_kooonQE7Me1A;FMB3BT@3PAI80
I20Q2@002P3PAI80e<XH05`ieWETMP08000002D0000<00000`0005@0001D0000Z08006l0003k0P00
9@400040002[Z^4o7LOQ_chD003N<@000@0004`00000000000000000003ooooooooooe00002Q0000
X00001P0000<0000000002D0000<0000100002P0000<00000`000580001`0@000`0007Goool00000
00000000002@0@00000000L00P9304d0C@1903L00000000000000000000000000000000000000000
0000000000000000000000000000000000000000000o000o100005C96010eY40S<XH0?Ea;WLK03h0
M06?0000001@0Hl0F0?O0@00T@0PdY40`7^A000000040000000005`100400000800000000@5DbAP0
000008c:603eLBige1d60OkooonZ>2YgXS@ZM`00000009408=:A03hP2RL000006=:A09c:602:DgMe
002?0000002QE7MeUa_BDchP2RLPdY40P07JM@0000180=l1003O0FS:600n80XWQ<`H001`NGDKF[<V
o_oooj5DMgD54]Ie8=:A0>15TP1T8249000:0>15TP3DbQP0G3WFMFAf00P000009@0000`000030000
E00005@0000I0`001P0004d3001?00000@000:^ZhClMan6o6AD00=Lb00010000C000000000000000
00000?ooooooooooD00006h0001T0000600000`0000000009@0000`000040000:00000`000030000
DP00070100030000MOooo`000000000000000901000000001`020T<0C@1C05T0=`00000000000000
0000000000000000000000000000000000000000000000000000000000000000000003l003l40000
E<TH043FT@2<bQP0mG4^Ma/0?P1d0Hl000000501S`1H0ml1002A023BT@30Ni40000000@000000000
G0400@00000P000000010EC960000000S<XH0?Ea;WOD7@H1o_ooojXh:WNR=2Yg00000000T@0PdY40
?R0::000000HdY40W<XH08YCMgD008l000000:5DMgFG6m9C?R0::23BT@200MYe000004P0g`400=l1
J<XH03hP2RR4c1P0071iMA]J/bKnooooXEAgM@DBeWDPdY40h4FB06@P8@T000X0h4FB0=C:601L>MIe
I7H02000000U0000300000<0001D0000E00004`300030000R`<0088000010000Zj[Q?ag7hKml5@00
ec800040001<00000000000000000000oooooooooom@0000X@0007P0000H000030000000000U0000
300000@0000X0000300000<0001B0000L04000<0001eoooo0000000000000000T040000000070082
@`1=0580=`0000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000?`00?`@0001DbAP0@=JA08c:603eLBig6`0n07@1S`000000D06?05P3g`400940
8=:A0<1kT@00000010000000001L0@010000020000000041E<TH0000002<bQP0mG4^Mm@M1P7noooo
ZSPZMj8d:WL00000002A023BT@0n80XY000001SBT@2LbQP0RU=gM@00S`000000XEAgMILKdU<n80XY
8=:A0801fWD00000B03O0@00g`5XbQP0?R0::HC<6000L7Ue6eZc9_kooonQE7Me1A;FMB3BT@3PAI80
I20Q2@002P3PAI80e<XH05`ieWETMP08000002D0000<00000`0005@0001D0000S0<000H0002f0`00
C`000040002[Z^4o7LOQ_oPE003G<P000@0004`00000000000000000003ooooooooooe00000b0000
D00001P0000<0000000002D0000<0000100002P0000<00000`000580001`0@000`0003Woool00000
00000000002@0@00000000L00P9304d0A@1H0340<000000000000000000000000000000000000000
0000000000000000000000000000000000000000000o000o100005C96010eY40S<XH0?Ea;WLK03h0
M06?0000001@0Hl0F0?O0@00T@0PdY40`7^A000000040000000005`100400000800000000@5DbAP0
000008c:603eLBige1d60OkooonZ>2YgXS@ZM`00000009408=:A03hP2RX000006=:A09c:602:DgMe
002?0000002QE7MeUa_BDchP2RXPdY40P07JM@0000180=l1003O0FS:600n80XZQ<`H001`NGDKF[<V
o_oooj5DMgD54]Ie8=:A0>15TP1T8249000:0>15TP3DbQP0G3WFMFAf00P000009@0000`000030000
E00005@0000L0`002`000:d3002C0@000@000:^ZhClMan6o81D009/b00010000C000000000000000
00000?ooooooooooD00005P0000H0@00600000`0000000009@0000`000040000:00000`000030000
DP00070100030000MOooo`000000000000000901000000001`020T<0C@1=04T0=`00000000000000
0000000000000000000000000000000000000000000000000000000000000000000003l003l40000
E<TH043FT@2<bQP0mG4^Ma/0?P1d0Hl000000501S`1H0ml1002A023BT@30Ni40000000@000000000
G0400@00000P000000010EC960000000S<XH0?Ea;WOD7@H1o_ooojXh:WNR=2Yg00000000T@0PdY40
?R0::`00000HdY40W<XH08YCMgD008l000000:5DMgFG6m9C?R0::b3BT@200MYe000004P0g`400=l1
J<XH03hP2R^4c1P0071iMA]J/bKnooooXEAgM@DBeWDPdY40h4FB06@P8@T000X0h4FB0=C:601L>MIe
I7H02000000U0000300000<0001D0000E00000h300050@00E`<004h100010000Zj[Q?ag7hKl55@00
mC000040001<00000000000000000000oooooooooom@0000K@0008`0000H000030000000000U0000
300000@0000X0000300000<0001B0000L04000<0001eoooo0000000000000000T040000000070082
@`1=0580=`0000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000?`00?`@0001DbAP0@=JA08c:603eLBig6`0n07@1S`000000D06?05P3g`400940
8=:A0<1kT@00000010000000001L0@010000020000000041E<TH0000002<bQP0mG4^Mm@M1P7noooo
ZSPZMj8d:WL00000002A023BT@0n80X/000001SBT@2LbQP0RU=gM@00S`000000XEAgMILKdU<n80X/
8=:A0801fWD00000B03O0@00g`5XbQP0?R0:;8C<6000L7Ue6eZc9_kooonQE7Me1A;FMB3BT@3PAI80
I20Q2@002P3PAI80e<XH05`ieWETMP08000002D0000<00000`0005@0001D0000E`<000D1002F0`00
CP400040002[Z^4o7LOQ_i8E003e<0000@0004`00000000000000000003ooooooooooe00000m0000
N00001P0000<0000000005@0001D0000U`<000D100310`00CP400040002[Z^4o7LOQ_`dF003e<000
0@0004`00000000000000000003ooooooooooe00000`0000D00001P0000<0000000002D0000<0000
100002P0000<00000`000580001`0@000`0003Woool0000000000000002@0@00000000L00P9304d0
DP0a0300000000000000000000000000000000000000000000000000000000000000000000000000
00000000000o000o100005C96010eY40S<XH0?Ea;WLK03h0M06?0000001@0Hl0F0?O0@00T@0PdY40
`7^A000000040000000005`100400000800000000@5DbAP0000008c:603eLBige1d60OkooonZ>2Yg
XS@ZM`00000009408=:A03hP2Rd000006=:A09c:602:DgMe002?0000002QE7MeUa_BDchP2RdPdY40
P07JM@0000180=l1003O0FS:600n80X]Q<`H001`NGDKF[<Vo_oooj5DMgD54]Ie8=:A0>15TP1T8249
000:0>15TP3DbQP0G3WFMFAf00P000009@0000`000030000E00005@0003U0`00F00001T400310000
0@000:^ZhClMan6oY1H0010b00010000C00000000000000000000?ooooooooooD00007h0001T0000
600000`0000000009@0000`000040000:00000`000030000DP00070100030000>Oooo`0000000000
00000901000000001`020T<0C@1=04T0<@0`00000000000000000000000000000000000000000000
00000000000000000000000000000000000003l003l40000E<TH043FT@2<bQP0mG4^Ma/0?P1d0Hl0
00000501S`1H0ml1002A023BT@30Ni40000000@000000000G0400@00000P000000010EC960000000
S<XH0?Ea;WOD7@H1o_ooojXh:WNR=2Yg00000000T@0PdY40?R0:;P00000HdY40W<XH08YCMgD008l0
00000:5DMgFG6m9C?R0:;R3BT@200MYe000004P0g`400=l1J<XH03hP2Rj4c1P0071iMA]J/bKnoooo
XEAgM@DBeWDPdY40h4FB06@P8@T000X0h4FB0=C:601L>MIeI7H02000000U0000300000<0001D0000
E0000=43001b00006P@00=/000010000Zj[Q?ag7hKmn5P00gS400040001<00000000000000000000
oooooooooom@0000E00007P0000H000030000000000U0000300000@0000X0000300000<0001B0000
L04000<0001eoooo0000000000000000T040000000070082@`1=0580=`0000000000000000000000
0000000000000000000000000000000000000000000000000000000000000000?`00?`@0001DbAP0
@=JA08c:603eLBig6`0n07@1S`000000D06?05P3g`4009408=:A0<1kT@00000010000000001L0@01
0000020000000041E<TH0000002<bQP0mG4^Mm@M1P7nooooZSPZMj8d:WL00000002A023BT@0n80X_
000001SBT@2LbQP0RU=gM@00S`000000XEAgMILKdU<n80X_8=:A0801fWD00000B03O0@00g`5XbQP0
?R0:;hC<6000L7Ue6eZc9_kooonQE7Me1A;FMB3BT@3PAI80I20Q2@002P3PAI80e<XH05`ieWETMP08
000002D0000<00000`0005@0001D000070@005l0000k1000Z0000040002[Z^4o7LOQ_`hG000`<P00
0@0004`00000000000000000003ooooooooooe00000X0000?00001P0000<0000000002D0000<0000
100002P0000<00000`000580001`0@000`0007Goool0000000000000002@0@00000000L00P9304d0
C@1903L0000000000000000000000000000000000000000000000000000000000000000000000000
00000000000o000o100005C96010eY40S<XH0?Ea;WLK03h0M06?0000001@0Hl0F0?O0@00T@0PdY40
`7^A000000040000000005`100400000800000000@5DbAP0000008c:603eLBige1d60OkooonZ>2Yg
XS@ZM`00000009408=:A03hP2S0000006=:A09c:602:DgMe002?0000002QE7MeUa_BDchP2S0PdY40
P07JM@0000180=l1003O0FS:600n80X`Q<`H001`NGDKF[<Vo_oooj5DMgD54]Ie8=:A0>15TP1T8249
000:0>15TP3DbQP0G3WFMFAf00P000009@0000`000030000E00005@0000l1000G`0006P4002X0000
0@000:^ZhClMan6oC1L0030b00010000C00000000000000000000?ooooooooooD0000;00001@0000
600000`0000000009@0000`000040000:00000`000030000DP00070100030000MOooo`0000000000
00000901000000001`020T<0C@1B03L0000000000000000000000000000000000000000000000000
00000000000000000000000000000000000003l003l40000E<TH043FT@2<bQP0mG4^Ma/0?P1d0Hl0
00000501S`1H0ml1002A023BT@30Ni40000000@000000000G0400@00000P000000010EC960000000
S<XH0?Ea;WOD7@H1o_ooojXh:WNR=2Yg00000000T@0PdY40?R0:<@00000HdY40W<XH08YCMgD008l0
00000:5DMgFG6m9C?R0:<B3BT@200MYe000004P0g`400=l1J<XH03hP2S64c1P0071iMA]J/bKnoooo
XEAgM@DBeWDPdY40h4FB06@P8@T000X0h4FB0=C:601L>MIeI7H02000000U0000300000<0001D0000
E00006`4001O0000R`@00:P000010000Zj[Q?ag7hKnX5`00<3800040001<00000000000000000000
oooooooooom@0000:@0003`0000H000030000000000U0000300000@0000X0000300000<0001B0000
L04000<0001eoooo0000000000000000T040000000070082@`1=04d0B@0g00000000000000000000
0000000000000000000000000000000000000000000000000000000000000000?`00?`@0001DbAP0
@=JA08c:603eLBig6`0n07@1S`000000D06?05P3g`4009408=:A0<1kT@00000010000000001L0@01
0000020000000041E<TH0000002<bQP0mG4^Mm@M1P7nooooZSPZMj8d:WL00000002A023BT@0n80Xb
000001SBT@2LbQP0RU=gM@00S`000000XEAgMILKdU<n80Xb8=:A0801fWD00000B03O0@00g`5XbQP0
?R0:<XC<6000L7Ue6eZc9_kooonQE7Me1A;FMB3BT@3PAI80I20Q2@002P3PAI80e<XH05`ieWETMP08
000002D0000<00000`0005@0001D00003@@00:@0001F1000k@000040002[Z^4o7LOQ_o8F002/<@00
0@0004`00000000000000000003ooooooooooe00001]0<3KS00001P0000<0000000005@0001D0000
E`@00:@0001/1000k@000040002[Z^4o7LOQ_h0G002/<@000@0004`00000000000000000003ooooo
oooooe00000k02`j:00001P0000<0000000005@0001D0000K`@00:@0002S1000k@000040002[Z^4o
7LOQ_jhG002/<@000@0004`00000000000000000003ooooooooooe00001^00<0I00001P0000<0000
000002D0000<0000100002P0000<00000`000580001`0@000`0003Woool0000000000000002@0@00
000000L00P9304d0A@1H0340<0000000000000000000000000000000000000000000000000000000
000000000000000000000000000o000o100005C96010eY40S<XH0?Ea;WLK03h0M06?0000001@0Hl0
F0?O0@00T@0PdY40`7^A000000040000000005`100400000800000000@5DbAP0000008c:603eLBig
e1d60OkooonZ>2YgXS@ZM`00000009408=:A03hP2S<000006=:A09c:602:DgMe002?0000002QE7Me
Ua_BDchP2S<PdY40P07JM@0000180=l1003O0FS:600n80XcQ<`H001`NGDKF[<Vo_oooj5DMgD54]Ie
8=:A0>15TP1T8249000:0>15TP3DbQP0G3WFMFAf00P000009@0000`000030000E00005@0002h1000
n_ooon`400220@000@000:^ZhClMan6o?1P00;`b00010000C00000000000000000000?oooooooooo
D00006P0001T0000600000`0000000009@0000`000040000:00000`000030000DP00070100030000
>Oooo`000000000000000901000000001`020T<0C@1=04T0<@0`0000000000000000000000000000
000000000000000000000000000000000000000000000000000003l003l40000E<TH043FT@2<bQP0
mG4^Ma/0?P1d0Hl000000501S`1H0ml1002A023BT@30Ni40000000@000000000G0400@00000P0000
00010EC960000000S<XH0?Ea;WOD7@H1o_ooojXh:WNR=2Yg00000000T@0PdY40?R0:=000000HdY40
W<XH08YCMgD008l000000:5DMgFG6m9C?R0:=23BT@200MYe000004P0g`400=l1J<XH03hP2SB4c1P0
071iMA]J/bKnooooXEAgM@DBeWDPdY40h4FB06@P8@T000X0h4FB0=C:601L>MIeI7H02000000U0000
300000<0001D0000E0000>T4001b0000=`D00=/000010000Zj[Q?ag7hKnK6000gS400040001<0000
0000000000000000oooooooooom@0000E@0008`0000H000030000000000U0000300000@0000X0000
300000<0001B0000L04000<0001eoooo0000000000000000T040000000070082@`1=0580=`000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
?`00?`@0001DbAP0@=JA08c:603eLBig6`0n07@1S`000000D06?05P3g`4009408=:A0<1kT@000000
10000000001L0@010000020000000041E<TH0000002<bQP0mG4^Mm@M1P7nooooZSPZMj8d:WL00000
002A023BT@0n80Xe000001SBT@2LbQP0RU=gM@00S`000000XEAgMILKdU<n80Xe8=:A0801fWD00000
B03O0@00g`5XbQP0?R0:=HC<6000L7Ue6eZc9_kooonQE7Me1A;FMB3BT@3PAI80I20Q2@002P3PAI80
e<XH05`ieWETMP08000002D0000<00000`0005@0001D0000>PD005<0001I1@00W0000040002[Z^4o
7LOQ_cPI0016<P000@0004`00000000000000000003ooooooooooe00000X0000?00001P0000<0000
000002D0000<0000100002P0000<00000`000580001`0@000`0007Goool0000000000000002@0@00
000000L00P9304d0C@1903L000000000000000000000000000000000000000000000000000000000
000000000000000000000000000o000o100005C96010eY40S<XH0?Ea;WLK03h0M06?0000001@0Hl0
F0?O0@00T@0PdY40`7^A000000040000000005`100400000800000000@5DbAP0000008c:603eLBig
e1d60OkooonZ>2YgXS@ZM`00000009408=:A03hP2SH000006=:A09c:602:DgMe002?0000002QE7Me
Ua_BDchP2SHPdY40P07JM@0000180=l1003O0FS:600n80XfQ<`H001`NGDKF[<Vo_oooj5DMgD54]Ie
8=:A0>15TP1T8249000:0>15TP3DbQP0G3WFMFAf00P000009@0000`000030000E00005@0001J1@00
D`000:<5002L00000@000:^ZhClMan6oMQT004Hb00010000C00000000000000000000?oooooooooo
D00006d0002<0000600000`0000000009@0000`000040000:00000`000030000DP00070100030000
MOooo`000000000000000901000000001`020T<0C@1B03L000000000000000000000000000000000
000000000000000000000000000000000000000000000000000003l003l40000E<TH043FT@2<bQP0
mG4^Ma/0?P1d0Hl000000501S`1H0ml1002A023BT@30Ni40000000@000000000G0400@00000P0000
00010EC960000000S<XH0?Ea;WOD7@H1o_ooojXh:WNR=2Yg00000000T@0PdY40?R0:=`00000HdY40
W<XH08YCMgD008l000000:5DMgFG6m9C?R0:=b3BT@200MYe000004P0g`400=l1J<XH03hP2SN4c1P0
071iMA]J/bKnooooXEAgM@DBeWDPdY40h4FB06@P8@T000X0h4FB0=C:601L>MIeI7H02000000U0000
300000<0001D0000E0000:@5001C0000h`D009`000010000Zj[Q?ag7hKl46P00AS800040001<0000
0000000000000000oooooooooom@0000:`0007P0000H000030000000001D0000E0000><5001C0000
3@H009`000010000Zj[Q?ag7hKmn6P00AS800040001<00000000000000000000oooooooooom@0000
<@000500000H000030000000001D0000E00000`6001C0000:`H009`000010000Zj[Q?ag7hKo=6P00
AS800040001<00000000000000000000oooooooooom@0000:@0003`0000H000030000000000U0000
300000@0000X0000300000<0001B0000L04000<0001eoooo0000000000000000T040000000070082
@`1=04d0B@0g00000000000000000000000000000000000000000000000000000000000000000000
0000000000000000?`00?`@0001DbAP0@=JA08c:603eLBig6`0n07@1S`000000D06?05P3g`400940
8=:A0<1kT@00000010000000001L0@010000020000000041E<TH0000002<bQP0mG4^Mm@M1P7noooo
ZSPZMj8d:WL00000002A023BT@0n80Xh000001SBT@2LbQP0RU=gM@00S`000000XEAgMILKdU<n80Xh
8=:A0801fWD00000B03O0@00g`5XbQP0?R0:>8C<6000L7Ue6eZc9_kooonQE7Me1A;FMB3BT@3PAI80
I20Q2@002P3PAI80e<XH05`ieWETMP08000002D0000<00000`0005@0001D0000;`D00:L0001>1@00
l0000040002[Z^4o7LOQ_b8I002V<@000@0004`00000000000000000003ooooooooooe00001Z0000
?00001P0000<0000000002D0000<0000100002P0000<00000`000580001`0@000`0003Woool00000
00000000002@0@00000000L00P9304d0D`1I0340<01?0580B@170000000000000000000000000000
0000000000000000000000000000000000000000000o000o100005C96010eY40S<XH0?Ea;WLK03h0
M06?0000001@0Hl0F0?O0@00T@0PdY40`7^A000000040000000005`100400000800000000@5DbAP0
000008c:603eLBige1d60OkooonZ>2YgXS@ZM`00000009408=:A03hP2ST000006=:A09c:602:DgMe
002?0000002QE7MeUa_BDchP2STPdY40P07JM@0000180=l1003O0FS:600n80XiQ<`H001`NGDKF[<V
o_oooj5DMgD54]Ie8=:A0>15TP1T8249000:0>15TP3DbQP0G3WFMFAf00P000009@0000`000030000
E00005@000181P00K`0009/6000U0@000@000:^ZhClMan6o@Q/00=ha00010000C000000000000000
00000?ooooooooooD0000:40002P0000600000`0000000009@0000`000040000:00000`000030000
DP00070100030000>Oooo`000000000000000901000000001`020T<0C@1=04T0<@0`000000000000
0000000000000000000000000000000000000000000000000000000000000000000003l003l40000
E<TH043FT@2<bQP0mG4^Ma/0?P1d0Hl000000501S`1H0ml1002A023BT@30Ni40000000@000000000
G0400@00000P000000010EC960000000S<XH0?Ea;WOD7@H1o_ooojXh:WNR=2Yg00000000T@0PdY40
?R0:>P00000HdY40W<XH08YCMgD008l000000:5DMgFG6m9C?R0:>R3BT@200MYe000004P0g`400=l1
J<XH03hP2SZ4c1P0071iMA]J/bKnooooXEAgM@DBeWDPdY40h4FB06@P8@T000X0h4FB0=C:601L>MIe
I7H02000000U0000300000<0001D0000E0000:l6001b0000o@H00=/000010000Zj[Q?ag7hKl97000
gS400040001<00000000000000000000oooooooooom@0000E@0008`0000H000030000000000U0000
300000@0000X0000300000<0001B0000L04000<0001eoooo0000000000000000T040000000070082
@`1=0580=`0000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000?`00?`@0001DbAP0@=JA08c:603eLBig6`0n07@1S`000000D06?05P3g`400940
8=:A0<1kT@00000010000000001L0@010000020000000041E<TH0000002<bQP0mG4^Mm@M1P7noooo
ZSPZMj8d:WL00000002A023BT@0n80Xk000001SBT@2LbQP0RU=gM@00S`000000XEAgMILKdU<n80Xk
8=:A0801fWD00000B03O0@00g`5XbQP0?R0:>hC<6000L7Ue6eZc9_kooonQE7Me1A;FMB3BT@3PAI80
I20Q2@002P3PAI80e<XH05`ieWETMP08000002D0000<00000`0005@0001D000000L005<0000O1`00
W0000040002[Z^4o7LOQ_jHL0016<P000@0004`00000000000000000003ooooooooooe00000X0000
?00001P0000<0000000002D0000<0000100002P0000<00000`000580001`0@000`0007Goool00000
00000000002@0@00000000L00P9304d0C@1903L00000000000000000000000000000000000000000
0000000000000000000000000000000000000000000o000o100005C96010eY40S<XH0?Ea;WLK03h0
M06?0000001@0Hl0F0?O0@00T@0PdY40`7^A000000040000000005`100400000800000000@5DbAP0
000008c:603eLBige1d60OkooonZ>2YgXS@ZM`00000009408=:A03hP2S`000006=:A09c:602:DgMe
002?0000002QE7MeUa_BDchP2S`PdY40P07JM@0000180=l1003O0FS:600n80XlQ<`H001`NGDKF[<V
o_oooj5DMgD54]Ie8=:A0>15TP1T8249000:0>15TP3DbQP0G3WFMFAf00P000009@0000`000030000
E00005@0000Q1`00D`0006X7002L00000@000:^ZhClMan6oiA`004Hb00010000C000000000000000
00000?ooooooooooD00006d0002<0000600000`0000000009@0000`000040000:00000`000030000
DP00070100030000MOooo`000000000000000901000000001`020T<0C@1B03L00000000000000000
0000000000000000000000000000000000000000000000000000000000000000000003l003l40000
E<TH043FT@2<bQP0mG4^Ma/0?P1d0Hl000000501S`1H0ml1002A023BT@30Ni40000000@000000000
G0400@00000P000000010EC960000000S<XH0?Ea;WOD7@H1o_ooojXh:WNR=2Yg00000000T@0PdY40
?R0:?@00000HdY40W<XH08YCMgD008l000000:5DMgFG6m9C?R0:?B3BT@200MYe000004P0g`400=l1
J<XH03hP2Sf4c1P0071iMA]J/bKnooooXEAgM@DBeWDPdY40h4FB06@P8@T000X0h4FB0=C:601L>MIe
I7H02000000U0000300000<0001D0000E00006X7001C0000R@L009`000010000Zj[Q?ag7hKmb7@00
AS800040001<00000000000000000000oooooooooom@0000:@0003`0000H000030000000000U0000
300000@0000X0000300000<0001B0000L04000<0001eoooo0000000000000000T040000000070082
@`1=04d0B@0g00000000000000000000000000000000000000000000000000000000000000000000
0000000000000000?`00?`@0001DbAP0@=JA08c:603eLBig6`0n07@1S`000000D06?05P3g`400940
8=:A0<1kT@00000010000000001L0@010000020000000041E<TH0000002<bQP0mG4^Mm@M1P7noooo
ZSPZMj8d:WL00000002A023BT@0n80Xn000001SBT@2LbQP0RU=gM@00S`000000XEAgMILKdU<n80Xn
8=:A0801fWD00000B03O0@00g`5XbQP0?R0:?XC<6000L7Ue6eZc9_kooonQE7Me1A;FMB3BT@3PAI80
I20Q2@002P3PAI80e<XH05`ieWETMP08000002D0000<00000`0005@0001D0000mPH00:L0000E1`00
l0000040002[Z^4o7LOQ_i4L002V<@000@0004`00000000000000000003ooooooooooe00001Z0000
?00001P0000<0000000002D0000<0000100002P0000<00000`000580001`0@000`0003Woool00000
00000000002@0@00000000L00P9304d0A@1H0340<000000000000000000000000000000000000000
0000000000000000000000000000000000000000000o000o100005C96010eY40S<XH0?Ea;WLK03h0
M06?0000001@0Hl0F0?O0@00T@0PdY40`7^A000000040000000005`100400000800000000@5DbAP0
000008c:603eLBige1d60OkooonZ>2YgXS@ZM`00000009408=:A03hP2Sl000006=:A09c:602:DgMe
002?0000002QE7MeUa_BDchP2SlPdY40P07JM@0000180=l1003O0FS:600n80XoQ<`H001`NGDKF[<V
o_oooj5DMgD54]Ie8=:A0>15TP1T8249000:0>15TP3DbQP0G3WFMFAf00P000009@0000`000030000
E00005@0002?1`00n_oool<700220@000@000:^ZhClMan6o^Qd00;`b00010000C000000000000000
00000?ooooooooooD00006T0001T0000600000`0000000009@0000`000040000:00000`000030000
DP00070100030000>Oooo`000000000000000901000000001`020T<0C@1B0340<000000000000000
0000000000000000000000000000000000000000000000000000000000000000000003l003l40000
E<TH043FT@2<bQP0mG4^Ma/0?P1d0Hl000000501S`1H0ml1002A023BT@30Ni40000000@000000000
G0400@00000P000000010EC960000000S<XH0?Ea;WOD7@H1o_ooojXh:WNR=2Yg00000000T@0PdY40
?R0:@000000HdY40W<XH08YCMgD008l000000:5DMgFG6m9C?R0:@23BT@200MYe000004P0g`400=l1
J<XH03hP2T24c1P0071iMA]J/bKnooooXEAgM@DBeWDPdY40h4FB06@P8@T000X0h4FB0=C:601L>MIe
I7H02000000U0000300000<0001D0000E0000=P7001b0000:`P00=/000010000Zj[Q?ag7hKm67P00
gS400040001<00000000000000000000oooooooooom@0000:`000:00000H000030000000000U0000
300000@0000X0000300000<0001B0000L04000<0000ioooo0000000000000000T040000000070082
@`1=04d0B@0a03000000000000000000000000000000000000000000000000000000000000000000
0000000000000000?`00?`@0001DbAP0@=JA08c:603eLBig6`0n07@1S`000000D06?05P3g`400940
8=:A0<1kT@00000010000000001L0@010000020000000041E<TH0000002<bQP0mG4^Mm@M1P7noooo
ZSPZMj8d:WL00000002A023BT@0n80Y1000001SBT@2LbQP0RU=gM@00S`000000XEAgMILKdU<n80Y1
8=:A0801fWD00000B03O0@00g`5XbQP0?R0:@HC<6000L7Ue6eZc9_kooonQE7Me1A;FMB3BT@3PAI80
I20Q2@002P3PAI80e<XH05`ieWETMP08000002D0000<00000`0005@0001D0000?PP00780002;2000
f`000040002[Z^4o7LOQ_`dO003N<@000@0004`00000000000000000003ooooooooooe0000160000
N00001P0000<0000000002D0000<0000100002P0000<00000`000580001`0@000`0007Goool00000
00000000002@0@00000000L00P9304d0DP0g00000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000o000o100005C96010eY40S<XH0?Ea;WLK03h0
M06?0000001@0Hl0F0?O0@00T@0PdY40`7^A000000040000000005`100400000800000000@5DbAP0
000008c:603eLBige1d60OkooonZ>2YgXS@ZM`00000009408=:A03hP2T8000006=:A09c:602:DgMe
002?0000002QE7MeUa_BDchP2T8PdY40P07JM@0000180=l1003O0FS:600n80Y2Q<`H001`NGDKF[<V
o_oooj5DMgD54]Ie8=:A0>15TP1T8249000:0>15TP3DbQP0G3WFMFAf00P000009@0000`000030000
E00005@0002?2000D`000:h8002L00000@000:^ZhClMan6oZAl004Hb00010000C000000000000000
00000?ooooooooooD00002P0000l0000600000`0000000009@0000`000040000:00000`000030000
DP00070100030000MOooo`000000000000000901000000001`020T<0C@1=04T0=`00000000000000
0000000000000000000000000000000000000000000000000000000000000000000003l003l40000
E<TH043FT@2<bQP0mG4^Ma/0?P1d0Hl000000501S`1H0ml1002A023BT@30Ni40000000@000000000
G0400@00000P000000010EC960000000S<XH0?Ea;WOD7@H1o_ooojXh:WNR=2Yg00000000T@0PdY40
?R0:@`00000HdY40W<XH08YCMgD008l000000:5DMgFG6m9C?R0:@b3BT@200MYe000004P0g`400=l1
J<XH03hP2T>4c1P0071iMA]J/bKnooooXEAgM@DBeWDPdY40h4FB06@P8@T000X0h4FB0=C:601L>MIe
I7H02000000U0000300000<0001D0000E0000:l8001C0000h`P009`000010000Zj[Q?ag7hKoW7`00
AS800040001<00000000000000000000oooooooooom@0000KP0006@0000H000030000000000U0000
300000@0000X0000300000<0001B0000L04000<0001eoooo0000000000000000T040000000070082
@`1=0580=`0000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000?`00?`@0001DbAP0@=JA08c:603eLBig6`0n07@1S`000000D06?05P3g`400940
8=:A0<1kT@00000010000000001L0@010000020000000041E<TH0000002<bQP0mG4^Mm@M1P7noooo
ZSPZMj8d:WL00000002A023BT@0n80Y4000001SBT@2LbQP0RU=gM@00S`000000XEAgMILKdU<n80Y4
8=:A0801fWD00000B03O0@00g`5XbQP0?R0:A8C<6000L7Ue6eZc9_kooonQE7Me1A;FMB3BT@3PAI80
I20Q2@002P3PAI80e<XH05`ieWETMP08000002D0000<00000`0005@0001D0000hPP005<000012@00
W0000040002[Z^4o7LOQ_dTP0016<P000@0004`00000000000000000003ooooooooooe00000Y0000
?00001P0000<0000000002D0000<0000100002P0000<00000`000580001`0@000`0007Goool00000
00000000002@0@00000000L00P9304d0C@1903L00000000000000000000000000000000000000000
0000000000000000000000000000000000000000000o000o100005C96010eY40S<XH0?Ea;WLK03h0
M06?0000001@0Hl0F0?O0@00T@0PdY40`7^A000000040000000005`100400000800000000@5DbAP0
000008c:603eLBige1d60OkooonZ>2YgXS@ZM`00000009408=:A03hP2TD000006=:A09c:602:DgMe
002?0000002QE7MeUa_BDchP2TDPdY40P07JM@0000180=l1003O0FS:600n80Y5Q<`H001`NGDKF[<V
o_oooj5DMgD54]Ie8=:A0>15TP1T8249000:0>15TP3DbQP0G3WFMFAf00P000009@0000`000030000
E00005@000212000Y`000:08003`00000@000:^ZhClMan6oSAl00:Ha00010000C000000000000000
00000?ooooooooooD00006X0000l00009@0000`000040000:00000`000030000AP0001@000080000
AdA9@`<0000R000030000?oooolR000030000?oooolU0000300000d0080X000030000080000X0000
300000@0000R000030000?oooom60000`0400;@10015CDH[;40002@0000H00000020?`0000000000
0020?`0008000020:T0002@0000H00003[hT@@0000000000DcLT@E8<nLC[U=95940000`000000000
:T0002@0000H0000/08/>P0000000000/08/>P008jT005VY:d0000`0000000007T0600`000000000
8D0500`000000000240211P0000<00000Q30f`000003000@=40200`0000000007T0900`000000000
:T0002@0000H0000/08/>P0000000000/08/>P008jT005VY8D0700`000000000:T0002@0000H0000
/08/>P0000000000/08/>P008jT005VY:d0000`000000000:d0000`0000000007T0600`000000000
8D0500`000000000240311P0000<00000Q30f`000003000@=40300`0000000007T0900`000000000
:T0002@0000H00000020?`00000000000020?`00000000008D0700`000000000C00006@000000000
000000@900190@000000000000052@00BP4002T0ZP00000000000000P3l0000000000000P3l00000
0000000000000000000000000000000000000280000<0000ooooodH0000L0000400004E=AR/2@000
30000000000>000050000000000@00005000
\>"], "Graphics",
  GeneratedCell->False,
  CellAutoOverwrite->False,
  ImageSize->{303.69473684210516`, 42.82029912090425},
  ImageMargins->{{6.652631578947361, 0.}, {0., 33.5578947368421}}],
 " \nof the paper is given here by the function GG[",
 StyleBox["j,n,",
  FontFamily->"Times New Roman",
  FontSlant->"Italic"],
 StyleBox["\[Gamma]",
  FontFamily->"Times New Roman"],
 "] , where  ",
 Cell[BoxData[
  FormBox[
   StyleBox[
    RowBox[{
     SubsuperscriptBox["F", "j", 
      RowBox[{"(", "n", ")"}]], "=", 
     RowBox[{
      RowBox[{"\[CapitalGamma]", "(", 
       RowBox[{"2", "-", "\[Gamma]"}], ")"}], " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         SubscriptBox["t", "n"], "-", 
         SubscriptBox["t", 
          RowBox[{"n", "-", "1"}]]}], ")"}], 
       RowBox[{"\[Gamma]", " "}]], 
      RowBox[{"f", "(", 
       RowBox[{
        SubscriptBox["x", 
         RowBox[{"j", ","}]], 
        SubscriptBox["t", "n"]}], ")"}]}]}],
    FontFamily->"Times New Roman"], TraditionalForm]]],
 " [see Eq. (9)], and ",
 Cell[BoxData[
  FormBox[
   StyleBox[
    RowBox[{"f", "(", 
     RowBox[{
      SubscriptBox["x", 
       RowBox[{"j", ","}]], 
      SubscriptBox["t", "n"]}], ")"}],
    FontFamily->"Times New Roman"], TraditionalForm]]],
 "  is given by  funSource[ ",
 StyleBox["j",
  FontFamily->"Times New Roman",
  FontSlant->"Italic"],
 StyleBox[" ",
  FontFamily->"Times New Roman"],
 Cell[BoxData[
  FormBox["\[CapitalDelta]x", TraditionalForm]],
  FontFamily->"Times New Roman"],
 StyleBox[",",
  FontFamily->"Times New Roman"],
 Cell[BoxData[
  FormBox[
   SubscriptBox["t", "n"], TraditionalForm]],
  FontFamily->"Times New Roman"],
 StyleBox[",\[Gamma]",
  FontFamily->"Times New Roman"],
 "] .  The solution U is stored in the matrix Umatrix. The element (1+m,1+j) \
of this matrix, i.e.,  Umatrix[[1+m,1+j]],  represents  ",
 Cell[BoxData[
  FormBox[
   SubsuperscriptBox["U", "j", 
    RowBox[{"(", "m", ")"}]], TraditionalForm]]],
 " with j=0,1,..., m=0,1,..."
}], "Text",
 CellChangeTimes->{{3.636977241041491*^9, 3.636977288861226*^9}, {
   3.6371540193780947`*^9, 3.637154134615897*^9}, {3.6371541746923676`*^9, 
   3.637154286800164*^9}, {3.637154545637219*^9, 3.6371546636212263`*^9}, {
   3.637154751871581*^9, 3.6371547646168036`*^9}, {3.63715482537891*^9, 
   3.6371550290886683`*^9}, {3.637155076341151*^9, 3.6371551248360367`*^9}, {
   3.6371555960680637`*^9, 3.637155605911681*^9}, {3.637158151363553*^9, 
   3.6371582455565186`*^9}, {3.63716491040341*^9, 3.637164939148054*^9}, {
   3.6371650212917523`*^9, 3.637165088747611*^9}, {3.637165127707839*^9, 
   3.637165210723587*^9}, {3.637238595523246*^9, 3.63723860049453*^9}, {
   3.6374193716464*^9, 3.6374193716474*^9}, 3.6374195670684*^9, {
   3.6374196036864*^9, 3.6374196180064*^9}, {3.6374197213354*^9, 
   3.6374199039054003`*^9}, {3.6374199558124*^9, 3.6374199854234*^9}, 
   3.6374200308384*^9, {3.6374200957934*^9, 3.6374201352064*^9}, {
   3.6381742993866*^9, 3.6381743103726*^9}, {3.6386009375966*^9, 
   3.6386009391406*^9}, {3.6386019635726*^9, 3.6386019636316*^9}, {
   3.6386020641546*^9, 3.6386020653366003`*^9}},
 Background->RGBColor[0.88, 1, 0.88]],

Cell[BoxData[
 RowBox[{
  RowBox[{"GG", "[", 
   RowBox[{"j_", ",", "1", ",", "gamma_"}], "]"}], ":=", 
  RowBox[{
   RowBox[{"Umatrix", "[", 
    RowBox[{"[", 
     RowBox[{"1", ",", 
      RowBox[{"j", "+", "1"}]}], "]"}], "]"}], " ", "+", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"tt", "[", "1", "]"}], "-", 
       RowBox[{"tt", "[", "0", "]"}]}], ")"}], "^", "gamma"}], "*", 
    RowBox[{"Gamma", "[", 
     RowBox[{"2", "-", "gamma"}], "]"}], "*", 
    RowBox[{"funSource", "[", 
     RowBox[{
      RowBox[{"j", "*", "deltax"}], ",", 
      RowBox[{"tt", "[", "1", "]"}], ",", "gamma"}], "]"}], "    ", 
    RowBox[{"(*", " ", 
     RowBox[{
     "El", " ", "elemento", " ", "1", " ", "de", " ", "Umatrix", " ", "es", 
      " ", "la", " ", "soluci\[OAcute]n", " ", "en", " ", "el", " ", 
      "instante", " ", 
      RowBox[{"inicial", ":", " ", 
       RowBox[{"u", 
        RowBox[{"(", 
         RowBox[{"x", ",", "0"}], ")"}]}]}]}], "   ", "*)"}]}]}]}]], "Input",
 CellChangeTimes->{{3.561048202626933*^9, 3.5610482156331596`*^9}, {
   3.5610484156122327`*^9, 3.561048418644936*^9}, {3.5611278257164*^9, 
   3.5611278943508*^9}, 3.63698257576462*^9, {3.636984470018965*^9, 
   3.6369844702019753`*^9}, {3.6369849805721664`*^9, 3.6369850003552985`*^9}, 
   3.6369850416056576`*^9, {3.63699164149115*^9, 3.636991642148187*^9}, {
   3.637237995180908*^9, 3.637237995187909*^9}, 3.6374195717404003`*^9},
 Background->RGBColor[0.88, 1, 0.88]],

Cell[BoxData[
 RowBox[{
  RowBox[{"GG", "[", 
   RowBox[{"j_", ",", "n_", ",", "gamma_"}], "]"}], ":=", 
  RowBox[{"(", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"kk", "=", 
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"tt", "[", "n", "]"}], "-", 
         RowBox[{"tt", "[", 
          RowBox[{"n", "-", "1"}], "]"}]}], ")"}], "^", "gamma"}], "*", 
      RowBox[{"Sum", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"Umatrix", "[", 
            RowBox[{"[", 
             RowBox[{
              RowBox[{"m", "+", "2"}], ",", 
              RowBox[{"j", "+", "1"}]}], "]"}], "]"}], "-", 
           RowBox[{"Umatrix", "[", 
            RowBox[{"[", 
             RowBox[{
              RowBox[{"m", "+", "1"}], ",", 
              RowBox[{"j", "+", "1"}]}], "]"}], "]"}]}], ")"}], " ", "*", 
         "\[IndentingNewLine]", 
         RowBox[{"TT", "[", 
          RowBox[{"m", ",", "n", ",", "gamma"}], "]"}]}], ",", 
        RowBox[{"{", 
         RowBox[{"m", ",", "0", ",", 
          RowBox[{"n", "-", "2"}]}], "}"}]}], "]"}]}]}], ";", 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"Umatrix", "[", 
      RowBox[{"[", 
       RowBox[{"n", ",", 
        RowBox[{"j", "+", "1"}]}], "]"}], "]"}], " ", "-", "kk", "+", 
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"tt", "[", "n", "]"}], "-", 
         RowBox[{"tt", "[", 
          RowBox[{"n", "-", "1"}], "]"}]}], ")"}], "^", "gamma"}], "*", 
      RowBox[{"Gamma", "[", 
       RowBox[{"2", "-", "gamma"}], "]"}], "*", 
      RowBox[{"funSource", "[", 
       RowBox[{
        RowBox[{"j", "*", "deltax"}], ",", 
        RowBox[{"tt", "[", "n", "]"}], ",", "gamma"}], "]"}]}]}]}], 
   ")"}]}]], "Input",
 CellChangeTimes->{{3.5610478883332863`*^9, 3.5610479262568197`*^9}, {
   3.5610480257190533`*^9, 3.5610480910563965`*^9}, {3.561048121968636*^9, 
   3.5610481363688374`*^9}, {3.5610484294923315`*^9, 
   3.5610484339010487`*^9}, {3.6369825808309097`*^9, 3.636982588389342*^9}, {
   3.636984474981249*^9, 3.6369844751562586`*^9}, {3.636985102335131*^9, 
   3.636985136472084*^9}, {3.6369916201439285`*^9, 3.6369916351157846`*^9}, {
   3.6370052090547595`*^9, 3.6370052151011057`*^9}, {3.637237995194909*^9, 
   3.6372379952049093`*^9}, 3.6374195743374*^9},
 Background->RGBColor[0.88, 1, 0.88]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 "The coefficient ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["S", "n"], TraditionalForm]]],
 " [Eq. (7)]  is given by the function Sfun[m,\[Gamma]]  where ",
 StyleBox["K",
  FontSlant->"Italic"],
 "=Kg and ",
 "\[CapitalDelta]x=deltax"
}], "Text",
 CellChangeTimes->{{3.636977241041491*^9, 3.636977288861226*^9}, {
  3.6371540193780947`*^9, 3.637154134615897*^9}, {3.6371541746923676`*^9, 
  3.637154286800164*^9}, {3.637154738875758*^9, 3.6371547440861673`*^9}, {
  3.6371553197739787`*^9, 3.63715540584133*^9}, {3.6371554887710752`*^9, 
  3.637155614335696*^9}},
 Background->RGBColor[0.88, 1, 0.88]],

Cell[BoxData[
 RowBox[{
  RowBox[{"Sfun", "[", 
   RowBox[{"m_", ",", "gamma_"}], "]"}], ":=", 
  RowBox[{
   RowBox[{
    RowBox[{"(", 
     RowBox[{"Kg", "*", 
      RowBox[{"Gamma", "[", 
       RowBox[{"2", "-", "gamma"}], "]"}]}], ")"}], "/", 
    RowBox[{
     RowBox[{"(", "deltax", ")"}], "^", "2"}]}], "*", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"tt", "[", "m", " ", "]"}], "-", 
      RowBox[{"tt", "[", 
       RowBox[{"m", "-", "1"}], "]"}]}], ")"}], "^", "gamma", 
    "    "}]}]}]], "Input",
 CellChangeTimes->{
  3.5610947421913333`*^9, {3.6369846480401473`*^9, 3.6369846512633314`*^9}, 
   3.6369847517600794`*^9, 3.636993846645277*^9},
 Background->RGBColor[0.88, 1, 0.88]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 "Next the matrix system \n",
 Cell[GraphicsData["Metafile", "\<\
CF5dJ6E]HGAYHf4PEfU^I6mgLb15CDHPAVmbKF5d0@0007b40@0006`0003ooooo^_ooolh800190@00
00000000000>9@00TP<00215CDH00040Q7`00?40000500000000000000000000HA<006PK003B0000
:@400000000000000000050d0`0XR0@0AP0002`0000P0000ADe6:`500@0L00004000008@`=/00000
F08005P200160000O04007010015CDH[7T0500`0000000007d0300`000000000<402010000040000
0020?b501`0<000000000290100<0000000002Y0000T000060000000P3l0000000000000P3l00000
000002]0000<0000000001i01P0<0000000002501@0<0000000001i02@0<0000000002Y0000T0000
60000000P3l0000000000000P3l00000000002501`0<0000000002Y0000T000060000;02;3X00000
00000;02;3X0P;k3080maB]0000<0000000002Y0000T000060000;02;3X0000000000;02;3X0P;k3
080maB]0000<0000000002Y0000T000060000;02;3X0000000000;02;3X00;jW000nZ@Y0080T0000
60000>7ohOl1000000000000002PRe1:P7ZQB24000080000HP0000`000010000900002@00000000n
000000000000000n00000000000200009`0001P00001000000000>7oh@0000009@0000`000010000
9@0000`000080020EP000300003ooooooooool88003I00001@000?coo?olol@634K41Pa6o?olooco
9@0000`0000700209@0000`000000020900002@00000001100000000000000110000000000020000
AP000>Pi003L>@00ADe6:b]0000<0000000001i01P0<0000000002501@0<0000000001i02@0<0000
000002Y0000T000060000;02;3X0000000000;02;3X00;jW000nZB501`0<0000000002]0000<0000
000002Y0000T000060000;HN9D40000000000>mH944dOog4Ra7CABA0100<0000000000Q000GH>000
c3P0008@`=/200000`000;`h00010000c0000<H0001XoOooWP4008gmoolA6`00HjGoomXh000YZ?oo
84E=AP000@2l>000_0000080000`0000K000000000201`00>0@00:D2001m0@000000000000000000
eED:04S@1@1W06D0KP1U0780H@1d06D0I00P0680N@0P05L0C@1602l0A@1=04H0801R0640H`1[06D0
KP1T0200K`1V0200L01c07@0K`1U06@0J@1d0000J@1^0700M@1d0000000A0000300000H0000:0000
40000000000000004P0000`0000100005P0000`0000H0000600000`000000000DP00070100010000
>Oooo`0000000000000009010000000000020T<0C@1=04T0<@0`0000000000000000000000000000
00000000000000000000000000000000000000000000000010000<S:60000000200000L000000000
SU<gMLS:600`bQP0k;1300@000240000b<XH00000000000030000000000100008<XH000000240000
X0l0008000030000b<XH000000000000?<XH07nN@`3l2]`1P<XH0000@`040000S[E30=bV8BiXO]`1
8HQ600000000000000000040001<bQP002m:00c;603PW48034Qn;_koool004<0gKE306Qng0400000
003L0FQng078bQP00@0003P07P0;0000b<XH06Qng0410`00/7gL0@40001PO]`1I7H02000000U0000
30000040001D0000E0000<H0001coOoocP0007gmool10000Zj[Q?ag7hKma3`00JS800040001<0000
0000000000000000oooooooooom@0000@@000:00000H000030000000001D0000E0000<l0001coOoo
e`0007gmool10000Zj[Q?ag7hKlX4000JS800040001<00000000000000000000oooooooooom@0000
E@0008`0000H000030000000000U0000300000d0080X000030000040001B0000L0400040001eoooo
0000000000000000T040000000000082@`1=0580=`00000000000000000000000000000000000000
000000000000000000000000000000000000000000000000?`00?`@000020000@=IV0<S:60000000
6`0n07@1I0000000D05T05P3g@4004<08=9V0<1kIP00000010000000001L0@010000020000000041
E<TH0000002<bQP0mG4^Mo3_F`7nooooZSPZMj8d:WL00000001V023BIP3@8@X@000001SBIP2LbQP0
RU=gM@00I0000000XEAgMJJI8bk@8@X@8=9V0801fWD0Q]`1B03M0@00g@5XbQP0d24:48C<6000L7Ue
:]Q2FokooonQE7Me1A;FMB3BIP3PAFL0ca8QQ@002P3PAFL0e<XH05`ieWETMP08000002D0000<0000
0@0005@0001D0000e`0007;moooJ0000N?goo`40002[Z^4o7LOQ_lH@002l<P000@0004`000000000
00000000003ooooooooooe00000X0000?00001P0000<0000000002D0000<00003@00P2P0000<0000
0@000580001`0@000@0007Goool0000000000000002@0@00000000000P9304d0C@1903L000000000
000000000000000000000000000000000000000000000000000000000000000000000000000o000o
100005C96010eVH0S<XH0?Ea;WLK03h0M05T0000001@0F@0F0?M0@00IP0PdVH0`7]V000000040000
000005`100400000800000000@5DbAP0000008c:603eLBigl>mK0OkooonZ>2YgXS@ZM`00000006H0
8=9V0=0Q2Q4000006=9V09c:602:DgMe001T0000002QE7MeYYTS;]0Q2Q4PdVH0P07JM@0000180=d1
003M0FS:603@8@XAQ<`H001`NGDZf49Ko_oooj5DMgD54]Ie8=9V0>15I`3?4R65000:0>15I`3DbQP0
G3WFMFAf00P000009@0000`000010000E00005@0003J0000L_goon40001hoOoo0@000:^ZhClMan6o
11400;`b00010000C00000000000000000000?ooooooooooD00006d0002<0000600000`000000000
9@0000`0000=0020:00000`000010000DP00070100010000MOooo`00000000000000090100000000
00020T<0C@1B03L00000000000000000000000000000000000000000000000000000000000000000
0000000000000000000003l003l40000E<TH043FIP2<bQP0mG4^Ma/0?P1d0F@000000501I01H0md1
001V023BIP30NfH0000000@000000000G0400@00000P000000010EC960000000S<XH0?Ea;WO`ke/1
o_ooojXh:WNR=2Yg00000000IP0PdVH0d24:4P00000HdVH0W<XH08YCMgD006@000000:5DMgFVVB<^
d24:4R3BIP200MYe000004P0g@400=d1J<XH0=0Q2Q:4c1P0071iMB[H@U_nooooXEAgM@DBeWDPdVH0
h4EW0<lB8HD000X0h4EW0=C:601L>MIeI7H02000000U000030000040001D0000E0000>40001boOoo
i00007Smool10000Zj[Q?ag7hKnB4@00_3800040001<00000000000000000000oooooooooom@0000
:@0003`0000H000030000000000U0000300000d0080X000030000040001B0000L0400040000ioooo
0000000000000000T040000000000082@`1=0580<@0`000000000000000000000000000000000000
000000000000000000000000000000000000000000000000?`00?`@0001DbAP0@=IV08c:603eLBig
6`0n07@1I0000000D05T05P3g@4006H08=9V0<1kIP00000010000000001L0@010000020000000041
E<TH0000002<bQP0mG4^Mo3_F`7nooooZSPZMj8d:WL00000001V023BIP3@8@XC000001SBIP2LbQP0
RU=gM@00I0000000XEAgMJJI8bk@8@XC8=9V0801fWD00000B03M0@00g@5XbQP0d24:4hC<6000L7Ue
:]Q2FokooonQE7Me1A;FMB3BIP3PAFL0ca8QQ@002P3PAFL0e<XH05`ieWETMP08000002D0000<0000
0@0005@0001D0000i`0007?mooo_0000OOgoo`40002[Z^4o7LOQ_a0B001Z<P000@0004`000000000
00000000003ooooooooooe00000m0000X00001P0000<0000000002D0000<00003@00P2P0000<0000
0@000580001`0@000@0003Woool0000000000000002@0@00000000000P9304d0C@190340<0000000
000000000000000000000000000000000000000000000000000000000000000000000000000o000o
100005C96010eVH0S<XH0?Ea;WLK03h0M05T0000001@0F@0F0?M0@00IP0PdVH0`7]V000000040000
000005`100400000800000000@5DbAP0000008c:603eLBigl>mK0OkooonZ>2YgXS@ZM`00000006H0
8=9V0=0Q2Q@000006=9V09c:602:DgMe001T0000002QE7MeYYTS;]0Q2Q@PdVH0P07JM@0000180=d1
003M0FS:603@8@XDQ<`H001`NGDZf49Ko_oooj5DMgD54]Ie8=9V0>15I`3?4R65000:0>15I`3DbQP0
G3WFMFAf00P000009@0000`000010000E00005@0003b0000LogoooX0001moOoo0@000:^ZhClMan6o
ha8006Xb00010000C00000000000000000000?ooooooooooD00004L0002P0000600000`000000000
9@0000`0000=0020:00000`000010000DP00070100010000>Oooo`00000000000000090100000000
00020T<0C@1505P0<@0`000000000000000000000000000000000000000000000000000000000000
0000000000000000000003l003l40000E<TH043FIP2<bQP0mG4^Ma/0?P1d0F@000000501I01H0md1
001V023BIP30NfH0000000@000000000G0400@00000P000000010EC960000000S<XH0?Ea;WO`ke/1
o_ooojXh:WNR=2Yg00000000IP0PdVH0d24:5@00000HdVH0W<XH08YCMgD006@000000:5DMgFVVB<^
d24:5B3BIP200MYe000004P0g@400=d1J<XH0=0Q2QF4c1P0071iMB[H@U_nooooXEAgM@DBeWDPdVH0
h4EW0<lB8HD000X0h4EW0=C:601L>MIeI7H02000000U000030000040001D0000E0000?/0001XoOoo
0@4008gmool10000Zj[Q?ag7hKnR4`00Ac<00040001<00000000000000000000oooooooooom@0000
/`0007P0000H000030000000000U0000300000d0080X000030000040001B0000L0400040000ioooo
0000000000000000T040000000000082@`1=04d0B@0a030000000000000000000000000000000000
000000000000000000000000000000000000000000000000?`00?`@0001DbAP0@=IV08c:603eLBig
6`0n07@1I0000000D05T05P3g@4006H08=9V0<1kIP00000010000000001L0@010000020000000041
E<TH0000002<bQP0mG4^Mo3_F`7nooooZSPZMj8d:WL00000001V023BIP3@8@XF000001SBIP2LbQP0
RU=gM@00I0000000XEAgMJJI8bk@8@XF8=9V0801fWD00000B03M0@00g@5XbQP0d24:5XC<6000L7Ue
:]Q2FokooonQE7Me1A;FMB3BIP3PAFL0ca8QQ@002P3PAFL0e<XH05`ieWETMP08000002D0000<0000
0@0005@0001D00000@4007?mool90@00OOgoo`40002[Z^4o7LOQ_aLD001Z<P000@0004`000000000
00000000003ooooooooooe00001E0000S00001P0000<0000000002D0000<00003@00P2P0000<0000
0@000580001`0@000@0007Goool0000000000000002@0@00000000000P9304d0DP0g000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000o000o
100005C96010eVH0S<XH0?Ea;WLK03h0M05T0000001@0F@0F0?M0@00IP0PdVH0`7]V000000040000
000005`100400000800000000@5DbAP0000008c:603eLBigl>mK0OkooonZ>2YgXS@ZM`00000006H0
8=9V0=0Q2QL000006=9V09c:602:DgMe001T0000002QE7MeYYTS;]0Q2QLPdVH0P07JM@0000180=d1
003M0FS:603@8@XGQ<`H001`NGDZf49Ko_oooj5DMgD54]Ie8=9V0>15I`3?4R65000:0>15I`3DbQP0
G3WFMFAf00P000009@0000`000010000E00005@000090@00L_goo``1001hoOoo0@000:^ZhClMan6o
]1@00;`b00010000C00000000000000000000?ooooooooooD00002P0000l0000600000`000000000
9@0000`0000=0020:00000`000010000DP00070100010000MOooo`00000000000000090100000000
00020T<0C@1=04T0=`00000000000000000000000000000000000000000000000000000000000000
0000000000000000000003l003l40000E<TH043FIP2<bQP0mG4^Ma/0?P1d0F@000000501I01H0md1
001V023BIP30NfH0000000@000000000G0400@00000P000000010EC960000000S<XH0?Ea;WO`ke/1
o_ooojXh:WNR=2Yg00000000IP0PdVH0d24:6000000HdVH0W<XH08YCMgD006@000000:5DMgFVVB<^
d24:623BIP200MYe000004P0g@400=d1J<XH0=0Q2QR4c1P0071iMB[H@U_nooooXEAgM@DBeWDPdVH0
h4EW0<lB8HD000X0h4EW0=C:601L>MIeI7H02000000U000030000040001D0000E00000`1001boOoo
4`4007Smool10000Zj[Q?ag7hKoc5000_3800040001<00000000000000000000oooooooooom@0000
K@0008`0000H000030000000000U0000300000d0080X000030000040001B0000L0400040001eoooo
0000000000000000T040000000000082@`1=05<0F@0g000000000000000000000000000000000000
000000000000000000000000000000000000000000000000?`00?`@0001DbAP0@=IV08c:603eLBig
6`0n07@1I0000000D05T05P3g@4006H08=9V0<1kIP00000010000000001L0@010000020000000041
E<TH0000002<bQP0mG4^Mo3_F`7nooooZSPZMj8d:WL00000001V023BIP3@8@XI000001SBIP2LbQP0
RU=gM@00I0000000XEAgMJJI8bk@8@XI8=9V0801fWD00000B03M0@00g@5XbQP0d24:6HC<6000L7Ue
:]Q2FokooonQE7Me1A;FMB3BIP3PAFL0ca8QQ@002P3PAFL0e<XH05`ieWETMP08000002D0000<0000
0@0005@0001D00004`4007;moolI0@00OOgoo`40002[Z^4o7LOQ_h0E002l<P000@0004`000000000
00000000003ooooooooooe00002Q0000N00001P0000<0000000002D0000<00003@00P2P0000<0000
0@000580001`0@000@0007Goool0000000000000002@0@00000000000P9304d0DP0g000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000o000o
100005C96010eVH0S<XH0?Ea;WLK03h0M05T0000001@0F@0F0?M0@00IP0PdVH0`7]V000000040000
000005`100400000800000000@5DbAP0000008c:603eLBigl>mK0OkooonZ>2YgXS@ZM`00000006H0
8=9V0=0Q2QX000006=9V09c:602:DgMe001T0000002QE7MeYYTS;]0Q2QXPdVH0P07JM@0000180=d1
003M0FS:603@8@XJQ<`H001`NGDZf49Ko_oooj5DMgD54]Ie8=9V0>15I`3?4R65000:0>15I`3DbQP0
G3WFMFAf00P000009@0000`000010000E00005@0000I0@00L_gooad1001hoOoo0@000:^ZhClMan6o
oAD00;`b00010000C00000000000000000000?ooooooooooD0000340001@0000600000`000000000
E00005@0000M0@00L_goob01001hoOoo0@000:^ZhClMan6oC1H00;`b00010000C000000000000000
00000?ooooooooooD00002T0000l0000600000`0000000009@0000`0000=0020:00000`000010000
DP00070100010000>Oooo`0000000000000009010000000000020T<0C@1=04T0<@0`000000000000
0000000000000000000000000000000000000000000000000000000000000000000003l003l40000
E<TH043FIP2<bQP0mG4^Ma/0?P1d0F@000000501I01H0md1001V023BIP30NfH0000000@000000000
G0400@00000P000000010EC960000000S<XH0?Ea;WO`ke/1o_ooojXh:WNR=2Yg00000000IP0PdVH0
d24:6`00000HdVH0W<XH08YCMgD006@000000:5DMgFVVB<^d24:6b3BIP200MYe000004P0g@400=d1
J<XH0=0Q2Q^4c1P0071iMB[H@U_nooooXEAgM@DBeWDPdVH0h4EW0<lB8HD000X0h4EW0=C:601L>MIe
I7H02000000U000030000040001D0000E0000241001coOoo904007gmool10000Zj[Q?ag7hKnD5P00
JS800040001<00000000000000000000oooooooooom@0000>`0003`0000H000030000000001D0000
E00002D1001coOoo;@4007gmool10000Zj[Q?ag7hKo]5P00JS800040001<00000000000000000000
oooooooooom@0000E@0008`0000H000030000000000U0000300000d0080X000030000040001B0000
L0400040001eoooo0000000000000000T040000000000082@`1=0580=`0000000000000000000000
0000000000000000000000000000000000000000000000000000000000000000?`00?`@0001DbAP0
@=IV08c:603eLBig6`0n07@1I0000000D05T05P3g@4006H08=9V0<1kIP00000010000000001L0@01
0000020000000041E<TH0000002<bQP0mG4^Mo3_F`7nooooZSPZMj8d:WL00000001V023BIP3@8@XL
000001SBIP2LbQP0RU=gM@00I0000000XEAgMJJI8bk@8@XL8=9V0801fWD00000B03M0@00g@5XbQP0
d24:78C<6000L7Ue:]Q2FokooonQE7Me1A;FMB3BIP3PAFL0ca8QQ@002P3PAFL0e<XH05`ieWETMP08
000002D0000<00000@0005@0001D0000;@4007;mool`0@00N?goo`40002[Z^4o7LOQ_hXG002l<P00
0@0004`00000000000000000003ooooooooooe00000X0000?00001P0000<0000000002D0000<0000
3@00P2P0000<00000@000580001`0@000@0007Goool0000000000000002@0@00000000000P9304d0
C@1903L0000000000000000000000000000000000000000000000000000000000000000000000000
00000000000o000o100005C96010eVH0S<XH0?Ea;WLK03h0M05T0000001@0F@0F0?M0@00IP0PdVH0
`7]V000000040000000005`100400000800000000@5DbAP0000008c:603eLBigl>mK0OkooonZ>2Yg
XS@ZM`00000006H08=9V0=0Q2Qd000006=9V09c:602:DgMe001T0000002QE7MeYYTS;]0Q2QdPdVH0
P07JM@0000180=d1003M0FS:603@8@XMQ<`H001`NGDZf49Ko_oooj5DMgD54]Ie8=9V0>15I`3?4R65
000:0>15I`3DbQP0G3WFMFAf00P000009@0000`000010000E00005@0000`0@00L_goocL1001hoOoo
0@000:^ZhClMan6obAL00;`b00010000C00000000000000000000?ooooooooooD00006d0002<0000
600000`0000000009@0000`0000=0020:00000`000010000DP00070100010000MOooo`0000000000
000009010000000000020T<0C@1C05T0=`0000000000000000000000000000000000000000000000
00000000000000000000000000000000000003l003l40000E<TH043FIP2<bQP0mG4^Ma/0?P1d0F@0
00000501I01H0md1001V023BIP30NfH0000000@000000000G0400@00000P000000010EC960000000
S<XH0?Ea;WO`ke/1o_ooojXh:WNR=2Yg00000000IP0PdVH0d24:7P00000HdVH0W<XH08YCMgD006@0
00000:5DMgFVVB<^d24:7R3BIP200MYe000004P0g@400=d1J<XH0=0Q2Qj4c1P0071iMB[H@U_noooo
XEAgM@DBeWDPdVH0h4EW0<lB8HD000X0h4EW0=C:601L>MIeI7H02000000U000030000040001D0000
E00003P1001boOoo?P4007gmool10000Zj[Q?ag7hKmF6000_3800040001<00000000000000000000
oooooooooom@0000X@0007P0000H000030000000000U0000300000d0080X000030000040001B0000
L0400040001eoooo0000000000000000T040000000000082@`1=0580=`0000000000000000000000
0000000000000000000000000000000000000000000000000000000000000000?`00?`@0001DbAP0
@=IV08c:603eLBig6`0n07@1I0000000D05T05P3g@4006H08=9V0<1kIP00000010000000001L0@01
0000020000000041E<TH0000002<bQP0mG4^Mo3_F`7nooooZSPZMj8d:WL00000001V023BIP3@8@XO
000001SBIP2LbQP0RU=gM@00I0000000XEAgMJJI8bk@8@XO8=9V0801fWFT?2Ygdc`ZM`00JWIXbQP0
d24:7hC<6000L7Ue:]Q2FokooonQE7Me1A;FMB3BIP3PAFL0ca8QQ@002P3PAFL0e<XH05`ieWETMP08
000002D0000<00000@0005@0001D0000?P4007;moom20@00N?goo`40002[Z^4o7LOQ_m<H002l<P00
0@0004`00000000000000000003ooooooooooe00000b0000D00001P0000<0000000005@0001D0000
@P4007;moom50@00N?goo`40002[Z^4o7LOQ_b8I002l<P000@0004`00000000000000000003ooooo
oooooe00000Y0000?00001P0000<0000000002D0000<00003@00P2P0000<00000@000580001`0@00
0@0003Woool0000000000000002@0@00000000000P9304d0C@190340<00000000000000000000000
00000000000000000000000000000000000000000000000000000000000o000o100005C96010eVH0
S<XH0?Ea;WLK03h0M05T0000001@0F@0F0?M0@00IP0PdVH0`7]V000000040000000005`100400000
800000000@5DbAP0000008c:603eLBigl>mK0OkooonZ>2YgXS@ZM`00000006H08=9V0=0Q2R000000
6=9V09c:602:DgMe001T0000002QE7MeYYTS;]0Q2R0PdVH0P07JM@00003C?2Yg001ZMVS:603@8@XP
Q<`H001`NGDZf49Ko_oooj5DMgD54]Ie8=9V0>15I`3?4R65000:0>15I`3DbQP0G3WFMFAf00P00000
9@0000`000010000E00005@000150@00LogoodP1001moOoo0@000:^ZhClMan6oK1T006Xb00010000
C00000000000000000000?ooooooooooD00003/0000l0000600000`000000000E00005@0001:0@00
Logoodd1001moOoo0@000:^ZhClMan6oa1T006Xb00010000C00000000000000000000?oooooooooo
D00003X0000l0000600000`000000000E00005@0001>0@00Logooe41001moOoo0@000:^ZhClMan6o
7AX006Xb00010000C00000000000000000000?ooooooooooD00003X0000l0000600000`000000000
E00005@0001C0@00LogooeH1001moOoo0@000:^ZhClMan6oMQX006Xb00010000C000000000000000
00000?ooooooooooD00003X0000l0000600000`000000000E00005@0001G0@00LogooeX1001moOoo
0@000:^ZhClMan6ocAX006Xb00010000C00000000000000000000?ooooooooooD00003/0000l0000
600000`000000000E00005@0001L0@00Logoof@1001moOoo0@000:^ZhClMan6o9Q/006Xb00010000
C00000000000000000000?ooooooooooD00005D0002<0000600000`0000000009@0000`0000=0020
:00000`000010000DP00070100010000MOooo`0000000000000009010000000000020T<0C@1B03L0
00000000000000000000000000000000000000000000000000000000000000000000000000000000
000003l003l40000E<TH043FIP2<bQP0mG4^Ma/0?P1d0F@000000501I01H0md1001V023BIP30NfH0
000000@000000000G0400@00000P000000010EC960000000S<XH0?Ea;WO`ke/1o_ooojXh:WNR=2Yg
00000000IP0PdVH0d24:8@00000HdVH0W<XH08YCMgD006@000000:5DMgFVVB<^d24:8B3BIP200MYe
00000=<l:WL006YfJ<XH0=0Q2R64c1P0071iMB[H@U_nooooXEAgM@DBeWDPdVH0h4EW0<lB8HD000X0
h4EW0=C:601L>MIeI7H02000000U000030000040001D0000E00006<1001boOooIP4007Smool10000
Zj[Q?ag7hKo46`00_3800040001<00000000000000000000oooooooooom@0000:00003`0000H0000
30000000001D0000E00006L1001boOooJ`4007Smool10000Zj[Q?ag7hKl27000_3800040001<0000
0000000000000000oooooooooom@0000<0000500000H000030000000001D0000E00006X1001boOoo
K@4007Smool10000Zj[Q?ag7hKmA7000_3800040001<00000000000000000000oooooooooom@0000
:@0003`0000H000030000000000U0000300000d0080X000030000040001B0000L0400040000ioooo
0000000000000000T040000000000082@`1=04d0B@0a030000000000000000000000000000000000
000000000000000000000000000000000000000000000000?`00?`@0001DbAP0@=IV08c:603eLBig
6`0n07@1I0000000D05T05P3g@4006H08=9V0<1kIP00000010000000001L0@010000020000000041
E<TH0000002<bQP0mG4^Mo3_F`7nooooZSPZMj8d:WL00000001V023BIP3@8@XR000001SBIP2LbQP0
RU=gM@00I0000000XEAgMJJI8bk@8@XR8=9V0801fWD00000dc`ZM`00JWIXbQP0d24:8XC<6000L7Ue
:]Q2FokooonQE7Me1A;FMB3BIP3PAFL0ca8QQ@002P3PAFL0e<XH05`ieWETMP08000002D0000<0000
0@0005@0001D0000KP4007?mooma0@00OOgoo`40002[Z^4o7LOQ_iTL001Z<P000@0004`000000000
00000000003ooooooooooe00000k0000?00001P0000<0000000005@0001D0000L`4007?moomi0@00
OOgoo`40002[Z^4o7LOQ_o8L001Z<P000@0004`00000000000000000003ooooooooooe0000160000
N00001P0000<0000000002D0000<00003@00P2P0000<00000@000580001`0@000@0007Goool00000
00000000002@0@00000000000P9304d0DP0g00000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000o000o100005C96010eVH0S<XH0?Ea;WLK03h0
M05T0000001@0F@0F0?M0@00IP0PdVH0`7]V000000040000000005`100400000800000000@5DbAP0
000008c:603eLBigl>mK0OkooonZ>2YgXS@ZM`00000006H08=9V0=0Q2R<000006=9V09c:602:DgMe
001T0000002QE7MeYYTS;]0Q2R<PdVH0P07JM@00003C?2Yg001ZMVS:603@8@XSQ<`H001`NGDZf49K
o_oooj5DMgD54]Ie8=9V0>15I`3?4R65000:0>15I`3DbQP0G3WFMFAf00P000009@0000`000010000
E00005@0001j0@00L_googd1001hoOoo0@000:^ZhClMan6oSQd00;`b00010000C000000000000000
00000?ooooooooooD00002P0000l0000600000`0000000009@0000`0000=0020:00000`000010000
DP00070100010000MOooo`0000000000000009010000000000020T<0C@1=04T0=`00000000000000
0000000000000000000000000000000000000000000000000000000000000000000003l003l40000
E<TH043FIP2<bQP0mG4^Ma/0?P1d0F@000000501I01H0md1001V023BIP30NfH0000000@000000000
G0400@00000P000000010EC960000000S<XH0?Ea;WO`ke/1o_ooojXh:WNR=2Yg00000000IP0PdVH0
d24:9000000HdVH0W<XH08YCMgD006@000000:5DMgFVVB<^d24:923BIP200MYe00000=<l:WL006Yf
J<XH0=0Q2RB4c1P0071iMB[H@U_nooooXEAgM@DBeWDPdVH0h4EW0<lB8HD000X0h4EW0=C:601L>MIe
I7H02000000U000030000040001D0000E00007d1001boOooQ04007Smool10000Zj[Q?ag7hKo<7@00
_3800040001<00000000000000000000oooooooooom@0000K@0008`0000H000030000000000U0000
300000d0080X000030000040001B0000L0400040001eoooo0000000000000000T040000000000082
@`1=0580=`0000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000?`00?`@0001DbAP0@=IV08c:603eLBig6`0n07@1I0000000D05T05P3g@4006H0
8=9V0<1kIP00000010000000001L0@010000020000000041E<TH0000002<bQP0mG4^Mo3_F`7noooo
ZSPZMj8d:WL00000001V023BIP3@8@XU000001SBIP2LbQP0RU=gM@00I0000000XEAgMJJI8bk@8@XU
8=9V0801fWD00000dc`ZM`00JWIXbQP0d24:9HC<6000L7Ue:]Q2FokooonQE7Me1A;FMB3BIP3PAFL0
ca8QQ@002P3PAFL0e<XH05`ieWETMP08000002D0000<00000@0005@0001D0000Q@4007;moon80@00
N?goo`40002[Z^4o7LOQ_eXN002l<P000@0004`00000000000000000003ooooooooooe00000Y0000
?00001P0000<0000000002D0000<00003@00P2P0000<00000@000580001`0@000@0003Woool00000
00000000002@0@00000000000P9304d0C@190340<000000000000000000000000000000000000000
0000000000000000000000000000000000000000000o000o100005C96010eVH0S<XH0?Ea;WLK03h0
M05T0000001@0F@0F0?M0@00IP0PdVH0`7]V000000040000000005`100400000800000000@5DbAP0
000008c:603eLBigl>mK0OkooonZ>2YgXS@ZM`00000006H08=9V0=0Q2RH000006=9V09c:602:DgMe
001T0000002QE7MeYYTS;]0Q2RHPdVH0P07JM@00003C?2Yg001ZMVS:603@8@XVQ<`H001`NGDZf49K
o_oooj5DMgD54]Ie8=9V0>15I`3?4R65000:0>15I`3DbQP0G3WFMFAf00P000009@0000`000010000
E00005@000280@00Logooh/1001moOoo0@000:^ZhClMan6oXQh006Xb00010000C000000000000000
00000?ooooooooooD00003/0000l0000600000`000000000E00005@0002=0@00Logooi41001moOoo
0@000:^ZhClMan6onah006Xb00010000C00000000000000000000?ooooooooooD00007@0001@0000
600000`0000000009@0000`0000=0020:00000`000010000DP00070100010000MOooo`0000000000
000009010000000000020T<0C@1=04T0=`0000000000000000000000000000000000000000000000
00000000000000000000000000000000000003l003l40000E<TH043FIP2<bQP0mG4^Ma/0?P1d0F@0
00000501I01H0md1001V023BIP30NfH0000000@000000000G0400@00000P000000010EC960000000
S<XH0?Ea;WO`ke/1o_ooojXh:WNR=2Yg00000000IP0PdVH0d24:9`00000HdVH0W<XH08YCMgD006@0
00000:5DMgFVVB<^d24:9b3BIP200MYe00000=<l:WL006YfJ<XH0=0Q2RN4c1P0071iMB[H@U_noooo
XEAgM@DBeWDPdVH0h4EW0<lB8HD000X0h4EW0=C:601L>MIeI7H02000000U000030000040001D0000
E0000901001goOooU`4007gmool10000Zj[Q?ag7hKm37`00C3800040001<00000000000000000000
oooooooooom@0000K@0008`0000H000030000000000U0000300000d0080X000030000040001B0000
L0400040000ioooo0000000000000000T040000000000082@`1=04D0F00a03000000000000000000
0000000000000000000000000000000000000000000000000000000000000000?`00?`@0001DbAP0
@=IV08c:603eLBig6`0n07@1I0000000D05T05P3g@4006H08=9V0<1kIP00000010000000001L0@01
0000020000000041E<TH0000002<bQP0mG4^Mo3_F`7nooooZSPZMj8d:WL00000001V023BIP3@8@XX
000001SBIP2LbQP0RU=gM@00I0000000XEAgMJJI8bk@8@XX8=9V0801fWD00000dc`ZM`00JWIXbQP0
d24::8C<6000L7Ue:]Q2FokooonQE7Me1A;FMB3BIP3PAFL0ca8QQ@002P3PAFL0e<XH05`ieWETMP08
000002D0000<00000@0005@0001D0000V04006SmoonN0@00SOgoo`40002[Z^4o7LOQ_mXO0017<`00
0@0004`00000000000000000003ooooooooooe00002d0000N00002D0000<00003@00P2P0000<0000
0@0000h0000D000000000100000D0000240122@0000H00000Q30f`40000300000000000000000000
6d000400000d00000@000080001OPTA3H6<Ta8@oFD<20ZU10`0005n2A4=PHbC4lN3>@f1S9<AOPTA3
D1/Oa24000080000HP0000`0000100008@0000P0000Q0000200007<0000<0000000001`000080000
9@0000`0000000209@0000`0000700209@0000`0000>00206@0000`0003oool0600000`000000000
4P0000`0000200004`0000`000010000500000`0000=00005@0000`0000100005P0000`000000000
3@00010000000000000003X0000<00002P0001/0000@000000000000000S0000800003_?9D400000
00000>:g:d4iS_k4jhSLAB@0000T0000>llU@@0000000000h[L[@CV>o/C[R=a5100007<0000<0000
000000d0000@000000000000001B0000L0400080000@00001`00000000000000_080000000070P8R
D`1i07<0M01U06d0000D0:3hooob0@00000003bm@P:0n?oo201HO__fool000000000022m@P:0n?oo
ool00000E0XHT7P00000P5c;=@3;c4`mT<`e0;SMPPLQ@kigfQlQIB80RP4H00000000062F2PH80000
cjTT@@00aceHPo4600000<3Lk0J/b3D00000000000000000ooooob3<=@1<c3D0?=Le08DI`WNeLfH1
o_ooohcS_GObh;eg003f23Sl0002000000000200001lc3D0X<`e0>]HkgH007P0200D02IJkgHAZA=U
0000062F2PKooooo0`00000000000000000006S<=@2:MFMX[=<e001`lGKik]LCo_ooobIJkgIR4aEg
@;YD2P40003Dc3D0f<`e02l`5GMTMP08000002D0000<00000P0004H000280000O00004M4BD<20000
a@0006kmoonM0@00Pogooc00001W06D0KP1U0780H@1d06D0I00P0680N@0P05L0C@1602l0A@1=04H0
801R0640H`1[06D0KP1T0200K`1V0200L01c07@0K`1U06@0J@1d0000J@1^0700M@1d0000000S0000
800009Rf13l0000000000>QO2KliS_k4jhSLAB@0000T0000V;H4?`0000000000j5l9_cV>o/C[R=a5
100002<0000P0000V;H4?`0000000000j5l9_cV>o/C[R=a5900002@0002H]P@o00000000003XG`Vo
>Hkna>^8g4D400004P0000`0000100005P0000`0000H0000600000`000000000DP00070100030000
>Oooo`000000000000000901000000001`020T<0C@1=04T0<@0`0000000000000000000000000000
00000000000000000000000000000000000000000000000010000<S:60000000200000L000000000
SU<gMLS:600`bQP0k;1300@000240000b<XH00000000000030000000000100008<XH000000240000
X0l0008000030000b<XH000000000000?<XH07nN@`3l2]`1P<XH0000@`040000S[E30=bV8BiXO]`1
8HQ600000000000000000040001<bQP002m:00c;603PW48034Qn;_koool004<0gKE306Qng0400000
003L0FQng078bQP00@0003P07P0;0000b<XH06Qng0410`00/7gL0@40001PO]`1I7H02000000U0000
300000<0001D0000E00000d0000c0000H00009h000010000Zj[Q?ag7hKma3`00JS800040001<0000
0000000000000000oooooooooom@0000@@3ooj00000H000030000000001D0000E00006`0000c0000
^`0009h000010000Zj[Q?ag7hKlX4000JS800040001<00000000000000000000oooooooooom@0000
E@0e08`0000H000030000000001B0000L04000@0000D00002@00000000000000_080000000070P8R
D`1i07<0M01U06d000000000003R0000000006a4NP:0n?oo000000000000000000000514NP:0n?oo
^YH000005GNgI1EgfQlQI@00000000000@000<Rmo@GHbcD0HF@EMmXO8FD00000000005@000000000
b;gm1E3<=@3NDAEgfQlQIDSPQ`020000f5aO0e@0000000000@0003P07P0;0000b<XH06Qng0410`00
/7gL0@40001PO]`100002000001PUPX6H9H:1U3<=@0_<1EgD<`e06H`5GNdlE/:H9H:1RD0000000X0
>48008C==@0MnV=XfQlQI@00Q`38_Od50P000=QLG`>b2VAXD0HIM`00001@1QUgP04IMbSbF`ZXc3D0
;c0EMjS<=@1V<1EgM?9K2V2F2PITMP08000002D0000<0000100002P0000<00000`000580001`0@00
0`0007Goool0000000000000002@0@00000000L00P9304d0DP0g0000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000o000o100000800010eVH0
b<XH0000000K03h0M05T0000001@0F@0F0?M0@00@`0PdVH0`7]V000000040000000005`100400000
800000000@5DbAP0000008c:603eLBigl>mK0OkooonZ>2YgXS@ZM`00000006H08=9V0=0Q2Q000000
6=9V09c:602:DgMe001T0000002QE7MeYYTS;]0Q2Q0PdVH0P07JM@26g0580=d1003M0FS:603@8@X@
Q<`H001`NGDZf49Ko_oooj5DMgD54]Ie8=9V0>15I`3?4R65000:0>15I`3DbQP0G3WFMFAf00P00000
9@0000`000030000E00005@0002n00007`000=h0001Z00000@000:^ZhClMan6oaQ000;`b00010000
C00000000000000000000?ooooooooooD00002P00`0l0000600000`0000000009@0000`000040000
:00000`000030000DP00070100030000MOooo`000000000000000901000000001`020T<0C@1=04T0
=`000000000000000000000000000000000000000000000000000000000000000000000000000000
000003l003l40000E<TH043FIP2<bQP0mG4^Ma/0?P1d0F@000000501I01H0md1001V023BIP30NfH0
000000@000000000G0400@00000P000000010EC960000000S<XH0?Ea;WO`ke/1o_ooojXh:WNR=2Yg
00000000IP0PdVH0d24:4@00000HdVH0W<XH08YCMgD006@000000:5DMgFVVB<^d24:4B3BIP200MYe
000004P0g@400=d1J<XH0=0Q2Q64c1P0071iMB[H@U_nooooXEAgM@DBeWDPdVH0h4EW0<lB8HD000X0
h4EW0=C:601L>MIeI7H02000000U0000300000<0001D0000E0000=h0000O00009`4006X000010000
Zj[Q?ag7hKl44@00_3800040001<00000000000000000000oooooooooom@0000K@0H08`0000H0000
30000000000U0000300000@0000X0000300000<0001B0000L04000<0001eoooo0000000000000000
T040000000070082@`1=0580=`000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000?`00?`@0001DbAP0@=IV08c:603eLBig6`0n07@1I0000000
D05T05P3g@4006H08=9V0<1kIP00000010000000001L0@010000020000000041E<TH0000002<bQP0
mG4^Mo3_F`7nooooZSPZMj8d:WL00000001V023BIP3@8@XB000001SBIP2LbQP0RU=gM@00I0000000
XEAgMJJI8bk@8@XB8=9V0801fWD00000B03M0@00g@5XbQP0d24:4XC<6000L7Ue:]Q2FokooonQE7Me
1A;FMB3BIP3PAFL0ca8QQ@002P3PAFL0e<XH05`ieWETMP08000002D0000<00000`0005@0001D0000
9`4001l000170@00JP000040002[Z^4o7LOQ_i8A002l<P000@0004`00000000000000000003ooooo
oooooe00000Y01P0?00001P0000<0000000002D0000<0000100002P0000<00000`000580001`0@00
0`0003Woool0000000000000002@0@00000000L00P9304d0DP0a0300000000000000000000000000
00000000000000000000000000000000000000000000000000000000000o000o100005C96010eVH0
S<XH0?Ea;WLK03h0M05T0000001@0F@0F0?M0@00IP0PdVH0`7]V000000040000000005`100400000
800000000@5DbAP0000008c:603eLBigl>mK0OkooonZ>2YgXS@ZM`00000006H08=9V0=0Q2Q<00000
6=9V09c:602:DgMe001T0000002QE7MeYYTS;]0Q2Q<PdVH0P07JM@0000180=d1003M0FS:603@8@XC
Q<`H001`NGDZf49Ko_oooj5DMgD54]Ie8=9V0>15I`3?4R65000:0>15I`3DbQP0G3WFMFAf00P00000
9@0000`000030000E00005@0001Y0@00<`000;`1002N00000@000:^ZhClMan6o418006Xb00010000
C00000000000000000000?ooooooooooD00003d0602P0000600000`0000000009@0000`000040000
:00000`000030000DP00070100030000>Oooo`000000000000000901000000001`020T<0C@1=04T0
<@0`0000000000000000000000000000000000000000000000000000000000000000000000000000
000003l003l40000E<TH043FIP2<bQP0mG4^Ma/0?P1d0F@000000501I01H0md1001V023BIP30NfH0
000000@000000000G0400@00000P000000010EC960000000S<XH0?Ea;WO`ke/1o_ooojXh:WNR=2Yg
00000000IP0PdVH0d24:5000000HdVH0W<XH08YCMgD006@000000:5DMgFVVB<^d24:523BIP200MYe
000004P0g@400=d1J<XH0=0Q2QB4c1P0071iMB[H@U_nooooXEAgM@DBeWDPdVH0h4EW0<lB8HD000X0
h4EW0=C:601L>MIeI7H02000000U0000300000<0001D0000E0000=H1000c0000:@8009h000010000
Zj[Q?ag7hKoS4P00JS800040001<00000000000000000000oooooooooom@0000A`0H0:00000H0000
30000000000U0000300000@0000X0000300000<0001B0000L04000<0000ioooo0000000000000000
T040000000070082@`1=04D0F00a0300000000000000000000000000000000000000000000000000
00000000000000000000000000000000?`00?`@0001DbAP0@=IV08c:603eLBig6`0n07@1I0000000
D05T05P3g@4006H08=9V0<1kIP00000010000000001L0@010000020000000041E<TH0000002<bQP0
mG4^Mo3_F`7nooooZSPZMj8d:WL00000001V023BIP3@8@XE000001SBIP2LbQP0RU=gM@00I0000000
XEAgMJJI8bk@8@XE8=9V0801fWD00000B03M0@00g@5XbQP0d24:5HC<6000L7Ue:]Q2FokooonQE7Me
1A;FMB3BIP3PAFL0ca8QQ@002P3PAFL0e<XH05`ieWETMP08000002D0000<00000`0005@0001D0000
>@800;[ooomh0P00B@400040002[Z^4o7LOQ_j8C0017<`000@0004`00000000000000000003ooooo
oooooe00002c01P0N00001P0000<0000000002D0000<0000100002P0000<00000`000580001`0@00
0`0003Woool0000000000000002@0@00000000L00P9304d0C@190340<00000000000000000000000
00000000000000000000000000000000000000000000000000000000000o000o100005C96010eVH0
S<XH0?Ea;WLK03h0M05T0000001@0F@0F0?M0@00IP0PdVH0`7]V000000040000000005`100400000
800000000@5DbAP0000008c:603eLBigl>mK0OkooonZ>2YgXS@ZM`00000006H08=9V0=0Q2QH00000
6=9V09c:602:DgMe001T0000002QE7MeYYTS;]0Q2QHPdVH0P07JM@0000180=d1003M0FS:603@8@XF
Q<`H001`NGDZf49Ko_oooj5DMgD54]Ie8=9V0>15I`3?4R65000:0>15I`3DbQP0G3WFMFAf00P00000
9@0000`000030000E00005@0001f0P00<`000<D2002N00000@000:^ZhClMan6o5a@006Xb00010000
C00000000000000000000?ooooooooooD00005D0602<0000600000`0000000009@0000`000040000
:00000`000030000DP00070100030000MOooo`000000000000000901000000001`020T<0C@1B03L0
00000000000000000000000000000000000000000000000000000000000000000000000000000000
000003l003l40000E<TH043FIP2<bQP0mG4^Ma/0?P1d0F@000000501I01H0md1001V023BIP30NfH0
000000@000000000G0400@00000P000000010EC960000000S<XH0?Ea;WO`ke/1o_ooojXh:WNR=2Yg
00000000IP0PdVH0d24:5`00000HdVH0W<XH08YCMgD006@000000:5DMgFVVB<^d24:5b3BIP200MYe
000004P0g@400=d1J<XH0=0Q2QN4c1P0071iMB[H@U_nooooXEAgM@DBeWDPdVH0h4EW0<lB8HD000X0
h4EW0=C:601L>MIeI7H02000000U0000300000<0001D0000E0000<L2000O0000i`8006X000010000
Zj[Q?ag7hKnd5000_3800040001<00000000000000000000oooooooooom@0000:00H03`0000H0000
30000000000U0000300000@0000X0000300000<0001B0000L04000<0001eoooo0000000000000000
T040000000070082@`1=04d0B@0g0000000000000000000000000000000000000000000000000000
00000000000000000000000000000000?`00?`@0001DbAP0@=IV08c:603eLBig6`0n07@1I0000000
D05T05P3g@4006H08=9V0<1kIP00000010000000001L0@010000020000000041E<TH0000002<bQP0
mG4^Mo3_F`7nooooZSPZMj8d:WL00000001V023BIP3@8@XH000001SBIP2LbQP0RU=gM@00I0000000
XEAgMJJI8bk@8@XH8=9V0801fWD00000B03M0@00g@5XbQP0d24:68C<6000L7Ue:]Q2FokooonQE7Me
1A;FMB3BIP3PAFL0ca8QQ@002P3PAFL0e<XH05`ieWETMP08000002D0000<00000`0005@0001D0000
j08001l0000a0`00JP000040002[Z^4o7LOQ_o<D002l<P000@0004`00000000000000000003ooooo
oooooe00001]01P0S00001P0000<0000000002D0000<0000100002P0000<00000`000580001`0@00
0`0007Goool0000000000000002@0@00000000L00P9304d0D`1I03L0000000000000000000000000
00000000000000000000000000000000000000000000000000000000000o000o100005C96010eVH0
S<XH0?Ea;WLK03h0M05T0000001@0F@0F0?M0@00IP0PdVH0`7]V000000040000000005`100400000
800000000@5DbAP0000008c:603eLBigl>mK0OkooonZ>2YgXS@ZM`00000006H08=9V0=0Q2QT00000
6=9V09c:602:DgMe001T0000002QE7MeYYTS;]0Q2QTPdVH0P07JM@0000180=d1003M0FS:603@8@XI
Q<`H001`NGDZf49Ko_oooj5DMgD54]Ie8=9V0>15I`3?4R65000:0>15I`3DbQP0G3WFMFAf00P00000
9@0000`000030000E00005@0000a0`007@000703002O00000@000:^ZhClMan6oP1D00;`b00010000
C00000000000000000000?ooooooooooD0000:40601h0000600000`0000000009@0000`000040000
:00000`000030000DP00070100030000MOooo`000000000000000901000000001`020T<0C@1B03L0
00000000000000000000000000000000000000000000000000000000000000000000000000000000
000003l003l40000E<TH043FIP2<bQP0mG4^Ma/0?P1d0F@000000501I01H0md1001V023BIP30NfH0
000000@000000000G0400@00000P000000010EC960000000S<XH0?Ea;WO`ke/1o_ooojXh:WNR=2Yg
00000000IP0PdVH0d24:6P00000HdVH0W<XH08YCMgD006@000000:5DMgFVVB<^d24:6R3BIP200MYe
000004P0g@400=d1J<XH0=0Q2QZ4c1P0071iMB[H@U_nooooXEAgM@DBeWDPdVH0h4EW0<lB8HD000X0
h4EW0=C:601L>MIeI7H02000000U0000300000<0001D0000E0000783000O0000W0<006X000010000
Zj[Q?ag7hKom5@00_3800040001<00000000000000000000oooooooooom@0000<@0H0500000H0000
30000000001D0000E00009/3000O0000^`<006X000010000Zj[Q?ag7hKm<5P00_3800040001<0000
0000000000000000oooooooooom@0000:@0H03`0000H000030000000000U0000300000@0000X0000
300000<0001B0000L04000<0000ioooo0000000000000000T040000000070082@`1=04d0B@0a0300
00000000000000000000000000000000000000000000000000000000000000000000000000000000
?`00?`@0001DbAP0@=IV08c:603eLBig6`0n07@1I0000000D05T05P3g@4006H08=9V0<1kIP000000
10000000001L0@010000020000000041E<TH0000002<bQP0mG4^Mo3_F`7nooooZSPZMj8d:WL00000
001V023BIP3@8@XK000001SBIP2LbQP0RU=gM@00I0000000XEAgMJJI8bk@8@XK8=9V0801fWD00000
B03M0@00g@5XbQP0d24:6hC<6000L7Ue:]Q2FokooonQE7Me1A;FMB3BIP3PAFL0ca8QQ@002P3PAFL0
e<XH05`ieWETMP08000002D0000<00000`0005@0001D0000`0<003<0003P0`00WP000040002[Z^4o
7LOQ_i@F001Z<P000@0004`00000000000000000003ooooooooooe00000k01P0?00001P0000<0000
000005@0001D0000kP<003<0000m1000WP000040002[Z^4o7LOQ_ndF001Z<P000@0004`000000000
00000000003ooooooooooe00001E0000S00001P0000<0000000002D0000<0000100002P0000<0000
0`000580001`0@000`0007Goool0000000000000002@0@00000000L00P9304d0DP0g000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000o000o
100005C96010eVH0S<XH0?Ea;WLK03h0M05T0000001@0F@0F0?M0@00IP0PdVH0`7]V000000040000
000005`100400000800000000@5DbAP0000008c:603eLBigl>mK0OkooonZ>2YgXS@ZM`00000006H0
8=9V0=0Q2Q`000006=9V09c:602:DgMe001T0000002QE7MeYYTS;]0Q2Q`PdVH0P07JM@0000180=d1
003M0FS:603@8@XLQ<`H001`NGDZf49Ko_oooj5DMgD54]Ie8=9V0>15I`3?4R65000:0>15I`3DbQP0
G3WFMFAf00P000009@0000`000030000E00005@0001010007`000604001Z00000@000:^ZhClMan6o
RQL00;`b00010000C00000000000000000000?ooooooooooD00002P0000l0000600000`000000000
9@0000`000040000:00000`000030000DP00070100030000MOooo`00000000000000090100000000
1`020T<0C@1=04T0=`00000000000000000000000000000000000000000000000000000000000000
0000000000000000000003l003l40000E<TH043FIP2<bQP0mG4^Ma/0?P1d0F@000000501I01H0md1
001V023BIP30NfH0000000@000000000G0400@00000P000000010EC960000000S<XH0?Ea;WO`ke/1
o_ooojXh:WNR=2Yg00000000IP0PdVH0d24:7@00000HdVH0W<XH08YCMgD006@000000:5DMgFVVB<^
d24:7B3BIP200MYe000004P0g@400=d1J<XH0=0Q2Qf4c1P0071iMB[H@U_nooooXEAgM@DBeWDPdVH0
h4EW0<lB8HD000X0h4EW0=C:601L>MIeI7H02000000U0000300000<0001D0000E0000604000O0000
Z@@006X000010000Zj[Q?ag7hKo95`00_3800040001<00000000000000000000oooooooooom@0000
K@1T08`0000H000030000000000U0000300000@0000X0000300000<0001B0000L04000<0001eoooo
0000000000000000T040000000070082@`1=05<0F@0g000000000000000000000000000000000000
000000000000000000000000000000000000000000000000?`00?`@0001DbAP0@=IV08c:603eLBig
6`0n07@1I0000000D05T05P3g@4006H08=9V0<1kIP00000010000000001L0@010000020000000041
E<TH0000002<bQP0mG4^Mo3_F`7nooooZSPZMj8d:WL00000001V023BIP3@8@XN000001SBIP2LbQP0
RU=gM@00I0000000XEAgMJJI8bk@8@XN8=9V0801fWD00000B03M0@00g@5XbQP0d24:7XC<6000L7Ue
:]Q2FokooonQE7Me1A;FMB3BIP3PAFL0ca8QQ@002P3PAFL0e<XH05`ieWETMP08000002D0000<0000
0`0005@0001D0000Z@@001d0003X1000W`000040002[Z^4o7LOQ_eHH002l<P000@0004`000000000
00000000003ooooooooooe00002Q0480N00001P0000<0000000002D0000<0000100002P0000<0000
0`000580001`0@000`0007Goool0000000000000002@0@00000000L00P9304d0DP0g000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000o000o
100005C96010eVH0S<XH0?Ea;WLK03h0M05T0000001@0F@0F0?M0@00IP0PdVH0`7]V000000040000
000005`100400000800000000@5DbAP0000008c:603eLBigl>mK0OkooonZ>2YgXS@ZM`00000006H0
8=9V0=0Q2Ql000006=9V09c:602:DgMe001T0000002QE7MeYYTS;]0Q2QlPdVH0P07JMJ@l:WOC?2Yg
001ZMVS:603@8@XOQ<`H001`NGDZf49Ko_oooj5DMgD54]Ie8=9V0>15I`3?4R65000:0>15I`3DbQP0
G3WFMFAf00P000009@0000`000030000E00005@0003Z10007`0001@5001Z00000@000:^ZhClMan6o
daP00;`b00010000C00000000000000000000?ooooooooooD0000380G`=@0000600000`000000000
E00005@0000C1@007`0003<5001Z00000@000:^ZhClMan6o8QT00;`b00010000C000000000000000
00000?ooooooooooD00002T0ooll0000600000`0000000009@0000`000040000:00000`000030000
DP00070100030000>Oooo`000000000000000901000000001`020T<0C@1=04T0<@0`000000000000
0000000000000000000000000000000000000000000000000000000000000000000003l003l40000
E<TH043FIP2<bQP0mG4^Ma/0?P1d0F@000000501I01H0md1001V023BIP30NfH0000000@000000000
G0400@00000P000000010EC960000000S<XH0?Ea;WO`ke/1o_ooojXh:WNR=2Yg00000000IP0PdVH0
d24:8000000HdVH0W<XH08YCMgD006@000000:5DMgFVVB<^d24:823BIP200MYe00000=<l:WL006Yf
J<XH0=0Q2R24c1P0071iMB[H@U_nooooXEAgM@DBeWDPdVH0h4EW0<lB8HD000X0h4EW0=C:601L>MIe
I7H02000000U0000300000<0001D0000E00003T5000c0000F@D009h000010000Zj[Q?ag7hKm/6@00
JS800040001<00000000000000000000oooooooooom@0000>`3ooc`0000H000030000000001D0000
E00006L5000c0000Q`D009h000010000Zj[Q?ag7hKo46@00JS800040001<00000000000000000000
oooooooooom@0000>P0003`0000H000030000000001D0000E00009D5000c0000]@D009h000010000
Zj[Q?ag7hKlM6P00JS800040001<00000000000000000000oooooooooom@0000>P0H03`0000H0000
30000000001D0000E0000<<5000c0000h`D009h000010000Zj[Q?ag7hKmf6P00JS800040001<0000
0000000000000000oooooooooom@0000>P0H03`0000H000030000000001D0000E0000?05000c0000
40H009h000010000Zj[Q?ag7hKo=6P00JS800040001<00000000000000000000oooooooooom@0000
>`0003`0000H000030000000001D0000E00001l6000c0000KPH009h000010000Zj[Q?ag7hKlV6`00
JS800040001<00000000000000000000oooooooooom@0000E@0008`0000H000030000000000U0000
300000@0000X0000300000<0001B0000L04000<0001eoooo0000000000000000T040000000070082
@`1=0580=`0000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000?`00?`@0001DbAP0@=IV08c:603eLBig6`0n07@1I0000000D05T05P3g@4006H0
8=9V0<1kIP00000010000000001L0@010000020000000041E<TH0000002<bQP0mG4^Mo3_F`7noooo
ZSPZMj8d:WL00000001V023BIP3@8@XQ000001SBIP2LbQP0RU=gM@00I0000000XEAgMJJI8bk@8@XQ
8=9V0801fWD00000dc`ZM`00JWIXbQP0d24:8HC<6000L7Ue:]Q2FokooonQE7Me1A;FMB3BIP3PAFL0
ca8QQ@002P3PAFL0e<XH05`ieWETMP08000002D0000<00000`0005@0001D0000L0H001l0002@1P00
JP000040002[Z^4o7LOQ_l@K002l<P000@0004`00000000000000000003ooooooooooe00000X0000
?00001P0000<0000000005@0001D0000T@H001l0002k1P00JP000040002[Z^4o7LOQ_`8L002l<P00
0@0004`00000000000000000003ooooooooooe00000`0000D00001P0000<0000000005@0001D0000
^PH001l0003J1P00JP000040002[Z^4o7LOQ_e4L002l<P000@0004`00000000000000000003ooooo
oooooe00000Y0000?00001P0000<0000000002D0000<0000100002P0000<00000`000580001`0@00
0`0003Woool0000000000000002@0@00000000L00P9304d0C@190340<00000000000000000000000
00000000000000000000000000000000000000000000000000000000000o000o100005C96010eVH0
S<XH0?Ea;WLK03h0M05T0000001@0F@0F0?M0@00IP0PdVH0`7]V000000040000000005`100400000
800000000@5DbAP0000008c:603eLBigl>mK0OkooonZ>2YgXS@ZM`00000006H08=9V0=0Q2R800000
6=9V09c:602:DgMe001T0000002QE7MeYYTS;]0Q2R8PdVH0P07JM@00003C?2Yg001ZMVS:603@8@XR
Q<`H001`NGDZf49Ko_oooj5DMgD54]Ie8=9V0>15I`3?4R65000:0>15I`3DbQP0G3WFMFAf00P00000
9@0000`000030000E00005@0003O1P00<`000?l6002N00000@000:^ZhClMan6oVA`006Xb00010000
C00000000000000000000?ooooooooooD00003/0000l0000600000`000000000E00005@0000=1`00
<`0005/7002N00000@000:^ZhClMan6olQ`006Xb00010000C00000000000000000000?oooooooooo
D00004H0T@1h0000600000`0000000009@0000`000040000:00000`000030000DP00070100030000
MOooo`000000000000000901000000001`020T<0C@1B03L000000000000000000000000000000000
000000000000000000000000000000000000000000000000000003l003l40000E<TH043FIP2<bQP0
mG4^Ma/0?P1d0F@000000501I01H0md1001V023BIP30NfH0000000@000000000G0400@00000P0000
00010EC960000000S<XH0?Ea;WO`ke/1o_ooojXh:WNR=2Yg00000000IP0PdVH0d24:8`00000HdVH0
W<XH08YCMgD006@000000:5DMgFVVB<^d24:8b3BIP200MYe00000=<l:WL006YfJ<XH0=0Q2R>4c1P0
071iMB[H@U_nooooXEAgM@DBeWDPdVH0h4EW0<lB8HD000X0h4EW0=C:601L>MIeI7H02000000U0000
300000<0001D0000E00005h7000O0000OPL006X000010000Zj[Q?ag7hKn>7@00_3800040001<0000
0000000000000000oooooooooom@0000:02A03`0000H000030000000000U0000300000@0000X0000
300000<0001B0000L04000<0001eoooo0000000000000000T040000000070082@`1=04d0B@0g0000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
?`00?`@0001DbAP0@=IV08c:603eLBig6`0n07@1I0000000D05T05P3g@4006H08=9V0<1kIP000000
10000000001L0@010000020000000041E<TH0000002<bQP0mG4^Mo3_F`7nooooZSPZMj8d:WL00000
001V023BIP3@8@XT000001SBIP2LbQP0RU=gM@00I0000000XEAgMJJI8bk@8@XT8=9V0801fWD00000
dc`ZM`00JWIXbQP0d24:98C<6000L7Ue:]Q2FokooonQE7Me1A;FMB3BIP3PAFL0ca8QQ@002P3PAFL0
e<XH05`ieWETMP08000002D0000<00000`0005@0001D0000OPL001l000371`00JP000040002[Z^4o
7LOQ_l`M002l<P000@0004`00000000000000000003ooooooooooe00001]0940S00001P0000<0000
000002D0000<0000100002P0000<00000`000580001`0@000`0007Goool0000000000000002@0@00
000000L00P9304d0DP0g000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000o000o100005C96010eVH0S<XH0?Ea;WLK03h0M05T0000001@0F@0
F0?M0@00IP0PdVH0`7]V000000040000000005`100400000800000000@5DbAP0000008c:603eLBig
l>mK0OkooonZ>2YgXS@ZM`00000006H08=9V0=0Q2RD000006=9V09c:602:DgMe001T0000002QE7Me
YYTS;]0Q2RDPdVH0P07JM@00003C?2Yg001ZMVS:603@8@XUQ<`H001`NGDZf49Ko_oooj5DMgD54]Ie
8=9V0>15I`3?4R65000:0>15I`3DbQP0G3WFMFAf00P000009@0000`000030000E00005@000381`00
7`000>P7001Z00000@000:^ZhClMan6oFQh00;`b00010000C00000000000000000000?oooooooooo
D00002T0T@0l0000600000`0000000009@0000`000040000:00000`000030000DP00070100030000
>Oooo`000000000000000901000000001`020T<0C@1=04T0<@0`0000000000000000000000000000
000000000000000000000000000000000000000000000000000003l003l40000E<TH043FIP2<bQP0
mG4^Ma/0?P1d0F@000000501I01H0md1001V023BIP30NfH0000000@000000000G0400@00000P0000
00010EC960000000S<XH0?Ea;WO`ke/1o_ooojXh:WNR=2Yg00000000IP0PdVH0d24:9P00000HdVH0
W<XH08YCMgD006@000000:5DMgFVVB<^d24:9R3BIP200MYe00000=<l:WL006YfJ<XH0=0Q2RJ4c1P0
071iMB[H@U_nooooXEAgM@DBeWDPdVH0h4EW0<lB8HD000X0h4EW0=C:601L>MIeI7H02000000U0000
300000<0001D0000E0000>d7000c00003@P009h000010000Zj[Q?ag7hKnR7P00JS800040001<0000
0000000000000000oooooooooom@0000>`2A03`0000H000030000000001D0000E00001/8000c0000
A@P009h000010000Zj[Q?ag7hKok7P00JS800040001<00000000000000000000oooooooooom@0000
M0000500000H000030000000000U0000300000@0000X0000300000<0001B0000L04000<0001eoooo
0000000000000000T040000000070082@`1=04d0B@0g000000000000000000000000000000000000
000000000000000000000000000000000000000000000000?`00?`@0001DbAP0@=IV08c:603eLBig
6`0n07@1I0000000D05T05P3g@4006H08=9V0<1kIP00000010000000001L0@010000020000000041
E<TH0000002<bQP0mG4^Mo3_F`7nooooZSPZMj8d:WL00000001V023BIP3@8@XW000001SBIP2LbQP0
RU=gM@00I0000000XEAgMJJI8bk@8@XW8=9V0801fWD00000dc`ZM`00JWIXbQP0d24:9hC<6000L7Ue
:]Q2FokooonQE7Me1A;FMB3BIP3PAFL0ca8QQ@002P3PAFL0e<XH05`ieWETMP08000002D0000<0000
0`0005@0001D0000@0P005/000292000YP000040002[Z^4o7LOQ_d<O001<<P000@0004`000000000
00000000003ooooooooooe00001]0000S00001P0000<0000000002D0000<0000100002P0000<0000
0`000580001`0@000`0003Woool0000000000000002@0@00000000L00P9304d0A@1H0340<0000000
000000000000000000000000000000000000000000000000000000000000000000000000000o000o
100005C96010eVH0S<XH0?Ea;WLK03h0M05T0000001@0F@0F0?M0@00IP0PdVH0`7]V000000040000
000005`100400000800000000@5DbAP0000008c:603eLBigl>mK0OkooonZ>2YgXS@ZM`00000006H0
8=9V0=0Q2RP000006=9V09c:602:DgMe001T0000002QE7MeYYTS;]0Q2RPPdVH0P07JM@00003C?2Yg
001ZMVS:603@8@XXQ<`H001`NGDZf49Ko_oooj5DMgD54]Ie8=9V0>15I`3?4R65000:0>15I`3DbQP0
G3WFMFAf00P000009@0000`000030000E00005@0002?2000^_ooolh800190@000@000:^ZhClMan6o
fQl004Lc00010000C00000000000000000000?ooooooooooD0000;@0T@1h00009@0000`000040000
:00000`000030000AP0001@000080000AdA9@`<0000R000030000?oooolR000030000?oooolU0000
300000d0080X000030000080000X0000300000@0000R000030000?oooom60000`0400;@10015CDH[
;40002@0000H00000020?`00000000000020?`0008000020:T0002@0000H0000]QhU@@0000000000
kePT@CAooLB;4M=5940000`000000000:T0002@0000H0000/08/>P0000000000/08/>P00_ZL003jY
:d0000`0000000007T0600`0000000008D0500`000000000240211P0000<00000Q30f`000003000@
=40200`0000000007T0900`000000000:T0002@0000H0000/08/>P0000000000/08/>P00_ZL003jY
8D0700`000000000:T0002@0000H0000/08/>P0000000000/08/>P00_ZL003jY:d0000`000000000
:d0000`0000000007T0600`0000000008D0500`000000000240311P0000<00000Q30f`000003000@
=40300`0000000007T0900`000000000:T0002@0000H00000020?`00000000000020?`0000000000
8D0700`000000000C00006@00000000000000<48003H00000000000000322000f@0002T0ZP000000
00000000P3l0000000000000P3l000000000000000000000000000000000000000000280000<0000
ooooodH0000L0000400004E=AR/2@00030000000000>000050000000000@00005000
\>"], "Graphics",
  GeneratedCell->False,
  CellAutoOverwrite->False,
  ImageSize->{304.6315789473684, 29.239191729323338`},
  ImageMargins->{{25.199999999999996`, 0.}, {0., 27.45263157894738}}],
 "\nis built and then solved inside the functions  U1stepMatrixt  and ",
 "U2stepsMatrixt.",
 "\nThe matrix ",
 StyleBox["A ",
  FontSlant->"Italic"],
 "is built by means of the instruction SparseArray[...], while the vector G \
is generated by means of the instruction \
Table[Which[j\[Equal]0,.....,{j,0,Np}] . Here uL[tt[m]]=",
 Cell[BoxData[
  FormBox[
   RowBox[{"u", "(", 
    RowBox[{
     SubscriptBox["x", "0"], ",", 
     SubscriptBox["t", "m"]}], ")"}], TraditionalForm]]],
 "  is the boundary condition to the left (at x=",
 Cell[BoxData[
  FormBox[
   SubscriptBox["x", "0"], TraditionalForm]]],
 ") and uR[tt[m]]=",
 Cell[BoxData[
  FormBox[
   RowBox[{"u", "(", 
    RowBox[{
     SubscriptBox["x", "L"], ",", 
     SubscriptBox["t", "m"]}], ")"}], TraditionalForm]]],
 "  is the boundary condition to the right (at x=",
 Cell[BoxData[
  FormBox[
   SubscriptBox["x", "R"], TraditionalForm]]],
 "). The solution ",
 Cell[BoxData[
  FormBox[
   RowBox[{"{", 
    RowBox[{
     SubsuperscriptBox["U", "0", 
      RowBox[{"(", "m", ")"}]], ",", 
     SubsuperscriptBox["U", "1", 
      RowBox[{"(", "m", ")"}]], ",", 
     SubsuperscriptBox["U", "2", 
      RowBox[{"(", "m", ")"}]], ",", 
     RowBox[{"...", " ", 
      SubsuperscriptBox["U", "Np", 
       RowBox[{"(", "m", ")"}]]}]}], "}"}], TraditionalForm]]],
 ", is stored in the vector uVectortm "
}], "Text",
 CellChangeTimes->{{3.5610475457867827`*^9, 3.5610478337653446`*^9}, {
   3.5610480157112875`*^9, 3.561048019487503*^9}, {3.5611279206324*^9, 
   3.5611280299488*^9}, 3.6334403817689524`*^9, {3.637155165115307*^9, 
   3.637155194708559*^9}, 3.63715565065256*^9, {3.637155681385614*^9, 
   3.637155681385614*^9}, {3.637155924387241*^9, 3.6371559467586803`*^9}, 
   3.63715612308879*^9, {3.637156556334751*^9, 3.637156850552268*^9}, {
   3.6371570592494345`*^9, 3.6371573086012726`*^9}, {3.6371573689109783`*^9, 
   3.637157415976261*^9}, {3.6371576035353904`*^9, 3.6371576035353904`*^9}, {
   3.637164801687192*^9, 3.6371648346090746`*^9}, {3.6372383573356223`*^9, 
   3.6372383618748817`*^9}, {3.6381743238496*^9, 3.6381743323596*^9}, {
   3.6385150613368*^9, 3.6385151057818003`*^9}, {3.6386019723896*^9, 
   3.6386019725285997`*^9}, {3.6386020699066*^9, 3.6386020710025997`*^9}},
 Background->RGBColor[0.88, 1, 0.88]],

Cell[CellGroupData[{

Cell[TextData[{
 "U1stepMatrixt[m]   provides the solution of \n",
 Cell[GraphicsData["Metafile", "\<\
CF5dJ6E]HGAYHf4PEfU^I6mgLb15CDHPAVmbKF5d0@0007b40@0006`0003ooooo^_ooolh800190@00
00000000000>9@00TP<00215CDH00040Q7`00?40000500000000000000000000HA<006PK003B0000
:@400000000000000000050d0`0XR0@0AP0002`0000P0000ADe6:`500@0L00004000008@`=/00000
F08005P200160000O04007010015CDH[7T0500`0000000007d0300`000000000<402010000040000
0020?b501`0<000000000290100<0000000002Y0000T000060000000P3l0000000000000P3l00000
000002]0000<0000000001i01P0<0000000002501@0<0000000001i02@0<0000000002Y0000T0000
60000000P3l0000000000000P3l00000000002501`0<0000000002Y0000T000060000;02;3X00000
00000;02;3X0P;k3080maB]0000<0000000002Y0000T000060000;02;3X0000000000;02;3X0P;k3
080maB]0000<0000000002Y0000T000060000;02;3X0000000000;02;3X00;jW000nZ@Y0080T0000
60000>7ohOl1000000000000002PRe1:P7ZQB24000080000HP0000`000010000900002@00000000n
000000000000000n00000000000200009`0001P00001000000000>7oh@0000009@0000`000010000
9@0000`000080020EP000300003ooooooooool88003I00001@000?coo?olol@634K41Pa6o?olooco
9@0000`0000700209@0000`000000020900002@00000001100000000000000110000000000020000
AP000>Pi003L>@00ADe6:b]0000<0000000001i01P0<0000000002501@0<0000000001i02@0<0000
000002Y0000T000060000;02;3X0000000000;02;3X00;jW000nZB501`0<0000000002]0000<0000
000002Y0000T000060000;HN9D40000000000>mH944dOog4Ra7CABA0100<0000000000Q000GH>000
c3P0008@`=/200000`000;`h00010000c0000<H0001XoOooWP4008gmoolA6`00HjGoomXh000YZ?oo
84E=AP000@2l>000_0000080000`0000K000000000201`00>0@00:D2001m0@000000000000000000
eED:04S@1@1W06D0KP1U0780H@1d06D0I00P0680N@0P05L0C@1602l0A@1=04H0801R0640H`1[06D0
KP1T0200K`1V0200L01c07@0K`1U06@0J@1d0000J@1^0700M@1d0000000A0000300000H0000:0000
40000000000000004P0000`0000100005P0000`0000H0000600000`000000000DP00070100010000
>Oooo`0000000000000009010000000000020T<0C@1=04T0<@0`0000000000000000000000000000
00000000000000000000000000000000000000000000000010000<S:60000000200000L000000000
SU<gMLS:600`bQP0k;1300@000240000b<XH00000000000030000000000100008<XH000000240000
X0l0008000030000b<XH000000000000?<XH07nN@`3l2]`1P<XH0000@`040000S[E30=bV8BiXO]`1
8HQ600000000000000000040001<bQP002m:00c;603PW48034Qn;_koool004<0gKE306Qng0400000
003L0FQng078bQP00@0003P07P0;0000b<XH06Qng0410`00/7gL0@40001PO]`1I7H02000000U0000
30000040001D0000E0000<H0001coOoocP0007gmool10000Zj[Q?ag7hKma3`00JS800040001<0000
0000000000000000oooooooooom@0000@@000:00000H000030000000001D0000E0000<l0001coOoo
e`0007gmool10000Zj[Q?ag7hKlX4000JS800040001<00000000000000000000oooooooooom@0000
E@0008`0000H000030000000000U0000300000d0080X000030000040001B0000L0400040001eoooo
0000000000000000T040000000000082@`1=0580=`00000000000000000000000000000000000000
000000000000000000000000000000000000000000000000?`00?`@000020000@=IV0<S:60000000
6`0n07@1I0000000D05T05P3g@4004<08=9V0<1kIP00000010000000001L0@010000020000000041
E<TH0000002<bQP0mG4^Mo3_F`7nooooZSPZMj8d:WL00000001V023BIP3@8@X@000001SBIP2LbQP0
RU=gM@00I0000000XEAgMJJI8bk@8@X@8=9V0801fWD0Q]`1B03M0@00g@5XbQP0d24:48C<6000L7Ue
:]Q2FokooonQE7Me1A;FMB3BIP3PAFL0ca8QQ@002P3PAFL0e<XH05`ieWETMP08000002D0000<0000
0@0005@0001D0000e`0007;moooJ0000N?goo`40002[Z^4o7LOQ_lH@002l<P000@0004`000000000
00000000003ooooooooooe00000X0000?00001P0000<0000000002D0000<00003@00P2P0000<0000
0@000580001`0@000@0007Goool0000000000000002@0@00000000000P9304d0C@1903L000000000
000000000000000000000000000000000000000000000000000000000000000000000000000o000o
100005C96010eVH0S<XH0?Ea;WLK03h0M05T0000001@0F@0F0?M0@00IP0PdVH0`7]V000000040000
000005`100400000800000000@5DbAP0000008c:603eLBigl>mK0OkooonZ>2YgXS@ZM`00000006H0
8=9V0=0Q2Q4000006=9V09c:602:DgMe001T0000002QE7MeYYTS;]0Q2Q4PdVH0P07JM@0000180=d1
003M0FS:603@8@XAQ<`H001`NGDZf49Ko_oooj5DMgD54]Ie8=9V0>15I`3?4R65000:0>15I`3DbQP0
G3WFMFAf00P000009@0000`000010000E00005@0003J0000L_goon40001hoOoo0@000:^ZhClMan6o
11400;`b00010000C00000000000000000000?ooooooooooD00006d0002<0000600000`000000000
9@0000`0000=0020:00000`000010000DP00070100010000MOooo`00000000000000090100000000
00020T<0C@1B03L00000000000000000000000000000000000000000000000000000000000000000
0000000000000000000003l003l40000E<TH043FIP2<bQP0mG4^Ma/0?P1d0F@000000501I01H0md1
001V023BIP30NfH0000000@000000000G0400@00000P000000010EC960000000S<XH0?Ea;WO`ke/1
o_ooojXh:WNR=2Yg00000000IP0PdVH0d24:4P00000HdVH0W<XH08YCMgD006@000000:5DMgFVVB<^
d24:4R3BIP200MYe000004P0g@400=d1J<XH0=0Q2Q:4c1P0071iMB[H@U_nooooXEAgM@DBeWDPdVH0
h4EW0<lB8HD000X0h4EW0=C:601L>MIeI7H02000000U000030000040001D0000E0000>40001boOoo
i00007Smool10000Zj[Q?ag7hKnB4@00_3800040001<00000000000000000000oooooooooom@0000
:@0003`0000H000030000000000U0000300000d0080X000030000040001B0000L0400040000ioooo
0000000000000000T040000000000082@`1=0580<@0`000000000000000000000000000000000000
000000000000000000000000000000000000000000000000?`00?`@0001DbAP0@=IV08c:603eLBig
6`0n07@1I0000000D05T05P3g@4006H08=9V0<1kIP00000010000000001L0@010000020000000041
E<TH0000002<bQP0mG4^Mo3_F`7nooooZSPZMj8d:WL00000001V023BIP3@8@XC000001SBIP2LbQP0
RU=gM@00I0000000XEAgMJJI8bk@8@XC8=9V0801fWD00000B03M0@00g@5XbQP0d24:4hC<6000L7Ue
:]Q2FokooonQE7Me1A;FMB3BIP3PAFL0ca8QQ@002P3PAFL0e<XH05`ieWETMP08000002D0000<0000
0@0005@0001D0000i`0007?mooo_0000OOgoo`40002[Z^4o7LOQ_a0B001Z<P000@0004`000000000
00000000003ooooooooooe00000m0000X00001P0000<0000000002D0000<00003@00P2P0000<0000
0@000580001`0@000@0003Woool0000000000000002@0@00000000000P9304d0C@190340<0000000
000000000000000000000000000000000000000000000000000000000000000000000000000o000o
100005C96010eVH0S<XH0?Ea;WLK03h0M05T0000001@0F@0F0?M0@00IP0PdVH0`7]V000000040000
000005`100400000800000000@5DbAP0000008c:603eLBigl>mK0OkooonZ>2YgXS@ZM`00000006H0
8=9V0=0Q2Q@000006=9V09c:602:DgMe001T0000002QE7MeYYTS;]0Q2Q@PdVH0P07JM@0000180=d1
003M0FS:603@8@XDQ<`H001`NGDZf49Ko_oooj5DMgD54]Ie8=9V0>15I`3?4R65000:0>15I`3DbQP0
G3WFMFAf00P000009@0000`000010000E00005@0003b0000LogoooX0001moOoo0@000:^ZhClMan6o
ha8006Xb00010000C00000000000000000000?ooooooooooD00004L0002P0000600000`000000000
9@0000`0000=0020:00000`000010000DP00070100010000>Oooo`00000000000000090100000000
00020T<0C@1505P0<@0`000000000000000000000000000000000000000000000000000000000000
0000000000000000000003l003l40000E<TH043FIP2<bQP0mG4^Ma/0?P1d0F@000000501I01H0md1
001V023BIP30NfH0000000@000000000G0400@00000P000000010EC960000000S<XH0?Ea;WO`ke/1
o_ooojXh:WNR=2Yg00000000IP0PdVH0d24:5@00000HdVH0W<XH08YCMgD006@000000:5DMgFVVB<^
d24:5B3BIP200MYe000004P0g@400=d1J<XH0=0Q2QF4c1P0071iMB[H@U_nooooXEAgM@DBeWDPdVH0
h4EW0<lB8HD000X0h4EW0=C:601L>MIeI7H02000000U000030000040001D0000E0000?/0001XoOoo
0@4008gmool10000Zj[Q?ag7hKnR4`00Ac<00040001<00000000000000000000oooooooooom@0000
/`0007P0000H000030000000000U0000300000d0080X000030000040001B0000L0400040000ioooo
0000000000000000T040000000000082@`1=04d0B@0a030000000000000000000000000000000000
000000000000000000000000000000000000000000000000?`00?`@0001DbAP0@=IV08c:603eLBig
6`0n07@1I0000000D05T05P3g@4006H08=9V0<1kIP00000010000000001L0@010000020000000041
E<TH0000002<bQP0mG4^Mo3_F`7nooooZSPZMj8d:WL00000001V023BIP3@8@XF000001SBIP2LbQP0
RU=gM@00I0000000XEAgMJJI8bk@8@XF8=9V0801fWD00000B03M0@00g@5XbQP0d24:5XC<6000L7Ue
:]Q2FokooonQE7Me1A;FMB3BIP3PAFL0ca8QQ@002P3PAFL0e<XH05`ieWETMP08000002D0000<0000
0@0005@0001D00000@4007?mool90@00OOgoo`40002[Z^4o7LOQ_aLD001Z<P000@0004`000000000
00000000003ooooooooooe00001E0000S00001P0000<0000000002D0000<00003@00P2P0000<0000
0@000580001`0@000@0007Goool0000000000000002@0@00000000000P9304d0DP0g000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000o000o
100005C96010eVH0S<XH0?Ea;WLK03h0M05T0000001@0F@0F0?M0@00IP0PdVH0`7]V000000040000
000005`100400000800000000@5DbAP0000008c:603eLBigl>mK0OkooonZ>2YgXS@ZM`00000006H0
8=9V0=0Q2QL000006=9V09c:602:DgMe001T0000002QE7MeYYTS;]0Q2QLPdVH0P07JM@0000180=d1
003M0FS:603@8@XGQ<`H001`NGDZf49Ko_oooj5DMgD54]Ie8=9V0>15I`3?4R65000:0>15I`3DbQP0
G3WFMFAf00P000009@0000`000010000E00005@000090@00L_goo``1001hoOoo0@000:^ZhClMan6o
]1@00;`b00010000C00000000000000000000?ooooooooooD00002P0000l0000600000`000000000
9@0000`0000=0020:00000`000010000DP00070100010000MOooo`00000000000000090100000000
00020T<0C@1=04T0=`00000000000000000000000000000000000000000000000000000000000000
0000000000000000000003l003l40000E<TH043FIP2<bQP0mG4^Ma/0?P1d0F@000000501I01H0md1
001V023BIP30NfH0000000@000000000G0400@00000P000000010EC960000000S<XH0?Ea;WO`ke/1
o_ooojXh:WNR=2Yg00000000IP0PdVH0d24:6000000HdVH0W<XH08YCMgD006@000000:5DMgFVVB<^
d24:623BIP200MYe000004P0g@400=d1J<XH0=0Q2QR4c1P0071iMB[H@U_nooooXEAgM@DBeWDPdVH0
h4EW0<lB8HD000X0h4EW0=C:601L>MIeI7H02000000U000030000040001D0000E00000`1001boOoo
4`4007Smool10000Zj[Q?ag7hKoc5000_3800040001<00000000000000000000oooooooooom@0000
K@0008`0000H000030000000000U0000300000d0080X000030000040001B0000L0400040001eoooo
0000000000000000T040000000000082@`1=05<0F@0g000000000000000000000000000000000000
000000000000000000000000000000000000000000000000?`00?`@0001DbAP0@=IV08c:603eLBig
6`0n07@1I0000000D05T05P3g@4006H08=9V0<1kIP00000010000000001L0@010000020000000041
E<TH0000002<bQP0mG4^Mo3_F`7nooooZSPZMj8d:WL00000001V023BIP3@8@XI000001SBIP2LbQP0
RU=gM@00I0000000XEAgMJJI8bk@8@XI8=9V0801fWD00000B03M0@00g@5XbQP0d24:6HC<6000L7Ue
:]Q2FokooonQE7Me1A;FMB3BIP3PAFL0ca8QQ@002P3PAFL0e<XH05`ieWETMP08000002D0000<0000
0@0005@0001D00004`4007;moolI0@00OOgoo`40002[Z^4o7LOQ_h0E002l<P000@0004`000000000
00000000003ooooooooooe00002Q0000N00001P0000<0000000002D0000<00003@00P2P0000<0000
0@000580001`0@000@0007Goool0000000000000002@0@00000000000P9304d0DP0g000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000o000o
100005C96010eVH0S<XH0?Ea;WLK03h0M05T0000001@0F@0F0?M0@00IP0PdVH0`7]V000000040000
000005`100400000800000000@5DbAP0000008c:603eLBigl>mK0OkooonZ>2YgXS@ZM`00000006H0
8=9V0=0Q2QX000006=9V09c:602:DgMe001T0000002QE7MeYYTS;]0Q2QXPdVH0P07JM@0000180=d1
003M0FS:603@8@XJQ<`H001`NGDZf49Ko_oooj5DMgD54]Ie8=9V0>15I`3?4R65000:0>15I`3DbQP0
G3WFMFAf00P000009@0000`000010000E00005@0000I0@00L_gooad1001hoOoo0@000:^ZhClMan6o
oAD00;`b00010000C00000000000000000000?ooooooooooD0000340001@0000600000`000000000
E00005@0000M0@00L_goob01001hoOoo0@000:^ZhClMan6oC1H00;`b00010000C000000000000000
00000?ooooooooooD00002T0000l0000600000`0000000009@0000`0000=0020:00000`000010000
DP00070100010000>Oooo`0000000000000009010000000000020T<0C@1=04T0<@0`000000000000
0000000000000000000000000000000000000000000000000000000000000000000003l003l40000
E<TH043FIP2<bQP0mG4^Ma/0?P1d0F@000000501I01H0md1001V023BIP30NfH0000000@000000000
G0400@00000P000000010EC960000000S<XH0?Ea;WO`ke/1o_ooojXh:WNR=2Yg00000000IP0PdVH0
d24:6`00000HdVH0W<XH08YCMgD006@000000:5DMgFVVB<^d24:6b3BIP200MYe000004P0g@400=d1
J<XH0=0Q2Q^4c1P0071iMB[H@U_nooooXEAgM@DBeWDPdVH0h4EW0<lB8HD000X0h4EW0=C:601L>MIe
I7H02000000U000030000040001D0000E0000241001coOoo904007gmool10000Zj[Q?ag7hKnD5P00
JS800040001<00000000000000000000oooooooooom@0000>`0003`0000H000030000000001D0000
E00002D1001coOoo;@4007gmool10000Zj[Q?ag7hKo]5P00JS800040001<00000000000000000000
oooooooooom@0000E@0008`0000H000030000000000U0000300000d0080X000030000040001B0000
L0400040001eoooo0000000000000000T040000000000082@`1=0580=`0000000000000000000000
0000000000000000000000000000000000000000000000000000000000000000?`00?`@0001DbAP0
@=IV08c:603eLBig6`0n07@1I0000000D05T05P3g@4006H08=9V0<1kIP00000010000000001L0@01
0000020000000041E<TH0000002<bQP0mG4^Mo3_F`7nooooZSPZMj8d:WL00000001V023BIP3@8@XL
000001SBIP2LbQP0RU=gM@00I0000000XEAgMJJI8bk@8@XL8=9V0801fWD00000B03M0@00g@5XbQP0
d24:78C<6000L7Ue:]Q2FokooonQE7Me1A;FMB3BIP3PAFL0ca8QQ@002P3PAFL0e<XH05`ieWETMP08
000002D0000<00000@0005@0001D0000;@4007;mool`0@00N?goo`40002[Z^4o7LOQ_hXG002l<P00
0@0004`00000000000000000003ooooooooooe00000X0000?00001P0000<0000000002D0000<0000
3@00P2P0000<00000@000580001`0@000@0007Goool0000000000000002@0@00000000000P9304d0
C@1903L0000000000000000000000000000000000000000000000000000000000000000000000000
00000000000o000o100005C96010eVH0S<XH0?Ea;WLK03h0M05T0000001@0F@0F0?M0@00IP0PdVH0
`7]V000000040000000005`100400000800000000@5DbAP0000008c:603eLBigl>mK0OkooonZ>2Yg
XS@ZM`00000006H08=9V0=0Q2Qd000006=9V09c:602:DgMe001T0000002QE7MeYYTS;]0Q2QdPdVH0
P07JM@0000180=d1003M0FS:603@8@XMQ<`H001`NGDZf49Ko_oooj5DMgD54]Ie8=9V0>15I`3?4R65
000:0>15I`3DbQP0G3WFMFAf00P000009@0000`000010000E00005@0000`0@00L_goocL1001hoOoo
0@000:^ZhClMan6obAL00;`b00010000C00000000000000000000?ooooooooooD00006d0002<0000
600000`0000000009@0000`0000=0020:00000`000010000DP00070100010000MOooo`0000000000
000009010000000000020T<0C@1C05T0=`0000000000000000000000000000000000000000000000
00000000000000000000000000000000000003l003l40000E<TH043FIP2<bQP0mG4^Ma/0?P1d0F@0
00000501I01H0md1001V023BIP30NfH0000000@000000000G0400@00000P000000010EC960000000
S<XH0?Ea;WO`ke/1o_ooojXh:WNR=2Yg00000000IP0PdVH0d24:7P00000HdVH0W<XH08YCMgD006@0
00000:5DMgFVVB<^d24:7R3BIP200MYe000004P0g@400=d1J<XH0=0Q2Qj4c1P0071iMB[H@U_noooo
XEAgM@DBeWDPdVH0h4EW0<lB8HD000X0h4EW0=C:601L>MIeI7H02000000U000030000040001D0000
E00003P1001boOoo?P4007gmool10000Zj[Q?ag7hKmF6000_3800040001<00000000000000000000
oooooooooom@0000X@0007P0000H000030000000000U0000300000d0080X000030000040001B0000
L0400040001eoooo0000000000000000T040000000000082@`1=0580=`0000000000000000000000
0000000000000000000000000000000000000000000000000000000000000000?`00?`@0001DbAP0
@=IV08c:603eLBig6`0n07@1I0000000D05T05P3g@4006H08=9V0<1kIP00000010000000001L0@01
0000020000000041E<TH0000002<bQP0mG4^Mo3_F`7nooooZSPZMj8d:WL00000001V023BIP3@8@XO
000001SBIP2LbQP0RU=gM@00I0000000XEAgMJJI8bk@8@XO8=9V0801fWFT?2Ygdc`ZM`00JWIXbQP0
d24:7hC<6000L7Ue:]Q2FokooonQE7Me1A;FMB3BIP3PAFL0ca8QQ@002P3PAFL0e<XH05`ieWETMP08
000002D0000<00000@0005@0001D0000?P4007;moom20@00N?goo`40002[Z^4o7LOQ_m<H002l<P00
0@0004`00000000000000000003ooooooooooe00000b0000D00001P0000<0000000005@0001D0000
@P4007;moom50@00N?goo`40002[Z^4o7LOQ_b8I002l<P000@0004`00000000000000000003ooooo
oooooe00000Y0000?00001P0000<0000000002D0000<00003@00P2P0000<00000@000580001`0@00
0@0003Woool0000000000000002@0@00000000000P9304d0C@190340<00000000000000000000000
00000000000000000000000000000000000000000000000000000000000o000o100005C96010eVH0
S<XH0?Ea;WLK03h0M05T0000001@0F@0F0?M0@00IP0PdVH0`7]V000000040000000005`100400000
800000000@5DbAP0000008c:603eLBigl>mK0OkooonZ>2YgXS@ZM`00000006H08=9V0=0Q2R000000
6=9V09c:602:DgMe001T0000002QE7MeYYTS;]0Q2R0PdVH0P07JM@00003C?2Yg001ZMVS:603@8@XP
Q<`H001`NGDZf49Ko_oooj5DMgD54]Ie8=9V0>15I`3?4R65000:0>15I`3DbQP0G3WFMFAf00P00000
9@0000`000010000E00005@000150@00LogoodP1001moOoo0@000:^ZhClMan6oK1T006Xb00010000
C00000000000000000000?ooooooooooD00003/0000l0000600000`000000000E00005@0001:0@00
Logoodd1001moOoo0@000:^ZhClMan6oa1T006Xb00010000C00000000000000000000?oooooooooo
D00003X0000l0000600000`000000000E00005@0001>0@00Logooe41001moOoo0@000:^ZhClMan6o
7AX006Xb00010000C00000000000000000000?ooooooooooD00003X0000l0000600000`000000000
E00005@0001C0@00LogooeH1001moOoo0@000:^ZhClMan6oMQX006Xb00010000C000000000000000
00000?ooooooooooD00003X0000l0000600000`000000000E00005@0001G0@00LogooeX1001moOoo
0@000:^ZhClMan6ocAX006Xb00010000C00000000000000000000?ooooooooooD00003/0000l0000
600000`000000000E00005@0001L0@00Logoof@1001moOoo0@000:^ZhClMan6o9Q/006Xb00010000
C00000000000000000000?ooooooooooD00005D0002<0000600000`0000000009@0000`0000=0020
:00000`000010000DP00070100010000MOooo`0000000000000009010000000000020T<0C@1B03L0
00000000000000000000000000000000000000000000000000000000000000000000000000000000
000003l003l40000E<TH043FIP2<bQP0mG4^Ma/0?P1d0F@000000501I01H0md1001V023BIP30NfH0
000000@000000000G0400@00000P000000010EC960000000S<XH0?Ea;WO`ke/1o_ooojXh:WNR=2Yg
00000000IP0PdVH0d24:8@00000HdVH0W<XH08YCMgD006@000000:5DMgFVVB<^d24:8B3BIP200MYe
00000=<l:WL006YfJ<XH0=0Q2R64c1P0071iMB[H@U_nooooXEAgM@DBeWDPdVH0h4EW0<lB8HD000X0
h4EW0=C:601L>MIeI7H02000000U000030000040001D0000E00006<1001boOooIP4007Smool10000
Zj[Q?ag7hKo46`00_3800040001<00000000000000000000oooooooooom@0000:00003`0000H0000
30000000001D0000E00006L1001boOooJ`4007Smool10000Zj[Q?ag7hKl27000_3800040001<0000
0000000000000000oooooooooom@0000<0000500000H000030000000001D0000E00006X1001boOoo
K@4007Smool10000Zj[Q?ag7hKmA7000_3800040001<00000000000000000000oooooooooom@0000
:@0003`0000H000030000000000U0000300000d0080X000030000040001B0000L0400040000ioooo
0000000000000000T040000000000082@`1=04d0B@0a030000000000000000000000000000000000
000000000000000000000000000000000000000000000000?`00?`@0001DbAP0@=IV08c:603eLBig
6`0n07@1I0000000D05T05P3g@4006H08=9V0<1kIP00000010000000001L0@010000020000000041
E<TH0000002<bQP0mG4^Mo3_F`7nooooZSPZMj8d:WL00000001V023BIP3@8@XR000001SBIP2LbQP0
RU=gM@00I0000000XEAgMJJI8bk@8@XR8=9V0801fWD00000dc`ZM`00JWIXbQP0d24:8XC<6000L7Ue
:]Q2FokooonQE7Me1A;FMB3BIP3PAFL0ca8QQ@002P3PAFL0e<XH05`ieWETMP08000002D0000<0000
0@0005@0001D0000KP4007?mooma0@00OOgoo`40002[Z^4o7LOQ_iTL001Z<P000@0004`000000000
00000000003ooooooooooe00000k0000?00001P0000<0000000005@0001D0000L`4007?moomi0@00
OOgoo`40002[Z^4o7LOQ_o8L001Z<P000@0004`00000000000000000003ooooooooooe0000160000
N00001P0000<0000000002D0000<00003@00P2P0000<00000@000580001`0@000@0007Goool00000
00000000002@0@00000000000P9304d0DP0g00000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000o000o100005C96010eVH0S<XH0?Ea;WLK03h0
M05T0000001@0F@0F0?M0@00IP0PdVH0`7]V000000040000000005`100400000800000000@5DbAP0
000008c:603eLBigl>mK0OkooonZ>2YgXS@ZM`00000006H08=9V0=0Q2R<000006=9V09c:602:DgMe
001T0000002QE7MeYYTS;]0Q2R<PdVH0P07JM@00003C?2Yg001ZMVS:603@8@XSQ<`H001`NGDZf49K
o_oooj5DMgD54]Ie8=9V0>15I`3?4R65000:0>15I`3DbQP0G3WFMFAf00P000009@0000`000010000
E00005@0001j0@00L_googd1001hoOoo0@000:^ZhClMan6oSQd00;`b00010000C000000000000000
00000?ooooooooooD00002P0000l0000600000`0000000009@0000`0000=0020:00000`000010000
DP00070100010000MOooo`0000000000000009010000000000020T<0C@1=04T0=`00000000000000
0000000000000000000000000000000000000000000000000000000000000000000003l003l40000
E<TH043FIP2<bQP0mG4^Ma/0?P1d0F@000000501I01H0md1001V023BIP30NfH0000000@000000000
G0400@00000P000000010EC960000000S<XH0?Ea;WO`ke/1o_ooojXh:WNR=2Yg00000000IP0PdVH0
d24:9000000HdVH0W<XH08YCMgD006@000000:5DMgFVVB<^d24:923BIP200MYe00000=<l:WL006Yf
J<XH0=0Q2RB4c1P0071iMB[H@U_nooooXEAgM@DBeWDPdVH0h4EW0<lB8HD000X0h4EW0=C:601L>MIe
I7H02000000U000030000040001D0000E00007d1001boOooQ04007Smool10000Zj[Q?ag7hKo<7@00
_3800040001<00000000000000000000oooooooooom@0000K@0008`0000H000030000000000U0000
300000d0080X000030000040001B0000L0400040001eoooo0000000000000000T040000000000082
@`1=0580=`0000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000?`00?`@0001DbAP0@=IV08c:603eLBig6`0n07@1I0000000D05T05P3g@4006H0
8=9V0<1kIP00000010000000001L0@010000020000000041E<TH0000002<bQP0mG4^Mo3_F`7noooo
ZSPZMj8d:WL00000001V023BIP3@8@XU000001SBIP2LbQP0RU=gM@00I0000000XEAgMJJI8bk@8@XU
8=9V0801fWD00000dc`ZM`00JWIXbQP0d24:9HC<6000L7Ue:]Q2FokooonQE7Me1A;FMB3BIP3PAFL0
ca8QQ@002P3PAFL0e<XH05`ieWETMP08000002D0000<00000@0005@0001D0000Q@4007;moon80@00
N?goo`40002[Z^4o7LOQ_eXN002l<P000@0004`00000000000000000003ooooooooooe00000Y0000
?00001P0000<0000000002D0000<00003@00P2P0000<00000@000580001`0@000@0003Woool00000
00000000002@0@00000000000P9304d0C@190340<000000000000000000000000000000000000000
0000000000000000000000000000000000000000000o000o100005C96010eVH0S<XH0?Ea;WLK03h0
M05T0000001@0F@0F0?M0@00IP0PdVH0`7]V000000040000000005`100400000800000000@5DbAP0
000008c:603eLBigl>mK0OkooonZ>2YgXS@ZM`00000006H08=9V0=0Q2RH000006=9V09c:602:DgMe
001T0000002QE7MeYYTS;]0Q2RHPdVH0P07JM@00003C?2Yg001ZMVS:603@8@XVQ<`H001`NGDZf49K
o_oooj5DMgD54]Ie8=9V0>15I`3?4R65000:0>15I`3DbQP0G3WFMFAf00P000009@0000`000010000
E00005@000280@00Logooh/1001moOoo0@000:^ZhClMan6oXQh006Xb00010000C000000000000000
00000?ooooooooooD00003/0000l0000600000`000000000E00005@0002=0@00Logooi41001moOoo
0@000:^ZhClMan6onah006Xb00010000C00000000000000000000?ooooooooooD00007@0001@0000
600000`0000000009@0000`0000=0020:00000`000010000DP00070100010000MOooo`0000000000
000009010000000000020T<0C@1=04T0=`0000000000000000000000000000000000000000000000
00000000000000000000000000000000000003l003l40000E<TH043FIP2<bQP0mG4^Ma/0?P1d0F@0
00000501I01H0md1001V023BIP30NfH0000000@000000000G0400@00000P000000010EC960000000
S<XH0?Ea;WO`ke/1o_ooojXh:WNR=2Yg00000000IP0PdVH0d24:9`00000HdVH0W<XH08YCMgD006@0
00000:5DMgFVVB<^d24:9b3BIP200MYe00000=<l:WL006YfJ<XH0=0Q2RN4c1P0071iMB[H@U_noooo
XEAgM@DBeWDPdVH0h4EW0<lB8HD000X0h4EW0=C:601L>MIeI7H02000000U000030000040001D0000
E0000901001goOooU`4007gmool10000Zj[Q?ag7hKm37`00C3800040001<00000000000000000000
oooooooooom@0000K@0008`0000H000030000000000U0000300000d0080X000030000040001B0000
L0400040000ioooo0000000000000000T040000000000082@`1=04D0F00a03000000000000000000
0000000000000000000000000000000000000000000000000000000000000000?`00?`@0001DbAP0
@=IV08c:603eLBig6`0n07@1I0000000D05T05P3g@4006H08=9V0<1kIP00000010000000001L0@01
0000020000000041E<TH0000002<bQP0mG4^Mo3_F`7nooooZSPZMj8d:WL00000001V023BIP3@8@XX
000001SBIP2LbQP0RU=gM@00I0000000XEAgMJJI8bk@8@XX8=9V0801fWD00000dc`ZM`00JWIXbQP0
d24::8C<6000L7Ue:]Q2FokooonQE7Me1A;FMB3BIP3PAFL0ca8QQ@002P3PAFL0e<XH05`ieWETMP08
000002D0000<00000@0005@0001D0000V04006SmoonN0@00SOgoo`40002[Z^4o7LOQ_mXO0017<`00
0@0004`00000000000000000003ooooooooooe00002d0000N00002D0000<00003@00P2P0000<0000
0@0000h0000D000000000100000D0000240122@0000H00000Q30f`40000300000000000000000000
6d000400000d00000@000080001OPTA3H6<Ta8@oFD<20ZU10`0005n2A4=PHbC4lN3>@f1S9<AOPTA3
D1/Oa24000080000HP0000`0000100008@0000P0000Q0000200007<0000<0000000001`000080000
9@0000`0000000209@0000`0000700209@0000`0000>00206@0000`0003oool0600000`000000000
4P0000`0000200004`0000`000010000500000`0000=00005@0000`0000100005P0000`000000000
3@00010000000000000003X0000<00002P0001/0000@000000000000000S0000800003_?9D400000
00000>:g:d4iS_k4jhSLAB@0000T0000>llU@@0000000000h[L[@CV>o/C[R=a5100007<0000<0000
000000d0000@000000000000001B0000L0400080000@00001`00000000000000_080000000070P8R
D`1i07<0M01U06d0000D0:3hooob0@00000003bm@P:0n?oo201HO__fool000000000022m@P:0n?oo
ool00000E0XHT7P00000P5c;=@3;c4`mT<`e0;SMPPLQ@kigfQlQIB80RP4H00000000062F2PH80000
cjTT@@00aceHPo4600000<3Lk0J/b3D00000000000000000ooooob3<=@1<c3D0?=Le08DI`WNeLfH1
o_ooohcS_GObh;eg003f23Sl0002000000000200001lc3D0X<`e0>]HkgH007P0200D02IJkgHAZA=U
0000062F2PKooooo0`00000000000000000006S<=@2:MFMX[=<e001`lGKik]LCo_ooobIJkgIR4aEg
@;YD2P40003Dc3D0f<`e02l`5GMTMP08000002D0000<00000P0004H000280000O00004M4BD<20000
a@0006kmoonM0@00Pogooc00001W06D0KP1U0780H@1d06D0I00P0680N@0P05L0C@1602l0A@1=04H0
801R0640H`1[06D0KP1T0200K`1V0200L01c07@0K`1U06@0J@1d0000J@1^0700M@1d0000000S0000
800009Rf13l0000000000>QO2KliS_k4jhSLAB@0000T0000V;H4?`0000000000j5l9_cV>o/C[R=a5
100002<0000P0000V;H4?`0000000000j5l9_cV>o/C[R=a5900002@0002H]P@o00000000003XG`Vo
>Hkna>^8g4D400004P0000`0000100005P0000`0000H0000600000`000000000DP00070100030000
>Oooo`000000000000000901000000001`020T<0C@1=04T0<@0`0000000000000000000000000000
00000000000000000000000000000000000000000000000010000<S:60000000200000L000000000
SU<gMLS:600`bQP0k;1300@000240000b<XH00000000000030000000000100008<XH000000240000
X0l0008000030000b<XH000000000000?<XH07nN@`3l2]`1P<XH0000@`040000S[E30=bV8BiXO]`1
8HQ600000000000000000040001<bQP002m:00c;603PW48034Qn;_koool004<0gKE306Qng0400000
003L0FQng078bQP00@0003P07P0;0000b<XH06Qng0410`00/7gL0@40001PO]`1I7H02000000U0000
300000<0001D0000E00000d0000c0000H00009h000010000Zj[Q?ag7hKma3`00JS800040001<0000
0000000000000000oooooooooom@0000@@3ooj00000H000030000000001D0000E00006`0000c0000
^`0009h000010000Zj[Q?ag7hKlX4000JS800040001<00000000000000000000oooooooooom@0000
E@0e08`0000H000030000000001B0000L04000@0000D00002@00000000000000_080000000070P8R
D`1i07<0M01U06d000000000003R0000000006a4NP:0n?oo000000000000000000000514NP:0n?oo
^YH000005GNgI1EgfQlQI@00000000000@000<Rmo@GHbcD0HF@EMmXO8FD00000000005@000000000
b;gm1E3<=@3NDAEgfQlQIDSPQ`020000f5aO0e@0000000000@0003P07P0;0000b<XH06Qng0410`00
/7gL0@40001PO]`100002000001PUPX6H9H:1U3<=@0_<1EgD<`e06H`5GNdlE/:H9H:1RD0000000X0
>48008C==@0MnV=XfQlQI@00Q`38_Od50P000=QLG`>b2VAXD0HIM`00001@1QUgP04IMbSbF`ZXc3D0
;c0EMjS<=@1V<1EgM?9K2V2F2PITMP08000002D0000<0000100002P0000<00000`000580001`0@00
0`0007Goool0000000000000002@0@00000000L00P9304d0DP0g0000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000o000o100000800010eVH0
b<XH0000000K03h0M05T0000001@0F@0F0?M0@00@`0PdVH0`7]V000000040000000005`100400000
800000000@5DbAP0000008c:603eLBigl>mK0OkooonZ>2YgXS@ZM`00000006H08=9V0=0Q2Q000000
6=9V09c:602:DgMe001T0000002QE7MeYYTS;]0Q2Q0PdVH0P07JM@26g0580=d1003M0FS:603@8@X@
Q<`H001`NGDZf49Ko_oooj5DMgD54]Ie8=9V0>15I`3?4R65000:0>15I`3DbQP0G3WFMFAf00P00000
9@0000`000030000E00005@0002n00007`000=h0001Z00000@000:^ZhClMan6oaQ000;`b00010000
C00000000000000000000?ooooooooooD00002P00`0l0000600000`0000000009@0000`000040000
:00000`000030000DP00070100030000MOooo`000000000000000901000000001`020T<0C@1=04T0
=`000000000000000000000000000000000000000000000000000000000000000000000000000000
000003l003l40000E<TH043FIP2<bQP0mG4^Ma/0?P1d0F@000000501I01H0md1001V023BIP30NfH0
000000@000000000G0400@00000P000000010EC960000000S<XH0?Ea;WO`ke/1o_ooojXh:WNR=2Yg
00000000IP0PdVH0d24:4@00000HdVH0W<XH08YCMgD006@000000:5DMgFVVB<^d24:4B3BIP200MYe
000004P0g@400=d1J<XH0=0Q2Q64c1P0071iMB[H@U_nooooXEAgM@DBeWDPdVH0h4EW0<lB8HD000X0
h4EW0=C:601L>MIeI7H02000000U0000300000<0001D0000E0000=h0000O00009`4006X000010000
Zj[Q?ag7hKl44@00_3800040001<00000000000000000000oooooooooom@0000K@0H08`0000H0000
30000000000U0000300000@0000X0000300000<0001B0000L04000<0001eoooo0000000000000000
T040000000070082@`1=0580=`000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000?`00?`@0001DbAP0@=IV08c:603eLBig6`0n07@1I0000000
D05T05P3g@4006H08=9V0<1kIP00000010000000001L0@010000020000000041E<TH0000002<bQP0
mG4^Mo3_F`7nooooZSPZMj8d:WL00000001V023BIP3@8@XB000001SBIP2LbQP0RU=gM@00I0000000
XEAgMJJI8bk@8@XB8=9V0801fWD00000B03M0@00g@5XbQP0d24:4XC<6000L7Ue:]Q2FokooonQE7Me
1A;FMB3BIP3PAFL0ca8QQ@002P3PAFL0e<XH05`ieWETMP08000002D0000<00000`0005@0001D0000
9`4001l000170@00JP000040002[Z^4o7LOQ_i8A002l<P000@0004`00000000000000000003ooooo
oooooe00000Y01P0?00001P0000<0000000002D0000<0000100002P0000<00000`000580001`0@00
0`0003Woool0000000000000002@0@00000000L00P9304d0DP0a0300000000000000000000000000
00000000000000000000000000000000000000000000000000000000000o000o100005C96010eVH0
S<XH0?Ea;WLK03h0M05T0000001@0F@0F0?M0@00IP0PdVH0`7]V000000040000000005`100400000
800000000@5DbAP0000008c:603eLBigl>mK0OkooonZ>2YgXS@ZM`00000006H08=9V0=0Q2Q<00000
6=9V09c:602:DgMe001T0000002QE7MeYYTS;]0Q2Q<PdVH0P07JM@0000180=d1003M0FS:603@8@XC
Q<`H001`NGDZf49Ko_oooj5DMgD54]Ie8=9V0>15I`3?4R65000:0>15I`3DbQP0G3WFMFAf00P00000
9@0000`000030000E00005@0001Y0@00<`000;`1002N00000@000:^ZhClMan6o418006Xb00010000
C00000000000000000000?ooooooooooD00003d0602P0000600000`0000000009@0000`000040000
:00000`000030000DP00070100030000>Oooo`000000000000000901000000001`020T<0C@1=04T0
<@0`0000000000000000000000000000000000000000000000000000000000000000000000000000
000003l003l40000E<TH043FIP2<bQP0mG4^Ma/0?P1d0F@000000501I01H0md1001V023BIP30NfH0
000000@000000000G0400@00000P000000010EC960000000S<XH0?Ea;WO`ke/1o_ooojXh:WNR=2Yg
00000000IP0PdVH0d24:5000000HdVH0W<XH08YCMgD006@000000:5DMgFVVB<^d24:523BIP200MYe
000004P0g@400=d1J<XH0=0Q2QB4c1P0071iMB[H@U_nooooXEAgM@DBeWDPdVH0h4EW0<lB8HD000X0
h4EW0=C:601L>MIeI7H02000000U0000300000<0001D0000E0000=H1000c0000:@8009h000010000
Zj[Q?ag7hKoS4P00JS800040001<00000000000000000000oooooooooom@0000A`0H0:00000H0000
30000000000U0000300000@0000X0000300000<0001B0000L04000<0000ioooo0000000000000000
T040000000070082@`1=04D0F00a0300000000000000000000000000000000000000000000000000
00000000000000000000000000000000?`00?`@0001DbAP0@=IV08c:603eLBig6`0n07@1I0000000
D05T05P3g@4006H08=9V0<1kIP00000010000000001L0@010000020000000041E<TH0000002<bQP0
mG4^Mo3_F`7nooooZSPZMj8d:WL00000001V023BIP3@8@XE000001SBIP2LbQP0RU=gM@00I0000000
XEAgMJJI8bk@8@XE8=9V0801fWD00000B03M0@00g@5XbQP0d24:5HC<6000L7Ue:]Q2FokooonQE7Me
1A;FMB3BIP3PAFL0ca8QQ@002P3PAFL0e<XH05`ieWETMP08000002D0000<00000`0005@0001D0000
>@800;[ooomh0P00B@400040002[Z^4o7LOQ_j8C0017<`000@0004`00000000000000000003ooooo
oooooe00002c01P0N00001P0000<0000000002D0000<0000100002P0000<00000`000580001`0@00
0`0003Woool0000000000000002@0@00000000L00P9304d0C@190340<00000000000000000000000
00000000000000000000000000000000000000000000000000000000000o000o100005C96010eVH0
S<XH0?Ea;WLK03h0M05T0000001@0F@0F0?M0@00IP0PdVH0`7]V000000040000000005`100400000
800000000@5DbAP0000008c:603eLBigl>mK0OkooonZ>2YgXS@ZM`00000006H08=9V0=0Q2QH00000
6=9V09c:602:DgMe001T0000002QE7MeYYTS;]0Q2QHPdVH0P07JM@0000180=d1003M0FS:603@8@XF
Q<`H001`NGDZf49Ko_oooj5DMgD54]Ie8=9V0>15I`3?4R65000:0>15I`3DbQP0G3WFMFAf00P00000
9@0000`000030000E00005@0001f0P00<`000<D2002N00000@000:^ZhClMan6o5a@006Xb00010000
C00000000000000000000?ooooooooooD00005D0602<0000600000`0000000009@0000`000040000
:00000`000030000DP00070100030000MOooo`000000000000000901000000001`020T<0C@1B03L0
00000000000000000000000000000000000000000000000000000000000000000000000000000000
000003l003l40000E<TH043FIP2<bQP0mG4^Ma/0?P1d0F@000000501I01H0md1001V023BIP30NfH0
000000@000000000G0400@00000P000000010EC960000000S<XH0?Ea;WO`ke/1o_ooojXh:WNR=2Yg
00000000IP0PdVH0d24:5`00000HdVH0W<XH08YCMgD006@000000:5DMgFVVB<^d24:5b3BIP200MYe
000004P0g@400=d1J<XH0=0Q2QN4c1P0071iMB[H@U_nooooXEAgM@DBeWDPdVH0h4EW0<lB8HD000X0
h4EW0=C:601L>MIeI7H02000000U0000300000<0001D0000E0000<L2000O0000i`8006X000010000
Zj[Q?ag7hKnd5000_3800040001<00000000000000000000oooooooooom@0000:00H03`0000H0000
30000000000U0000300000@0000X0000300000<0001B0000L04000<0001eoooo0000000000000000
T040000000070082@`1=04d0B@0g0000000000000000000000000000000000000000000000000000
00000000000000000000000000000000?`00?`@0001DbAP0@=IV08c:603eLBig6`0n07@1I0000000
D05T05P3g@4006H08=9V0<1kIP00000010000000001L0@010000020000000041E<TH0000002<bQP0
mG4^Mo3_F`7nooooZSPZMj8d:WL00000001V023BIP3@8@XH000001SBIP2LbQP0RU=gM@00I0000000
XEAgMJJI8bk@8@XH8=9V0801fWD00000B03M0@00g@5XbQP0d24:68C<6000L7Ue:]Q2FokooonQE7Me
1A;FMB3BIP3PAFL0ca8QQ@002P3PAFL0e<XH05`ieWETMP08000002D0000<00000`0005@0001D0000
j08001l0000a0`00JP000040002[Z^4o7LOQ_o<D002l<P000@0004`00000000000000000003ooooo
oooooe00001]01P0S00001P0000<0000000002D0000<0000100002P0000<00000`000580001`0@00
0`0007Goool0000000000000002@0@00000000L00P9304d0D`1I03L0000000000000000000000000
00000000000000000000000000000000000000000000000000000000000o000o100005C96010eVH0
S<XH0?Ea;WLK03h0M05T0000001@0F@0F0?M0@00IP0PdVH0`7]V000000040000000005`100400000
800000000@5DbAP0000008c:603eLBigl>mK0OkooonZ>2YgXS@ZM`00000006H08=9V0=0Q2QT00000
6=9V09c:602:DgMe001T0000002QE7MeYYTS;]0Q2QTPdVH0P07JM@0000180=d1003M0FS:603@8@XI
Q<`H001`NGDZf49Ko_oooj5DMgD54]Ie8=9V0>15I`3?4R65000:0>15I`3DbQP0G3WFMFAf00P00000
9@0000`000030000E00005@0000a0`007@000703002O00000@000:^ZhClMan6oP1D00;`b00010000
C00000000000000000000?ooooooooooD0000:40601h0000600000`0000000009@0000`000040000
:00000`000030000DP00070100030000MOooo`000000000000000901000000001`020T<0C@1B03L0
00000000000000000000000000000000000000000000000000000000000000000000000000000000
000003l003l40000E<TH043FIP2<bQP0mG4^Ma/0?P1d0F@000000501I01H0md1001V023BIP30NfH0
000000@000000000G0400@00000P000000010EC960000000S<XH0?Ea;WO`ke/1o_ooojXh:WNR=2Yg
00000000IP0PdVH0d24:6P00000HdVH0W<XH08YCMgD006@000000:5DMgFVVB<^d24:6R3BIP200MYe
000004P0g@400=d1J<XH0=0Q2QZ4c1P0071iMB[H@U_nooooXEAgM@DBeWDPdVH0h4EW0<lB8HD000X0
h4EW0=C:601L>MIeI7H02000000U0000300000<0001D0000E0000783000O0000W0<006X000010000
Zj[Q?ag7hKom5@00_3800040001<00000000000000000000oooooooooom@0000<@0H0500000H0000
30000000001D0000E00009/3000O0000^`<006X000010000Zj[Q?ag7hKm<5P00_3800040001<0000
0000000000000000oooooooooom@0000:@0H03`0000H000030000000000U0000300000@0000X0000
300000<0001B0000L04000<0000ioooo0000000000000000T040000000070082@`1=04d0B@0a0300
00000000000000000000000000000000000000000000000000000000000000000000000000000000
?`00?`@0001DbAP0@=IV08c:603eLBig6`0n07@1I0000000D05T05P3g@4006H08=9V0<1kIP000000
10000000001L0@010000020000000041E<TH0000002<bQP0mG4^Mo3_F`7nooooZSPZMj8d:WL00000
001V023BIP3@8@XK000001SBIP2LbQP0RU=gM@00I0000000XEAgMJJI8bk@8@XK8=9V0801fWD00000
B03M0@00g@5XbQP0d24:6hC<6000L7Ue:]Q2FokooonQE7Me1A;FMB3BIP3PAFL0ca8QQ@002P3PAFL0
e<XH05`ieWETMP08000002D0000<00000`0005@0001D0000`0<003<0003P0`00WP000040002[Z^4o
7LOQ_i@F001Z<P000@0004`00000000000000000003ooooooooooe00000k01P0?00001P0000<0000
000005@0001D0000kP<003<0000m1000WP000040002[Z^4o7LOQ_ndF001Z<P000@0004`000000000
00000000003ooooooooooe00001E0000S00001P0000<0000000002D0000<0000100002P0000<0000
0`000580001`0@000`0007Goool0000000000000002@0@00000000L00P9304d0DP0g000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000o000o
100005C96010eVH0S<XH0?Ea;WLK03h0M05T0000001@0F@0F0?M0@00IP0PdVH0`7]V000000040000
000005`100400000800000000@5DbAP0000008c:603eLBigl>mK0OkooonZ>2YgXS@ZM`00000006H0
8=9V0=0Q2Q`000006=9V09c:602:DgMe001T0000002QE7MeYYTS;]0Q2Q`PdVH0P07JM@0000180=d1
003M0FS:603@8@XLQ<`H001`NGDZf49Ko_oooj5DMgD54]Ie8=9V0>15I`3?4R65000:0>15I`3DbQP0
G3WFMFAf00P000009@0000`000030000E00005@0001010007`000604001Z00000@000:^ZhClMan6o
RQL00;`b00010000C00000000000000000000?ooooooooooD00002P0000l0000600000`000000000
9@0000`000040000:00000`000030000DP00070100030000MOooo`00000000000000090100000000
1`020T<0C@1=04T0=`00000000000000000000000000000000000000000000000000000000000000
0000000000000000000003l003l40000E<TH043FIP2<bQP0mG4^Ma/0?P1d0F@000000501I01H0md1
001V023BIP30NfH0000000@000000000G0400@00000P000000010EC960000000S<XH0?Ea;WO`ke/1
o_ooojXh:WNR=2Yg00000000IP0PdVH0d24:7@00000HdVH0W<XH08YCMgD006@000000:5DMgFVVB<^
d24:7B3BIP200MYe000004P0g@400=d1J<XH0=0Q2Qf4c1P0071iMB[H@U_nooooXEAgM@DBeWDPdVH0
h4EW0<lB8HD000X0h4EW0=C:601L>MIeI7H02000000U0000300000<0001D0000E0000604000O0000
Z@@006X000010000Zj[Q?ag7hKo95`00_3800040001<00000000000000000000oooooooooom@0000
K@1T08`0000H000030000000000U0000300000@0000X0000300000<0001B0000L04000<0001eoooo
0000000000000000T040000000070082@`1=05<0F@0g000000000000000000000000000000000000
000000000000000000000000000000000000000000000000?`00?`@0001DbAP0@=IV08c:603eLBig
6`0n07@1I0000000D05T05P3g@4006H08=9V0<1kIP00000010000000001L0@010000020000000041
E<TH0000002<bQP0mG4^Mo3_F`7nooooZSPZMj8d:WL00000001V023BIP3@8@XN000001SBIP2LbQP0
RU=gM@00I0000000XEAgMJJI8bk@8@XN8=9V0801fWD00000B03M0@00g@5XbQP0d24:7XC<6000L7Ue
:]Q2FokooonQE7Me1A;FMB3BIP3PAFL0ca8QQ@002P3PAFL0e<XH05`ieWETMP08000002D0000<0000
0`0005@0001D0000Z@@001d0003X1000W`000040002[Z^4o7LOQ_eHH002l<P000@0004`000000000
00000000003ooooooooooe00002Q0480N00001P0000<0000000002D0000<0000100002P0000<0000
0`000580001`0@000`0007Goool0000000000000002@0@00000000L00P9304d0DP0g000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000o000o
100005C96010eVH0S<XH0?Ea;WLK03h0M05T0000001@0F@0F0?M0@00IP0PdVH0`7]V000000040000
000005`100400000800000000@5DbAP0000008c:603eLBigl>mK0OkooonZ>2YgXS@ZM`00000006H0
8=9V0=0Q2Ql000006=9V09c:602:DgMe001T0000002QE7MeYYTS;]0Q2QlPdVH0P07JMJ@l:WOC?2Yg
001ZMVS:603@8@XOQ<`H001`NGDZf49Ko_oooj5DMgD54]Ie8=9V0>15I`3?4R65000:0>15I`3DbQP0
G3WFMFAf00P000009@0000`000030000E00005@0003Z10007`0001@5001Z00000@000:^ZhClMan6o
daP00;`b00010000C00000000000000000000?ooooooooooD0000380G`=@0000600000`000000000
E00005@0000C1@007`0003<5001Z00000@000:^ZhClMan6o8QT00;`b00010000C000000000000000
00000?ooooooooooD00002T0ooll0000600000`0000000009@0000`000040000:00000`000030000
DP00070100030000>Oooo`000000000000000901000000001`020T<0C@1=04T0<@0`000000000000
0000000000000000000000000000000000000000000000000000000000000000000003l003l40000
E<TH043FIP2<bQP0mG4^Ma/0?P1d0F@000000501I01H0md1001V023BIP30NfH0000000@000000000
G0400@00000P000000010EC960000000S<XH0?Ea;WO`ke/1o_ooojXh:WNR=2Yg00000000IP0PdVH0
d24:8000000HdVH0W<XH08YCMgD006@000000:5DMgFVVB<^d24:823BIP200MYe00000=<l:WL006Yf
J<XH0=0Q2R24c1P0071iMB[H@U_nooooXEAgM@DBeWDPdVH0h4EW0<lB8HD000X0h4EW0=C:601L>MIe
I7H02000000U0000300000<0001D0000E00003T5000c0000F@D009h000010000Zj[Q?ag7hKm/6@00
JS800040001<00000000000000000000oooooooooom@0000>`3ooc`0000H000030000000001D0000
E00006L5000c0000Q`D009h000010000Zj[Q?ag7hKo46@00JS800040001<00000000000000000000
oooooooooom@0000>P0003`0000H000030000000001D0000E00009D5000c0000]@D009h000010000
Zj[Q?ag7hKlM6P00JS800040001<00000000000000000000oooooooooom@0000>P0H03`0000H0000
30000000001D0000E0000<<5000c0000h`D009h000010000Zj[Q?ag7hKmf6P00JS800040001<0000
0000000000000000oooooooooom@0000>P0H03`0000H000030000000001D0000E0000?05000c0000
40H009h000010000Zj[Q?ag7hKo=6P00JS800040001<00000000000000000000oooooooooom@0000
>`0003`0000H000030000000001D0000E00001l6000c0000KPH009h000010000Zj[Q?ag7hKlV6`00
JS800040001<00000000000000000000oooooooooom@0000E@0008`0000H000030000000000U0000
300000@0000X0000300000<0001B0000L04000<0001eoooo0000000000000000T040000000070082
@`1=0580=`0000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000?`00?`@0001DbAP0@=IV08c:603eLBig6`0n07@1I0000000D05T05P3g@4006H0
8=9V0<1kIP00000010000000001L0@010000020000000041E<TH0000002<bQP0mG4^Mo3_F`7noooo
ZSPZMj8d:WL00000001V023BIP3@8@XQ000001SBIP2LbQP0RU=gM@00I0000000XEAgMJJI8bk@8@XQ
8=9V0801fWD00000dc`ZM`00JWIXbQP0d24:8HC<6000L7Ue:]Q2FokooonQE7Me1A;FMB3BIP3PAFL0
ca8QQ@002P3PAFL0e<XH05`ieWETMP08000002D0000<00000`0005@0001D0000L0H001l0002@1P00
JP000040002[Z^4o7LOQ_l@K002l<P000@0004`00000000000000000003ooooooooooe00000X0000
?00001P0000<0000000005@0001D0000T@H001l0002k1P00JP000040002[Z^4o7LOQ_`8L002l<P00
0@0004`00000000000000000003ooooooooooe00000`0000D00001P0000<0000000005@0001D0000
^PH001l0003J1P00JP000040002[Z^4o7LOQ_e4L002l<P000@0004`00000000000000000003ooooo
oooooe00000Y0000?00001P0000<0000000002D0000<0000100002P0000<00000`000580001`0@00
0`0003Woool0000000000000002@0@00000000L00P9304d0C@190340<00000000000000000000000
00000000000000000000000000000000000000000000000000000000000o000o100005C96010eVH0
S<XH0?Ea;WLK03h0M05T0000001@0F@0F0?M0@00IP0PdVH0`7]V000000040000000005`100400000
800000000@5DbAP0000008c:603eLBigl>mK0OkooonZ>2YgXS@ZM`00000006H08=9V0=0Q2R800000
6=9V09c:602:DgMe001T0000002QE7MeYYTS;]0Q2R8PdVH0P07JM@00003C?2Yg001ZMVS:603@8@XR
Q<`H001`NGDZf49Ko_oooj5DMgD54]Ie8=9V0>15I`3?4R65000:0>15I`3DbQP0G3WFMFAf00P00000
9@0000`000030000E00005@0003O1P00<`000?l6002N00000@000:^ZhClMan6oVA`006Xb00010000
C00000000000000000000?ooooooooooD00003/0000l0000600000`000000000E00005@0000=1`00
<`0005/7002N00000@000:^ZhClMan6olQ`006Xb00010000C00000000000000000000?oooooooooo
D00004H0T@1h0000600000`0000000009@0000`000040000:00000`000030000DP00070100030000
MOooo`000000000000000901000000001`020T<0C@1B03L000000000000000000000000000000000
000000000000000000000000000000000000000000000000000003l003l40000E<TH043FIP2<bQP0
mG4^Ma/0?P1d0F@000000501I01H0md1001V023BIP30NfH0000000@000000000G0400@00000P0000
00010EC960000000S<XH0?Ea;WO`ke/1o_ooojXh:WNR=2Yg00000000IP0PdVH0d24:8`00000HdVH0
W<XH08YCMgD006@000000:5DMgFVVB<^d24:8b3BIP200MYe00000=<l:WL006YfJ<XH0=0Q2R>4c1P0
071iMB[H@U_nooooXEAgM@DBeWDPdVH0h4EW0<lB8HD000X0h4EW0=C:601L>MIeI7H02000000U0000
300000<0001D0000E00005h7000O0000OPL006X000010000Zj[Q?ag7hKn>7@00_3800040001<0000
0000000000000000oooooooooom@0000:02A03`0000H000030000000000U0000300000@0000X0000
300000<0001B0000L04000<0001eoooo0000000000000000T040000000070082@`1=04d0B@0g0000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
?`00?`@0001DbAP0@=IV08c:603eLBig6`0n07@1I0000000D05T05P3g@4006H08=9V0<1kIP000000
10000000001L0@010000020000000041E<TH0000002<bQP0mG4^Mo3_F`7nooooZSPZMj8d:WL00000
001V023BIP3@8@XT000001SBIP2LbQP0RU=gM@00I0000000XEAgMJJI8bk@8@XT8=9V0801fWD00000
dc`ZM`00JWIXbQP0d24:98C<6000L7Ue:]Q2FokooonQE7Me1A;FMB3BIP3PAFL0ca8QQ@002P3PAFL0
e<XH05`ieWETMP08000002D0000<00000`0005@0001D0000OPL001l000371`00JP000040002[Z^4o
7LOQ_l`M002l<P000@0004`00000000000000000003ooooooooooe00001]0940S00001P0000<0000
000002D0000<0000100002P0000<00000`000580001`0@000`0007Goool0000000000000002@0@00
000000L00P9304d0DP0g000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000o000o100005C96010eVH0S<XH0?Ea;WLK03h0M05T0000001@0F@0
F0?M0@00IP0PdVH0`7]V000000040000000005`100400000800000000@5DbAP0000008c:603eLBig
l>mK0OkooonZ>2YgXS@ZM`00000006H08=9V0=0Q2RD000006=9V09c:602:DgMe001T0000002QE7Me
YYTS;]0Q2RDPdVH0P07JM@00003C?2Yg001ZMVS:603@8@XUQ<`H001`NGDZf49Ko_oooj5DMgD54]Ie
8=9V0>15I`3?4R65000:0>15I`3DbQP0G3WFMFAf00P000009@0000`000030000E00005@000381`00
7`000>P7001Z00000@000:^ZhClMan6oFQh00;`b00010000C00000000000000000000?oooooooooo
D00002T0T@0l0000600000`0000000009@0000`000040000:00000`000030000DP00070100030000
>Oooo`000000000000000901000000001`020T<0C@1=04T0<@0`0000000000000000000000000000
000000000000000000000000000000000000000000000000000003l003l40000E<TH043FIP2<bQP0
mG4^Ma/0?P1d0F@000000501I01H0md1001V023BIP30NfH0000000@000000000G0400@00000P0000
00010EC960000000S<XH0?Ea;WO`ke/1o_ooojXh:WNR=2Yg00000000IP0PdVH0d24:9P00000HdVH0
W<XH08YCMgD006@000000:5DMgFVVB<^d24:9R3BIP200MYe00000=<l:WL006YfJ<XH0=0Q2RJ4c1P0
071iMB[H@U_nooooXEAgM@DBeWDPdVH0h4EW0<lB8HD000X0h4EW0=C:601L>MIeI7H02000000U0000
300000<0001D0000E0000>d7000c00003@P009h000010000Zj[Q?ag7hKnR7P00JS800040001<0000
0000000000000000oooooooooom@0000>`2A03`0000H000030000000001D0000E00001/8000c0000
A@P009h000010000Zj[Q?ag7hKok7P00JS800040001<00000000000000000000oooooooooom@0000
M0000500000H000030000000000U0000300000@0000X0000300000<0001B0000L04000<0001eoooo
0000000000000000T040000000070082@`1=04d0B@0g000000000000000000000000000000000000
000000000000000000000000000000000000000000000000?`00?`@0001DbAP0@=IV08c:603eLBig
6`0n07@1I0000000D05T05P3g@4006H08=9V0<1kIP00000010000000001L0@010000020000000041
E<TH0000002<bQP0mG4^Mo3_F`7nooooZSPZMj8d:WL00000001V023BIP3@8@XW000001SBIP2LbQP0
RU=gM@00I0000000XEAgMJJI8bk@8@XW8=9V0801fWD00000dc`ZM`00JWIXbQP0d24:9hC<6000L7Ue
:]Q2FokooonQE7Me1A;FMB3BIP3PAFL0ca8QQ@002P3PAFL0e<XH05`ieWETMP08000002D0000<0000
0`0005@0001D0000@0P005/000292000YP000040002[Z^4o7LOQ_d<O001<<P000@0004`000000000
00000000003ooooooooooe00001]0000S00001P0000<0000000002D0000<0000100002P0000<0000
0`000580001`0@000`0003Woool0000000000000002@0@00000000L00P9304d0A@1H0340<0000000
000000000000000000000000000000000000000000000000000000000000000000000000000o000o
100005C96010eVH0S<XH0?Ea;WLK03h0M05T0000001@0F@0F0?M0@00IP0PdVH0`7]V000000040000
000005`100400000800000000@5DbAP0000008c:603eLBigl>mK0OkooonZ>2YgXS@ZM`00000006H0
8=9V0=0Q2RP000006=9V09c:602:DgMe001T0000002QE7MeYYTS;]0Q2RPPdVH0P07JM@00003C?2Yg
001ZMVS:603@8@XXQ<`H001`NGDZf49Ko_oooj5DMgD54]Ie8=9V0>15I`3?4R65000:0>15I`3DbQP0
G3WFMFAf00P000009@0000`000030000E00005@0002?2000^_ooolh800190@000@000:^ZhClMan6o
fQl004Lc00010000C00000000000000000000?ooooooooooD0000;@0T@1h00009@0000`000040000
:00000`000030000AP0001@000080000AdA9@`<0000R000030000?oooolR000030000?oooolU0000
300000d0080X000030000080000X0000300000@0000R000030000?oooom60000`0400;@10015CDH[
;40002@0000H00000020?`00000000000020?`0008000020:T0002@0000H0000]QhU@@0000000000
kePT@CAooLB;4M=5940000`000000000:T0002@0000H0000/08/>P0000000000/08/>P00_ZL003jY
:d0000`0000000007T0600`0000000008D0500`000000000240211P0000<00000Q30f`000003000@
=40200`0000000007T0900`000000000:T0002@0000H0000/08/>P0000000000/08/>P00_ZL003jY
8D0700`000000000:T0002@0000H0000/08/>P0000000000/08/>P00_ZL003jY:d0000`000000000
:d0000`0000000007T0600`0000000008D0500`000000000240311P0000<00000Q30f`000003000@
=40300`0000000007T0900`000000000:T0002@0000H00000020?`00000000000020?`0000000000
8D0700`000000000C00006@00000000000000<48003H00000000000000322000f@0002T0ZP000000
00000000P3l0000000000000P3l000000000000000000000000000000000000000000280000<0000
ooooodH0000L0000400004E=AR/2@00030000000000>000050000000000@00005000
\>"], "Graphics",
  GeneratedCell->False,
  CellAutoOverwrite->False,
  ImageSize->{319.8947368421051, 30.70418233082711},
  ImageMargins->{{17.831578947368417`, 0.}, {0., 28.526315789473706`}}],
 "\ni.e., it provides the solution ",
 Cell[BoxData[
  FormBox[
   RowBox[{"{", 
    RowBox[{
     SubsuperscriptBox["U", "0", 
      RowBox[{"(", "m", ")"}]], ",", 
     SubsuperscriptBox["U", "1", 
      RowBox[{"(", "m", ")"}]], ",", 
     SubsuperscriptBox["U", "2", 
      RowBox[{"(", "m", ")"}]], ",", 
     RowBox[{"...", " ", 
      SubsuperscriptBox["U", "Np", 
       RowBox[{"(", "m", ")"}]]}]}], "}"}], TraditionalForm]]],
 "  at time ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["t", "m"], TraditionalForm]]],
 " from the solutions ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        SubsuperscriptBox["U", "0", 
         RowBox[{"(", 
          RowBox[{"m", "-", "1"}], ")"}]], ",", 
        SubsuperscriptBox["U", "1", 
         RowBox[{"(", 
          RowBox[{"m", "-", "1"}], ")"}]], ",", 
        SubsuperscriptBox["U", "2", 
         RowBox[{"(", 
          RowBox[{"m", "-", "1"}], ")"}]], ",", 
        RowBox[{"...", " ", 
         SubsuperscriptBox["U", "Np", 
          RowBox[{"(", 
           RowBox[{"m", "-", "1"}], ")"}]]}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        SubsuperscriptBox["U", "0", 
         RowBox[{"(", 
          RowBox[{"m", "-", "2"}], ")"}]], ",", 
        SubsuperscriptBox["U", "1", 
         RowBox[{"(", 
          RowBox[{"m", "-", "2"}], ")"}]], ",", 
        SubsuperscriptBox["U", "2", 
         RowBox[{"(", 
          RowBox[{"m", "-", "2"}], ")"}]], ",", 
        RowBox[{"...", " ", 
         SubsuperscriptBox["U", "Np", 
          RowBox[{"(", 
           RowBox[{"m", "-", "2"}], ")"}]]}]}], "}"}], " ", ",", 
      "\[CenterEllipsis]"}], "}"}], " "}], TraditionalForm]]],
 ",  employing a single timestep of size  ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["t", "m"], TraditionalForm]]],
 "-",
 Cell[BoxData[
  FormBox[
   SubscriptBox["t", 
    RowBox[{"m", "-", "1"}]], TraditionalForm]]],
 "=ht"
}], "Subsubsection",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 CellChangeTimes->{{3.5610913126613097`*^9, 3.56109140331946*^9}, {
   3.5610914876944838`*^9, 3.5610915214480352`*^9}, {3.5611269260439997`*^9, 
   3.5611270545306*^9}, {3.6334403275358505`*^9, 3.6334403294079576`*^9}, 
   3.6370047946140547`*^9, {3.637155674879402*^9, 3.6371557000432467`*^9}, {
   3.6371557716161723`*^9, 3.6371558227842627`*^9}, {3.6371568868223314`*^9, 
   3.637156912499977*^9}, {3.6371569827625003`*^9, 3.6371570266921773`*^9}, {
   3.6371573632793684`*^9, 3.6371573632793684`*^9}, {3.637157418019865*^9, 
   3.637157442075107*^9}, {3.6371575519461*^9, 3.637157661161892*^9}, {
   3.637157691940746*^9, 3.6371577029543653`*^9}, 3.6371577405982313`*^9, 
   3.637238067519046*^9, {3.6374203398283997`*^9, 3.6374203398283997`*^9}, {
   3.6381743388486*^9, 3.6381743417265997`*^9}, 3.6386011988366003`*^9, {
   3.6386017122876*^9, 3.6386017819896*^9}, {3.6386019739466*^9, 
   3.6386019752346*^9}, {3.6386020756586*^9, 3.6386020812206*^9}},
 Background->RGBColor[0.88, 1, 0.88]],

Cell[BoxData[
 RowBox[{
  RowBox[{"U1stepMatrixt", "[", "m_", "]"}], ":=", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{
     RowBox[{"tt", "[", "0", "]"}], "=", "0"}], ";", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"tt", "[", "m", "]"}], "=", " ", 
     RowBox[{
      RowBox[{"tt", "[", 
       RowBox[{"m", "-", "1"}], "]"}], "+", "ht"}]}], ";", 
    "\[IndentingNewLine]", 
    RowBox[{"uVectortm", "=", "\[IndentingNewLine]", 
     RowBox[{"LinearSolve", "[", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"SparseArray", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{
            RowBox[{"Band", "[", 
             RowBox[{"{", 
              RowBox[{"1", ",", "2"}], "}"}], "]"}], "\[Rule]", 
            RowBox[{"Table", "[", 
             RowBox[{
              RowBox[{"Which", "[", 
               RowBox[{
                RowBox[{"j", "\[Equal]", "0"}], ",", "0.", ",", "True", ",", 
                RowBox[{"-", 
                 RowBox[{"Sfun", "[", 
                  RowBox[{"m", ",", "gammak"}], "]"}]}]}], "]"}], ",", 
              RowBox[{"{", 
               RowBox[{"j", ",", "0", ",", 
                RowBox[{"Np", "-", "1"}]}], "}"}]}], "]"}]}], ",", 
           RowBox[{
            RowBox[{"Band", "[", 
             RowBox[{"{", 
              RowBox[{"1", ",", "1"}], "}"}], "]"}], "\[Rule]", 
            RowBox[{"Table", "[", 
             RowBox[{
              RowBox[{"Which", "[", 
               RowBox[{
                RowBox[{"j", "\[Equal]", "0"}], ",", "1.", ",", 
                RowBox[{"j", "\[Equal]", "Np"}], ",", "1.", ",", "True", ",", 
                RowBox[{"1.", "+", 
                 RowBox[{"2.", "*", 
                  RowBox[{"Sfun", "[", 
                   RowBox[{"m", ",", "gammak"}], "]"}]}]}]}], "]"}], ",", 
              RowBox[{"{", 
               RowBox[{"j", ",", "0", ",", "Np"}], "}"}]}], "]"}]}], ",", 
           RowBox[{
            RowBox[{"Band", "[", 
             RowBox[{"{", 
              RowBox[{"2", ",", "1"}], "}"}], "]"}], "\[Rule]", 
            RowBox[{"Table", "[", 
             RowBox[{
              RowBox[{"Which", "[", 
               RowBox[{
                RowBox[{"j", "\[Equal]", 
                 RowBox[{"Np", "-", "1"}]}], ",", "0.", ",", "True", ",", 
                RowBox[{"-", 
                 RowBox[{"Sfun", "[", 
                  RowBox[{"m", ",", "gammak"}], "]"}]}]}], "]"}], ",", 
              RowBox[{"{", 
               RowBox[{"j", ",", "0", ",", 
                RowBox[{"Np", "-", "1"}]}], "}"}]}], "]"}]}]}], "}"}], ",", 
         RowBox[{"Np", "+", "1"}]}], "]"}], ",", 
       RowBox[{"Table", "[", 
        RowBox[{
         RowBox[{"Which", "[", 
          RowBox[{
           RowBox[{"j", "\[Equal]", "0"}], ",", 
           RowBox[{"uL", "[", 
            RowBox[{"tt", "[", "m", "]"}], "]"}], ",", 
           RowBox[{"j", "\[Equal]", "Np"}], ",", 
           RowBox[{"uR", "[", 
            RowBox[{"tt", "[", "m", "]"}], "]"}], ",", "True", ",", 
           RowBox[{"GG", "[", 
            RowBox[{"j", ",", "m", ",", "gammak"}], "]"}]}], "]"}], ",", 
         RowBox[{"{", 
          RowBox[{"j", ",", "0", ",", "Np"}], "}"}]}], "]"}]}], "]"}]}]}], 
   ")"}]}]], "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 CellChangeTimes->{
  3.561047090713702*^9, {3.561047182331005*^9, 3.5610471941390977`*^9}, {
   3.5610472501335993`*^9, 3.5610473240092154`*^9}, {3.5610474395463357`*^9, 
   3.561047452436073*^9}, {3.5610475182601*^9, 3.5610475336629443`*^9}, 
   3.56104776779445*^9, {3.561048703202833*^9, 3.561048704828926*^9}, {
   3.561049078629552*^9, 3.561049080978057*^9}, {3.5610492055315557`*^9, 
   3.5610492461843014`*^9}, {3.561050018056771*^9, 3.561050084352785*^9}, {
   3.561050231857547*^9, 3.5610502321535635`*^9}, {3.561050651906489*^9, 
   3.561050664526911*^9}, {3.561050702098199*^9, 3.5610507030418344`*^9}, {
   3.5610887438682175`*^9, 3.5610887452194667`*^9}, {3.561089269026931*^9, 
   3.5610893438658133`*^9}, {3.5610893945856357`*^9, 3.5610894008619337`*^9}, 
   3.5610894993111367`*^9, {3.5610919456199656`*^9, 3.5610919708068123`*^9}, {
   3.5610926610045834`*^9, 3.561092667686966*^9}, {3.5610929882829447`*^9, 
   3.5610930445257874`*^9}, {3.561093123779629*^9, 3.561093145218856*^9}, {
   3.5610932006739593`*^9, 3.56109323064141*^9}, {3.5610941404912214`*^9, 
   3.5610941558755445`*^9}, {3.5610950175372014`*^9, 3.5610950378777647`*^9}, 
   3.5611203246774*^9, 3.5611270545306*^9, {3.5894768097678723`*^9, 
   3.5894768184388847`*^9}, {3.5915409488513656`*^9, 3.591540954575693*^9}, {
   3.636982754366835*^9, 3.636982800700485*^9}, {3.6369843082397118`*^9, 
   3.6369843482930026`*^9}, {3.6369843894293556`*^9, 3.6369843902514024`*^9}, 
   3.636984485092827*^9, {3.63699182297353*^9, 3.6369918239835873`*^9}, {
   3.636993714427715*^9, 3.636993723980261*^9}, 3.637004794643057*^9, {
   3.637156172650077*^9, 3.6371561769244843`*^9}, {3.637156271928652*^9, 
   3.6371562860622764`*^9}, 3.637238069832178*^9},
 Background->RGBColor[0.88, 1, 0.88]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 "U2stepsMatrixt[n]  provides the solution ",
 Cell[BoxData[
  FormBox[
   RowBox[{"{", 
    RowBox[{
     SubsuperscriptBox["U", "0", 
      RowBox[{"(", "n", ")"}]], ",", 
     SubsuperscriptBox["U", "1", 
      RowBox[{"(", "n", ")"}]], ",", 
     SubsuperscriptBox["U", "2", 
      RowBox[{"(", "n", ")"}]], ",", 
     RowBox[{"...", " ", 
      SubsuperscriptBox["U", "Np", 
       RowBox[{"(", "n", ")"}]]}]}], "}"}], TraditionalForm]]],
 "  at time ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["t", "n"], TraditionalForm]]],
 " from the solutions ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        SubsuperscriptBox["U", "0", 
         RowBox[{"(", 
          RowBox[{"n", "-", "1"}], ")"}]], ",", 
        SubsuperscriptBox["U", "1", 
         RowBox[{"(", 
          RowBox[{"n", "-", "1"}], ")"}]], ",", 
        SubsuperscriptBox["U", "2", 
         RowBox[{"(", 
          RowBox[{"n", "-", "1"}], ")"}]], ",", 
        RowBox[{"...", " ", 
         SubsuperscriptBox["U", "Np", 
          RowBox[{"(", 
           RowBox[{"n", "-", "1"}], ")"}]]}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        SubsuperscriptBox["U", "0", 
         RowBox[{"(", 
          RowBox[{"n", "-", "2"}], ")"}]], ",", 
        SubsuperscriptBox["U", "1", 
         RowBox[{"(", 
          RowBox[{"n", "-", "2"}], ")"}]], ",", 
        SubsuperscriptBox["U", "2", 
         RowBox[{"(", 
          RowBox[{"n", "-", "2"}], ")"}]], ",", 
        RowBox[{"...", " ", 
         SubsuperscriptBox["U", "Np", 
          RowBox[{"(", 
           RowBox[{"n", "-", "2"}], ")"}]]}]}], "}"}], " ", ",", 
      "\[CenterEllipsis]"}], "}"}], " "}], TraditionalForm]]],
 ",  employing  two timesteps of size  ",
 Cell[BoxData[
  FormBox[
   RowBox[{"(", 
    SubscriptBox["t", "n"]}], TraditionalForm]]],
 "-",
 Cell[BoxData[
  FormBox[
   SubscriptBox["t", 
    RowBox[{"n", "-", "1"}]], TraditionalForm]]],
 ")/2=ht/2=hthalf"
}], "Subsubsection",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 CellChangeTimes->{{3.5610913126613097`*^9, 3.56109140331946*^9}, {
   3.5610914876944838`*^9, 3.5610915214480352`*^9}, {3.5611269260439997`*^9, 
   3.5611270545306*^9}, {3.6334403275358505`*^9, 3.6334403294079576`*^9}, 
   3.6370047946140547`*^9, {3.637155674879402*^9, 3.6371557000432467`*^9}, {
   3.6371557716161723`*^9, 3.6371558227842627`*^9}, {3.6371568868223314`*^9, 
   3.637156912499977*^9}, {3.6371569827625003`*^9, 3.6371570266921773`*^9}, {
   3.6371573632793684`*^9, 3.6371573632793684`*^9}, {3.637157418019865*^9, 
   3.637157442075107*^9}, {3.6371575519461*^9, 3.637157661161892*^9}, {
   3.637157691940746*^9, 3.6371578482706203`*^9}, {3.637165659783272*^9, 
   3.637165695372308*^9}, 3.6372380842940054`*^9, {3.6386018953596*^9, 
   3.6386019120976*^9}, 3.6386020934206*^9},
 Background->RGBColor[0.88, 1, 0.88]],

Cell[BoxData[
 RowBox[{
  RowBox[{"U2stepsMatrixt", "[", "n_", "]"}], ":=", 
  RowBox[{"(", "\[IndentingNewLine]", " ", 
   RowBox[{
    RowBox[{"hthalf", "=", 
     RowBox[{"ht", "/", "2."}]}], ";", "\[IndentingNewLine]", 
    RowBox[{"Do", "[", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"tt", "[", "m", "]"}], "=", " ", 
        RowBox[{
         RowBox[{"tt", "[", 
          RowBox[{"m", "-", "1"}], "]"}], "+", "hthalf"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"uVectortm", "=", "\[IndentingNewLine]", 
        RowBox[{"LinearSolve", "[", "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{"SparseArray", "[", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{
               RowBox[{"Band", "[", 
                RowBox[{"{", 
                 RowBox[{"1", ",", "2"}], "}"}], "]"}], "\[Rule]", 
               RowBox[{"Table", "[", 
                RowBox[{
                 RowBox[{"Which", "[", 
                  RowBox[{
                   RowBox[{"j", "\[Equal]", "0"}], ",", "0.", ",", "True", 
                   ",", 
                   RowBox[{"-", 
                    RowBox[{"Sfun", "[", 
                    RowBox[{"m", ",", "gammak"}], "]"}]}]}], "]"}], ",", 
                 RowBox[{"{", 
                  RowBox[{"j", ",", "0", ",", 
                   RowBox[{"Np", "-", "1"}]}], "}"}]}], "]"}]}], ",", 
              RowBox[{
               RowBox[{"Band", "[", 
                RowBox[{"{", 
                 RowBox[{"1", ",", "1"}], "}"}], "]"}], "\[Rule]", 
               RowBox[{"Table", "[", 
                RowBox[{
                 RowBox[{"Which", "[", 
                  RowBox[{
                   RowBox[{"j", "\[Equal]", "0"}], ",", "1.", ",", 
                   RowBox[{"j", "\[Equal]", "Np"}], ",", "1.", ",", "True", 
                   ",", 
                   RowBox[{"1.", "+", 
                    RowBox[{"2.", "*", 
                    RowBox[{"Sfun", "[", 
                    RowBox[{"m", ",", "gammak"}], "]"}]}]}]}], "]"}], ",", 
                 RowBox[{"{", 
                  RowBox[{"j", ",", "0", ",", "Np"}], "}"}]}], "]"}]}], ",", 
              RowBox[{
               RowBox[{"Band", "[", 
                RowBox[{"{", 
                 RowBox[{"2", ",", "1"}], "}"}], "]"}], "\[Rule]", 
               RowBox[{"Table", "[", 
                RowBox[{
                 RowBox[{"Which", "[", 
                  RowBox[{
                   RowBox[{"j", "\[Equal]", 
                    RowBox[{"Np", "-", "1"}]}], ",", "0.", ",", "True", ",", 
                   RowBox[{"-", 
                    RowBox[{"Sfun", "[", 
                    RowBox[{"m", ",", "gammak"}], "]"}]}]}], "]"}], ",", 
                 RowBox[{"{", 
                  RowBox[{"j", ",", "0", ",", 
                   RowBox[{"Np", "-", "1"}]}], "}"}]}], "]"}]}]}], "}"}], ",", 
            RowBox[{"Np", "+", "1"}]}], "]"}], ",", 
          RowBox[{"Table", "[", 
           RowBox[{
            RowBox[{"Which", "[", 
             RowBox[{
              RowBox[{"j", "\[Equal]", "0"}], ",", 
              RowBox[{"uL", "[", 
               RowBox[{"tt", "[", "m", "]"}], "]"}], ",", 
              RowBox[{"j", "\[Equal]", "Np"}], ",", 
              RowBox[{"uR", "[", 
               RowBox[{"tt", "[", "m", "]"}], "]"}], ",", "True", ",", 
              RowBox[{"GG", "[", 
               RowBox[{"j", ",", "m", ",", "gammak"}], "]"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"j", ",", "0", ",", "Np"}], "}"}]}], "]"}]}], "]"}]}], 
       ";", "\[IndentingNewLine]", 
       RowBox[{"Umatrix", "=", 
        RowBox[{"Append", "[", 
         RowBox[{"Umatrix", ",", "uVectortm"}], "]"}]}]}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"{", 
       RowBox[{"m", ",", "n", ",", 
        RowBox[{"n", "+", "1"}]}], "}"}]}], "\[IndentingNewLine]", "]"}], ";",
     " ", "\[IndentingNewLine]", 
    RowBox[{"Umatrix", "=", 
     RowBox[{"Drop", "[", 
      RowBox[{"Umatrix", ",", 
       RowBox[{"-", "2"}]}], "]"}]}], ";", "\[IndentingNewLine]", 
    "uVectortm"}], ")"}]}]], "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10001.},
 CellChangeTimes->{
  3.561047090713702*^9, {3.561047182331005*^9, 3.5610471941390977`*^9}, {
   3.5610472501335993`*^9, 3.5610473240092154`*^9}, {3.5610474395463357`*^9, 
   3.561047452436073*^9}, {3.5610475182601*^9, 3.5610475336629443`*^9}, 
   3.56104776779445*^9, {3.561048703202833*^9, 3.561048704828926*^9}, {
   3.561049078629552*^9, 3.561049080978057*^9}, {3.5610492055315557`*^9, 
   3.5610492461843014`*^9}, {3.561050018056771*^9, 3.561050084352785*^9}, {
   3.561050231857547*^9, 3.5610502321535635`*^9}, {3.561050651906489*^9, 
   3.561050664526911*^9}, {3.561050702098199*^9, 3.5610507030418344`*^9}, {
   3.5610887438682175`*^9, 3.5610887452194667`*^9}, {3.561089269026931*^9, 
   3.5610893438658133`*^9}, {3.5610893945856357`*^9, 3.5610894008619337`*^9}, 
   3.5610894993111367`*^9, {3.561089685730995*^9, 3.561089715184351*^9}, {
   3.561089984263118*^9, 3.5610900003814273`*^9}, {3.5610901027100296`*^9, 
   3.561090160306106*^9}, {3.5610902087165785`*^9, 3.561090314080208*^9}, {
   3.561090347148292*^9, 3.5610903555088515`*^9}, {3.5610908107547235`*^9, 
   3.561090817454107*^9}, {3.5610908631859007`*^9, 3.5610908633519096`*^9}, 
   3.5610909187298365`*^9, {3.5610914220415306`*^9, 3.5610914958745537`*^9}, {
   3.561091608994463*^9, 3.561091635168696*^9}, {3.5610917818818626`*^9, 
   3.5610917937185397`*^9}, {3.5610926835403028`*^9, 3.5610926904511147`*^9}, 
   3.5610927414813676`*^9, {3.561092778447144*^9, 3.5610929708405294`*^9}, {
   3.5610931515122156`*^9, 3.5610932055762396`*^9}, {3.561093237396221*^9, 
   3.561093237817422*^9}, {3.5610933289416833`*^9, 3.5610933447035847`*^9}, {
   3.5610933808333626`*^9, 3.5610933813793635`*^9}, {3.5610941147913666`*^9, 
   3.56109412790693*^9}, 3.5610941681292458`*^9, {3.561094506301923*^9, 
   3.5610945068739552`*^9}, 3.5611270584306*^9, {3.5894768318209033`*^9, 
   3.589476832250904*^9}, 3.5915409979031715`*^9, {3.636984415837866*^9, 
   3.636984422588252*^9}, 3.636984493459306*^9, {3.6369917995211887`*^9, 
   3.636991830435957*^9}, {3.636993691981431*^9, 3.636993701731989*^9}, 
   3.637004758583994*^9, {3.637156297980697*^9, 3.637156308198715*^9}, {
   3.637156445293756*^9, 3.637156446370158*^9}, {3.637157901997115*^9, 
   3.6371579053979206`*^9}, {3.6372379952129097`*^9, 3.6372379952249107`*^9}, 
   3.6372380843350077`*^9},
 Background->RGBColor[0.88, 1, 0.88]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 "uMsolutionFixedTimesteps[t,\[CapitalDelta]]  provides the full  solution   ",
 Cell[BoxData[
  FormBox[
   RowBox[{"{", 
    RowBox[{
     SubsuperscriptBox["U", "0", 
      RowBox[{"(", "m", ")"}]], ",", 
     SubsuperscriptBox["U", "1", 
      RowBox[{"(", "m", ")"}]], ",", 
     SubsuperscriptBox["U", "2", 
      RowBox[{"(", "m", ")"}]], ",", 
     RowBox[{"...", " ", 
      SubsuperscriptBox["U", "Np", 
       RowBox[{"(", "m", ")"}]]}]}], "}"}], TraditionalForm]]],
 "  with m=0,1,2,....n  for fixed timesteps of size \[CapitalDelta] from t=0 \
to t=",
 Cell[BoxData[
  FormBox[
   SubscriptBox["t", "n"], TraditionalForm]]],
 "  where n=",
 Cell[BoxData[
  FormBox[
   SubscriptBox["t", "n"], TraditionalForm]]],
 "/",
 Cell[BoxData[
  FormBox["\[CapitalDelta]", TraditionalForm]],
  FormatType->"TraditionalForm"],
 " .  The full solution is stored in the matrix Umatrix so that its element \
(1+m,1+j), i.e., Umatrix[[1+m,1+j]],  gives  ",
 Cell[BoxData[
  FormBox[
   SubsuperscriptBox["U", "j", 
    RowBox[{"(", "m", ")"}]], TraditionalForm]],
  FormatType->"TraditionalForm"],
 ". "
}], "Subsubsection",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 CellChangeTimes->{{3.5610913126613097`*^9, 3.56109140331946*^9}, {
   3.5610914876944838`*^9, 3.5610915214480352`*^9}, {3.5611269260439997`*^9, 
   3.5611270545306*^9}, {3.6334403275358505`*^9, 3.6334403294079576`*^9}, 
   3.6370047946140547`*^9, {3.637155674879402*^9, 3.6371557000432467`*^9}, {
   3.6371557716161723`*^9, 3.6371558227842627`*^9}, {3.6371568868223314`*^9, 
   3.637156912499977*^9}, {3.6371569827625003`*^9, 3.6371570266921773`*^9}, {
   3.6371573632793684`*^9, 3.6371573632793684`*^9}, {3.637157418019865*^9, 
   3.637157442075107*^9}, {3.6371575519461*^9, 3.637157661161892*^9}, {
   3.637157691940746*^9, 3.6371578482706203`*^9}, {3.637165659783272*^9, 
   3.637165695372308*^9}, 3.6372380842940054`*^9, {3.6372384809746943`*^9, 
   3.637238527949381*^9}, {3.6372386475472217`*^9, 3.6372387420841646`*^9}, {
   3.637238784210574*^9, 3.6372390407962503`*^9}, 3.6372394118814754`*^9},
 Background->RGBColor[0.88, 1, 0.88]],

Cell[BoxData[
 RowBox[{
  RowBox[{"uMsolutionFixedTimesteps", "[", 
   RowBox[{"t_", ",", "htFixed_"}], "]"}], ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", "numpasos", "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"ht", "=", "htFixed"}], ";", "\[IndentingNewLine]", 
     RowBox[{"numpasos", "=", 
      RowBox[{"Round", "[", 
       RowBox[{"t", "/", "htFixed"}], "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"Umatrix", "=", 
      RowBox[{"{", "}"}]}], ";", 
     RowBox[{"Umatrix", "=", 
      RowBox[{"AppendTo", "[", 
       RowBox[{"Umatrix", ",", "UmatrixIni"}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"Do", "[", "\[IndentingNewLine]", "\t", 
      RowBox[{
       RowBox[{"Umatrix", "=", 
        RowBox[{"Append", "[", 
         RowBox[{"Umatrix", ",", 
          RowBox[{"U1stepMatrixt", "[", "m", "]"}]}], "]"}]}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"{", 
        RowBox[{"m", ",", "1", ",", "numpasos"}], "}"}]}], "]"}], ";", 
     "\[IndentingNewLine]", "Umatrix"}]}], "\[IndentingNewLine]", 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.5611175304854*^9, 3.5611178158406*^9}, {
   3.5611178594114*^9, 3.5611180036802*^9}, {3.5611180779986*^9, 
   3.5611180850810003`*^9}, {3.561118140774*^9, 3.5611182677072*^9}, {
   3.5611183022455997`*^9, 3.561118506824*^9}, 3.5611185494119997`*^9, {
   3.5611187160044003`*^9, 3.5611187284688*^9}, {3.5611189629368*^9, 
   3.5611190066792*^9}, {3.5611192326608*^9, 3.5611192925959997`*^9}, {
   3.5611195041174*^9, 3.5611195293114*^9}, {3.5611195729758*^9, 
   3.5611196111802*^9}, {3.5611196647974*^9, 3.5611196823006*^9}, {
   3.5611197142338*^9, 3.5611197383982*^9}, {3.5611198172562*^9, 
   3.5611198918554*^9}, {3.561119935707*^9, 3.5611199664858*^9}, {
   3.5611200243929996`*^9, 3.561120028683*^9}, 3.561120065889*^9, {
   3.561120213309*^9, 3.5611202301414003`*^9}, {3.5611203336474*^9, 
   3.5611203397469997`*^9}, 3.561120462519*^9, {3.5611205206914*^9, 
   3.561120537009*^9}, {3.5611205826858*^9, 3.5611206541026*^9}, 
   3.5611208318968*^9, 3.561121233816*^9, {3.5611212722076*^9, 
   3.5611212728784*^9}, {3.5611215947298*^9, 3.5611216368688*^9}, {
   3.5611216735738*^9, 3.5611216737808*^9}, {3.5611217371108*^9, 
   3.5611217609318*^9}, {3.5611219140168*^9, 3.5611219264628*^9}, 
   3.5611219569968*^9, 3.5611221823638*^9, {3.5611222751916*^9, 
   3.5611222764248*^9}, {3.561122309192*^9, 3.5611223095352*^9}, {
   3.5611259517696*^9, 3.5611259534116*^9}, {3.5611260219376*^9, 
   3.5611260223566*^9}, {3.5611270933666*^9, 3.5611271943246*^9}, {
   3.5611273344718*^9, 3.5611273351118*^9}, {3.589005766587*^9, 
   3.589005894926*^9}, {3.589006162262*^9, 3.589006162454*^9}, 
   3.589293606650919*^9, 3.5894687570824423`*^9, {3.589476867184953*^9, 
   3.58947687917597*^9}, {3.5896353425604*^9, 3.5896353431703997`*^9}, 
   3.5896394125674*^9, {3.5897154601619997`*^9, 3.5897155886610003`*^9}, 
   3.58971578551*^9, {3.589715853558*^9, 3.589715908293*^9}, 
   3.589715965303*^9, {3.5898927236173887`*^9, 3.5898927648638616`*^9}, {
   3.5898929202869344`*^9, 3.5898929374469643`*^9}, {3.5898929686002192`*^9, 
   3.589892976260833*^9}, {3.589895479756954*^9, 3.589895480420992*^9}, {
   3.5898957909367523`*^9, 3.5898957915147853`*^9}, 3.637004794682059*^9, {
   3.637005437622833*^9, 3.637005440966024*^9}, 3.6370054711187487`*^9, {
   3.637237958788827*^9, 3.6372379943098583`*^9}, 3.637238069848179*^9, 
   3.6372384641787333`*^9, {3.637238769148713*^9, 3.637238775791093*^9}},
 Background->RGBColor[0.88, 1, 0.88]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 "uMsolutionTE[n,\[Tau]]  provides the full  solution   ",
 Cell[BoxData[
  FormBox[
   RowBox[{"{", 
    RowBox[{
     SubsuperscriptBox["U", "0", 
      RowBox[{"(", "m", ")"}]], ",", 
     SubsuperscriptBox["U", "1", 
      RowBox[{"(", "m", ")"}]], ",", 
     SubsuperscriptBox["U", "2", 
      RowBox[{"(", "m", ")"}]], ",", 
     RowBox[{"...", " ", 
      SubsuperscriptBox["U", "Np", 
       RowBox[{"(", "m", ")"}]]}]}], "}"}], TraditionalForm]]],
 "  with m=0,1,2,....n  for variable timesteps whose size is determined by \
the ",
 StyleBox["trial and error",
  FontSlant->"Italic"],
 " (T&E) method for a tolerance \[Tau] .  The full solution is stored in the \
matrix Umatrix so that its element (1+m,1+j), i.e., Umatrix[[1+m,1+j]],  \
gives  ",
 Cell[BoxData[
  FormBox[
   SubsuperscriptBox["U", "j", 
    RowBox[{"(", "m", ")"}]], TraditionalForm]]],
 ". "
}], "Subsubsection",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 CellChangeTimes->{{3.5610913126613097`*^9, 3.56109140331946*^9}, {
   3.5610914876944838`*^9, 3.5610915214480352`*^9}, {3.5611269260439997`*^9, 
   3.5611270545306*^9}, {3.6334403275358505`*^9, 3.6334403294079576`*^9}, 
   3.6370047946140547`*^9, {3.637155674879402*^9, 3.6371557000432467`*^9}, {
   3.6371557716161723`*^9, 3.6371558227842627`*^9}, {3.6371568868223314`*^9, 
   3.637156912499977*^9}, {3.6371569827625003`*^9, 3.6371570266921773`*^9}, {
   3.6371573632793684`*^9, 3.6371573632793684`*^9}, {3.637157418019865*^9, 
   3.637157442075107*^9}, {3.6371575519461*^9, 3.637157661161892*^9}, {
   3.637157691940746*^9, 3.6371578482706203`*^9}, {3.637165659783272*^9, 
   3.637165695372308*^9}, 3.6372380842940054`*^9, {3.6372384809746943`*^9, 
   3.637238527949381*^9}, {3.6372386475472217`*^9, 3.6372387420841646`*^9}, {
   3.637238784210574*^9, 3.6372390407962503`*^9}, {3.6372391044228897`*^9, 
   3.6372391129183755`*^9}, {3.637239166812458*^9, 3.6372391991713085`*^9}, {
   3.6372393619346185`*^9, 3.637239450800701*^9}, {3.6372437122664433`*^9, 
   3.6372437137655287`*^9}, 3.6381087962693996`*^9},
 Background->RGBColor[0.88, 1, 0.88]],

Cell[CellGroupData[{

Cell[TextData[{
 "Some arbitrary parameters one has to chose:\n\[Bullet] The initial  \
timestep ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["\[CapitalDelta]", "0"], TraditionalForm]]],
 "=Delta0TE.  Here is fixed to the arbitrary (but hardly relevant) value of \
0.01\n\[Bullet] The maximum value of the timestep, DeltatcapTE, one is ready \
to accept.  Here we choose Deltatmax=",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["10", 
    RowBox[{"6", " "}]], TraditionalForm]]],
 " (the actual value could be somewhat larger). ",
 StyleBox["[When the solution goes towards zero, the absolute value of this \
solution will be smaller than the tolerance for times long enough. In this \
case, the condition ",
  FontSize->12],
 Cell[GraphicsData["Metafile", "\<\
CF5dJ6E]HGAYHf4PEfU^I6mgLb15CDHPAVmbKF5d0@0001id0@0006`000000000000001/2000o0P00
00000000003Z2000E`D00215CDH00040M1h005X0000600000000000000000000HA<006PK003B0000
:@400000000000000000050d0`0XR0@0AP0002`0000P0000ADe6:`500@0L00004000008@`=/00000
F08005P200160000O04007010015CDH[7T0500`0000000007d0300`000000000<402010000040000
0020?b501`0<000000000290100<0000000002Y0000T000060000000P3l0000000000000P3l00000
000002]0000<0000000001i01P0<0000000002501@0<0000000001i02@0<0000000002Y0000T0000
60000000P3l0000000000000P3l00000000002501`0<0000000002Y0000T000060000;02;3X00000
00000;02;3X0X;74031?aB]0000<0000000002Y0000T000060000;02;3X0000000000;02;3X0X;74
031?aB]0000<0000000002Y0000T000060000;02;3X0000000000;02;3X00;:X001?Z@Y0080T0000
60000<cook810000000000000000jdQ901[aB24000080000HP0000`0000100009`0001P000010000
00000?ooc00000009@0000`000010000C00006@000000000000001/200130@0000000000000L0P00
A04004T0FP00000000000000P3l0000000000000P3l0000000000000000000000000000000000000
000001P0000<0000oooo02@0000T00000020?@00000000000020?@00000000000P0005h0001d0000
0P000000000T0000<00005@0000P0000000002P000080000200000400@0000008000000000000000
0000000000000000oooo0000001E0000200005D000000000E@0008P0001E00009@0000`000020000
9@0000`000080020C00006@000000000000001/200130@00n?ooooSoooo08@00@1@00<T0X0000000
00000000P3l0000000000000P3l0000000000000000000000000000000000000000002D0000<0000
1`00P2D0000<00000@0002@0000T00000020@@00000000000020@@00000000000P0001P0000<0000
000004`0001T000000000000000K0P00@`40000000000000708004@1001905X0000000000000080o
000000000000080o0000000000000000000000000000000000000000000U00003000000008160000
40X000@:0015CDH[:d0000`0000000007T0600`0000000008D0500`0000000007T0900`000000000
:T0002@0000H0000/08/>P0000000000/08/>P00/ZP004nY8D0700`000000000:d0000`000000000
:T0002@0000H0000/GKF@@0000000000R@7F@GbMmlEQ08U6940400`00000000024001@09003d2000
0Q30f`8000030000i0P00040003<0000:@4007;moolj0@00Q?gookHX002ZYOooFB/003:WoolPADe6
00010>@8000N00000P000300001/000000000807000h1000Y@8007d10000000000000000003EE@X0
B=0506L0I@1^06D0LP1Q07@0I@1T0200HP1i0200E`1=04H0;`1504d0AP0P0680H@1S06/0I@1^06@0
801_06H0801`07<0M01_06D0I01Y07@0001Y06h0L01e07@000000140000<00001P0000X0000@0000
00000000000B000030000040000F0000300001P0000H000030000000001B0000L0400040000ioooo
0000000000000000T040000000000082@`1=05<0F@0a0300C`1B04T0A`0000000000000000000000
000000000000000000000000000000000000000000040000b<XH0000000800001`000000002>DcMe
b<XH033:603//4<0100008@00038bQP000000000000<000000000040000PbQP0000008@0002P3`00
0P0000<00038bQP000000000000lbQP0Oii30?`:GP20bQP0001300@0002>]D<0WHk9UFQnGP0QR4H0
00000000000000000@0004c:6000;dX03</H0>2L@P1=H9JEo_ooo`00@`3M]D<0J7iN0000000005h0
J7iN0<S:60010000>00N00/00038bQP0J7iN0043002`OEh00@00061nGP1TMP08000002D0000<0000
0@0005@0001D0000:@4007?mool_0@00Q?goo`40002[Z^4o7LOQ_bhG001Z<P000@0004`000000000
00000000003ooooooooooe0000150000I00001P0000<0000000002D0000<00003@00P2P0000<0000
0@000580001`0@000@0007Goool0000000000000002@0@00000000000P9304d0DP0g000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000o000o
100000800010eVD0b<XH0000000K03h0M05S0000001@0F<0F0=;0000@`0PdVD0`7]U000000040000
000005`100400000800000000@5DbAP0S><YMhc:603eLBigI:Y>1_kooonZ>2YgXS@ZM`00000006D0
8=9U09DP2SX000006=9U09c:602:DgMe001S0000002QE7Me;]G9UIDP2SXPdVD0P07JM@26GP1804/0
001;06S:602E80XjQ<`H001`NGFRU:SPo_oooj5DMgD54]Ie8=9U0<15IP0_4B58000:0<15IP3DbQP0
G3WFMFAf00P000009@0000`000010000E00005@0000_0@00L_gooc81001hoOoo0@000:^ZhClMan6o
ZQL00;`b00010000C00000000000000000000?ooooooooooD00002P0000l0000600000`000000000
9@0000`0000=0020:00000`000010000DP00070100010000MOooo`00000000000000090100000000
00020T<0C@1=04T0=`00000000000000000000000000000000000000000000000000000000000000
0000000000000000000003l003l40000E<TH043FI@2<bQP0mG4^Ma/0?P1d0F<000000501H`1H0d/0
001U023BI@30NfD0000000@000000000G0400@00000P000000010EC960000000S<XH0?Ea;WMTZTh6
o_ooojXh:WNR=2Yg00000000I@0PdVD0UB0:>`00000HdVD0W<XH08YCMgD006<000000:5DMgD^eLVE
UB0:>b3BI@200MYe000004P0B`0004/0J<XH09DP2S^4c1P0071iMJ:DZ>3nooooXEAgM@DBeWDPdVD0
`4EV02lA8DP000X0`4EV0=C:601L>MIeI7H02000000U000030000040001D0000E0000381001boOoo
=`4007Smool10000Zj[Q?ag7hKoX5`00_3800040001<00000000000000000000oooooooooom@0000
KP0006@0000H000030000000000U0000300000d0080X000030000040001B0000L0400040001eoooo
0000000000000000T040000000000082@`1=0580=`00000000000000000000000000000000000000
000000000000000000000000000000000000000000000000?`00?`@0001DbAP0@=IU08c:603eLBig
6`0n07@1H`000000D05S05P3B`0006D08=9U0<1kI@00000010000000001L0@010000020000000041
E<TH0000002<bQP0mG4^MfBZCPKnooooZSPZMj8d:WL00000001U023BI@2E80Xl000001SBI@2LbQP0
RU=gM@00H`000000XEAgMBkEbIFE80Xl8=9U0801fWD00000B01;0000B`1XbQP0UB0:?8C<6000L7Ue
XYBXh?kooonQE7Me1A;FMB3BI@30AFH0;a4QB0002P30AFH0e<XH05`ieWETMP08000002D0000<0000
0@0005@0001D0000=`4007;moolj0@00N?goo`40002[Z^4o7LOQ_dXH002l<P000@0004`000000000
00000000003ooooooooooe00000Y0000?00002D0000<00003@00P2P0000<00000@0000h0000D0000
00000100000D0000240122@0000H00000Q30f`400003000000000000000000006d000400000d0000
0@000080000mbI=3TN8Sa6dUXD7ibD510`0003g9Td>AhR?4Tm^M@i7R8l@mbI=3J]/Pa24000080000
HP0000`0000100008@0000P0000Q0000200007<0000<0000000001`0000800009@0000`000000020
9@0000`0000700209@0000`0000>00206@0000`0003oool0600000`0000000004P0000`000020000
4`0000`000010000500000`0000=00005@0000`0000100005P0000`0000000003@00010000000000
000003X0000<00002P0001/0000@000000000000000S000080000:hohD400000000009^;j46T20;6
/mjDAR@0000T0000[SoQ@@0000000000Vh_X@J@80/JcgYA6100007<0000<0000000000d0000@0000
00000000001B0000L04000<0000@00001`00000000000000_080000000070P8RD`1i07<0M01U06d0
000C0:3hooob0@00000003c=6`:0n?oo201HO__fool000000000023=6`:0n?ooool00000000H0000
00000=STnPH800000000P1Sin`H30000MR8QWb80RP4500001<e2051JeGDP0000000000QQeGG3H=Ee
MR8QWiDP1FT00000200006@af0Ld<MP70000020000000000G37H1aC>@P0@<MP7@0<Z0V@af0L80000
0000073=@P3M^mIeMR8QWiDP1FT00000200006@af0Ld<MP70000010af0NLcD80JK_FMGHR8InE80EY
00000000001T<MP7>0OJM@00000h1mYeP07JMK2Xn@JhcD806N;EMH01fWD00100A1l@EMSTnPKdcd80
h<e202l`eWETMP08000002D0000<00000`0004H000280000O00004M4BD<20000:040073moolk0@00
O?gooc00001W06D0KP1U0780H@1d06D0I00P0680N@0P05L0C@1602l0A@1=04H0801R0640H`1[06D0
KP1T0200K`1V0200L01c07@0K`1U06@0J@1d0000J@1^0700M@1d0000000S000080000<Q9]3l00000
000004T9^[nT20;6/mjDAR@0000T0000b4Vd?`0000000000B@Vj_j@80/JcgYA6100002<0000P0000
b4Vd?`0000000000B@Vj_j@80/JcgYA6900002@00038BK@o0000000000192KZoY0P2a[?NU4H40000
4P0000`0000100005P0000`0000H0000600000`000000000DP00070100040000>Oooo`0000000000
00000901000000001`020T<0C@1C05T0<@0`04l0DP1904L000000000000000000000000000000000
0000000000000000000000000000000010000<S:60000000200000L000000000SU<gMLS:600`bQP0
k;1300@000240000b<XH00000000000030000000000100008<XH000000240000X0l0008000030000
b<XH000000000000?<XH07nN@`3l2Uh0P<XH0000@`040000S[E309f>bIEXOUh08HQ6000000000000
00000040001<bQP002m:00c;603PW480CF2FUOkoool004<0gKE306QnGP000000001N06QnGP38bQP0
0@0003P07P0;0000b<XH06QnGP010`00/7eN0040001POUh0I7H02000000U0000300000@0001D0000
E00002@000190000`P0003l200010000Zj[Q?ag7hKl^5`00JS800040001<00000000000000000000
oooooooooom@0000A@0006@0000H000030000000001B0000L04000D0000D00002@00000000000000
_080000000070P8RD`1i07<0M01U06d000000000003R0000000006bDR`:0n?oo0000000000000000
0000052DR`:0n?oo^YH00000eWFgI=IeMR8QW`00000000000@000<3d0POPc480HFCFMGHR8Il00000
000005@000000000`?@21eS=@P3NDMIeMR8QWgRco`H20000D63I2E@0000000000@0003P07P0;0000
b<XH06QnGP010`00/7eN0040001POUh000002000002E80EY000005S=@P0_<=IeF<e206H`eWDT@]P7
f>Cj1RD0000000X001@008c>@P0MnREdMR8QW`00o`K0m0870P00051Pf@Vb2RId00SJM@0000002=Ye
P07JMCQ2f0N`cD80;c3FMK3=@P1V<=IeQ4;H1mSTnPITMP08000002D0000<00001@0002P0000<0000
10000580001`0@00100007Goool0000000000000002@0@00000000L00P9304d0DP0g000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000o000o
100000800010eVD0b<XH0000000K03h0M05S0000001@0F<0F0=;0000@`0PdVD0`7]U000000040000
000005`100400000800000000@5DbAP0S><YMhc:603eLBigI:Y>1_kooonZ>2YgXS@ZM`00000006D0
8=9U09DP2SX000006=9U09c:602:DgMe001S0000002QE7Me;]G9UIDP2SXPdVD0P07JM@26GP1804/0
001;06S:602E80XjQ<`H001`NGFRU:SPo_oooj5DMgD54]Ie8=9U0<15IP0_4B58000:0<15IP3DbQP0
G3WFMFAf00P000009@0000`000040000E00005@0003C00006`0002P1003U00000@000:^ZhClMan6o
ZQL00;`b00010000C00000000000000000000?ooooooooooD00002P0000l0000600000`000000000
9@0000`000050000:00000`000040000DP00070100040000MOooo`00000000000000090100000000
1`020T<0C@1=04T0=`00000000000000000000000000000000000000000000000000000000000000
0000000000000000000003l003l40000E<TH043FI@2<bQP0mG4^Ma/0?P1d0F<000000501H`1H0d/0
001U023BI@30NfD0000000@000000000G0400@00000P000000010EC960000000S<XH0?Ea;WMTZTh6
o_ooojXh:WNR=2Yg00000000I@0PdVD0UB0:>`00000HdVD0W<XH08YCMgD006<000000:5DMgD^eLVE
UB0:>b3BI@200MYe000004P0B`0004/0J<XH09DP2S^4c1P0071iMJ:DZ>3nooooXEAgM@DBeWDPdVD0
`4EV02lA8DP000X0`4EV0=C:601L>MIeI7H02000000U0000300000@0001D0000E00002X1000K0000
]`400>D000010000Zj[Q?ag7hKoX5`00_3800040001<00000000000000000000oooooooooom@0000
KP0006@0000H000030000000000U0000300000D0000X0000300000@0001B0000L04000@0001eoooo
0000000000000000T040000000070082@`1=0580=`00000000000000000000000000000000000000
000000000000000000000000000000000000000000000000?`00?`@0001DbAP0@=IU08c:603eLBig
6`0n07@1H`000000D05S05P3B`0006D08=9U0<1kI@00000010000000001L0@010000020000000041
E<TH0000002<bQP0mG4^MfBZCPKnooooZSPZMj8d:WL00000001U023BI@2E80Xl000001SBI@2LbQP0
RU=gM@00H`000000XEAgMBkEbIFE80Xl8=9U0801fWD00000B01;0000B`1XbQP0UB0:?8C<6000L7Ue
XYBXh?kooonQE7Me1A;FMB3BI@30AFH0;a4QB0002P30AFH0e<XH05`ieWETMP08000002D0000<0000
100005@0001D0000]04001/000090P00i@000040002[Z^4o7LOQ_dXH002l<P000@0004`000000000
00000000003ooooooooooe00000Y02`j?00002D0000<00001@0002P0000<0000100004H0000D0000
200004M4BD<300008P0000`0003ooooo8P0000`0003ooooo9@0000`0000=0020:00000`000030000
:00000`0000500008P0000`0003oooooAP000<01002d0@00ADe6:ba0000T000060000000P3l00000
00000000P3l000200000P2Y0000T000060000;5feT400000000008T1eT5lWOO5H@29ARA0000<0000
000002Y0000T000060000;02;3X0000000000;02;3X00;:X001?ZB]0000<0000000001i01P0<0000
000002501@0<0000000000Q00P@H00003000008@`=/000000`0043A00P0<0000000001i02@0<0000
000002Y0000T000060000;02;3X0000000000;02;3X00;:X001?ZB501`0<0000000002Y0000T0000
60000;02;3X0000000000;02;3X00;:X001?ZB]0000<0000000002]0000<0000000001i01P0<0000
000002501@0<0000000000Q00`@H00003000008@`=/000000`0043A00`0<0000000001i02@0<0000
000002Y0000T000060000000P3l0000000000000P3l00000000002501`0<0000000004`0001T0000
00000000000K0P00@`40000000000000708004@1000Y0:X0000000000000080o000000000000080o
0000000000000000000000000000000000000000000R000030000?oooom60000700001000015CDH[
0T0000`0000000003P0001@000000000400001@0
\>"], "Graphics",
  GeneratedCell->False,
  CellAutoOverwrite->False,
  ImageSize->{27.00000000000003, 16.14953271028036},
  ImageMargins->{{0., 0.}, {0., 3.171728971962615}},
  FontSize->12],
 StyleBox["=udif<tolerance always holds and the search of  ever-increasing \
timesteps would never end. Besides, to cap the size of the timesteps \
guarantees a minimum sampling of the solution.]",
  FontSize->12]
}], "Text",
 CellChangeTimes->{{3.636977241041491*^9, 3.636977288861226*^9}, {
   3.6371540193780947`*^9, 3.637154134615897*^9}, {3.6371541746923676`*^9, 
   3.637154286800164*^9}, {3.637154738875758*^9, 3.6371547440861673`*^9}, {
   3.6371553197739787`*^9, 3.63715540584133*^9}, {3.6371554887710752`*^9, 
   3.637155614335696*^9}, {3.6372396898443737`*^9, 3.63723983296556*^9}, {
   3.637239886282609*^9, 3.6372399870033703`*^9}, {3.637240021827362*^9, 
   3.6372401240682096`*^9}, {3.6372401561950474`*^9, 
   3.6372401567390785`*^9}, {3.6372402300702724`*^9, 
   3.6372402584158945`*^9}, {3.6372403174082685`*^9, 
   3.6372403178482933`*^9}, {3.637240657443717*^9, 3.637240663366056*^9}, {
   3.6372416176106358`*^9, 3.6372416247140417`*^9}, {3.637366634603321*^9, 
   3.637366735909899*^9}, {3.6373667725855637`*^9, 3.6373668101504297`*^9}, {
   3.637366842270886*^9, 3.637367054556059*^9}, {3.6373670854909134`*^9, 
   3.637367117299369*^9}, {3.637367305808232*^9, 3.63736736050036*^9}, {
   3.6373673958993845`*^9, 3.63736746697445*^9}, 3.637367530626091*^9, {
   3.637367649660899*^9, 3.6373677047170477`*^9}, {3.6386009981886*^9, 
   3.6386010006935997`*^9}},
 Background->RGBColor[1, 1, 0.85]],

Cell[BoxData[
 RowBox[{
  RowBox[{"Delta0TE", "=", "0.01"}], ";", 
  RowBox[{"DeltatcapTE", "=", 
   RowBox[{"10.", "^", "6"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.6372395797630777`*^9, 3.637239587733533*^9}, {
   3.637239826428186*^9, 3.63723982719623*^9}, {3.637240133192732*^9, 
   3.6372401500916986`*^9}, {3.6372403259417562`*^9, 3.6372403455008755`*^9}, 
   3.6373291921949387`*^9, 3.6373675306700935`*^9, 3.6373677575560703`*^9},
 Background->RGBColor[1, 1, 0.85]]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"uMsolutionTE", "[", 
   RowBox[{"numpasos_", ",", "tolerance_"}], "]"}], ":=", 
  RowBox[{"(", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Umatrix", "=", 
     RowBox[{"{", "}"}]}], ";", 
    RowBox[{"Umatrix", "=", 
     RowBox[{"AppendTo", "[", 
      RowBox[{"Umatrix", ",", "UmatrixIni"}], "]"}]}], ";", 
    "\[IndentingNewLine]", 
    RowBox[{"ht", "=", "Delta0TE"}], ";", "\[IndentingNewLine]", 
    RowBox[{"Do", "[", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"usingle", "=", 
        RowBox[{"U1stepMatrixt", "[", "m", "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"uhalf", "=", 
        RowBox[{"U2stepsMatrixt", "[", "m", "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"udif", "=", 
        RowBox[{"Max", "[", 
         RowBox[{"Abs", "[", 
          RowBox[{"usingle", "-", "uhalf"}], "]"}], "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{"udif", "<", "tolerance"}], ",", "\[IndentingNewLine]", "\t", 
         RowBox[{
          RowBox[{"While", "[", "\t", "\[IndentingNewLine]", "\t", 
           RowBox[{
            RowBox[{
             RowBox[{"ht", "<", "DeltatcapTE"}], "&&", 
             RowBox[{"udif", "<", "tolerance"}]}], ",", "\[IndentingNewLine]",
             "\t", 
            RowBox[{
             RowBox[{"ht", "=", 
              RowBox[{"2.", "*", "ht"}]}], ";", "\[IndentingNewLine]", "\t", 
             RowBox[{"usingle", "=", 
              RowBox[{"U1stepMatrixt", "[", "m", "]"}]}], ";", 
             "\[IndentingNewLine]", "\t", 
             RowBox[{"uhalf", "=", 
              RowBox[{"U2stepsMatrixt", "[", "m", "]"}]}], ";", 
             "\[IndentingNewLine]", "\t", 
             RowBox[{"udif", "=", 
              RowBox[{"Max", "[", 
               RowBox[{"Abs", "[", 
                RowBox[{"usingle", "-", "uhalf"}], "]"}], "]"}]}], ";"}]}], 
           "\[IndentingNewLine]", "\t\t         ", "]"}], ";", 
          "\[IndentingNewLine]", "        ", 
          RowBox[{"ht", "=", " ", 
           RowBox[{"ht", "/", "2."}]}], ";"}], "\[IndentingNewLine]", "    ", 
         ",", "\[IndentingNewLine]", "\t", 
         RowBox[{"While", "[", "\[IndentingNewLine]", "\t", 
          RowBox[{
           RowBox[{"udif", ">", "tolerance"}], ",", "\[IndentingNewLine]", 
           "\t", 
           RowBox[{
            RowBox[{"ht", "=", 
             RowBox[{"ht", "/", "2"}]}], ";", "\[IndentingNewLine]", "\t", 
            RowBox[{"usingle", "=", 
             RowBox[{"U1stepMatrixt", "[", "m", "]"}]}], ";", 
            "\[IndentingNewLine]", "\t", 
            RowBox[{"uhalf", "=", 
             RowBox[{"U2stepsMatrixt", "[", "m", "]"}]}], ";", 
            "\[IndentingNewLine]", "\t", 
            RowBox[{"udif", "=", 
             RowBox[{"Max", "[", 
              RowBox[{"Abs", "[", 
               RowBox[{"usingle", "-", "uhalf"}], "]"}], "]"}]}], ";"}]}], 
          "\[IndentingNewLine]", "\t", "\[IndentingNewLine]", "\t         ", 
          "]"}]}], "\[IndentingNewLine]", "   ", "]"}], ";", 
       "\[IndentingNewLine]", " ", 
       RowBox[{"usingle", "=", 
        RowBox[{"U1stepMatrixt", "[", "m", "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"uhalf", "=", 
        RowBox[{"U2stepsMatrixt", "[", "m", "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"udif", "=", 
        RowBox[{"Max", "[", 
         RowBox[{"Abs", "[", 
          RowBox[{"usingle", "-", "uhalf"}], "]"}], "]"}]}], ";", 
       "\[IndentingNewLine]", "\[IndentingNewLine]", 
       RowBox[{"Umatrix", "=", 
        RowBox[{"Append", "[", 
         RowBox[{"Umatrix", ",", 
          RowBox[{"U1stepMatrixt", "[", "m", "]"}]}], "]"}]}]}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"{", 
       RowBox[{"m", ",", "1", ",", "numpasos"}], "}"}]}], "]"}], ";", 
    "\[IndentingNewLine]", "Umatrix"}], "\[IndentingNewLine]", 
   ")"}]}]], "Input",
 CellChangeTimes->{{3.5611175304854*^9, 3.5611178158406*^9}, {
   3.5611178594114*^9, 3.5611180036802*^9}, {3.5611180779986*^9, 
   3.5611180850810003`*^9}, {3.561118140774*^9, 3.5611182677072*^9}, {
   3.5611183022455997`*^9, 3.561118506824*^9}, 3.5611185494119997`*^9, {
   3.5611187160044003`*^9, 3.5611187284688*^9}, {3.5611189629368*^9, 
   3.5611190066792*^9}, {3.5611192326608*^9, 3.5611192925959997`*^9}, {
   3.5611195041174*^9, 3.5611195293114*^9}, {3.5611195729758*^9, 
   3.5611196111802*^9}, {3.5611196647974*^9, 3.5611196823006*^9}, {
   3.5611197142338*^9, 3.5611197383982*^9}, {3.5611198172562*^9, 
   3.5611198918554*^9}, {3.561119935707*^9, 3.5611199664858*^9}, {
   3.5611200243929996`*^9, 3.561120028683*^9}, 3.561120065889*^9, {
   3.561120213309*^9, 3.5611202301414003`*^9}, {3.5611203336474*^9, 
   3.5611203397469997`*^9}, 3.561120462519*^9, {3.5611205206914*^9, 
   3.561120537009*^9}, {3.5611205826858*^9, 3.5611206541026*^9}, 
   3.5611208318968*^9, 3.561121233816*^9, {3.5611212722076*^9, 
   3.5611212728784*^9}, {3.5611215947298*^9, 3.5611216368688*^9}, {
   3.5611216735738*^9, 3.5611216737808*^9}, {3.5611217371108*^9, 
   3.5611217609318*^9}, {3.5611219140168*^9, 3.5611219264628*^9}, 
   3.5611219569968*^9, 3.5611221823638*^9, {3.5611222751916*^9, 
   3.5611222764248*^9}, {3.561122309192*^9, 3.5611223095352*^9}, {
   3.5611259517696*^9, 3.5611259534116*^9}, {3.5611260219376*^9, 
   3.5611260223566*^9}, {3.5611270933666*^9, 3.5611271943246*^9}, {
   3.5611273344718*^9, 3.5611273351118*^9}, {3.589009494885*^9, 
   3.589009495092*^9}, {3.5894687592865686`*^9, 3.5894687686071014`*^9}, {
   3.5894768422319183`*^9, 3.589476862873947*^9}, {3.5916910738879504`*^9, 
   3.591691123240773*^9}, {3.5916914162675333`*^9, 3.591691426801136*^9}, {
   3.5916915066417027`*^9, 3.5916915083347993`*^9}, 3.636986274446172*^9, {
   3.636986360293082*^9, 3.6369863911028447`*^9}, 3.6369864923636365`*^9, 
   3.636986675219095*^9, {3.6369918424056416`*^9, 3.636991869413186*^9}, {
   3.6369919606444044`*^9, 3.636991963596573*^9}, {3.637004762338209*^9, 
   3.6370047946760583`*^9}, 3.637004853844443*^9, {3.637004961017573*^9, 
   3.6370049762344427`*^9}, {3.637005010216387*^9, 3.637005022234074*^9}, {
   3.637237994324859*^9, 3.6372379943438606`*^9}, {3.6372380698551793`*^9, 
   3.6372380843540087`*^9}, 3.6372395935548663`*^9, 3.637239834852668*^9, 
   3.637240177672276*^9, {3.637240210722166*^9, 3.637240210732167*^9}, 
   3.6372403534563303`*^9, 3.6373675306760936`*^9, 3.637367724876201*^9},
 Background->RGBColor[0.88, 1, 0.88]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 "uMsolutionPredictive[n,\[Tau]]  provides the full  solution   ",
 Cell[BoxData[
  FormBox[
   RowBox[{"{", 
    RowBox[{
     SubsuperscriptBox["U", "0", 
      RowBox[{"(", "m", ")"}]], ",", 
     SubsuperscriptBox["U", "1", 
      RowBox[{"(", "m", ")"}]], ",", 
     SubsuperscriptBox["U", "2", 
      RowBox[{"(", "m", ")"}]], ",", 
     RowBox[{"...", " ", 
      SubsuperscriptBox["U", "Np", 
       RowBox[{"(", "m", ")"}]]}]}], "}"}], TraditionalForm]]],
 "  with m=0,1,2,....n  for variable timesteps whose size is determined by \
the ",
 StyleBox["predictive",
  FontSlant->"Italic"],
 " method for a tolerance \[Tau] .  The full solution is stored in the matrix \
Umatrix so that its element (1+m,1+j), i.e., Umatrix[[1+m,1+j]],  gives  ",
 Cell[BoxData[
  FormBox[
   SubsuperscriptBox["U", "j", 
    RowBox[{"(", "m", ")"}]], TraditionalForm]]],
 ". "
}], "Subsubsection",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 CellChangeTimes->{{3.5610913126613097`*^9, 3.56109140331946*^9}, {
   3.5610914876944838`*^9, 3.5610915214480352`*^9}, {3.5611269260439997`*^9, 
   3.5611270545306*^9}, {3.6334403275358505`*^9, 3.6334403294079576`*^9}, 
   3.6370047946140547`*^9, {3.637155674879402*^9, 3.6371557000432467`*^9}, {
   3.6371557716161723`*^9, 3.6371558227842627`*^9}, {3.6371568868223314`*^9, 
   3.637156912499977*^9}, {3.6371569827625003`*^9, 3.6371570266921773`*^9}, {
   3.6371573632793684`*^9, 3.6371573632793684`*^9}, {3.637157418019865*^9, 
   3.637157442075107*^9}, {3.6371575519461*^9, 3.637157661161892*^9}, {
   3.637157691940746*^9, 3.6371578482706203`*^9}, {3.637165659783272*^9, 
   3.637165695372308*^9}, 3.6372380842940054`*^9, {3.6372384809746943`*^9, 
   3.637238527949381*^9}, {3.6372386475472217`*^9, 3.6372387420841646`*^9}, {
   3.637238784210574*^9, 3.6372390407962503`*^9}, {3.6372391044228897`*^9, 
   3.6372391129183755`*^9}, {3.637239166812458*^9, 3.6372391991713085`*^9}, {
   3.6372393619346185`*^9, 3.637239450800701*^9}, {3.637243686738983*^9, 
   3.6372436989296803`*^9}},
 Background->RGBColor[0.88, 1, 0.88]],

Cell[CellGroupData[{

Cell[TextData[{
 "Some arbitrary parameters one has to chose:\n\[Bullet] The initial  \
timestep ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["\[CapitalDelta]", "0"], TraditionalForm]]],
 "=Delta0Predictive. Here is fixed to the arbitrary (but hardly relevant) \
value of 0.01\n\[Bullet] The maximum value of the timestep, DeltatcapTE, one \
is ready to accept.  Here we choose Deltatmax=",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["10", 
    RowBox[{"6", " "}]], TraditionalForm]]],
 " (the actual value could be somewhat larger). ",
 StyleBox["[When the solution goes towards zero, the absolute value of this \
solution will be smaller than the tolerance for times long enough. In this \
case, the condition ",
  FontSize->12],
 Cell[GraphicsData["Metafile", "\<\
CF5dJ6E]HGAYHf4PEfU^I6mgLb15CDHPAVmbKF5d0@0001id0@0006`000000000000001/2000o0P00
00000000003Z2000E`D00215CDH00040M1h005X0000600000000000000000000HA<006PK003B0000
:@400000000000000000050d0`0XR0@0AP0002`0000P0000ADe6:`500@0L00004000008@`=/00000
F08005P200160000O04007010015CDH[7T0500`0000000007d0300`000000000<402010000040000
0020?b501`0<000000000290100<0000000002Y0000T000060000000P3l0000000000000P3l00000
000002]0000<0000000001i01P0<0000000002501@0<0000000001i02@0<0000000002Y0000T0000
60000000P3l0000000000000P3l00000000002501`0<0000000002Y0000T000060000;02;3X00000
00000;02;3X0X;74031?aB]0000<0000000002Y0000T000060000;02;3X0000000000;02;3X0X;74
031?aB]0000<0000000002Y0000T000060000;02;3X0000000000;02;3X00;:X001?Z@Y0080T0000
60000<cook810000000000000000jdQ901[aB24000080000HP0000`0000100009`0001P000010000
00000?ooc00000009@0000`000010000C00006@000000000000001/200130@0000000000000L0P00
A04004T0FP00000000000000P3l0000000000000P3l0000000000000000000000000000000000000
000001P0000<0000oooo02@0000T00000020?@00000000000020?@00000000000P0005h0001d0000
0P000000000T0000<00005@0000P0000000002P000080000200000400@0000008000000000000000
0000000000000000oooo0000001E0000200005D000000000E@0008P0001E00009@0000`000020000
9@0000`000080020C00006@000000000000001/200130@00n?ooooSoooo08@00@1@00<T0X0000000
00000000P3l0000000000000P3l0000000000000000000000000000000000000000002D0000<0000
1`00P2D0000<00000@0002@0000T00000020@@00000000000020@@00000000000P0001P0000<0000
000004`0001T000000000000000K0P00@`40000000000000708004@1001905X0000000000000080o
000000000000080o0000000000000000000000000000000000000000000U00003000000008160000
40X000@:0015CDH[:d0000`0000000007T0600`0000000008D0500`0000000007T0900`000000000
:T0002@0000H0000/08/>P0000000000/08/>P00/ZP004nY8D0700`000000000:d0000`000000000
:T0002@0000H0000/GKF@@0000000000R@7F@GbMmlEQ08U6940400`00000000024001@09003d2000
0Q30f`8000030000i0P00040003<0000:@4007;moolj0@00Q?gookHX002ZYOooFB/003:WoolPADe6
00010>@8000N00000P000300001/000000000807000h1000Y@8007d10000000000000000003EE@X0
B=0506L0I@1^06D0LP1Q07@0I@1T0200HP1i0200E`1=04H0;`1504d0AP0P0680H@1S06/0I@1^06@0
801_06H0801`07<0M01_06D0I01Y07@0001Y06h0L01e07@000000140000<00001P0000X0000@0000
00000000000B000030000040000F0000300001P0000H000030000000001B0000L0400040000ioooo
0000000000000000T040000000000082@`1=05<0F@0a0300C`1B04T0A`0000000000000000000000
000000000000000000000000000000000000000000040000b<XH0000000800001`000000002>DcMe
b<XH033:603//4<0100008@00038bQP000000000000<000000000040000PbQP0000008@0002P3`00
0P0000<00038bQP000000000000lbQP0Oii30?`:GP20bQP0001300@0002>]D<0WHk9UFQnGP0QR4H0
00000000000000000@0004c:6000;dX03</H0>2L@P1=H9JEo_ooo`00@`3M]D<0J7iN0000000005h0
J7iN0<S:60010000>00N00/00038bQP0J7iN0043002`OEh00@00061nGP1TMP08000002D0000<0000
0@0005@0001D0000:@4007?mool_0@00Q?goo`40002[Z^4o7LOQ_bhG001Z<P000@0004`000000000
00000000003ooooooooooe0000150000I00001P0000<0000000002D0000<00003@00P2P0000<0000
0@000580001`0@000@0007Goool0000000000000002@0@00000000000P9304d0DP0g000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000o000o
100000800010eVD0b<XH0000000K03h0M05S0000001@0F<0F0=;0000@`0PdVD0`7]U000000040000
000005`100400000800000000@5DbAP0S><YMhc:603eLBigI:Y>1_kooonZ>2YgXS@ZM`00000006D0
8=9U09DP2SX000006=9U09c:602:DgMe001S0000002QE7Me;]G9UIDP2SXPdVD0P07JM@26GP1804/0
001;06S:602E80XjQ<`H001`NGFRU:SPo_oooj5DMgD54]Ie8=9U0<15IP0_4B58000:0<15IP3DbQP0
G3WFMFAf00P000009@0000`000010000E00005@0000_0@00L_gooc81001hoOoo0@000:^ZhClMan6o
ZQL00;`b00010000C00000000000000000000?ooooooooooD00002P0000l0000600000`000000000
9@0000`0000=0020:00000`000010000DP00070100010000MOooo`00000000000000090100000000
00020T<0C@1=04T0=`00000000000000000000000000000000000000000000000000000000000000
0000000000000000000003l003l40000E<TH043FI@2<bQP0mG4^Ma/0?P1d0F<000000501H`1H0d/0
001U023BI@30NfD0000000@000000000G0400@00000P000000010EC960000000S<XH0?Ea;WMTZTh6
o_ooojXh:WNR=2Yg00000000I@0PdVD0UB0:>`00000HdVD0W<XH08YCMgD006<000000:5DMgD^eLVE
UB0:>b3BI@200MYe000004P0B`0004/0J<XH09DP2S^4c1P0071iMJ:DZ>3nooooXEAgM@DBeWDPdVD0
`4EV02lA8DP000X0`4EV0=C:601L>MIeI7H02000000U000030000040001D0000E0000381001boOoo
=`4007Smool10000Zj[Q?ag7hKoX5`00_3800040001<00000000000000000000oooooooooom@0000
KP0006@0000H000030000000000U0000300000d0080X000030000040001B0000L0400040001eoooo
0000000000000000T040000000000082@`1=0580=`00000000000000000000000000000000000000
000000000000000000000000000000000000000000000000?`00?`@0001DbAP0@=IU08c:603eLBig
6`0n07@1H`000000D05S05P3B`0006D08=9U0<1kI@00000010000000001L0@010000020000000041
E<TH0000002<bQP0mG4^MfBZCPKnooooZSPZMj8d:WL00000001U023BI@2E80Xl000001SBI@2LbQP0
RU=gM@00H`000000XEAgMBkEbIFE80Xl8=9U0801fWD00000B01;0000B`1XbQP0UB0:?8C<6000L7Ue
XYBXh?kooonQE7Me1A;FMB3BI@30AFH0;a4QB0002P30AFH0e<XH05`ieWETMP08000002D0000<0000
0@0005@0001D0000=`4007;moolj0@00N?goo`40002[Z^4o7LOQ_dXH002l<P000@0004`000000000
00000000003ooooooooooe00000Y0000?00002D0000<00003@00P2P0000<00000@0000h0000D0000
00000100000D0000240122@0000H00000Q30f`400003000000000000000000006d000400000d0000
0@000080000mbI=3TN8Sa6dUXD7ibD510`0003g9Td>AhR?4Tm^M@i7R8l@mbI=3J]/Pa24000080000
HP0000`0000100008@0000P0000Q0000200007<0000<0000000001`0000800009@0000`000000020
9@0000`0000700209@0000`0000>00206@0000`0003oool0600000`0000000004P0000`000020000
4`0000`000010000500000`0000=00005@0000`0000100005P0000`0000000003@00010000000000
000003X0000<00002P0001/0000@000000000000000S000080000:hohD400000000009^;j46T20;6
/mjDAR@0000T0000[SoQ@@0000000000Vh_X@J@80/JcgYA6100007<0000<0000000000d0000@0000
00000000001B0000L04000<0000@00001`00000000000000_080000000070P8RD`1i07<0M01U06d0
000C0:3hooob0@00000003c=6`:0n?oo201HO__fool000000000023=6`:0n?ooool00000000H0000
00000=STnPH800000000P1Sin`H30000MR8QWb80RP4500001<e2051JeGDP0000000000QQeGG3H=Ee
MR8QWiDP1FT00000200006@af0Ld<MP70000020000000000G37H1aC>@P0@<MP7@0<Z0V@af0L80000
0000073=@P3M^mIeMR8QWiDP1FT00000200006@af0Ld<MP70000010af0NLcD80JK_FMGHR8InE80EY
00000000001T<MP7>0OJM@00000h1mYeP07JMK2Xn@JhcD806N;EMH01fWD00100A1l@EMSTnPKdcd80
h<e202l`eWETMP08000002D0000<00000`0004H000280000O00004M4BD<20000:040073moolk0@00
O?gooc00001W06D0KP1U0780H@1d06D0I00P0680N@0P05L0C@1602l0A@1=04H0801R0640H`1[06D0
KP1T0200K`1V0200L01c07@0K`1U06@0J@1d0000J@1^0700M@1d0000000S000080000<Q9]3l00000
000004T9^[nT20;6/mjDAR@0000T0000b4Vd?`0000000000B@Vj_j@80/JcgYA6100002<0000P0000
b4Vd?`0000000000B@Vj_j@80/JcgYA6900002@00038BK@o0000000000192KZoY0P2a[?NU4H40000
4P0000`0000100005P0000`0000H0000600000`000000000DP00070100040000>Oooo`0000000000
00000901000000001`020T<0C@1C05T0<@0`04l0DP1904L000000000000000000000000000000000
0000000000000000000000000000000010000<S:60000000200000L000000000SU<gMLS:600`bQP0
k;1300@000240000b<XH00000000000030000000000100008<XH000000240000X0l0008000030000
b<XH000000000000?<XH07nN@`3l2Uh0P<XH0000@`040000S[E309f>bIEXOUh08HQ6000000000000
00000040001<bQP002m:00c;603PW480CF2FUOkoool004<0gKE306QnGP000000001N06QnGP38bQP0
0@0003P07P0;0000b<XH06QnGP010`00/7eN0040001POUh0I7H02000000U0000300000@0001D0000
E00002@000190000`P0003l200010000Zj[Q?ag7hKl^5`00JS800040001<00000000000000000000
oooooooooom@0000A@0006@0000H000030000000001B0000L04000D0000D00002@00000000000000
_080000000070P8RD`1i07<0M01U06d000000000003R0000000006bDR`:0n?oo0000000000000000
0000052DR`:0n?oo^YH00000eWFgI=IeMR8QW`00000000000@000<3d0POPc480HFCFMGHR8Il00000
000005@000000000`?@21eS=@P3NDMIeMR8QWgRco`H20000D63I2E@0000000000@0003P07P0;0000
b<XH06QnGP010`00/7eN0040001POUh000002000002E80EY000005S=@P0_<=IeF<e206H`eWDT@]P7
f>Cj1RD0000000X001@008c>@P0MnREdMR8QW`00o`K0m0870P00051Pf@Vb2RId00SJM@0000002=Ye
P07JMCQ2f0N`cD80;c3FMK3=@P1V<=IeQ4;H1mSTnPITMP08000002D0000<00001@0002P0000<0000
10000580001`0@00100007Goool0000000000000002@0@00000000L00P9304d0DP0g000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000o000o
100000800010eVD0b<XH0000000K03h0M05S0000001@0F<0F0=;0000@`0PdVD0`7]U000000040000
000005`100400000800000000@5DbAP0S><YMhc:603eLBigI:Y>1_kooonZ>2YgXS@ZM`00000006D0
8=9U09DP2SX000006=9U09c:602:DgMe001S0000002QE7Me;]G9UIDP2SXPdVD0P07JM@26GP1804/0
001;06S:602E80XjQ<`H001`NGFRU:SPo_oooj5DMgD54]Ie8=9U0<15IP0_4B58000:0<15IP3DbQP0
G3WFMFAf00P000009@0000`000040000E00005@0003C00006`0002P1003U00000@000:^ZhClMan6o
ZQL00;`b00010000C00000000000000000000?ooooooooooD00002P0000l0000600000`000000000
9@0000`000050000:00000`000040000DP00070100040000MOooo`00000000000000090100000000
1`020T<0C@1=04T0=`00000000000000000000000000000000000000000000000000000000000000
0000000000000000000003l003l40000E<TH043FI@2<bQP0mG4^Ma/0?P1d0F<000000501H`1H0d/0
001U023BI@30NfD0000000@000000000G0400@00000P000000010EC960000000S<XH0?Ea;WMTZTh6
o_ooojXh:WNR=2Yg00000000I@0PdVD0UB0:>`00000HdVD0W<XH08YCMgD006<000000:5DMgD^eLVE
UB0:>b3BI@200MYe000004P0B`0004/0J<XH09DP2S^4c1P0071iMJ:DZ>3nooooXEAgM@DBeWDPdVD0
`4EV02lA8DP000X0`4EV0=C:601L>MIeI7H02000000U0000300000@0001D0000E00002X1000K0000
]`400>D000010000Zj[Q?ag7hKoX5`00_3800040001<00000000000000000000oooooooooom@0000
KP0006@0000H000030000000000U0000300000D0000X0000300000@0001B0000L04000@0001eoooo
0000000000000000T040000000070082@`1=0580=`00000000000000000000000000000000000000
000000000000000000000000000000000000000000000000?`00?`@0001DbAP0@=IU08c:603eLBig
6`0n07@1H`000000D05S05P3B`0006D08=9U0<1kI@00000010000000001L0@010000020000000041
E<TH0000002<bQP0mG4^MfBZCPKnooooZSPZMj8d:WL00000001U023BI@2E80Xl000001SBI@2LbQP0
RU=gM@00H`000000XEAgMBkEbIFE80Xl8=9U0801fWD00000B01;0000B`1XbQP0UB0:?8C<6000L7Ue
XYBXh?kooonQE7Me1A;FMB3BI@30AFH0;a4QB0002P30AFH0e<XH05`ieWETMP08000002D0000<0000
100005@0001D0000]04001/000090P00i@000040002[Z^4o7LOQ_dXH002l<P000@0004`000000000
00000000003ooooooooooe00000Y02`j?00002D0000<00001@0002P0000<0000100004H0000D0000
200004M4BD<300008P0000`0003ooooo8P0000`0003ooooo9@0000`0000=0020:00000`000030000
:00000`0000500008P0000`0003oooooAP000<01002d0@00ADe6:ba0000T000060000000P3l00000
00000000P3l000200000P2Y0000T000060000;5feT400000000008T1eT5lWOO5H@29ARA0000<0000
000002Y0000T000060000;02;3X0000000000;02;3X00;:X001?ZB]0000<0000000001i01P0<0000
000002501@0<0000000000Q00P@H00003000008@`=/000000`0043A00P0<0000000001i02@0<0000
000002Y0000T000060000;02;3X0000000000;02;3X00;:X001?ZB501`0<0000000002Y0000T0000
60000;02;3X0000000000;02;3X00;:X001?ZB]0000<0000000002]0000<0000000001i01P0<0000
000002501@0<0000000000Q00`@H00003000008@`=/000000`0043A00`0<0000000001i02@0<0000
000002Y0000T000060000000P3l0000000000000P3l00000000002501`0<0000000004`0001T0000
00000000000K0P00@`40000000000000708004@1000Y0:X0000000000000080o000000000000080o
0000000000000000000000000000000000000000000R000030000?oooom60000700001000015CDH[
0T0000`0000000003P0001@000000000400001@0
\>"], "Graphics",
  GeneratedCell->False,
  CellAutoOverwrite->False,
  ImageSize->{27.00000000000003, 16.14953271028036},
  ImageMargins->{{0., 0.}, {0., 3.171728971962615}},
  FontSize->12],
 StyleBox["=udif<fac2*tolerance always holds and the search of  \
ever-increasing timesteps would never end. Besides, to cap the size of the \
timesteps guarantees a minimum sampling of the solution.]",
  FontSize->12],
 "\n\[Bullet] The under-relaxation parameter \[Omega]=omegaParameter. Here we \
use  \[Omega]=1/2. \n\[Bullet] The scaling exponent \[Theta]=thetaParameter.  \
Here we use  \[Theta]=3/2. \n\[Bullet] The fac1 and fac2 parameteres. The \
timestep is accepted if the difference ",
 Cell[GraphicsData["Metafile", "\<\
CF5dJ6E]HGAYHf4PEfU^I6mgLb15CDHPAVmbKF5d0@0001id0@0006`000000000000001/2000o0P00
00000000003Z2000E`D00215CDH00040M1h005X0000600000000000000000000HA<006PK003B0000
:@400000000000000000050d0`0XR0@0AP0002`0000P0000ADe6:`500@0L00004000008@`=/00000
F08005P200160000O04007010015CDH[7T0500`0000000007d0300`000000000<402010000040000
0020?b501`0<000000000290100<0000000002Y0000T000060000000P3l0000000000000P3l00000
000002]0000<0000000001i01P0<0000000002501@0<0000000001i02@0<0000000002Y0000T0000
60000000P3l0000000000000P3l00000000002501`0<0000000002Y0000T000060000;02;3X00000
00000;02;3X0X;74031?aB]0000<0000000002Y0000T000060000;02;3X0000000000;02;3X0X;74
031?aB]0000<0000000002Y0000T000060000;02;3X0000000000;02;3X00;:X001?Z@Y0080T0000
60000<cook810000000000000000jdQ901[aB24000080000HP0000`0000100009`0001P000010000
00000?ooc00000009@0000`000010000C00006@000000000000001/200130@0000000000000L0P00
A04004T0FP00000000000000P3l0000000000000P3l0000000000000000000000000000000000000
000001P0000<0000oooo02@0000T00000020?@00000000000020?@00000000000P0005h0001d0000
0P000000000T0000<00005@0000P0000000002P000080000200000400@0000008000000000000000
0000000000000000oooo0000001E0000200005D000000000E@0008P0001E00009@0000`000020000
9@0000`000080020C00006@000000000000001/200130@00n?ooooSoooo08@00@1@00<T0X0000000
00000000P3l0000000000000P3l0000000000000000000000000000000000000000002D0000<0000
1`00P2D0000<00000@0002@0000T00000020@@00000000000020@@00000000000P0001P0000<0000
000004`0001T000000000000000K0P00@`40000000000000708004@1001905X0000000000000080o
000000000000080o0000000000000000000000000000000000000000000U00003000000008160000
40X000@:0015CDH[:d0000`0000000007T0600`0000000008D0500`0000000007T0900`000000000
:T0002@0000H0000/08/>P0000000000/08/>P00/ZP004nY8D0700`000000000:d0000`000000000
:T0002@0000H0000/GKF@@0000000000R@7F@GbMmlEQ08U6940400`00000000024001@09003d2000
0Q30f`8000030000i0P00040003<0000:@4007;moolj0@00Q?gookHX002ZYOooFB/003:WoolPADe6
00010>@8000N00000P000300001/000000000807000h1000Y@8007d10000000000000000003EE@X0
B=0506L0I@1^06D0LP1Q07@0I@1T0200HP1i0200E`1=04H0;`1504d0AP0P0680H@1S06/0I@1^06@0
801_06H0801`07<0M01_06D0I01Y07@0001Y06h0L01e07@000000140000<00001P0000X0000@0000
00000000000B000030000040000F0000300001P0000H000030000000001B0000L0400040000ioooo
0000000000000000T040000000000082@`1=05<0F@0a0300C`1B04T0A`0000000000000000000000
000000000000000000000000000000000000000000040000b<XH0000000800001`000000002>DcMe
b<XH033:603//4<0100008@00038bQP000000000000<000000000040000PbQP0000008@0002P3`00
0P0000<00038bQP000000000000lbQP0Oii30?`:GP20bQP0001300@0002>]D<0WHk9UFQnGP0QR4H0
00000000000000000@0004c:6000;dX03</H0>2L@P1=H9JEo_ooo`00@`3M]D<0J7iN0000000005h0
J7iN0<S:60010000>00N00/00038bQP0J7iN0043002`OEh00@00061nGP1TMP08000002D0000<0000
0@0005@0001D0000:@4007?mool_0@00Q?goo`40002[Z^4o7LOQ_bhG001Z<P000@0004`000000000
00000000003ooooooooooe0000150000I00001P0000<0000000002D0000<00003@00P2P0000<0000
0@000580001`0@000@0007Goool0000000000000002@0@00000000000P9304d0DP0g000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000o000o
100000800010eVD0b<XH0000000K03h0M05S0000001@0F<0F0=;0000@`0PdVD0`7]U000000040000
000005`100400000800000000@5DbAP0S><YMhc:603eLBigI:Y>1_kooonZ>2YgXS@ZM`00000006D0
8=9U09DP2SX000006=9U09c:602:DgMe001S0000002QE7Me;]G9UIDP2SXPdVD0P07JM@26GP1804/0
001;06S:602E80XjQ<`H001`NGFRU:SPo_oooj5DMgD54]Ie8=9U0<15IP0_4B58000:0<15IP3DbQP0
G3WFMFAf00P000009@0000`000010000E00005@0000_0@00L_gooc81001hoOoo0@000:^ZhClMan6o
ZQL00;`b00010000C00000000000000000000?ooooooooooD00002P0000l0000600000`000000000
9@0000`0000=0020:00000`000010000DP00070100010000MOooo`00000000000000090100000000
00020T<0C@1=04T0=`00000000000000000000000000000000000000000000000000000000000000
0000000000000000000003l003l40000E<TH043FI@2<bQP0mG4^Ma/0?P1d0F<000000501H`1H0d/0
001U023BI@30NfD0000000@000000000G0400@00000P000000010EC960000000S<XH0?Ea;WMTZTh6
o_ooojXh:WNR=2Yg00000000I@0PdVD0UB0:>`00000HdVD0W<XH08YCMgD006<000000:5DMgD^eLVE
UB0:>b3BI@200MYe000004P0B`0004/0J<XH09DP2S^4c1P0071iMJ:DZ>3nooooXEAgM@DBeWDPdVD0
`4EV02lA8DP000X0`4EV0=C:601L>MIeI7H02000000U000030000040001D0000E0000381001boOoo
=`4007Smool10000Zj[Q?ag7hKoX5`00_3800040001<00000000000000000000oooooooooom@0000
KP0006@0000H000030000000000U0000300000d0080X000030000040001B0000L0400040001eoooo
0000000000000000T040000000000082@`1=0580=`00000000000000000000000000000000000000
000000000000000000000000000000000000000000000000?`00?`@0001DbAP0@=IU08c:603eLBig
6`0n07@1H`000000D05S05P3B`0006D08=9U0<1kI@00000010000000001L0@010000020000000041
E<TH0000002<bQP0mG4^MfBZCPKnooooZSPZMj8d:WL00000001U023BI@2E80Xl000001SBI@2LbQP0
RU=gM@00H`000000XEAgMBkEbIFE80Xl8=9U0801fWD00000B01;0000B`1XbQP0UB0:?8C<6000L7Ue
XYBXh?kooonQE7Me1A;FMB3BI@30AFH0;a4QB0002P30AFH0e<XH05`ieWETMP08000002D0000<0000
0@0005@0001D0000=`4007;moolj0@00N?goo`40002[Z^4o7LOQ_dXH002l<P000@0004`000000000
00000000003ooooooooooe00000Y0000?00002D0000<00003@00P2P0000<00000@0000h0000D0000
00000100000D0000240122@0000H00000Q30f`400003000000000000000000006d000400000d0000
0@000080000mbI=3TN8Sa6dUXD7ibD510`0003g9Td>AhR?4Tm^M@i7R8l@mbI=3J]/Pa24000080000
HP0000`0000100008@0000P0000Q0000200007<0000<0000000001`0000800009@0000`000000020
9@0000`0000700209@0000`0000>00206@0000`0003oool0600000`0000000004P0000`000020000
4`0000`000010000500000`0000=00005@0000`0000100005P0000`0000000003@00010000000000
000003X0000<00002P0001/0000@000000000000000S000080000:hohD400000000009^;j46T20;6
/mjDAR@0000T0000[SoQ@@0000000000Vh_X@J@80/JcgYA6100007<0000<0000000000d0000@0000
00000000001B0000L04000<0000@00001`00000000000000_080000000070P8RD`1i07<0M01U06d0
000C0:3hooob0@00000003c=6`:0n?oo201HO__fool000000000023=6`:0n?ooool00000000H0000
00000=STnPH800000000P1Sin`H30000MR8QWb80RP4500001<e2051JeGDP0000000000QQeGG3H=Ee
MR8QWiDP1FT00000200006@af0Ld<MP70000020000000000G37H1aC>@P0@<MP7@0<Z0V@af0L80000
0000073=@P3M^mIeMR8QWiDP1FT00000200006@af0Ld<MP70000010af0NLcD80JK_FMGHR8InE80EY
00000000001T<MP7>0OJM@00000h1mYeP07JMK2Xn@JhcD806N;EMH01fWD00100A1l@EMSTnPKdcd80
h<e202l`eWETMP08000002D0000<00000`0004H000280000O00004M4BD<20000:040073moolk0@00
O?gooc00001W06D0KP1U0780H@1d06D0I00P0680N@0P05L0C@1602l0A@1=04H0801R0640H`1[06D0
KP1T0200K`1V0200L01c07@0K`1U06@0J@1d0000J@1^0700M@1d0000000S000080000<Q9]3l00000
000004T9^[nT20;6/mjDAR@0000T0000b4Vd?`0000000000B@Vj_j@80/JcgYA6100002<0000P0000
b4Vd?`0000000000B@Vj_j@80/JcgYA6900002@00038BK@o0000000000192KZoY0P2a[?NU4H40000
4P0000`0000100005P0000`0000H0000600000`000000000DP00070100040000>Oooo`0000000000
00000901000000001`020T<0C@1C05T0<@0`04l0DP1904L000000000000000000000000000000000
0000000000000000000000000000000010000<S:60000000200000L000000000SU<gMLS:600`bQP0
k;1300@000240000b<XH00000000000030000000000100008<XH000000240000X0l0008000030000
b<XH000000000000?<XH07nN@`3l2Uh0P<XH0000@`040000S[E309f>bIEXOUh08HQ6000000000000
00000040001<bQP002m:00c;603PW480CF2FUOkoool004<0gKE306QnGP000000001N06QnGP38bQP0
0@0003P07P0;0000b<XH06QnGP010`00/7eN0040001POUh0I7H02000000U0000300000@0001D0000
E00002@000190000`P0003l200010000Zj[Q?ag7hKl^5`00JS800040001<00000000000000000000
oooooooooom@0000A@0006@0000H000030000000001B0000L04000D0000D00002@00000000000000
_080000000070P8RD`1i07<0M01U06d000000000003R0000000006bDR`:0n?oo0000000000000000
0000052DR`:0n?oo^YH00000eWFgI=IeMR8QW`00000000000@000<3d0POPc480HFCFMGHR8Il00000
000005@000000000`?@21eS=@P3NDMIeMR8QWgRco`H20000D63I2E@0000000000@0003P07P0;0000
b<XH06QnGP010`00/7eN0040001POUh000002000002E80EY000005S=@P0_<=IeF<e206H`eWDT@]P7
f>Cj1RD0000000X001@008c>@P0MnREdMR8QW`00o`K0m0870P00051Pf@Vb2RId00SJM@0000002=Ye
P07JMCQ2f0N`cD80;c3FMK3=@P1V<=IeQ4;H1mSTnPITMP08000002D0000<00001@0002P0000<0000
10000580001`0@00100007Goool0000000000000002@0@00000000L00P9304d0DP0g000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000o000o
100000800010eVD0b<XH0000000K03h0M05S0000001@0F<0F0=;0000@`0PdVD0`7]U000000040000
000005`100400000800000000@5DbAP0S><YMhc:603eLBigI:Y>1_kooonZ>2YgXS@ZM`00000006D0
8=9U09DP2SX000006=9U09c:602:DgMe001S0000002QE7Me;]G9UIDP2SXPdVD0P07JM@26GP1804/0
001;06S:602E80XjQ<`H001`NGFRU:SPo_oooj5DMgD54]Ie8=9U0<15IP0_4B58000:0<15IP3DbQP0
G3WFMFAf00P000009@0000`000040000E00005@0003C00006`0002P1003U00000@000:^ZhClMan6o
ZQL00;`b00010000C00000000000000000000?ooooooooooD00002P0000l0000600000`000000000
9@0000`000050000:00000`000040000DP00070100040000MOooo`00000000000000090100000000
1`020T<0C@1=04T0=`00000000000000000000000000000000000000000000000000000000000000
0000000000000000000003l003l40000E<TH043FI@2<bQP0mG4^Ma/0?P1d0F<000000501H`1H0d/0
001U023BI@30NfD0000000@000000000G0400@00000P000000010EC960000000S<XH0?Ea;WMTZTh6
o_ooojXh:WNR=2Yg00000000I@0PdVD0UB0:>`00000HdVD0W<XH08YCMgD006<000000:5DMgD^eLVE
UB0:>b3BI@200MYe000004P0B`0004/0J<XH09DP2S^4c1P0071iMJ:DZ>3nooooXEAgM@DBeWDPdVD0
`4EV02lA8DP000X0`4EV0=C:601L>MIeI7H02000000U0000300000@0001D0000E00002X1000K0000
]`400>D000010000Zj[Q?ag7hKoX5`00_3800040001<00000000000000000000oooooooooom@0000
KP0006@0000H000030000000000U0000300000D0000X0000300000@0001B0000L04000@0001eoooo
0000000000000000T040000000070082@`1=0580=`00000000000000000000000000000000000000
000000000000000000000000000000000000000000000000?`00?`@0001DbAP0@=IU08c:603eLBig
6`0n07@1H`000000D05S05P3B`0006D08=9U0<1kI@00000010000000001L0@010000020000000041
E<TH0000002<bQP0mG4^MfBZCPKnooooZSPZMj8d:WL00000001U023BI@2E80Xl000001SBI@2LbQP0
RU=gM@00H`000000XEAgMBkEbIFE80Xl8=9U0801fWD00000B01;0000B`1XbQP0UB0:?8C<6000L7Ue
XYBXh?kooonQE7Me1A;FMB3BI@30AFH0;a4QB0002P30AFH0e<XH05`ieWETMP08000002D0000<0000
100005@0001D0000]04001/000090P00i@000040002[Z^4o7LOQ_dXH002l<P000@0004`000000000
00000000003ooooooooooe00000Y02`j?00002D0000<00001@0002P0000<0000100004H0000D0000
200004M4BD<300008P0000`0003ooooo8P0000`0003ooooo9@0000`0000=0020:00000`000030000
:00000`0000500008P0000`0003oooooAP000<01002d0@00ADe6:ba0000T000060000000P3l00000
00000000P3l000200000P2Y0000T000060000;5feT400000000008T1eT5lWOO5H@29ARA0000<0000
000002Y0000T000060000;02;3X0000000000;02;3X00;:X001?ZB]0000<0000000001i01P0<0000
000002501@0<0000000000Q00P@H00003000008@`=/000000`0043A00P0<0000000001i02@0<0000
000002Y0000T000060000;02;3X0000000000;02;3X00;:X001?ZB501`0<0000000002Y0000T0000
60000;02;3X0000000000;02;3X00;:X001?ZB]0000<0000000002]0000<0000000001i01P0<0000
000002501@0<0000000000Q00`@H00003000008@`=/000000`0043A00`0<0000000001i02@0<0000
000002Y0000T000060000000P3l0000000000000P3l00000000002501`0<0000000004`0001T0000
00000000000K0P00@`40000000000000708004@1000Y0:X0000000000000080o000000000000080o
0000000000000000000000000000000000000000000R000030000?oooom60000700001000015CDH[
0T0000`0000000003P0001@000000000400001@0
\>"], "Graphics",
  GeneratedCell->False,
  CellAutoOverwrite->False,
  ImageSize->{31.37500000000003, 18.76635514018691},
  ImageMargins->{{0., 0.}, {0., 3.171728971962615}}],
 "=udif  is larger than fac1*tolerance and smaller than fac2*tolerance.  Here \
we use fac1=1/2 and fac2=2  [see Eq. (18)]"
}], "Text",
 CellChangeTimes->CompressedData["
1:eJxN0E0ow3EYB/C/DREHRYz9LRYmsjloVoy2ZJOkJg6SFsZIU2ozzZa8Rc04
KEJxmvdIOZhZaF53kJfWtJpFouZCKS8r9v2dHJ4+p+/z9H3Sm7oUKgZFUdzQ
wKeadNcPKyDJmWBfwfrkTlqRHJBodm5yoJ/nFsD32TsxFEY26ODDIaMHdjk/
HTDv1XYOreusWxjpuHiEdETRmyGk74nD7AvJjTmPhvNsZSI86LWlwBP+AA/e
ikdy4ah1mrheelQAGdVVIjgWt1EKRZl7RLVXroC2KXktPB72NcPgWmY7LD5c
cJPcsNYL24SGezip3/eTvRlhTGNIjvYrHLLetXHwwatnQ6t4vxCe0VIRpBqT
xPB6XE6MCo+Vwk67rA6WOKe7YfaSUAvnZB8GaG6ljdCvcwyRe6ero5Dbvz0D
LW/PxBpL5SVUqjzEFYHOA3uXqTtY9i3rmEP/TzWRny8J7v5To7G32PBvV7wK
OoKmPtiftGiEG78Vg5BjniXq569XEuiApHwqaxWaUl82YVqzbwv+AZL8+bU=

  "],
 Background->RGBColor[1, 1, 0.85]],

Cell[BoxData[
 RowBox[{
  RowBox[{"Delta0Predictive", "=", "0.01"}], ";", 
  RowBox[{"DeltatcapPredictive", "=", 
   RowBox[{"10.", "^", "6"}]}], ";", 
  RowBox[{"omegaParameter", "=", "0.5"}], ";", 
  RowBox[{"thetaParameter", "=", 
   RowBox[{"3.", "/", "2."}]}], ";", " ", 
  RowBox[{"fac1", "=", "0.5"}], ";", " ", 
  RowBox[{"fac2", "=", "2."}], ";"}]], "Input",
 CellChangeTimes->{{3.5890056888389997`*^9, 3.589005735523*^9}, {
   3.589006714939*^9, 3.589006717499*^9}, {3.589006865347*^9, 
   3.589006866027*^9}, {3.589007532692*^9, 3.589007535075*^9}, {
   3.589007652124*^9, 3.589007676123*^9}, 3.637239609324768*^9, {
   3.63723983839587*^9, 3.637239842092082*^9}, {3.637240778415636*^9, 
   3.6372407925054426`*^9}, {3.637240846126509*^9, 3.6372408712149444`*^9}, 
   3.6372429272645435`*^9, {3.637246709824894*^9, 3.6372467457729497`*^9}, {
   3.6373039638002996`*^9, 3.6373039691583*^9}, {3.6373282593045807`*^9, 
   3.637328259879613*^9}, {3.6373284233339624`*^9, 3.6373284240130014`*^9}, {
   3.6373289974458*^9, 3.637329000444971*^9}, {3.6373291494844956`*^9, 
   3.6373291500105257`*^9}, {3.6373291825553875`*^9, 3.637329184387492*^9}, 
   3.6373675926676393`*^9, 3.6373678873594947`*^9},
 Background->RGBColor[1, 1, 0.85]]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"uMsolutionPredictive", "[", 
   RowBox[{"numpasos_", ",", "tolerance_"}], "]"}], ":=", 
  RowBox[{"(", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Umatrix", "=", 
     RowBox[{"{", "}"}]}], ";", 
    RowBox[{"Umatrix", "=", 
     RowBox[{"AppendTo", "[", 
      RowBox[{"Umatrix", ",", "UmatrixIni"}], "]"}]}], ";", 
    "\[IndentingNewLine]", 
    RowBox[{"ht", "=", "Delta0Predictive"}], ";", " ", "\[IndentingNewLine]", 
    RowBox[{"Do", "[", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"usingle", "=", 
        RowBox[{"U1stepMatrixt", "[", "m", "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"uhalf", "=", 
        RowBox[{"U2stepsMatrixt", "[", "m", "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"udif", "=", 
        RowBox[{"Max", "[", 
         RowBox[{"Abs", "[", 
          RowBox[{"usingle", "-", "uhalf"}], "]"}], "]"}]}], ";", 
       "\[IndentingNewLine]", 
       StyleBox["\t",
        Background->RGBColor[0.88, 1, 0.88]], 
       RowBox[{
        StyleBox["While",
         Background->RGBColor[0.88, 1, 0.88]], 
        StyleBox["[",
         Background->RGBColor[0.88, 1, 0.88]], 
        StyleBox["\t",
         Background->RGBColor[0.88, 1, 0.88]], 
        RowBox[{
         StyleBox[
          RowBox[{
           RowBox[{"ht", "<", "DeltatcapPredictive"}], "&&", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"udif", "<", 
              RowBox[{"fac1", "*", "tolerance"}]}], "||", 
             RowBox[{"udif", ">", 
              RowBox[{"fac2", "*", "tolerance"}]}]}], ")"}]}],
          Background->RGBColor[0.88, 1, 0.88]], 
         StyleBox[",",
          Background->RGBColor[0.88, 1, 0.88]], 
         StyleBox["\t",
          Background->RGBColor[0.88, 1, 0.88]], 
         RowBox[{
          RowBox[{
           StyleBox["ht",
            FontColor->GrayLevel[0]], 
           StyleBox["=",
            FontColor->RGBColor[1, 0, 0],
            Background->RGBColor[0.88, 1, 0.88]], 
           StyleBox[
            RowBox[{
             RowBox[{
              RowBox[{"(", 
               RowBox[{"1.", "-", "omegaParameter"}], ")"}], "*", "ht"}], "+", 
             RowBox[{"omegaParameter", "*", "ht", "*", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{"tolerance", "/", "udif"}], ")"}], "^", 
               RowBox[{"(", 
                RowBox[{"1.", "/", "thetaParameter"}], ")"}]}]}]}],
            FontColor->GrayLevel[0],
            Background->RGBColor[0.88, 1, 0.88]]}], 
          StyleBox[";",
           FontColor->RGBColor[1, 0, 0],
           Background->RGBColor[0.88, 1, 0.88]], 
          StyleBox["  ",
           FontColor->RGBColor[1, 0, 0],
           Background->RGBColor[1, 1, 0]], "\[IndentingNewLine]", "\t", 
          RowBox[{"uhalf", "=", 
           RowBox[{"U2stepsMatrixt", "[", "m", "]"}]}], ";", 
          "\[IndentingNewLine]", "\t", 
          RowBox[{"usingle", "=", 
           RowBox[{"U1stepMatrixt", "[", "m", "]"}]}], ";", "\t", 
          "\[IndentingNewLine]", "\t", 
          RowBox[{"udif", "=", 
           RowBox[{"Max", "[", 
            RowBox[{"Abs", "[", 
             RowBox[{"usingle", "-", "uhalf"}], "]"}], "]"}]}], ";"}]}], 
        "\[IndentingNewLine]", "\t\t         ", "]"}], ";", 
       "\[IndentingNewLine]", " ", "\[IndentingNewLine]", 
       RowBox[{"Umatrix", "=", 
        RowBox[{"Append", "[", 
         RowBox[{"Umatrix", ",", 
          RowBox[{"U1stepMatrixt", "[", "m", "]"}]}], "]"}]}]}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"{", 
       RowBox[{"m", ",", "1", ",", "numpasos"}], "}"}]}], "]"}], ";", 
    "\[IndentingNewLine]", 
    RowBox[{"htVariableUltimo", "=", "ht"}], ";", "\[IndentingNewLine]", 
    "Umatrix"}], "\[IndentingNewLine]", ")"}]}]], "Input",
 CellChangeTimes->{{3.5611175304854*^9, 3.5611178158406*^9}, {
   3.5611178594114*^9, 3.5611180036802*^9}, {3.5611180779986*^9, 
   3.5611180850810003`*^9}, {3.561118140774*^9, 3.5611182677072*^9}, {
   3.5611183022455997`*^9, 3.561118506824*^9}, 3.5611185494119997`*^9, {
   3.5611187160044003`*^9, 3.5611187284688*^9}, {3.5611189629368*^9, 
   3.5611190066792*^9}, {3.5611192326608*^9, 3.5611192925959997`*^9}, {
   3.5611195041174*^9, 3.5611195293114*^9}, {3.5611195729758*^9, 
   3.5611196111802*^9}, {3.5611196647974*^9, 3.5611196823006*^9}, {
   3.5611197142338*^9, 3.5611197383982*^9}, {3.5611198172562*^9, 
   3.5611198918554*^9}, {3.561119935707*^9, 3.5611199664858*^9}, {
   3.5611200243929996`*^9, 3.561120028683*^9}, 3.561120065889*^9, {
   3.561120213309*^9, 3.5611202301414003`*^9}, {3.5611203336474*^9, 
   3.5611203397469997`*^9}, 3.561120462519*^9, {3.5611205206914*^9, 
   3.561120537009*^9}, {3.5611205826858*^9, 3.5611206541026*^9}, 
   3.5611208318968*^9, 3.561121233816*^9, {3.5611212722076*^9, 
   3.5611212728784*^9}, {3.5611215947298*^9, 3.5611216368688*^9}, {
   3.5611216735738*^9, 3.5611216737808*^9}, {3.5611217371108*^9, 
   3.5611217609318*^9}, {3.5611219140168*^9, 3.5611219264628*^9}, 
   3.5611219569968*^9, 3.5611221823638*^9, {3.5611222751916*^9, 
   3.5611222764248*^9}, {3.561122309192*^9, 3.5611223095352*^9}, {
   3.5611259517696*^9, 3.5611259534116*^9}, {3.5611260219376*^9, 
   3.5611260223566*^9}, {3.5611270933666*^9, 3.5611271943246*^9}, {
   3.5611273344718*^9, 3.5611273351118*^9}, {3.589005766587*^9, 
   3.589005894926*^9}, {3.589006162262*^9, 3.589006162454*^9}, 
   3.5892700971210003`*^9, {3.5892701887939997`*^9, 3.589270219929*^9}, {
   3.5892703487130003`*^9, 3.589270350273*^9}, {3.5892715239379997`*^9, 
   3.5892715344820004`*^9}, {3.5892935891779194`*^9, 3.589293596585343*^9}, 
   3.589468754893317*^9, {3.5894768836969767`*^9, 3.5894768953379927`*^9}, {
   3.5896346890004*^9, 3.5896346897104*^9}, 3.5896393245794*^9, {
   3.5903880217724*^9, 3.5903880297883997`*^9}, {3.5903881932214003`*^9, 
   3.5903881957094*^9}, {3.5917031302775364`*^9, 3.591703173184991*^9}, 
   3.599063524271947*^9, {3.5990640369232693`*^9, 3.5990640842579765`*^9}, {
   3.5990646909456773`*^9, 3.599064750134063*^9}, {3.5990647974607697`*^9, 
   3.599064801538003*^9}, {3.599064896400429*^9, 3.5990649227409353`*^9}, {
   3.601901114664*^9, 3.601901123758*^9}, {3.601908552032*^9, 
   3.601908565366*^9}, 3.601909730429*^9, {3.601910300991*^9, 
   3.601910335111*^9}, {3.601915562743327*^9, 3.6019156016505523`*^9}, {
   3.60191582819951*^9, 3.6019158318597193`*^9}, {3.6369865753183813`*^9, 
   3.6369865842438917`*^9}, {3.636991855540393*^9, 3.6369918594166145`*^9}, {
   3.637004766589452*^9, 3.6370047946980596`*^9}, 3.637004923298415*^9, {
   3.637004961042574*^9, 3.637004976203441*^9}, {3.637005010243388*^9, 
   3.6370050222000723`*^9}, {3.6372379943488607`*^9, 
   3.6372379943678617`*^9}, {3.6372380698721805`*^9, 3.6372380843630095`*^9}, 
   3.637239599657215*^9, 3.637239845582281*^9, {3.637240210740167*^9, 
   3.637240210749168*^9}, {3.637240509268242*^9, 3.637240515292587*^9}, {
   3.6372407724402947`*^9, 3.6372407740793886`*^9}, {3.6372408313346634`*^9, 
   3.637240852068849*^9}, {3.63724088477372*^9, 3.637240923912958*^9}, {
   3.6372420894196215`*^9, 3.6372420934678535`*^9}, 3.6372422096705*^9, {
   3.6372475724342318`*^9, 3.63724758726408*^9}, 3.6373675926736393`*^9, 
   3.637367897665084*^9, 3.6386019264676*^9},
 Background->RGBColor[0.88, 1, 0.88]]
}, Open  ]]
}, Open  ]],

Cell[" ", "Text",
 CellChangeTimes->{{3.6373024057792997`*^9, 3.6373024248943*^9}}],

Cell[CellGroupData[{

Cell[TextData[{
 "Example 1\n",
 Cell[GraphicsData["Metafile", "\<\
CF5dJ6E]HGAYHf4PEfU^I6mgLb15CDHPAVmbKF5d0@0009T<0@0006`0003oooooooooobX5000g0P00
0000000000375@00G0T00215CDH0004039T003<1000700000000000000000000HA<006PK003B0000
:@400000000000000000050d0`0XR0@0AP0002`0000P0000ADe6:`500@0L00004000008@`=/00000
F08005P200160000O04007010015CDH[7T0500`0000000007d0300`000000000<402010000040000
0020?b501`0<000000000290100<0000000002Y0000T000060000000P3l0000000000000P3l00000
000002]0000<0000000001i01P0<0000000002501@0<0000000001i02@0<0000000002Y0000T0000
60000000P3l0000000000000P3l00000000002501`0<0000000002Y0000T000060000;02;3X00000
00000;02;3X0`7S4081aaB]0000<0000000002Y0000T000060000;02;3X0000000000;02;3X0`7S4
081aaB]0000<0000000002Y0000T000060000;02;3X0000000000;02;3X007VX001bZ@Y0080T0000
60000?ooool10000000000000030<OE9`?IBBB4000080000HP0000`000010000900002@00000080m
000000000000080m00000000000200009`0001P00001000000000?ooo`0000009@0000`000010000
9@0000`000080020EP000300003oooooooooobH5000g0P001@000?Son?ohofPSF59X8eQBn?ohooSo
9@0000`0000700209@0000`000000020900002@00000081100000000000008110000000000020000
AP0002a8000PB000ADe6:b]0000<0000000001i01P0<0000000002501@0<0000000001i02@0<0000
000002Y0000T000060000;02;3X0000000000;02;3X007VX001bZB501`0<0000000002]0000<0000
000002Y0000T00006000061o94400000000002bK946Y=A_53bo@ABA0100<0000000000Q000DLA`00
44L0008@`=/200000`00001700010000c0000?<0001ioOooL@400:gmoom58@00a:KoolXb000i[_oo
84E=AP000@00A`00oP0000@0000`0000K000000000201`00>0@00:D2001m0@000000000000000000
eED:04S@1@1W06D0KP1U0780H@1d06D0I00P0680N@0P05L0C@1602l0A@1=04H0801R0640H`1[06D0
KP1T0200K`1V0200L01c07@0K`1U06@0J@1d0000J@1^0700M@1d0000000A0000300000H0000:0000
40000000000000004P0000`0000100005P0000`0000H0000600000`000000000DP00070100010000
>Oooo`0000000000000009010000000000020T<0C@1=04T0<@0`0000000000000000000000000000
00000000000000000000000000000000000000000000000010000<S:60000000200000L000000000
SU<gMLS:600`bQP0k;1300@000240000b<XH00000000000030000000000100008<XH000000240000
X0l0008000030000b<XH000000000000?<XH07nN@`3l2R`0P<XH0000@`040000S[E3060gg>UXOR`0
8HQ600000000000000000040001<bQP002m:00c;603PW480/=V3jOkoool004<0gKE306Qn;0000000
000/06Qn;038bQP00@0003P07P0;0000b<XH06Qn;0010`00/7d/0040001POR`0I7H02000000U0000
30000040001D0000E0000?@0001joOoonP0008Cmool10000Zj[Q?ag7hKl:4`00fc400040001<0000
0000000000000000oooooooooom@0000@00006@0000H000030000000000U0000300000d0080X0000
30000040001B0000L0400040001eoooo0000000000000000T040000000000082@`1=04d0B@0g0000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
?`00?`@000020000@=IQ0<S:600000006`0n07@1G`000000D05O05P3B`0004<08=9Q0<1kH@000000
10000000001L0@010000020000000041E<TH08cS:GN<bQP0mG4^MoafK@KnooooZSPZMj8d:WL00000
001Q023BH@2V5PZ3000001SBH@2LbQP0RU=gM@00G`000000XEAgMM6hgnVV5PZ38=9Q0801fWD0QR`0
B01;0000B`1XbQP0YQH:PhC<6000L7UeGOVnW?kooonQE7Me1A;FMB3BH@30AF805QDQ?P002P30AF80
e<XH05`ieWETMP08000002D0000<00000@0005@0001D0000nP0007Wmooon0000Oogoo`40002[Z^4o
7LOQ_glC000S<P000@0004`00000000000000000003ooooooooooe00002`0000D00001P0000<0000
000002D0000<00003@00P2P0000<00000@000580001`0@000@0003Woool0000000000000002@0@00
000000000P9304d0C@190340<0000000000000000000000000000000000000000000000000000000
000000000000000000000000000o000o100005C96010eV40S<XH0?Ea;WLK03h0M05O0000001@0El0
F0=;0000H@0PdV40`7]Q000000040000000005`100400000800000000@5DbAP0000008c:603eLBig
o7I]1_kooonZ>2YgXS@ZM`00000006408=9Q0:HF2X@000006=9Q09c:602:DgMe001O0000002QE7Me
dKSOjJHF2X@PdV40P07JM@00001804/0001;06S:602V5PZ4Q<`H001`NGEMnKjLo_oooj5DMgD54]Ie
8=9Q0<15HP0F5B4n000:0<15HP3DbQP0G3WFMFAf00P000009@0000`000010000E00005@0003o0000
N_goo`D10024oOoo0@000:^ZhClMan6oiA<00=/a00010000C00000000000000000000?oooooooooo
D00007D0001h00009P0001`0000200000000000000000000000002D0000<00000P0002L0000H0000
0`00000000000000000002D0000<00000`0001<0000<00000P0005/0000h0000m00008Kmool50@00
Q_goo`40000500001@00010CR35N58PaGQB@<A0CT34@4hPa600000`000000000E00005@0003e0000
Qogooo/0002AoOoo0@000:^ZhClMan6o81<00<``00010000C00000000000000000000?oooooooooo
D0000400001T0000600000`000000000E00005@0003k0000Qogoool0002AoOoo0@000:^ZhClMan6o
U1<00<``00010000C00000000000000000000?ooooooooooD00007@0001@0000600000`000000000
9@0000`0000=0020:00000`000010000DP00070100010000MOooo`00000000000000090100000000
00020T<0C@1=04T0=`00000000000000000000000000000000000000000000000000000000000000
0000000000000000000003l003l4000005]I043FH@0@@2`0j00001/0?P1d0El000000501G`1H0d/0
>04/023BH@1P3f80000000@000000000G0400@00000P000000010EC960000000S<XH0?Ea;WOlMVd6
o_ooojXh:WNR=2Yg00000000H@0PdV40YQH:Q@00000HdV40W<XH08YCMgD005l000000:5DMgGA^=oY
YQH:QB3BH@200MYe2P000>RM;00002`0J<XH0:HF2XF4c1P0071iMEgi_YcnooooXEAgM@DBeWDPdV40
`4ER01HE8Ch000X0`4ER0=C:601L>MIeI7H02000000U000030000040001D0000E0000?h00028oOoo
0P4008kmool10000Zj[Q?ag7hKoL4`001S400040001<00000000000000000000oooooooooom@0000
/0000500000H000030000000000U0000300000d0080X000030000040001B0000L0400040000ioooo
0000000000000000T040000000000082@`1=0580<@0`000000000000000000000000000000000000
000000000000000000000000000000000000000000000000?`00?`@0001DbAP0@=IQ08c:603eLBig
6`0n07@1G`000000D05O05P3B`0006408=9Q060?HP00000010000000001L0@010000020000000041
E<TH0000002<bQP0mG4^MoafK@KnooooZSPZMj8d:WL00000001Q023BH@2V5PZ6000001SBH@2LbQP0
RU=gM@00G`000000XEAgMM6hgnVV5PZ68=9Q0801fWD00000j9d/0000;01XbQP0YQH:QXC<6000L7Ue
GOVnW?kooonQE7Me1A;FMB3BH@30AF805QDQ?P002P30AF80e<XH05`ieWETMP08000002D0000<0000
0@0005@0001D00002040087mool@0@00Rogoo`40002[Z^4o7LOQ_jHD001E<@000@0004`000000000
00000000003ooooooooooe00000m0000X00001P0000<0000000002D0000<00003@00P2P0000<0000
0@000580001`0@000@0003Woool0000000000000002@0@00000000000P9304d0C@190340<0000000
000000000000000000000000000000000000000000000000000000000000000000000000000o000o
100005C96010eV40S<XH0?Ea;WLK03h0M05O0000001@0El0F0=;0000H@0PdV40H0mR000000040000
000005`100400000800000000@5DbAP0000008c:603eLBigo7I]1_kooonZ>2YgXS@ZM`0000000640
8=9Q0:HF2XL000006=9Q09c:602:DgMe001O0000002QE7MedKSOjJHF2XLPdV40P07JM@00003XWB`0
000/06S:602V5PZ7Q<`H001`NGEMnKjLo_oooj5DMgD54]Ie8=9Q0<15HP0F5B4n000:0<15HP3DbQP0
G3WFMFAf00P000009@0000`000010000E00005@0000D0@00N_gooaX10024oOoo0@000:^ZhClMan6o
TAD00=/a00010000C00000000000000000000?ooooooooooD0000400001T0000600000`000000000
9@0000`0000=0020:00000`000010000DP00070100010000MOooo`00000000000000090100000000
00020T<0C@1B03L00000000000000000000000000000000000000000000000000000000000000000
0000000000000000000003l003l40000E<TH043FH@2<bQP0mG4^Ma/0?P1d0El000000501G`1H0d/0
001Q023BH@1P3f80000000@000000000G0400@00000P000000010EC960000000S<XH0?Ea;WOlMVd6
o_ooojXh:WNR=2Yg00000000H@0PdV40YQH:R000000HdV40W<XH08YCMgD005l000000:5DMgGA^=oY
YQH:R23BH@200MYe00000>RM;00002`0J<XH0:HF2XR4c1P0071iMEgi_YcnooooXEAgM@DBeWDPdV40
`4ER01HE8Ch000X0`4ER0=C:601L>MIeI7H02000000U000030000040001D0000E00001X1001ioOoo
7P4007omool10000Zj[Q?ag7hKl65P008c800040001<00000000000000000000oooooooooom@0000
<P000500000H000030000000000U0000300000d0080X000030000040001B0000L0400040000ioooo
0000000000000000T040000000000082@`1=04d0B@0a030000000000000000000000000000000000
000000000000000000000000000000000000000000000000?`00?`@0001DbAP0@=IQ08c:603eLBig
6`0n07@1G`000000D05O05P3B`0006408=9Q060?HP00000010000000001L0@010000020000000041
E<TH0000002<bQP0mG4^MoafK@KnooooZSPZMj8d:WL00000001Q023BH@2V5PZ9000001SBH@2LbQP0
RU=gM@00G`000000XEAgMM6hgnVV5PZ98=9Q0801fWD00000j9d/0000;01XbQP0YQH:RHC<6000L7Ue
GOVnW?kooonQE7Me1A;FMB3BH@30AF805QDQ?P002P30AF80e<XH05`ieWETMP08000002D0000<0000
0@0005@0001D00007P4007[moolT0@00Q?goo`40002[Z^4o7LOQ_ehF003K<@000@0004`000000000
00000000003ooooooooooe00001e0000N00002D0000<00001`00P2P0000<00000P0002H0000L0000
0P0000000000000000000000000U000030000080000U000030000000080X0000300000<0000W0000
600000<00000000000000000000U0000300000<0000C000030000080001K0000>00001@10026oOoo
904008Kmool100001@0000D0002@5HPad1J8<M0FT36@5I0aT1F8<AP0000<0000000005@0001D0000
504008OmoolJ0@00TOgoo`40002[Z^4o7LOQ_i4E003<<0000@0004`00000000000000000003ooooo
oooooe0000100000I00001P0000<0000000005@0001D00006P4008OmoolP0@00TOgoo`40002[Z^4o
7LOQ_`HF003<<0000@0004`00000000000000000003ooooooooooe00001h0000N00001P0000<0000
000002D0000<00003@00P2P0000<00000@000580001`0@000@0007Goool0000000000000002@0@00
000000000P9304d0DP0g000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000o000o1000001KF@10eV40440/0>P0000K03h0M05O0000001@0El0
F0=;03P1;00PdV40H0mR000000040000000005`100400000800000000@5DbAP0000008c:603eLBig
o7I]1_kooonZ>2YgXS@ZM`00000006408=9Q0:HF2XX000006=9Q09c:602:DgMe001O0000002QE7Me
dKSOjJHF2XXPdV40P07JM@X0003XWB`0000/06S:602V5PZ:Q<`H001`NGEMnKjLo_oooj5DMgD54]Ie
8=9Q0<15HP0F5B4n000:0<15HP3DbQP0G3WFMFAf00P000009@0000`000010000E00005@0000P0@00
R?goob@1002>oOoo0@000:^ZhClMan6oN1H000Ha00010000C00000000000000000000?oooooooooo
D0000380001@0000600000`0000000009@0000`0000=0020:00000`000010000DP00070100010000
>Oooo`0000000000000009010000000000020T<0C@1=04T0<@0`0000000000000000000000000000
000000000000000000000000000000000000000000000000000003l003l40000E<TH043FH@2<bQP0
mG4^Ma/0?P1d0El000000501G`1H0d/0001Q023BH@1P3f80000000@000000000G0400@00000P0000
00010EC960000000S<XH0?Ea;WOlMVd6o_ooojXh:WNR=2Yg00000000H@0PdV40YQH:R`00000HdV40
W<XH08YCMgD005l000000:5DMgGA^=oYYQH:Rb3BH@200MYe00000>RM;00002`0J<XH0:HF2X^4c1P0
071iMEgi_YcnooooXEAgM@DBeWDPdV40`4ER01HE8Ch000X0`4ER0=C:601L>MIeI7H02000000U0000
30000040001D0000E00002D10021oOoo:04008_mool10000Zj[Q?ag7hKoX5P00EC400040001<0000
0000000000000000oooooooooom@0000>`0003`0000H000030000000000U0000300000d0080X0000
30000040001B0000L0400040000ioooo0000000000000000T040000000000082@`1=0580<@0`0000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
?`00?`@0001DbAP0@=IQ08c:603eLBig6`0n07@1G`000000D05O05P3B`0006408=9Q060?HP000000
10000000001L0@010000020000000041E<TH0000002<bQP0mG4^MoafK@KnooooZSPZMj8d:WL00000
001Q023BH@2V5PZ<000001SBH@2LbQP0RU=gM@00G`000000XEAgMM6hgnVV5PZ<8=9Q0801fWD00000
j9d/0000;01XbQP0YQH:S8C<6000L7UeGOVnW?kooonQE7Me1A;FMB3BH@30AF805QDQ?P002P30AF80
e<XH05`ieWETMP08000002D0000<00000@0005@0001D0000=040087mooli0@00Rogoo`40002[Z^4o
7LOQ_`PH001E<@000@0004`00000000000000000003ooooooooooe00000`0000I00001P0000<0000
000002D0000<00003@00P2P0000<00000@000580001`0@000@0003Woool0000000000000002@0@00
000000000P9304d0D`1I0340<01?0580B@1700000000000000000000000000000000000000000000
000000000000000000000000000o000o100005C96010eV40S<XH0?Ea;WLK03h0M05O0000001@0El0
F0=;0000H@0PdV40H0mR000000040000000005`100400000800000000@5DbAP0000008c:603eLBig
o7I]1_kooonZ>2YgXS@ZM`00000006408=9Q0:HF2Xd000006=9Q09c:602:DgMe001O0000002QE7Me
dKSOjJHF2XdPdV40P07JM@00003XWB`0000/06S:602V5PZ=Q<`H001`NGEMnKjLo_oooj5DMgD54]Ie
8=9Q0<15HP0F5B4n000:0<15HP3DbQP0G3WFMFAf00P000009@0000`000010000E00005@0000k0@00
POgood<1002BoOoo0@000:^ZhClMan6oXaP005Da00010000C00000000000000000000?oooooooooo
D0000;L0002P0000600000`0000000009@0000`0000=0020:00000`000010000DP00070100010000
>Oooo`0000000000000009010000000000020T<0C@1=04T0<@0`0000000000000000000000000000
000000000000000000000000000000000000000000000000000003l003l40000E<TH043FH@2<bQP0
mG4^Ma/0?P1d0El000000501G`1H0d/0001Q023BH@1P3f80000000@000000000G0400@00000P0000
00010EC960000000S<XH0?Ea;WOlMVd6o_ooojXh:WNR=2Yg00000000H@0PdV40YQH:SP00000HdV40
W<XH08YCMgD005l000000:5DMgGA^=oYYQH:SR3BH@200MYe00000>RM;00002`0J<XH0:HF2Xj4c1P0
071iMEgi_YcnooooXEAgM@DBeWDPdV40`4ER01HE8Ch000X0`4ER0=C:601L>MIeI7H02000000U0000
30000040001D0000E00004H10021oOooC04008_mool10000Zj[Q?ag7hKmf6@00EC400040001<0000
0000000000000000oooooooooom@0000N00007P0000H000030000000000U0000300000d0080X0000
30000040001B0000L0400040000ioooo0000000000000000T040000000000082@`1=05<0F@0a0300
C`1B04T0A`0000000000000000000000000000000000000000000000000000000000000000000000
?`00?`@0001DbAP0@=IQ08c:603eLBig6`0n07@1G`000000D05O05P3B`0006408=9Q060?HP000000
10000000001L0@010000020000000041E<TH0000002<bQP0mG4^MoafK@KnooooZSPZMj8d:WL00000
001Q023BH@2V5PZ?000001SBH@2LbQP0RU=gM@00G`000000XEAgMM6hgnVV5PZ?8=9Q0801fWD00000
j9d/0000;01XbQP0YQH:ShC<6000L7UeGOVnW?kooonQE7Me1A;FMB3BH@30AF805QDQ?P002P30AF80
e<XH05`ieWETMP08000002D0000<00000@0005@0001D0000CP40087moomF0@00T_goo`40002[Z^4o
7LOQ_alJ001E<@000@0004`00000000000000000003ooooooooooe00002g0000X00001P0000<0000
000002D0000<00003@00P2P0000<00000@000580001`0@000@0003Woool0000000000000002@0@00
000000000P9304d0C@190340<0000000000000000000000000000000000000000000000000000000
000000000000000000000000000o000o100005C96010eV40S<XH0?Ea;WLK03h0M05O0000001@0El0
F0=;0000H@0PdV40H0mR000000040000000005`100400000800000000@5DbAP0000008c:603eLBig
o7I]1_kooonZ>2YgXS@ZM`00000006408=9Q0:HF2Y0000006=9Q09c:602:DgMe001O0000002QE7Me
dKSOjJHF2Y0PdV40P07JM@00003XWB`0000/06S:602V5PZ@Q<`H001`NGEMnKjLo_oooj5DMgD54]Ie
8=9Q0<15HP0F5B4n000:0<15HP3DbQP0G3WFMFAf00P000009@0000`000010000E00005@0001I0@00
POgooel1002;oOoo0@000:^ZhClMan6olAX005Da00010000C00000000000000000000?oooooooooo
D0000;`0001h0000600000`000000000E00005@0001O0@00POgoof81002;oOoo0@000:^ZhClMan6o
JQ/005Da00010000C00000000000000000000?ooooooooooD00003/0000l0000600000`000000000
E00005@0003c0000U?goooT0002NoOoo0@000:^ZhClMan6olQ800=D_00010000C000000000000000
00000?ooooooooooD00007D0001h0000600000`0000000009@0000`0000=0020:00000`000010000
DP00070100010000>Oooo`0000000000000009010000000000020T<0C@1B0340<000000000000000
0000000000000000000000000000000000000000000000000000000000000000000003l003l40000
E<TH043FH@2<bQP0mG4^Ma/0?P1d0El000000501G`1H0d/0001Q023BH@1P3f80000000@000000000
G0400@00000P000000010EC960000000S<XH0?Ea;WOlMVd6o_ooojXh:WNR=2Yg00000000H@0PdV40
YQH:T@00000HdV40W<XH08YCMgD005l000000:5DMgGA^=oYYQH:TB3BH@200MYe00000>RM;00002`0
J<XH0:HF2Y64c1P0071iMEgi_YcnooooXEAgM@DBeWDPdV40`4ER01HE8Ch000X0`4ER0=C:601L>MIe
I7H02000000U000030000040001D0000E0000?P0002DoOooo00009kmool10000Zj[Q?ag7hKmT4`00
eBl00040001<00000000000000000000oooooooooom@0000:0000500000H000030000000000U0000
300000d0080X000030000040001B0000L0400040000ioooo0000000000000000T040000000000082
@`1=04d0B@0a03000000000000000000000000000000000000000000000000000000000000000000
0000000000000000?`00?`@0001DbAP0@=IQ08c:603eLBig6`0n07@1G`000000D05O05P3B`000640
8=9Q060?HP00000010000000001L0@010000020000000041E<TH0000002<bQP0mG4^MoafK@Knoooo
ZSPZMj8d:WL00000001Q023BH@2V5PZB000001SBH@2LbQP0RU=gM@00G`000000XEAgMM6hgnVV5PZB
8=9Q0801fWD00000j9d/0000;01XbQP0YQH:TXC<6000L7UeGOVnW?kooonQE7Me1A;FMB3BH@30AF80
5QDQ?P002P30AF80e<XH05`ieWETMP08000002D0000<00000@0005@0001D0000o00009Cmool20@00
W_goo`40002[Z^4o7LOQ_k8C003E;`000@0004`00000000000000000003ooooooooooe00001h0000
N00001P0000<0000000002D0000<00003@00P2P0000<00000@000580001`0@000@0003Woool00000
00000000002@0@00000000000P9304d0DP0a03000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000o000o100005C96010eV40S<XH0?Ea;WLK03h0
M05O0000001@0El0F0=;0000H@0PdV40H0mR000000040000000005`100400000800000000@5DbAP0
000008c:603eLBigo7I]1_kooonZ>2YgXS@ZM`00000006408=9Q0:HF2Y<000006=9Q09c:602:DgMe
001O0000002QE7MedKSOjJHF2Y<PdV40P07JM@00003XWB`0000/06S:602V5PZCQ<`H001`NGEMnKjL
o_oooj5DMgD54]Ie8=9Q0<15HP0F5B4n000:0<15HP3DbQP0G3WFMFAf00P000009@0000`000010000
E00005@000050@00U?goo`d1002NoOoo0@000:^ZhClMan6oFQ@00=D_00010000C000000000000000
00000?ooooooooooD00003d0002P0000600000`000000000E00005@0000?0@00U?gooa@1002NoOoo
0@000:^ZhClMan6o;QD00=D_00010000C00000000000000000000?ooooooooooD0000300001T0000
600000`0000000009@0000`0000=0020:00000`000010000DP00070100010000>Oooo`0000000000
000009010000000000020T<0C@1=04T0<@0`00000000000000000000000000000000000000000000
00000000000000000000000000000000000003l003l40000E<TH043FH@2<bQP0mG4^Ma/0?P1d0El0
00000501G`1H0d/0001Q023BH@1P3f80000000@000000000G0400@00000P000000010EC960000000
S<XH0?Ea;WOlMVd6o_ooojXh:WNR=2Yg00000000H@0PdV40YQH:U000000HdV40W<XH08YCMgD005l0
00000:5DMgGA^=oYYQH:U23BH@200MYe00000>RM;00002`0J<XH0:HF2YB4c1P0071iMEgi_Ycnoooo
XEAgM@DBeWDPdV40`4ER01HE8Ch000X0`4ER0=C:601L>MIeI7H02000000U000030000040001D0000
E00001@1002DoOoo5`4009kmool10000Zj[Q?ag7hKnA5@00eBl00040001<00000000000000000000
oooooooooom@0000>`0003`0000H000030000000001D0000E00001T1002DoOoo7@4009kmool10000
Zj[Q?ag7hKoZ5@00eBl00040001<00000000000000000000oooooooooom@0000M0000500000H0000
30000000000U0000300000d0080X000030000040001B0000L0400040000ioooo0000000000000000
T040000000000082@`1=0580<@0`0000000000000000000000000000000000000000000000000000
00000000000000000000000000000000?`00?`@0001DbAP0@=IQ08c:603eLBig6`0n07@1G`000000
D05O05P3B`0006408=9Q060?HP00000010000000001L0@010000020000000041E<TH0000002<bQP0
mG4^MoafK@KnooooZSPZMj8d:WL00000001Q023BH@2V5PZE000001SBH@2LbQP0RU=gM@00G`000000
XEAgMM6hgnVV5PZE8=9Q0801fWD00000j9d/0000;01XbQP0YQH:UHC<6000L7UeGOVnW?kooonQE7Me
1A;FMB3BH@30AF805QDQ?P002P30AF80e<XH05`ieWETMP08000002D0000<00000@0005@0001D0000
704009CmoolP0@00W_goo`40002[Z^4o7LOQ_c8F003E;`000@0004`00000000000000000003ooooo
oooooe00000Y0000D00001P0000<0000000005@0001D00008`4009Cmool[0@00W_goo`40002[Z^4o
7LOQ_kHF003E;`000@0004`00000000000000000003ooooooooooe00000m0000X00001P0000<0000
000002D0000<00003@00P2P0000<00000@000580001`0@000@0003Woool0000000000000002@0@00
000000000P9304d0C@190340<0000000000000000000000000000000000000000000000000000000
000000000000000000000000000o000o100005C96010eV40S<XH0?Ea;WLK03h0M05O0000001@0El0
F0=;0000H@0PdV40H0mR000000040000000005`100400000800000000@5DbAP0000008c:603eLBig
o7I]1_kooonZ>2YgXS@ZM`00000006408=9Q0:HF2YH000006=9Q09c:602:DgMe001O0000002QE7Me
dKSOjJHF2YHPdV40P07JM@00003XWB`0000/06S:602V5PZFQ<`H001`NGEMnKjLo_oooj5DMgD54]Ie
8=9Q0<15HP0F5B4n000:0<15HP3DbQP0G3WFMFAf00P000009@0000`000010000E00005@0000]0@00
U?gooc<1002NoOoo0@000:^ZhClMan6oR1L00=D_00010000C00000000000000000000?oooooooooo
D00007D0001h0000600000`0000000009@0000`0000=0020:00000`000010000DP00070100010000
>Oooo`0000000000000009010000000000020T<0C@1B0340<0000000000000000000000000000000
000000000000000000000000000000000000000000000000000003l003l40000E<TH043FH@2<bQP0
mG4^Ma/0?P1d0El000000501G`1H0d/0001Q023BH@1P3f80000000@000000000G0400@00000P0000
00010EC960000000S<XH0?Ea;WOlMVd6o_ooojXh:WNR=2Yg00000000H@0PdV40YQH:U`00000HdV40
W<XH08YCMgD005l000000:5DMgGA^=oYYQH:Ub3BH@200MYe00000>RM;00002`0J<XH0:HF2YN4c1P0
071iMEgi_YcnooooXEAgM@DBeWDPdV40`4ER01HE8Ch000X0`4ER0=C:601L>MIeI7H02000000U0000
30000040001D0000E00003<1002DoOoo=`4009kmool10000Zj[Q?ag7hKoj5`00eBl00040001<0000
0000000000000000oooooooooom@0000:0000500000H000030000000000U0000300000d0080X0000
30000040001B0000L0400040000ioooo0000000000000000T040000000000082@`1=04d0B@0a0300
00000000000000000000000000000000000000000000000000000000000000000000000000000000
?`00?`@0001DbAP0@=IQ08c:603eLBig6`0n07@1G`000000D05O05P3B`0006408=9Q060?HP000000
10000000001L0@010000020000000041E<TH0000002<bQP0mG4^MoafK@KnooooZSPZMj8d:WL00000
001Q023BH@2V5PZH000001SBH@2LbQP0RU=gM@00G`000000XEAgMM6hgnVV5PZH8=9Q0801fWD00000
j9d/0000;01XbQP0YQH:V8C<6000L7UeGOVnW?kooonQE7Me1A;FMB3BH@30AF805QDQ?P002P30AF80
e<XH05`ieWETMP08000002D0000<00000@0005@0001D0000=`4009Cmoolm0@00W_goo`40002[Z^4o
7LOQ_dPH003E;`000@0004`00000000000000000003ooooooooooe00001h0000N00001P0000<0000
000002D0000<00003@00P2P0000<00000@000580001`0@000@0003Woool0000000000000002@0@00
000000000P9304d0DP0a030000000000000000000000000000000000000000000000000000000000
000000000000000000000000000o000o100005C96010eV40S<XH0?Ea;WLK03h0M05O0000001@0El0
F0=;0000H@0PdV40H0mR000000040000000005`100400000800000000@5DbAP0000008c:603eLBig
o7I]1_kooonZ>2YgXS@ZM`00000006408=9Q0:HF2YT000006=9Q09c:602:DgMe001O0000002QE7Me
dKSOjJHF2YTPdV40P07JM@00003XWB`0000/06S:602V5PZIQ<`H001`NGEMnKjLo_oooj5DMgD54]Ie
8=9Q0<15HP0F5B4n000:0<15HP3DbQP0G3WFMFAf00P000009@0000`000010000E00005@0000o0@00
U?goodL1002NoOoo0@000:^ZhClMan6olAP00=D_00010000C00000000000000000000?oooooooooo
D00003d0002P0000600000`0000000009@0000`0000=0020:00000`000010000DP00070100010000
>Oooo`0000000000000009010000000000020T<0C@1=04T0<@0`0000000000000000000000000000
000000000000000000000000000000000000000000000000000003l003l40000E<TH043FH@2<bQP0
mG4^Ma/0?P1d0El000000501G`1H0d/0001Q023BH@1P3f80000000@000000000G0400@00000P0000
00010EC960000000S<XH0?Ea;WOlMVd6o_ooojXh:WNR=2Yg00000000H@0PdV40YQH:VP00000HdV40
W<XH08YCMgD005l000000:5DMgGA^=oYYQH:VR3BH@200MYe00000>RM;00002`0J<XH0:HF2YZ4c1P0
071iMEgi_YcnooooXEAgM@DBeWDPdV40`4ER01HE8Ch000X0`4ER0=C:601L>MIeI7H02000000U0000
30000040001D0000E00004X1002DoOooD04009kmool10000Zj[Q?ag7hKo36@00eBl00040001<0000
0000000000000000oooooooooom@0000_00007P0000H000030000000001D0000E0000501002DoOoo
D`4009kmool10000Zj[Q?ag7hKlk6P00eBl00040001<00000000000000000000oooooooooom@0000
>`0003`0000H000030000000001D0000E00005@1002DoOooF04009kmool10000Zj[Q?ag7hKnD6P00
eBl00040001<00000000000000000000oooooooooom@0000M0000500000H000030000000000U0000
300000d0080X000030000040001B0000L0400040000ioooo0000000000000000T040000000000082
@`1=0580<@0`00000000000000000000000000000000000000000000000000000000000000000000
0000000000000000?`00?`@0001DbAP0@=IQ08c:603eLBig6`0n07@1G`000000D05O05P3B`000640
8=9Q060?HP00000010000000001L0@010000020000000041E<TH0000002<bQP0mG4^MoafK@Knoooo
ZSPZMj8d:WL00000001Q023BH@2V5PZK000001SBH@2LbQP0RU=gM@00G`000000XEAgMM6hgnVV5PZK
8=9Q0801fWD00000j9d/0000;01XbQP0YQH:VhC<6000L7UeGOVnW?kooonQE7Me1A;FMB3BH@30AF80
5QDQ?P002P30AF80e<XH05`ieWETMP08000002D0000<00000@0005@0001D0000F04009CmoomL0@00
W_goo`40002[Z^4o7LOQ_m`J003E;`000@0004`00000000000000000003ooooooooooe00000Y0000
D00001P0000<0000000005@0001D0000GP4009CmoomV0@00W_goo`40002[Z^4o7LOQ_f0K003E;`00
0@0004`00000000000000000003ooooooooooe00000m0000X00001P0000<0000000005@0001D0000
J@4009Cmoom^0@00W_goo`40002[Z^4o7LOQ_c<L003E;`000@0004`00000000000000000003ooooo
oooooe00000`0000I00001P0000<0000000002D0000<00003@00P2P0000<00000@000580001`0@00
0@0003Woool0000000000000002@0@00000000000P9304d0C@190340<00000000000000000000000
00000000000000000000000000000000000000000000000000000000000o000o100005C96010eV40
S<XH0?Ea;WLK03h0M05O0000001@0El0F0=;0000H@0PdV40H0mR000000040000000005`100400000
800000000@5DbAP0000008c:603eLBigo7I]1_kooonZ>2YgXS@ZM`00000006408=9Q0:HF2Y`00000
6=9Q09c:602:DgMe001O0000002QE7MedKSOjJHF2Y`PdV40P07JM@00003XWB`0000/06S:602V5PZL
Q<`H001`NGEMnKjLo_oooj5DMgD54]Ie8=9Q0<15HP0F5B4n000:0<15HP3DbQP0G3WFMFAf00P00000
9@0000`000010000E00005@0001^0@00U?goog41002NoOoo0@000:^ZhClMan6oUa`00=D_00010000
C00000000000000000000?ooooooooooD00003/0000l0000600000`000000000E00005@0003c0000
XogoooT0002]oOoo0@000:^ZhClMan6olQ800:X^00010000C00000000000000000000?oooooooooo
D00007D0001h0000600000`0000000009@0000`0000=0020:00000`000010000DP00070100010000
>Oooo`0000000000000009010000000000020T<0C@1B0340<0000000000000000000000000000000
000000000000000000000000000000000000000000000000000003l003l40000E<TH043FH@2<bQP0
mG4^Ma/0?P1d0El000000501G`1H0d/0001Q023BH@1P3f80000000@000000000G0400@00000P0000
00010EC960000000S<XH0?Ea;WOlMVd6o_ooojXh:WNR=2Yg00000000H@0PdV40YQH:W@00000HdV40
W<XH08YCMgD005l000000:5DMgGA^=oYYQH:WB3BH@200MYeY3`ZMm<l:WL005aaJ<XH0:HF2Yf4c1P0
071iMEgi_YcnooooXEAgM@DBeWDPdV40`4ER01HE8Ch000X0`4ER0=C:601L>MIeI7H02000000U0000
30000040001D0000E0000?P0002SoOooo0000:gmool10000Zj[Q?ag7hKmT4`00ZRh00040001<0000
0000000000000000oooooooooom@0000:0000500000H000030000000000U0000300000d0080X0000
30000040001B0000L0400040000ioooo0000000000000000T040000000000082@`1=04d0B@0a0300
00000000000000000000000000000000000000000000000000000000000000000000000000000000
?`00?`@0001DbAP0@=IQ08c:603eLBig6`0n07@1G`000000D05O05P3B`0006408=9Q060?HP000000
10000000001L0@010000020000000041E<TH0000002<bQP0mG4^MoafK@KnooooZSPZMj8d:WL00000
001Q023BH@2V5PZN000001SBH@2LbQP0RU=gM@00G`000000XEAgMM6hgnVV5PZN8=9Q0801fWD00000
dc`ZM`00G75XbQP0YQH:WXC<6000L7UeGOVnW?kooonQE7Me1A;FMB3BH@30AF805QDQ?P002P30AF80
e<XH05`ieWETMP08000002D0000<00000@0005@0001D0000o0000:?mool20@00[Ogoo`40002[Z^4o
7LOQ_k8C002Z;P000@0004`00000000000000000003ooooooooooe00001h0000N00001P0000<0000
000005@0001D00000P400:?mool50@00[Ogoo`40002[Z^4o7LOQ_b@D002Z;P000@0004`000000000
00000000003ooooooooooe00000k07<0?00001P0000<0000000002D0000<00003@00P2P0000<0000
0@000580001`0@000@0003Woool0000000000000002@0@00000000000P9304d0DP0a030000000000
000000000000000000000000000000000000000000000000000000000000000000000000000o000o
100005C96010eV40S<XH0?Ea;WLK03h0M05O0000001@0El0F0=;0000H@0PdV40H0mR000000040000
000005`100400000800000000@5DbAP0000008c:603eLBigo7I]1_kooonZ>2YgXS@ZM`0000000640
8=9Q0:HF2Yl000006=9Q09c:602:DgMe001O0000002QE7MedKSOjJHF2YlPdV40P07JM@00003C?2Yg
001LLFS:602V5PZOQ<`H001`NGEMnKjLo_oooj5DMgD54]Ie8=9Q0<15HP0F5B4n000:0<15HP3DbQP0
G3WFMFAf00P000009@0000`000010000E00005@000060@00Xogoo`/1002]oOoo0@000:^ZhClMan6o
OA@00:X^00010000C00000000000000000000?ooooooooooD0000300001T0000600000`000000000
E00005@0000;0@00Xogoo`l1002]oOoo0@000:^ZhClMan6ohA@00:X^00010000C000000000000000
00000?ooooooooooD00002T0001@0000600000`000000000E00005@0000B0@00XogooaX1002]oOoo
0@000:^ZhClMan6oIAD00:X^00010000C00000000000000000000?ooooooooooD00003d0002P0000
600000`000000000E00005@0000L0@00Xogoob01002]oOoo0@000:^ZhClMan6o=aH00:X^00010000
C00000000000000000000?ooooooooooD00007<00@5@0000600000`000000000E00005@0000P0@00
Xogoob<1002]oOoo0@000:^ZhClMan6oQAH00:X^00010000C00000000000000000000?oooooooooo
D00006T0;00l0000600000`000000000E00005@0000S0@00XogoobT1002]oOoo0@000:^ZhClMan6o
_1H00:X^00010000C00000000000000000000?ooooooooooD00006h0001h0000600000`000000000
9@0000`0000=0020:00000`000010000DP00070100010000>Oooo`00000000000000090100000000
00020T<0C@1=04T0<@0`000000000000000000000000000000000000000000000000000000000000
0000000000000000000003l003l40000E<TH043FH@2<bQP0mG4^Ma/0?P1d0El000000501G`1H0d/0
001Q023BH@1P3f80000000@000000000G0400@00000P000000010EC960000000S<XH0?Ea;WOlMVd6
o_ooojXh:WNR=2Yg00000000H@0PdV40YQH:X000000HdV40W<XH08YCMgD005l000000:5DMgGA^=oY
YQH:X23BH@200MYe00000=<l:WL005aaJ<XH0:HF2Z24c1P0071iMEgi_YcnooooXEAgM@DBeWDPdV40
`4ER01HE8Ch000X0`4ER0=C:601L>MIeI7H02000000U000030000040001D0000E00002X1002SoOoo
<0400:gmool10000Zj[Q?ag7hKm=5`00ZRh00040001<00000000000000000000oooooooooom@0000
N00007P0000H000030000000001D0000E0000301002SoOoo<`400:gmool10000Zj[Q?ag7hKno5`00
ZRh00040001<00000000000000000000oooooooooom@0000>P0003`0000U0000300000L0080X0000
30000080000U000030000000080X0000300000<0000U0000300000d0080X000030000040000>0000
50000000000@0000500000Q00@PT00006000008@`=/100000`00000000000000000001]000100000
=000004000020000[8]a@oWR8LA9<P136GAL@P<0002/Rg53nN8Qa?[N^4?ihR74[8]a@kPK5<@Q0000
20000680000<00000@000240000800008@0000P0001c000030000000000L0000200002D0000<0000
0000P2D0000<00001`00P2D0000<00003P00P1T0000<0000oooo01P0000<000000000180000<0000
0P0001<0000<00000@0001@0000<00003@0001D0000<00000@0001H0000<0000000000d0000@0000
00000000000j0000300000X0000K000040000000000000008`000200000lZRE100000000000_FRM1
Z4lLaC6XddDT0000900003bZ9D400000000002mJ9d6XCac5<JSCA@@0001c000030000000000=0000
4000000000000000DP00070100020000400000L00000000000000;`2000000001`828U<0N@1c07@0
I@1]00004`2Pn?oolP400000000lcA/2P?Soo`P0F7kkm_oo00000000000PcA/2P?Sooooo00000?h6
620H1jQV2POH4^d600<00740002Xio/6ZBdZMkHM8F0R08X1lPP00:Xh:WNh8GAf00000000N`0@h1L7
0P000USOOPc0g:d2]<U200000000000000000?oooooV@P2T001k0040003eLBig0`0000P0002hJ0`7
^6P<1`0030L000000P000000N`030000X<a20:S=@P3lcT80mG4^Mo`T7`7noooodc`ZMohl:WL00040
20010;9X30L000`7000000SP5`L18000RWDYM;CD@P00L7UeMY:>@O8800000000HQ<00BR:oPH10000
g<d00N3=@P0_<=IeI7H02000000U00003000008000160000R00007`00017A4U30P000?80001hoOoo
L@400:omool`0000I`1U06h0I@1b0640M01U06@0801R07T0801G04d0AP0_04D0C@160200HP1Q06<0
J`1U06h0I00P06l0IP0P0700L`1d06l0I@1T06T0M00006T0KP1`07D0M00000008`000200003lV0@o
00000000002oh@FoZ4lLaC6XddDT000090000?bH13l0000000000;oQ1KnXCac5<JSCA@@0000S0000
80000?bH13l0000000000;oQ1KnXCac5<JSCAB@0000T0000o9P4?`0000000000_n45_jQ?7<DaZ==5
10000180000<00000@0001H0000<0000600001P0000<000000000580001`0@000`0003Woool00000
00000000002@0@00000000L00P9304d0C@190340<000000000000000000000000000000000000000
00000000000000000000000000000000000000@00038bQP0000000P000070000000008iC=gG8bQP0
<<XH0>b`@`040000Q0000<S:60000000000000`0000000000@00023:60000000Q0000:0?00020000
0`000<S:60000000000003c:601oWT<0o0X/083:600004<0100008je@`1P=mcYJ7h/0268AP000000
0000000000010000C<XH000_BP0<baP0h9a20;3IPnWnoooo00130=fe@`1XOR`000000000;01XOR`0
b<XH0040000h01h02`000<S:601XOR`00@<00;1m;0010000H7h/06Af00P000009@0000`000030000
E00005@0000H0000500005<0001k00000@000:^ZhClMan6o2Q<00=/a00010000C000000000000000
00000?ooooooooooD0000400oomT0000600000`000000000DP00070100040000500000T000000000
00000;`2000000001`828U<0N@1c07@0I@1]000000000000hP000000001/U8/2P?Soo`0000000000
00000000001@U8/2P?SookZF00000=Ie]fCFMKHM8F00000000000040002h<=P7h<a2065TeWFf7B5P
00000000001D000000000;P`f0MHcD80gU7FMKHM8F30O_T61000072Qf@UD000000000040000h01h0
2`000<S:601XOR`00@<00;1m;0010000H7h/000000P00000`=b]0[C9@P1HcD80;c3FMES=@P1V<=Ie
:;T<1mSTnPHU0000000:07a@002<cT807OXUM;HM8F000?T6^33H1`@0001`XMT9/PXVM8`6fWD00000
S0KJMH01fWDl^@`7/<e202l`eWF`cD80IS3FMHRi30OHi?X6I7H02000000U0000300000@0000X0000
300000<0001B0000L04000<0001eoooo0000000000000000T040000000070082@`1=04d0B@0g0000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
?`00?`@000020000@=IQ0<S:600000006`0n07@1G`000000D05O05P3B`0004<08=9Q0<1kH@000000
10000000001L0@010000020000000041E<TH08cS:GN<bQP0mG4^MoafK@KnooooZSPZMj8d:WL00000
001Q023BH@2V5PZ3000001SBH@2LbQP0RU=gM@00G`000000XEAgMM6hgnVV5PZ38=9Q0801fWD0QR`0
B01;0000B`1XbQP0YQH:PhC<6000L7UeGOVnW?kooonQE7Me1A;FMB3BH@30AF805QDQ?P002P30AF80
e<XH05`ieWETMP08000002D0000<00000`0005@0001D0000E00000H000210000C`000040002[Z^4o
7LOQ_glC000S<P000@0004`00000000000000000003ooooooooooe00002`08l0D00001P0000<0000
000002D0000<0000100002P0000<00000`000580001`0@000`0003Woool0000000000000002@0@00
000000L00P9304d0C@190340<0000000000000000000000000000000000000000000000000000000
000000000000000000000000000o000o100005C96010eV40S<XH0?Ea;WLK03h0M05O0000001@0El0
F0=;0000H@0PdV40`7]Q000000040000000005`100400000800000000@5DbAP0000008c:603eLBig
o7I]1_kooonZ>2YgXS@ZM`00000006408=9Q0:HF2X@000006=9Q09c:602:DgMe001O0000002QE7Me
dKSOjJHF2X@PdV40P07JM@00001804/0001;06S:602V5PZ4Q<`H001`NGEMnKjLo_oooj5DMgD54]Ie
8=9Q0<15HP0F5B4n000:0<15HP3DbQP0G3WFMFAf00P000009@0000`000030000E00005@000290000
50000<P0001k00000@000:^ZhClMan6oiA<00=/a00010000C00000000000000000000?oooooooooo
D00007D0S`1h00009P0001`0000500000000000000000000000002D0000<00001@0002L0000H0000
1P00000000000000000002D0000<00001P0001<0000<00000P0005/0000h00006P0008T000380000
SP000040000500001@00010CR35N58PaGQB@<A0CT34@4hPa600000`000000000E00005@0000S0000
XP0005h000090@000@000:^ZhClMan6o81<00<``00010000C00000000000000000000?oooooooooo
D0000400001T0000600000`000000000E00005@0001O0000XP0008T000090@000@000:^ZhClMan6o
U1<00<``00010000C00000000000000000000?ooooooooooD00007@0001@0000600000`000000000
9@0000`000040000:00000`000030000DP00070100030000MOooo`00000000000000090100000000
1`020T<0C@1=04T0=`00000000000000000000000000000000000000000000000000000000000000
0000000000000000000003l003l4000005]I043FH@0@@2`0j00001/0?P1d0El000000501G`1H0d/0
>04/023BH@1P3f80000000@000000000G0400@00000P000000010EC960000000S<XH0?Ea;WOlMVd6
o_ooojXh:WNR=2Yg00000000H@0PdV40YQH:Q@00000HdV40W<XH08YCMgD005l000000:5DMgGA^=oY
YQH:QB3BH@200MYe2P000>RM;00002`0J<XH0:HF2XF4c1P0071iMEgi_YcnooooXEAgM@DBeWDPdV40
`4ER01HE8Ch000X0`4ER0=C:601L>MIeI7H02000000U0000300000<0001D0000E00008@0002K0000
/@000>@000010000Zj[Q?ag7hKoL4`001S400040001<00000000000000000000oooooooooom@0000
/0000500000H000030000000000U0000300000@0000X0000300000<0001B0000L04000<0000ioooo
0000000000000000T040000000070082@`1=0580<@0`000000000000000000000000000000000000
000000000000000000000000000000000000000000000000?`00?`@0001DbAP0@=IQ08c:603eLBig
6`0n07@1G`000000D05O05P3B`0006408=9Q060?HP00000010000000001L0@010000020000000041
E<TH0000002<bQP0mG4^MoafK@KnooooZSPZMj8d:WL00000001Q023BH@2V5PZ6000001SBH@2LbQP0
RU=gM@00G`000000XEAgMM6hgnVV5PZ68=9Q0801fWD00000j9d/0000;01XbQP0YQH:QXC<6000L7Ue
GOVnW?kooonQE7Me1A;FMB3BH@30AF805QDQ?P002P30AF80e<XH05`ieWETMP08000002D0000<0000
0`0005@0001D0000k@0005X000100@00`@000040002[Z^4o7LOQ_jHD001E<@000@0004`000000000
00000000003ooooooooooe00000m0000X00001P0000<0000000002D0000<0000100002P0000<0000
0`000580001`0@000`0003Woool0000000000000002@0@00000000L00P9304d0C@190340<0000000
000000000000000000000000000000000000000000000000000000000000000000000000000o000o
100005C96010eV40S<XH0?Ea;WLK03h0M05O0000001@0El0F0=;0000H@0PdV40H0mR000000040000
000005`100400000800000000@5DbAP0000008c:603eLBigo7I]1_kooonZ>2YgXS@ZM`0000000640
8=9Q0:HF2XL000006=9Q09c:602:DgMe001O0000002QE7MedKSOjJHF2XLPdV40P07JM@00003XWB`0
000/06S:602V5PZ7Q<`H001`NGEMnKjLo_oooj5DMgD54]Ie8=9Q0<15HP0F5B4n000:0<15HP3DbQP0
G3WFMFAf00P000009@0000`000030000E00005@0001W0@0050000:81001k00000@000:^ZhClMan6o
TAD00=/a00010000C00000000000000000000?ooooooooooD00004009<AT0000600000`000000000
9@0000`000040000:00000`000030000DP00070100030000MOooo`00000000000000090100000000
1`020T<0C@1B03L00000000000000000000000000000000000000000000000000000000000000000
0000000000000000000003l003l40000E<TH043FH@2<bQP0mG4^Ma/0?P1d0El000000501G`1H0d/0
001Q023BH@1P3f80000000@000000000G0400@00000P000000010EC960000000S<XH0?Ea;WOlMVd6
o_ooojXh:WNR=2Yg00000000H@0PdV40YQH:R000000HdV40W<XH08YCMgD005l000000:5DMgGA^=oY
YQH:R23BH@200MYe00000>RM;00002`0J<XH0:HF2XR4c1P0071iMEgi_YcnooooXEAgM@DBeWDPdV40
`4ER01HE8Ch000X0`4ER0=C:601L>MIeI7H02000000U0000300000<0001D0000E0000:<100060000
c@4004l000010000Zj[Q?ag7hKl65P008c800040001<00000000000000000000oooooooooom@0000
<P1n3500000H000030000000000U0000300000@0000X0000300000<0001B0000L04000<0000ioooo
0000000000000000T040000000070082@`1=04d0B@0a030000000000000000000000000000000000
000000000000000000000000000000000000000000000000?`00?`@0001DbAP0@=IQ08c:603eLBig
6`0n07@1G`000000D05O05P3B`0006408=9Q060?HP00000010000000001L0@010000020000000041
E<TH0000002<bQP0mG4^MoafK@KnooooZSPZMj8d:WL00000001Q023BH@2V5PZ9000001SBH@2LbQP0
RU=gM@00G`000000XEAgMM6hgnVV5PZ98=9Q0801fWD00000j9d/0000;01XbQP0YQH:RHC<6000L7Ue
GOVnW?kooonQE7Me1A;FMB3BH@30AF805QDQ?P002P30AF80e<XH05`ieWETMP08000002D0000<0000
0`0005@0001D0000d@4001@0000@0P00N`000040002[Z^4o7LOQ_ehF003K<@000@0004`000000000
00000000003ooooooooooe00001e0000N00002D0000<00001`00P2P0000<00001@0002H0000L0000
1@0000000000000000000000000U0000300000D0000U000030000000080X0000300000H0000W0000
600000H00000000000000000000U0000300000H0000C000030000080001K0000>00006H100290000
308008h0000100001@0000D0002@5HPad1J8<M0FT36@5I0aT1F8<AP0000<0000000005@0001D0000
I`400:80002R0@002@400040002[Z^4o7LOQ_i4E003<<0000@0004`00000000000000000003ooooo
oooooe00001001P0I00001P0000<0000000005@0001D0000X`400:80003R0@002@400040002[Z^4o
7LOQ_`HF003<<0000@0004`00000000000000000003ooooooooooe00001h0000N00001P0000<0000
000002D0000<0000100002P0000<00000`000580001`0@000`0007Goool0000000000000002@0@00
000000L00P9304d0DP0g000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000o000o1000001KF@10eV40440/0>P0000K03h0M05O0000001@0El0
F0=;03P1;00PdV40H0mR000000040000000005`100400000800000000@5DbAP0000008c:603eLBig
o7I]1_kooonZ>2YgXS@ZM`00000006408=9Q0:HF2XX000006=9Q09c:602:DgMe001O0000002QE7Me
dKSOjJHF2XXPdV40P07JM@X0003XWB`0000/06S:602V5PZ:Q<`H001`NGEMnKjLo_oooj5DMgD54]Ie
8=9Q0<15HP0F5B4n000:0<15HP3DbQP0G3WFMFAf00P000009@0000`000030000E00005@0003N0@00
V`0000P2003T00000@000:^ZhClMan6oN1H000Ha00010000C00000000000000000000?oooooooooo
D0000380001@0000600000`0000000009@0000`000040000:00000`000030000DP00070100030000
>Oooo`000000000000000901000000001`020T<0C@1=04T0<@0`0000000000000000000000000000
000000000000000000000000000000000000000000000000000003l003l40000E<TH043FH@2<bQP0
mG4^Ma/0?P1d0El000000501G`1H0d/0001Q023BH@1P3f80000000@000000000G0400@00000P0000
00010EC960000000S<XH0?Ea;WOlMVd6o_ooojXh:WNR=2Yg00000000H@0PdV40YQH:R`00000HdV40
W<XH08YCMgD005l000000:5DMgGA^=oYYQH:Rb3BH@200MYe00000>RM;00002`0J<XH0:HF2X^4c1P0
071iMEgi_YcnooooXEAgM@DBeWDPdV40`4ER01HE8Ch000X0`4ER0=C:601L>MIeI7H02000000U0000
300000<0001D0000E00001P2001J0000>0800<4000010000Zj[Q?ag7hKoX5P00EC400040001<0000
0000000000000000oooooooooom@0000>`0003`0000H000030000000000U0000300000@0000X0000
300000<0001B0000L04000<0000ioooo0000000000000000T040000000070082@`1=0580<@0`0000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
?`00?`@0001DbAP0@=IQ08c:603eLBig6`0n07@1G`000000D05O05P3B`0006408=9Q060?HP000000
10000000001L0@010000020000000041E<TH0000002<bQP0mG4^MoafK@KnooooZSPZMj8d:WL00000
001Q023BH@2V5PZ<000001SBH@2LbQP0RU=gM@00G`000000XEAgMM6hgnVV5PZ<8=9Q0801fWD00000
j9d/0000;01XbQP0YQH:S8C<6000L7UeGOVnW?kooonQE7Me1A;FMB3BH@30AF805QDQ?P002P30AF80
e<XH05`ieWETMP08000002D0000<00000`0005@0001D0000[P8005X0003R0P00`@000040002[Z^4o
7LOQ_`PH001E<@000@0004`00000000000000000003ooooooooooe00000`0000I00001P0000<0000
000002D0000<0000100002P0000<00000`000580001`0@000`0003Woool0000000000000002@0@00
000000L00P9304d0D`1I0340<01?0580B@1700000000000000000000000000000000000000000000
000000000000000000000000000o000o100005C96010eV40S<XH0?Ea;WLK03h0M05O0000001@0El0
F0=;0000H@0PdV40H0mR000000040000000005`100400000800000000@5DbAP0000008c:603eLBig
o7I]1_kooonZ>2YgXS@ZM`00000006408=9Q0:HF2Xd000006=9Q09c:602:DgMe001O0000002QE7Me
dKSOjJHF2XdPdV40P07JM@00003XWB`0000/06S:602V5PZ=Q<`H001`NGEMnKjLo_oooj5DMgD54]Ie
8=9Q0<15HP0F5B4n000:0<15HP3DbQP0G3WFMFAf00P000009@0000`000030000E00005@0003n0P00
E`000543000;0@000@000:^ZhClMan6oXaP005Da00010000C00000000000000000000?oooooooooo
D0000;L0002P0000600000`0000000009@0000`000040000:00000`000030000DP00070100030000
>Oooo`000000000000000901000000001`020T<0C@1=04T0<@0`0000000000000000000000000000
000000000000000000000000000000000000000000000000000003l003l40000E<TH043FH@2<bQP0
mG4^Ma/0?P1d0El000000501G`1H0d/0001Q023BH@1P3f80000000@000000000G0400@00000P0000
00010EC960000000S<XH0?Ea;WOlMVd6o_ooojXh:WNR=2Yg00000000H@0PdV40YQH:SP00000HdV40
W<XH08YCMgD005l000000:5DMgGA^=oYYQH:SR3BH@200MYe00000>RM;00002`0J<XH0:HF2Xj4c1P0
071iMEgi_YcnooooXEAgM@DBeWDPdV40`4ER01HE8Ch000X0`4ER0=C:601L>MIeI7H02000000U0000
300000<0001D0000E00006/3001J0000ZP<00<4000010000Zj[Q?ag7hKmf6@00EC400040001<0000
0000000000000000oooooooooom@0000N00007P0000H000030000000000U0000300000@0000X0000
300000<0001B0000L04000<0000ioooo0000000000000000T040000000070082@`1=05<0F@0a0300
C`1B04T0A`0000000000000000000000000000000000000000000000000000000000000000000000
?`00?`@0001DbAP0@=IQ08c:603eLBig6`0n07@1G`000000D05O05P3B`0006408=9Q060?HP000000
10000000001L0@010000020000000041E<TH0000002<bQP0mG4^MoafK@KnooooZSPZMj8d:WL00000
001Q023BH@2V5PZ?000001SBH@2LbQP0RU=gM@00G`000000XEAgMM6hgnVV5PZ?8=9Q0801fWD00000
j9d/0000;01XbQP0YQH:ShC<6000L7UeGOVnW?kooonQE7Me1A;FMB3BH@30AF805QDQ?P002P30AF80
e<XH05`ieWETMP08000002D0000<00000`0005@0001D0000``<005L0000F10002`400040002[Z^4o
7LOQ_alJ001E<@000@0004`00000000000000000003ooooooooooe00002g0000X00001P0000<0000
000002D0000<0000100002P0000<00000`000580001`0@000`0003Woool0000000000000002@0@00
000000L00P9304d0C@190340<0000000000000000000000000000000000000000000000000000000
000000000000000000000000000o000o100005C96010eV40S<XH0?Ea;WLK03h0M05O0000001@0El0
F0=;0000H@0PdV40H0mR000000040000000005`100400000800000000@5DbAP0000008c:603eLBig
o7I]1_kooonZ>2YgXS@ZM`00000006408=9Q0:HF2Y0000006=9Q09c:602:DgMe001O0000002QE7Me
dKSOjJHF2Y0PdV40P07JM@00003XWB`0000/06S:602V5PZ@Q<`H001`NGEMnKjLo_oooj5DMgD54]Ie
8=9Q0<15HP0F5B4n000:0<15HP3DbQP0G3WFMFAf00P000009@0000`000030000E00005@0000_1000
FP0006h4003100000@000:^ZhClMan6olAX005Da00010000C00000000000000000000?oooooooooo
D0000;`0001h0000600000`000000000E00005@0001^1000FP0008h4003100000@000:^ZhClMan6o
JQ/005Da00010000C00000000000000000000?ooooooooooD00003/0000l0000600000`000000000
E00005@0000;00008`4004X0002:0@000@000:^ZhClMan6olQ800=D_00010000C000000000000000
00000?ooooooooooD00007D00@5h0000600000`0000000009@0000`000040000:00000`000030000
DP00070100030000>Oooo`000000000000000901000000001`020T<0C@1B0340<000000000000000
0000000000000000000000000000000000000000000000000000000000000000000003l003l40000
E<TH043FH@2<bQP0mG4^Ma/0?P1d0El000000501G`1H0d/0001Q023BH@1P3f80000000@000000000
G0400@00000P000000010EC960000000S<XH0?Ea;WOlMVd6o_ooojXh:WNR=2Yg00000000H@0PdV40
YQH:T@00000HdV40W<XH08YCMgD005l000000:5DMgGA^=oYYQH:TB3BH@200MYe00000>RM;00002`0
J<XH0:HF2Y64c1P0071iMEgi_YcnooooXEAgM@DBeWDPdV40`4ER01HE8Ch000X0`4ER0=C:601L>MIe
I7H02000000U0000300000<0001D0000E00004H0000S0@00L00008X100010000Zj[Q?ag7hKmT4`00
eBl00040001<00000000000000000000oooooooooom@0000:0010E00000H000030000000000U0000
300000@0000X0000300000<0001B0000L04000<0000ioooo0000000000000000T040000000070082
@`1=04d0B@0a03000000000000000000000000000000000000000000000000000000000000000000
0000000000000000?`00?`@0001DbAP0@=IQ08c:603eLBig6`0n07@1G`000000D05O05P3B`000640
8=9Q060?HP00000010000000001L0@010000020000000041E<TH0000002<bQP0mG4^MoafK@Knoooo
ZSPZMj8d:WL00000001Q023BH@2V5PZB000001SBH@2LbQP0RU=gM@00G`000000XEAgMM6hgnVV5PZB
8=9Q0801fWD00000j9d/0000;01XbQP0YQH:TXC<6000L7UeGOVnW?kooonQE7Me1A;FMB3BH@30AF80
5QDQ?P002P30AF80e<XH05`ieWETMP08000002D0000<00000`0005@0001D0000K`0002<1002^0000
RP400040002[Z^4o7LOQ_k8C003E;`000@0004`00000000000000000003ooooooooooe00001h0041
N00001P0000<0000000002D0000<0000100002P0000<00000`000580001`0@000`0003Woool00000
00000000002@0@00000000L00P9304d0DP0a03000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000o000o100005C96010eV40S<XH0?Ea;WLK03h0
M05O0000001@0El0F0=;0000H@0PdV40H0mR000000040000000005`100400000800000000@5DbAP0
000008c:603eLBigo7I]1_kooonZ>2YgXS@ZM`00000006408=9Q0:HF2Y<000006=9Q09c:602:DgMe
001O0000002QE7MedKSOjJHF2Y<PdV40P07JM@00003XWB`0000/06S:602V5PZCQ<`H001`NGEMnKjL
o_oooj5DMgD54]Ie8=9Q0<15HP0F5B4n000:0<15HP3DbQP0G3WFMFAf00P000009@0000`000030000
E00005@0003600008`4001T1002:0@000@000:^ZhClMan6oFQ@00=D_00010000C000000000000000
00000?ooooooooooD00003d00@6P0000600000`000000000E00005@0000c0@008`4006L1002:0@00
0@000:^ZhClMan6o;QD00=D_00010000C00000000000000000000?ooooooooooD0000300001T0000
600000`0000000009@0000`000040000:00000`000030000DP00070100030000>Oooo`0000000000
00000901000000001`020T<0C@1=04T0<@0`00000000000000000000000000000000000000000000
00000000000000000000000000000000000003l003l40000E<TH043FH@2<bQP0mG4^Ma/0?P1d0El0
00000501G`1H0d/0001Q023BH@1P3f80000000@000000000G0400@00000P000000010EC960000000
S<XH0?Ea;WOlMVd6o_ooojXh:WNR=2Yg00000000H@0PdV40YQH:U000000HdV40W<XH08YCMgD005l0
00000:5DMgGA^=oYYQH:U23BH@200MYe00000>RM;00002`0J<XH0:HF2YB4c1P0071iMEgi_Ycnoooo
XEAgM@DBeWDPdV40`4ER01HE8Ch000X0`4ER0=C:601L>MIeI7H02000000U0000300000<0001D0000
E00006L1000S0@00Q`4008X100010000Zj[Q?ag7hKnA5@00eBl00040001<00000000000000000000
oooooooooom@0000>`010C`0000H000030000000001D0000E00009D1000S0@00_`4008X100010000
Zj[Q?ag7hKoZ5@00eBl00040001<00000000000000000000oooooooooom@0000M0000500000H0000
30000000000U0000300000@0000X0000300000<0001B0000L04000<0000ioooo0000000000000000
T040000000070082@`1=0580<@0`0000000000000000000000000000000000000000000000000000
00000000000000000000000000000000?`00?`@0001DbAP0@=IQ08c:603eLBig6`0n07@1G`000000
D05O05P3B`0006408=9Q060?HP00000010000000001L0@010000020000000041E<TH0000002<bQP0
mG4^MoafK@KnooooZSPZMj8d:WL00000001Q023BH@2V5PZE000001SBH@2LbQP0RU=gM@00G`000000
XEAgMM6hgnVV5PZE8=9Q0801fWD00000j9d/0000;01XbQP0YQH:UHC<6000L7UeGOVnW?kooonQE7Me
1A;FMB3BH@30AF805QDQ?P002P30AF80e<XH05`ieWETMP08000002D0000<00000`0005@0001D0000
^P4002<1003T0@00RP400040002[Z^4o7LOQ_c8F003E;`000@0004`00000000000000000003ooooo
oooooe00000Y0000D00001P0000<0000000005@0001D0000oP4002<1001A0P00RP400040002[Z^4o
7LOQ_kHF003E;`000@0004`00000000000000000003ooooooooooe00000m0000X00001P0000<0000
000002D0000<0000100002P0000<00000`000580001`0@000`0003Woool0000000000000002@0@00
000000L00P9304d0C@190340<0000000000000000000000000000000000000000000000000000000
000000000000000000000000000o000o100005C96010eV40S<XH0?Ea;WLK03h0M05O0000001@0El0
F0=;0000H@0PdV40H0mR000000040000000005`100400000800000000@5DbAP0000008c:603eLBig
o7I]1_kooonZ>2YgXS@ZM`00000006408=9Q0:HF2YH000006=9Q09c:602:DgMe001O0000002QE7Me
dKSOjJHF2YHPdV40P07JM@00003XWB`0000/06S:602V5PZFQ<`H001`NGEMnKjLo_oooj5DMgD54]Ie
8=9Q0<15HP0F5B4n000:0<15HP3DbQP0G3WFMFAf00P000009@0000`000030000E00005@0001[0P00
8`400:X2002:0@000@000:^ZhClMan6oR1L00=D_00010000C00000000000000000000?oooooooooo
D00007D0001h0000600000`0000000009@0000`000040000:00000`000030000DP00070100030000
>Oooo`000000000000000901000000001`020T<0C@1B0340<0000000000000000000000000000000
000000000000000000000000000000000000000000000000000003l003l40000E<TH043FH@2<bQP0
mG4^Ma/0?P1d0El000000501G`1H0d/0001Q023BH@1P3f80000000@000000000G0400@00000P0000
00010EC960000000S<XH0?Ea;WOlMVd6o_ooojXh:WNR=2Yg00000000H@0PdV40YQH:U`00000HdV40
W<XH08YCMgD005l000000:5DMgGA^=oYYQH:Ub3BH@200MYe00000>RM;00002`0J<XH0:HF2YN4c1P0
071iMEgi_YcnooooXEAgM@DBeWDPdV40`4ER01HE8Ch000X0`4ER0=C:601L>MIeI7H02000000U0000
300000<0001D0000E0000:H2000S0@00d08008X100010000Zj[Q?ag7hKoj5`00eBl00040001<0000
0000000000000000oooooooooom@0000:0000500000H000030000000000U0000300000@0000X0000
300000<0001B0000L04000<0000ioooo0000000000000000T040000000070082@`1=04d0B@0a0300
00000000000000000000000000000000000000000000000000000000000000000000000000000000
?`00?`@0001DbAP0@=IQ08c:603eLBig6`0n07@1G`000000D05O05P3B`0006408=9Q060?HP000000
10000000001L0@010000020000000041E<TH0000002<bQP0mG4^MoafK@KnooooZSPZMj8d:WL00000
001Q023BH@2V5PZH000001SBH@2LbQP0RU=gM@00G`000000XEAgMM6hgnVV5PZH8=9Q0801fWD00000
j9d/0000;01XbQP0YQH:V8C<6000L7UeGOVnW?kooonQE7Me1A;FMB3BH@30AF805QDQ?P002P30AF80
e<XH05`ieWETMP08000002D0000<00000`0005@0001D0000c`8002<1000>0`00RP400040002[Z^4o
7LOQ_dPH003E;`000@0004`00000000000000000003ooooooooooe00001h0000N00001P0000<0000
000002D0000<0000100002P0000<00000`000580001`0@000`0003Woool0000000000000002@0@00
000000L00P9304d0DP0a030000000000000000000000000000000000000000000000000000000000
000000000000000000000000000o000o100005C96010eV40S<XH0?Ea;WLK03h0M05O0000001@0El0
F0=;0000H@0PdV40H0mR000000040000000005`100400000800000000@5DbAP0000008c:603eLBig
o7I]1_kooonZ>2YgXS@ZM`00000006408=9Q0:HF2YT000006=9Q09c:602:DgMe001O0000002QE7Me
dKSOjJHF2YTPdV40P07JM@00003XWB`0000/06S:602V5PZIQ<`H001`NGEMnKjLo_oooj5DMgD54]Ie
8=9Q0<15HP0F5B4n000:0<15HP3DbQP0G3WFMFAf00P000009@0000`000030000E00005@0000V0`00
8`4007T3002:0@000@000:^ZhClMan6olAP00=D_00010000C00000000000000000000?oooooooooo
D00003d0002P0000600000`0000000009@0000`000040000:00000`000030000DP00070100030000
>Oooo`000000000000000901000000001`020T<0C@1=04T0<@0`0000000000000000000000000000
000000000000000000000000000000000000000000000000000003l003l40000E<TH043FH@2<bQP0
mG4^Ma/0?P1d0El000000501G`1H0d/0001Q023BH@1P3f80000000@000000000G0400@00000P0000
00010EC960000000S<XH0?Ea;WOlMVd6o_ooojXh:WNR=2Yg00000000H@0PdV40YQH:VP00000HdV40
W<XH08YCMgD005l000000:5DMgGA^=oYYQH:VR3BH@200MYe00000>RM;00002`0J<XH0:HF2YZ4c1P0
071iMEgi_YcnooooXEAgM@DBeWDPdV40`4ER01HE8Ch000X0`4ER0=C:601L>MIeI7H02000000U0000
300000<0001D0000E00009<3000S0@00dP<008X100010000Zj[Q?ag7hKo36@00eBl00040001<0000
0000000000000000oooooooooom@0000_00007P0000H000030000000001D0000E0000=43000S0@00
l@<008X100010000Zj[Q?ag7hKlk6P00eBl00040001<00000000000000000000oooooooooom@0000
>`0003`0000H000030000000001D0000E0000?l3000S0@00:@@008X100010000Zj[Q?ag7hKnD6P00
eBl00040001<00000000000000000000oooooooooom@0000M0000500000H000030000000000U0000
300000@0000X0000300000<0001B0000L04000<0000ioooo0000000000000000T040000000070082
@`1=0580<@0`00000000000000000000000000000000000000000000000000000000000000000000
0000000000000000?`00?`@0001DbAP0@=IQ08c:603eLBig6`0n07@1G`000000D05O05P3B`000640
8=9Q060?HP00000010000000001L0@010000020000000041E<TH0000002<bQP0mG4^MoafK@Knoooo
ZSPZMj8d:WL00000001Q023BH@2V5PZK000001SBH@2LbQP0RU=gM@00G`000000XEAgMM6hgnVV5PZK
8=9Q0801fWD00000j9d/0000;01XbQP0YQH:VhC<6000L7UeGOVnW?kooonQE7Me1A;FMB3BH@30AF80
5QDQ?P002P30AF80e<XH05`ieWETMP08000002D0000<00000`0005@0001D00009@@002<1001?1000
RP400040002[Z^4o7LOQ_m`J003E;`000@0004`00000000000000000003ooooooooooe00000Y0000
D00001P0000<0000000005@0001D0000J@@002<1002l1000RP400040002[Z^4o7LOQ_f0K003E;`00
0@0004`00000000000000000003ooooooooooe00000m0000X00001P0000<0000000005@0001D0000
eP@002<1000:1@00RP400040002[Z^4o7LOQ_c<L003E;`000@0004`00000000000000000003ooooo
oooooe00000`0000I00001P0000<0000000002D0000<0000100002P0000<00000`000580001`0@00
0`0003Woool0000000000000002@0@00000000L00P9304d0C@190340<00000000000000000000000
00000000000000000000000000000000000000000000000000000000000o000o100005C96010eV40
S<XH0?Ea;WLK03h0M05O0000001@0El0F0=;0000H@0PdV40H0mR000000040000000005`100400000
800000000@5DbAP0000008c:603eLBigo7I]1_kooonZ>2YgXS@ZM`00000006408=9Q0:HF2Y`00000
6=9Q09c:602:DgMe001O0000002QE7MedKSOjJHF2Y`PdV40P07JM@00003XWB`0000/06S:602V5PZL
Q<`H001`NGEMnKjLo_oooj5DMgD54]Ie8=9Q0<15HP0F5B4n000:0<15HP3DbQP0G3WFMFAf00P00000
9@0000`000030000E00005@0000:1@008`4002X5002:0@000@000:^ZhClMan6oUa`00=D_00010000
C00000000000000000000?ooooooooooD00003/0000l0000600000`000000000E00005@0000;0000
`04004X0000W0P000@000:^ZhClMan6olQ800:X^00010000C00000000000000000000?oooooooooo
D00007D0MgEh0000600000`0000000009@0000`000040000:00000`000030000DP00070100030000
>Oooo`000000000000000901000000001`020T<0C@1B0340<0000000000000000000000000000000
000000000000000000000000000000000000000000000000000003l003l40000E<TH043FH@2<bQP0
mG4^Ma/0?P1d0El000000501G`1H0d/0001Q023BH@1P3f80000000@000000000G0400@00000P0000
00010EC960000000S<XH0?Ea;WOlMVd6o_ooojXh:WNR=2Yg00000000H@0PdV40YQH:W@00000HdV40
W<XH08YCMgD005l000000:5DMgGA^=oYYQH:WB3BH@200MYeY3`ZMm<l:WL005aaJ<XH0:HF2Yf4c1P0
071iMEgi_YcnooooXEAgM@DBeWDPdV40`4ER01HE8Ch000X0`4ER0=C:601L>MIeI7H02000000U0000
300000<0001D0000E00004H000300@00L00002L200010000Zj[Q?ag7hKmT4`00ZRh00040001<0000
0000000000000000oooooooooom@0000:01gME00000H000030000000000U0000300000@0000X0000
300000<0001B0000L04000<0000ioooo0000000000000000T040000000070082@`1=04d0B@0a0300
00000000000000000000000000000000000000000000000000000000000000000000000000000000
?`00?`@0001DbAP0@=IQ08c:603eLBig6`0n07@1G`000000D05O05P3B`0006408=9Q060?HP000000
10000000001L0@010000020000000041E<TH0000002<bQP0mG4^MoafK@KnooooZSPZMj8d:WL00000
001Q023BH@2V5PZN000001SBH@2LbQP0RU=gM@00G`000000XEAgMM6hgnVV5PZN8=9Q0801fWD00000
dc`ZM`00G75XbQP0YQH:WXC<6000L7UeGOVnW?kooonQE7Me1A;FMB3BH@30AF805QDQ?P002P30AF80
e<XH05`ieWETMP08000002D0000<00000`0005@0001D0000K`000<01002^00009`800040002[Z^4o
7LOQ_k8C002Z;P000@0004`00000000000000000003ooooooooooe00001h07MeN00001P0000<0000
000005@0001D0000ZP000<01003:00009`800040002[Z^4o7LOQ_b@D002Z;P000@0004`000000000
00000000003ooooooooooe00000k0000?00001P0000<0000000002D0000<0000100002P0000<0000
0`000580001`0@000`0003Woool0000000000000002@0@00000000L00P9304d0DP0a030000000000
000000000000000000000000000000000000000000000000000000000000000000000000000o000o
100005C96010eV40S<XH0?Ea;WLK03h0M05O0000001@0El0F0=;0000H@0PdV40H0mR000000040000
000005`100400000800000000@5DbAP0000008c:603eLBigo7I]1_kooonZ>2YgXS@ZM`0000000640
8=9Q0:HF2Yl000006=9Q09c:602:DgMe001O0000002QE7MedKSOjJHF2YlPdV40P07JM@00003C?2Yg
001LLFS:602V5PZOQ<`H001`NGEMnKjLo_oooj5DMgD54]Ie8=9Q0<15HP0F5B4n000:0<15HP3DbQP0
G3WFMFAf00P000009@0000`000030000E00005@0003H0000`04000`1000W0P000@000:^ZhClMan6o
OA@00:X^00010000C00000000000000000000?ooooooooooD0000300001T0000600000`000000000
E00005@0000<0@00`04003H1000W0P000@000:^ZhClMan6ohA@00:X^00010000C000000000000000
00000?ooooooooooD00002T0001@0000600000`000000000E00005@0001@0@00`0400:<1000W0P00
0@000:^ZhClMan6oIAD00:X^00010000C00000000000000000000?ooooooooooD00003d0002P0000
600000`000000000E00005@0002m0@00`0400>L1000W0P000@000:^ZhClMan6o=aH00:X^00010000
C00000000000000000000?ooooooooooD00007<0g`5@0000600000`000000000E00005@0003U0@00
`04000D2000W0P000@000:^ZhClMan6oQAH00:X^00010000C00000000000000000000?oooooooooo
D00006T0T@0l0000600000`000000000E00005@000020P00`0400442000W0P000@000:^ZhClMan6o
_1H00:X^00010000C00000000000000000000?ooooooooooD00006h02P1h0000600000`000000000
9@0000`000040000:00000`000030000DP00070100030000>Oooo`00000000000000090100000000
1`020T<0C@1=04T0<@0`000000000000000000000000000000000000000000000000000000000000
0000000000000000000003l003l40000E<TH043FH@2<bQP0mG4^Ma/0?P1d0El000000501G`1H0d/0
001Q023BH@1P3f80000000@000000000G0400@00000P000000010EC960000000S<XH0?Ea;WOlMVd6
o_ooojXh:WNR=2Yg00000000H@0PdV40YQH:X000000HdV40W<XH08YCMgD005l000000:5DMgGA^=oY
YQH:X23BH@200MYe00000=<l:WL005aaJ<XH0:HF2Z24c1P0071iMEgi_YcnooooXEAgM@DBeWDPdV40
`4ER01HE8Ch000X0`4ER0=C:601L>MIeI7H02000000U0000300000<0001D0000E00004d200300@00
S08002L200010000Zj[Q?ag7hKm=5`00ZRh00040001<00000000000000000000oooooooooom@0000
N03O0GP0000H000030000000001D0000E00008P200300@00Z08002L200010000Zj[Q?ag7hKno5`00
ZRh00040001<00000000000000000000oooooooooom@0000>P2A03`0000U0000300000L0080X0000
300000D0000U000030000000080X0000300000H0000U0000300000@0000X0000300000<000160000
500000P00017A4U30`000280000<0000ooooob80000<0000ooooobD0000<00003@00P2P0000<0000
0P0002P0000<000010000280000<0000ooooodH000300@00]04004E=AR//@000900001P00000080o
000000000000080o0000P000080Z@000900001P0001PObA100000000000/VbA1ZCDKa@l_d4DT@000
30000000000Z@000900001P0002`0R`j00000000002`0R`j001iZ000LZT[@00030000000000N@0H0
30000000000Q@0D0300000000008@084600000`000024<3K000000<0010d@08030000000000N@0T0
30000000000Z@000900001P0002`0R`j00000000002`0R`j001iZ000LZTQ@0L030000000000Z@000
900001P0002`0R`j00000000002`0R`j001iZ000LZT[@00030000000000[@00030000000000N@0H0
30000000000Q@0D0300000000008@0<4600000`000024<3K000000<0010d@0<030000000000N@0T0
30000000000Z@000900001P00000080o000000000000080o00000000000Q@0L030000000001<0000
I0000000000000009@D003H200000000000002H5000g0P00:@2Z0000000000000020?`0000000000
0020?`0000000000000000000000000000000000000000008P0000`0003oooooAP0001`0000@0000
ADe6:`90000<0000000000h0000D000000000100000D0000
\>"], "Graphics",
  GeneratedCell->False,
  CellAutoOverwrite->False,
  ImageSize->{263., 113.00000000000001`},
  ImageMargins->{{0., 0.}, {0., 0.5263157894736842}}]
}], "Subchapter",
 CellChangeTimes->{{3.6371524922410097`*^9, 3.63715252674827*^9}, {
   3.6372440832236605`*^9, 3.6372440871428847`*^9}, 3.637244169179577*^9, {
   3.637244299470029*^9, 3.6372443032602463`*^9}, {3.6372453817689333`*^9, 
   3.637245384542092*^9}, {3.6386019852595997`*^9, 3.6386019852606*^9}}],

Cell[CellGroupData[{

Cell["\<\
Here we provide the parameters of the problem and its exact solution\
\>", "Subsubsection",
 CellChangeTimes->{{3.633439583415289*^9, 3.6334395909637213`*^9}, {
   3.636904756973955*^9, 3.636904760701168*^9}, 3.637138408549569*^9, {
   3.6373022788703003`*^9, 3.6373023184623003`*^9}},
 Background->RGBColor[1, 1, 0]],

Cell[CellGroupData[{

Cell[TextData[{
 "Parameter:  ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["K", "\[Gamma]"], TraditionalForm]]],
 "=Kg=1"
}], "Text",
 CellChangeTimes->{{3.6371384131203775`*^9, 3.6371384241807966`*^9}, 
   3.637138525300174*^9, {3.637244470420807*^9, 3.63724447152387*^9}, {
   3.637322014427394*^9, 3.6373220162184963`*^9}},
 Background->RGBColor[1, 1, 0]],

Cell[BoxData[
 RowBox[{
  RowBox[{"Kg", "=", "1."}], ";"}]], "Input",
 CellChangeTimes->{{3.6371380791081905`*^9, 3.6371380857850027`*^9}, 
   3.6371383766475134`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 "Exact solution: ",
 Cell[GraphicsData["Metafile", "\<\
CF5dJ6E]HGAYHf4PEfU^I6mgLb15CDHPAVmbKF5d0@0004Dl0@0006`0003ooooomOooodL400330000
0000000000064P00<`800215CDH00040?4D009L0000500000000000000000000HA<006PK003B0000
:@400000000000000000050d0`0XR0@0AP0002`0000P0000ADe6:`500@0L00004000008@`=/00000
F08005P200160000O04007010015CDH[7T0500`0000000007d0300`000000000<402010000040000
0020?b501`0<000000000290100<0000000002Y0000T000060000000P3l0000000000000P3l00000
000002]0000<0000000001i01P0<0000000002501@0<0000000001i02@0<0000000002Y0000T0000
60000000P3l0000000000000P3l00000000002501`0<0000000002Y0000T000060000;02;3X00000
00000;02;3X0l9O5030AaB]0000<0000000002Y0000T000060000;02;3X0000000000;02;3X0l9O5
030AaB]0000<0000000002Y0000T000060000;02;3X0000000000;02;3X009RY000AZ@Y0080T0000
6000003oool1000000000000003Pm/Y906i7B24000080000HP0000`000010000900002@00000080m
000000000000080m00000000000200009`0001P00001000000000?oo000000009@0000`000010000
9@0000`000080020EP000300003ooooooooood<4002600001@000?Son?ohoeP8:4AH22Q4n?ohooSo
9@0000`0000700209@0000`000000020900002@00000081100000000000008110000000000020000
AP0004@N000h7P00ADe6:b]0000<0000000001i01P0<0000000002501@0<0000000001i02@0<0000
000002Y0000T000060000;02;3X0000000000;02;3X009RY000AZB501`0<0000000002]0000<0000
000002Y0000T000060000?=R94400000000000I38d6j:b;5FfK@ABA0100<0000000000Q000Dd7@00
:1d0008@`=/200000`0001PM00010000c0000?d0001boOooIP4008Cmooo98P00l:GoodHa002LYooo
84E=AP000@0H7@00HP000080000`0000K000000000201`00>0@00:D2001m0@000000000000000000
eED:04S@1@1W06D0KP1U0780H@1d06D0I00P0680N@0P05L0C@1602l0A@1=04H0801R0640H`1[06D0
KP1T0200K`1V0200L01c07@0K`1U06@0J@1d0000J@1^0700M@1d0000000A0000300000H0000:0000
40000000000000004P0000`0000100005P0000`0000H0000600000`000000000DP00070100010000
>Oooo`0000000000000009010000000000020T<0C@1=04T0<@0`0000000000000000000000000000
00000000000000000000000000000000000000000000000010000<S:60000000200000L000000000
SU<gMLS:600`bQP0k;1300@000240000b<XH00000000000030000000000100008<XH000000240000
X0l0008000030000b<XH000000000000?<XH07nN@`3l2SD0P<XH0000@`040000S[E309i^E=eXOSD0
8HQ600000000000000000040001<bQP002m:00c;603PW480CX0;gOkoool004<0gKE306Qn=@000000
000e06Qn=@38bQP00@0003P07P0;0000b<XH06Qn=@010`00/7de0040001POSD0I7H02000000U0000
30000040001D0000E0000?d0001coOoo0`4007gmool10000Zj[Q?ag7hKo<4`00JS800040001<0000
0000000000000000oooooooooom@0000M@0007P0000H000030000000000U0000300000d0080X0000
30000040001B0000L0400040000ioooo0000000000000000T040000000000082@`1=0580<@0`0000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
?`00?`@000020000@=IG0<S:600000006`0n07@1E@000000D05E05P3e`4004<08=9G0<1kE`000000
10000000001L0@010000020000000041E<TH08cS:GN<bQP0mG4^MeI5JPKnooooZSPZMj8d:WL00000
001G023BE`1n7PZ;000001SBE`2LbQP0RU=gM@00E@000000XEAgMDDTE=en7PZ;8=9G0801fWD0QSD0
B03G0@00e`5XbQP0OQh:RhC<6000L7UebFDeZ?kooonQE7Me1A;FMB3BE`30AEP0Fb8QR0002P30AEP0
e<XH05`ieWETMP08000002D0000<00000@0005@0001D00000`4007?mool70@00OOgoo`40002[Z^4o
7LOQ_chD001Z<P000@0004`00000000000000000003ooooooooooe00000X0000D00001P0000<0000
000002D0000<00003@00P2P0000<00000@000580001`0@000@0003Woool0000000000000002@0@00
000000000P9304d0C@190340<0000000000000000000000000000000000000000000000000000000
000000000000000000000000000o000o100005C96010eUL0S<XH0?Ea;WLK03h0M05E0000001@0ED0
F0?G0@00E`0PdUL0`7]G000000040000000005`100400000800000000@5DbAP0000008c:603eLBig
ETEZ1_kooonZ>2YgXS@ZM`00000005L08=9G07hN2X`000006=9G09c:602:DgMe001E0000002QE7Me
ABADgGhN2X`PdUL0P07JM@0000180=L1003G0FS:601n7PZ<Q<`H001`NGG9ICFXo_oooj5DMgD54]Ie
8=9G0<15F01K8R68000:0<15F03DbQP0G3WFMFAf00P000009@0000`000010000E00005@000070@00
Logoo`d1001moOoo0@000:^ZhClMan6oS1@006Xb00010000C00000000000000000000?oooooooooo
D00007P0001h0000600000`000000000E00005@0000=0@00Logooa01001moOoo0@000:^ZhClMan6o
oQ@006Xb00010000C00000000000000000000?ooooooooooD00003/0000l0000600000`000000000
E00005@0000A0@00LogooaD1001moOoo0@000:^ZhClMan6oEQD006Xb00010000C000000000000000
00000?ooooooooooD00007@0001@0000600000`0000000009@0000`0000=0020:00000`000010000
DP00070100010000>Oooo`0000000000000009010000000000020T<0C@1B0340<000000000000000
0000000000000000000000000000000000000000000000000000000000000000000003l003l40000
E<TH043FE`2<bQP0mG4^Ma/0?P1d0ED000000501E@1H0mL1001G023BE`30NeL0000000@000000000
G0400@00000P000000010EC960000000S<XH0?Ea;WMFAFX6o_ooojXh:WNR=2Yg00000000E`0PdUL0
OQh:S@00000HdUL0W<XH08YCMgD005D000000:5DMgE595CMOQh:SB3BE`200MYe000004P0e`400=L1
J<XH07hN2Xf4c1P0071iMLUU=JSnooooXEAgM@DBeWDPdUL0`4EH05/R8HP000X0`4EH0=C:601L>MIe
I7H02000000U000030000040001D0000E00001D1001coOoo6@4007gmool10000Zj[Q?ag7hKnN5@00
JS800040001<00000000000000000000oooooooooom@0000:@000500000H000030000000001D0000
E00001/1001coOoo8`4007gmool10000Zj[Q?ag7hKlR5P00JS800040001<00000000000000000000
oooooooooom@0000?@000:00000H000030000000000U0000300000d0080X000030000040001B0000
L0400040000ioooo0000000000000000T040000000000082@`1=04d0B@0a03000000000000000000
0000000000000000000000000000000000000000000000000000000000000000?`00?`@0001DbAP0
@=IG08c:603eLBig6`0n07@1E@000000D05E05P3e`4005L08=9G0<1kE`00000010000000001L0@01
0000020000000041E<TH0000002<bQP0mG4^MeI5JPKnooooZSPZMj8d:WL00000001G023BE`1n7PZ>
000001SBE`2LbQP0RU=gM@00E@000000XEAgMDDTE=en7PZ>8=9G0801fWD00000B03G0@00e`5XbQP0
OQh:SXC<6000L7UebFDeZ?kooonQE7Me1A;FMB3BE`30AEP0Fb8QR0002P30AEP0e<XH05`ieWETMP08
000002D0000<00000@0005@0001D00009P4007?mool^0@00OOgoo`40002[Z^4o7LOQ_o@F001Z<P00
0@0004`00000000000000000003ooooooooooe0000150000S00001P0000<0000000002D0000<0000
3@00P2P0000<00000@000580001`0@000@0007Goool0000000000000002@0@00000000000P9304d0
C@1903L0000000000000000000000000000000000000000000000000000000000000000000000000
00000000000o000o100005C96010eUL0S<XH0?Ea;WLK03h0M05E0000001@0ED0F0?G0@00E`0PdUL0
`7]G000000040000000005`100400000800000000@5DbAP0000008c:603eLBigETEZ1_kooonZ>2Yg
XS@ZM`00000005L08=9G07hN2Xl000006=9G09c:602:DgMe001E0000002QE7MeABADgGhN2XlPdUL0
P07JM@0000180=L1003G0FS:601n7PZ?Q<`H001`NGG9ICFXo_oooj5DMgD54]Ie8=9G0<15F01K8R68
000:0<15F03DbQP0G3WFMFAf00P000009@0000`000010000E00005@0000]0@00Mogooc41001moOoo
0@000:^ZhClMan6oR1L004`b00010000C00000000000000000000?ooooooooooD0000;00001@0000
600000`0000000009@0000`0000=0020:00000`000010000DP00070100010000>Oooo`0000000000
000009010000000000020T<0C@1B0340<00000000000000000000000000000000000000000000000
00000000000000000000000000000000000003l003l40000E<TH043FE`2<bQP0mG4^Ma/0?P1d0ED0
00000501E@1H0mL1001G023BE`30NeL0000000@000000000G0400@00000P000000010EC960000000
S<XH0?Ea;WMFAFX6o_ooojXh:WNR=2Yg00000000E`0PdUL0OQh:T000000HdUL0W<XH08YCMgD005D0
00000:5DMgE595CMOQh:T23BE`200MYe000004P0e`400=L1J<XH07hN2Y24c1P0071iMLUU=JSnoooo
XEAgM@DBeWDPdUL0`4EH05/R8HP000X0`4EH0=C:601L>MIeI7H02000000U000030000040001D0000
E0000381001coOoo=P4007gmool10000Zj[Q?ag7hKo^5`00JS800040001<00000000000000000000
oooooooooom@0000:0000500000H000030000000000U0000300000d0080X000030000040001B0000
L0400040000ioooo0000000000000000T040000000000082@`1=05<0F@0a0300C`1B04T0A`000000
0000000000000000000000000000000000000000000000000000000000000000?`00?`@0001DbAP0
@=IG08c:603eLBig6`0n07@1E@000000D05E05P3e`4005L08=9G0<1kE`00000010000000001L0@01
0000020000000041E<TH0000002<bQP0mG4^MeI5JPKnooooZSPZMj8d:WL00000001G023BE`1n7PZA
000001SBE`2LbQP0RU=gM@00E@000000XEAgMDDTE=en7PZA8=9G0801fWD00000B03G0@00e`5XbQP0
OQh:THC<6000L7UebFDeZ?kooonQE7Me1A;FMB3BE`30AEP0Fb8QR0002P30AEP0e<XH05`ieWETMP08
000002D0000<00000@0005@0001D0000=P4007?mooln0@00Q?goo`40002[Z^4o7LOQ_c`H001Z<P00
0@0004`00000000000000000003ooooooooooe00002Q0000X00001P0000<0000000002D0000<0000
3@00P2P0000<00000@000580001`0@000@0003Woool0000000000000002@0@00000000000P9304d0
C@190340<00000000000000000000000000000000000000000000000000000000000000000000000
00000000000o000o100005C96010eUL0S<XH0?Ea;WLK03h0M05E0000001@0ED0F0?G0@00E`0PdUL0
`7]G000000040000000005`100400000800000000@5DbAP0000008c:603eLBigETEZ1_kooonZ>2Yg
XS@ZM`00000005L08=9G07hN2Y8000006=9G09c:602:DgMe001E0000002QE7MeABADgGhN2Y8PdUL0
P07JM@0000180=L1003G0FS:601n7PZBQ<`H001`NGG9ICFXo_oooj5DMgD54]Ie8=9G0<15F01K8R68
000:0<15F03DbQP0G3WFMFAf00P000009@0000`000010000E00005@0000n0@00Logood81001moOoo
0@000:^ZhClMan6oeaP006Xb00010000C00000000000000000000?ooooooooooD00007@0001@0000
600000`0000000009@0000`0000=0020:00000`000010000DP00070100010000MOooo`0000000000
000009010000000000020T<0C@1=04T0=`0000000000000000000000000000000000000000000000
00000000000000000000000000000000000003l003l40000E<TH043FE`2<bQP0mG4^Ma/0?P1d0ED0
00000501E@1H0mL1001G023BE`30NeL0000000@000000000G0400@00000P000000010EC960000000
S<XH0?Ea;WMFAFX6o_ooojXh:WNR=2Yg00000000E`0PdUL0OQh:T`00000HdUL0W<XH08YCMgD005D0
00000:5DMgE595CMOQh:Tb3BE`200MYe000004P0e`400=L1J<XH07hN2Y>4c1P0071iMLUU=JSnoooo
XEAgM@DBeWDPdUL0`4EH05/R8HP000X0`4EH0=C:601L>MIeI7H02000000U000030000040001D0000
E0000481001boOooAP4007Smool10000Zj[Q?ag7hKlO6@00_3800040001<00000000000000000000
oooooooooom@0000/0000500000H000030000000000U0000300000d0080X000030000040001B0000
L0400040000ioooo0000000000000000T040000000000082@`1=0580<@0`00000000000000000000
0000000000000000000000000000000000000000000000000000000000000000?`00?`@0001DbAP0
@=IG08c:603eLBig6`0n07@1E@000000D05E05P3e`4005L08=9G0<1kE`00000010000000001L0@01
0000020000000041E<TH0000002<bQP0mG4^MeI5JPKnooooZSPZMj8d:WL00000001G023BE`1n7PZD
000001SBE`2LbQP0RU=gM@00E@000000XEAgMDDTE=en7PZD8=9G0801fWD00000B03G0@00e`5XbQP0
OQh:U8C<6000L7UebFDeZ?kooonQE7Me1A;FMB3BE`30AEP0Fb8QR0002P30AEP0e<XH05`ieWETMP08
000002D0000<00000@0005@0001D0000A`4007?moom;0@00OOgoo`40002[Z^4o7LOQ_hDI001Z<P00
0@0004`00000000000000000003ooooooooooe00000Y0000D00001P0000<0000000005@0001D0000
C04007?moom@0@00OOgoo`40002[Z^4o7LOQ_o@I001Z<P000@0004`00000000000000000003ooooo
oooooe00001c0000D00001P0000<0000000005@0001D0000D04007?moomC0@00OOgoo`40002[Z^4o
7LOQ_d8J001Z<P000@0004`00000000000000000003ooooooooooe00001Y0000?00001P0000<0000
000005@0001D0000D`4007?moomI0@00OOgoo`40002[Z^4o7LOQ_gXJ001Z<P000@0004`000000000
00000000003ooooooooooe00001^0000N00001P0000<0000000005@0001D0000F04007?moomL0@00
OOgoo`40002[Z^4o7LOQ_nPJ001Z<P000@0004`00000000000000000003ooooooooooe00000X0000
D00001P0000<0000000002D0000<00003@00P2P0000<00000@000580001`0@000@0003Woool00000
00000000002@0@00000000000P9304d0C@190340<000000000000000000000000000000000000000
0000000000000000000000000000000000000000000o000o100005C96010eUL0S<XH0?Ea;WLK03h0
M05E0000001@0ED0F0?G0@00E`0PdUL0`7]G000000040000000005`100400000800000000@5DbAP0
000008c:603eLBigETEZ1_kooonZ>2YgXS@ZM`00000005L08=9G07hN2YD000006=9G09c:602:DgMe
001E0000002QE7MeABADgGhN2YDPdUL0P07JM@0000180=L1003G0FS:601n7PZEQ<`H001`NGG9ICFX
o_oooj5DMgD54]Ie8=9G0<15F01K8R68000:0<15F03DbQP0G3WFMFAf00P000009@0000`000010000
E00005@0001L0@00Logoof81001moOoo0@000:^ZhClMan6o=Q/006Xb00010000C000000000000000
00000?ooooooooooD00007P0001h0000600000`0000000009@0000`0000=0020:00000`000010000
DP00070100010000>Oooo`0000000000000009010000000000020T<0C@1B0340<000000000000000
0000000000000000000000000000000000000000000000000000000000000000000003l003l40000
E<TH043FE`2<bQP0mG4^Ma/0?P1d0ED000000501E@1H0mL1001G023BE`30NeL0000000@000000000
G0400@00000P000000010EC960000000S<XH0?Ea;WMFAFX6o_ooojXh:WNR=2Yg00000000E`0PdUL0
OQh:UP00000HdUL0W<XH08YCMgD005D000000:5DMgE595CMOQh:UR3BE`200MYe000004P0e`400=L1
J<XH07hN2YJ4c1P0071iMLUU=JSnooooXEAgM@DBeWDPdUL0`4EH05/R8HP000X0`4EH0=C:601L>MIe
I7H02000000U000030000040001D0000E0000681001coOooIP4007gmool10000Zj[Q?ag7hKnX6`00
JS800040001<00000000000000000000oooooooooom@0000:@000500000U0000300000d0080X0000
30000040000>000050000000000@0000500000Q00@PT00006000008@`=/100000`00000000000000
000001]000100000=000004000020000Z8al@i=S8lBTH=A2daeB@@<0002XS7a3Tf<Sa7eN/d>CHb?4
Z8al@a`K8<@Q000020000680000<00000@000240000800008@0000P0001c000030000000000L0000
200002D0000<00000000P2D0000<00001`00P2D0000<00003P00P1T0000<0000oooo01P0000<0000
00000180000<00000P0001<0000<00000@0001@0000<00003@0001D0000<00000@0001H0000<0000
000000d0000@000000000000000j0000300000X0000K000040000000000000008`000200000Bc2E1
00000000001HIRm1oHlSaLSTgdDT0000900001;<9D400000000005QV;d7mSb?5b>COA@@0001c0000
30000000000=00004000000000000000DP00070100020000400000L00000000000000;`200000000
1`828U<0N@1c07@0I@1]00004`2Pn?oolP400000000lcA/2P?Soo`P0F7kkm_oo00000000000PcA/2
P?Sooooo00000?T6R9]l0000081Tc480bla<?IS=@P0HnO/6bB`ZMc0R8CdR08X160000000003Hi?X6
20000<nY94400<Lmh8^b0P000030g:d2]<U200000000000000000?oooolXcD80E<e204CH@P3eLBig
53hO0Okooon<hbUgl^0YM`00h@Tho0000P000000000P0000Q<e20:S=@P3[F7Me001k00P0500VFWMe
U]Be=000003Hi?X6ooooo`<00000000000000000001`cD8000000;CD@P00L7UeMY:>@OkooolVFWMe
HQ?FMK2Xn@H10000g<e20>3=@P0_<=IeI7H02000000U00003000008000160000R00007`00017A4U3
0P000?d0001boOooIP4007omool`0000I`1U06h0I@1b0640M01U06@0801R07T0801G04d0AP0_04D0
C@160200HP1Q06<0J`1U06h0I00P06l0IP0P0700L`1d06l0I@1T06T0M00006T0KP1`07D0M0000000
8`000200000A]0@o00000000003PD@booHlSaLSTgdDT00009000016d13l0000000000>1A3;omSb?5
b>COA@@0000S00008000016d13l0000000000>1A3;omSb?5b>COAB@0000T00004K@4?`0000000000
h54<_of?8lG8i=m510000180000<00000@0001H0000<0000600001P0000<000000000580001`0@00
0`0003Woool0000000000000002@0@00000000L00P9304d0C@190340<00000000000000000000000
000000000000000000000000000000000000000000000000000000@00038bQP0000000P000070000
000008iC=gG8bQP0<<XH0>b`@`040000Q0000<S:60000000000000`0000000000@00023:60000000
Q0000:0?000200000`000<S:60000000000003c:601oWT<0o0Xe083:600004<0100008je@`2NKUCM
J7he0268AP0000000000000000010000C<XH000_BP0<baP0h9a204j02mgnoooo00130=fe@`1XOSD0
00000000=@1XOSD0b<XH0040000h01h02`000<S:601XOSD00@<00;1m=@010000H7he06Af00P00000
9@0000`000030000E00005@0000:00002@0004T0001f00000@000:^ZhClMan6oc1<006Xb00010000
C00000000000000000000?ooooooooooD00007D0gnUh0000600000`000000000DP00070100040000
500000T00000000000000;`2000000001`828U<0N@1c07@0I@1]000000000000hP000000001/U8/2
P?Soo`000000000000000000001@U8/2P?SookZF00000=Ie]fCFMC0R8Cd0000000000040001Xj]L7
h<a2065TeWD`8R4m00000000001D0000000006SZe`MHcD80gU7FMC0R8CgX_`070P00073M[@9D0000
00000040000h01h02`000<S:601XOSD00@<00;1m=@010000H7he000000P00000`=b]0[C9@P1HcD80
;c3FMES=@P1V<=IeV0HH1mSTnPHU0000000:09@V002<cT807OXUM30R8Cd00007J>[G1`80001`gJd2
/PXVM;@7fWD00000]0OJMH01fWF/1QP7/<e202l`eWF`cD80IS3FMOP660OHi?X6I7H02000000U0000
300000@0000X0000300000<0001B0000L04000<0000ioooo0000000000000000T040000000070082
@`1=0580<@0`00000000000000000000000000000000000000000000000000000000000000000000
0000000000000000?`00?`@000020000@=IG0<S:600000006`0n07@1E@000000D05E05P3e`4004<0
8=9G0<1kE`00000010000000001L0@010000020000000041E<TH08cS:GN<bQP0mG4^MeI5JPKnoooo
ZSPZMj8d:WL00000001G023BE`1n7PZ;000001SBE`2LbQP0RU=gM@00E@000000XEAgMDDTE=en7PZ;
8=9G0801fWD0QSD0B03G0@00e`5XbQP0OQh:RhC<6000L7UebFDeZ?kooonQE7Me1A;FMB3BE`30AEP0
Fb8QR0002P30AEP0e<XH05`ieWETMP08000002D0000<00000`0005@0001D0000A@0000T0001_0000
MP000040002[Z^4o7LOQ_chD001Z<P000@0004`00000000000000000003ooooooooooe00000X0?oo
D00001P0000<0000000002D0000<0000100002P0000<00000`000580001`0@000`0003Woool00000
00000000002@0@00000000L00P9304d0C@190340<000000000000000000000000000000000000000
0000000000000000000000000000000000000000000o000o100005C96010eUL0S<XH0?Ea;WLK03h0
M05E0000001@0ED0F0?G0@00E`0PdUL0`7]G000000040000000005`100400000800000000@5DbAP0
000008c:603eLBigETEZ1_kooonZ>2YgXS@ZM`00000005L08=9G07hN2X`000006=9G09c:602:DgMe
001E0000002QE7MeABADgGhN2X`PdUL0P07JM@0000180=L1003G0FS:601n7PZ<Q<`H001`NGG9ICFX
o_oooj5DMgD54]Ie8=9G0<15F01K8R68000:0<15F03DbQP0G3WFMFAf00P000009@0000`000030000
E00005@0001^00002@000:d0001f00000@000:^ZhClMan6oS1@006Xb00010000C000000000000000
00000?ooooooooooD00007P0oomh0000600000`000000000E00005@0002Y00002@000<T0001f0000
0@000:^ZhClMan6ooQ@006Xb00010000C00000000000000000000?ooooooooooD00003/0ooll0000
600000`000000000E00005@0003F00002@000001001f00000@000:^ZhClMan6oEQD006Xb00010000
C00000000000000000000?ooooooooooD00007@0B@1@0000600000`0000000009@0000`000040000
:00000`000030000DP00070100030000>Oooo`000000000000000901000000001`020T<0C@1B0340
<0000000000000000000000000000000000000000000000000000000000000000000000000000000
000003l003l40000E<TH043FE`2<bQP0mG4^Ma/0?P1d0ED000000501E@1H0mL1001G023BE`30NeL0
000000@000000000G0400@00000P000000010EC960000000S<XH0?Ea;WMFAFX6o_ooojXh:WNR=2Yg
00000000E`0PdUL0OQh:S@00000HdUL0W<XH08YCMgD005D000000:5DMgE595CMOQh:SB3BE`200MYe
000004P0e`400=L1J<XH07hN2Xf4c1P0071iMLUU=JSnooooXEAgM@DBeWDPdUL0`4EH05/R8HP000X0
`4EH0=C:601L>MIeI7H02000000U0000300000<0001D0000E0000?`0000900009P4007H000010000
Zj[Q?ag7hKnN5@00JS800040001<00000000000000000000oooooooooom@0000:@0a0500000H0000
30000000001D0000E000040100090000T`4007H000010000Zj[Q?ag7hKlR5P00JS800040001<0000
0000000000000000oooooooooom@0000?@1O0:00000H000030000000000U0000300000@0000X0000
300000<0001B0000L04000<0000ioooo0000000000000000T040000000070082@`1=04d0B@0a0300
00000000000000000000000000000000000000000000000000000000000000000000000000000000
?`00?`@0001DbAP0@=IG08c:603eLBig6`0n07@1E@000000D05E05P3e`4005L08=9G0<1kE`000000
10000000001L0@010000020000000041E<TH0000002<bQP0mG4^MeI5JPKnooooZSPZMj8d:WL00000
001G023BE`1n7PZ>000001SBE`2LbQP0RU=gM@00E@000000XEAgMDDTE=en7PZ>8=9G0801fWD00000
B03G0@00e`5XbQP0OQh:SXC<6000L7UebFDeZ?kooonQE7Me1A;FMB3BE`30AEP0Fb8QR0002P30AEP0
e<XH05`ieWETMP08000002D0000<00000`0005@0001D0000[@4000T0003l0@00MP000040002[Z^4o
7LOQ_o@F001Z<P000@0004`00000000000000000003ooooooooooe00001505l0S00001P0000<0000
000002D0000<0000100002P0000<00000`000580001`0@000`0007Goool0000000000000002@0@00
000000L00P9304d0C@1903L000000000000000000000000000000000000000000000000000000000
000000000000000000000000000o000o100005C96010eUL0S<XH0?Ea;WLK03h0M05E0000001@0ED0
F0?G0@00E`0PdUL0`7]G000000040000000005`100400000800000000@5DbAP0000008c:603eLBig
ETEZ1_kooonZ>2YgXS@ZM`00000005L08=9G07hN2Xl000006=9G09c:602:DgMe001E0000002QE7Me
ABADgGhN2XlPdUL0P07JM@0000180=L1003G0FS:601n7PZ?Q<`H001`NGG9ICFXo_oooj5DMgD54]Ie
8=9G0<15F01K8R68000:0<15F03DbQP0G3WFMFAf00P000009@0000`000030000E00005@0003j0@00
<P0002H2001m00000@000:^ZhClMan6oR1L004`b00010000C00000000000000000000?oooooooooo
D0000;00G`1@0000600000`0000000009@0000`000040000:00000`000030000DP00070100030000
>Oooo`000000000000000901000000001`020T<0C@1B0340<0000000000000000000000000000000
000000000000000000000000000000000000000000000000000003l003l40000E<TH043FE`2<bQP0
mG4^Ma/0?P1d0ED000000501E@1H0mL1001G023BE`30NeL0000000@000000000G0400@00000P0000
00010EC960000000S<XH0?Ea;WMFAFX6o_ooojXh:WNR=2Yg00000000E`0PdUL0OQh:T000000HdUL0
W<XH08YCMgD005D000000:5DMgE595CMOQh:T23BE`200MYe000004P0e`400=L1J<XH07hN2Y24c1P0
071iMLUU=JSnooooXEAgM@DBeWDPdUL0`4EH05/R8HP000X0`4EH0=C:601L>MIeI7H02000000U0000
300000<0001D0000E00002l200090000F@8007H000010000Zj[Q?ag7hKo^5`00JS800040001<0000
0000000000000000oooooooooom@0000:01O0500000H000030000000000U0000300000@0000X0000
300000<0001B0000L04000<0000ioooo0000000000000000T040000000070082@`1=05<0F@0a0300
C`1B04T0A`0000000000000000000000000000000000000000000000000000000000000000000000
?`00?`@0001DbAP0@=IG08c:603eLBig6`0n07@1E@000000D05E05P3e`4005L08=9G0<1kE`000000
10000000001L0@010000020000000041E<TH0000002<bQP0mG4^MeI5JPKnooooZSPZMj8d:WL00000
001G023BE`1n7PZA000001SBE`2LbQP0RU=gM@00E@000000XEAgMDDTE=en7PZA8=9G0801fWD00000
B03G0@00e`5XbQP0OQh:THC<6000L7UebFDeZ?kooonQE7Me1A;FMB3BE`30AEP0Fb8QR0002P30AEP0
e<XH05`ieWETMP08000002D0000<00000`0005@0001D0000E`8000H0002Z0P00``000040002[Z^4o
7LOQ_c`H001Z<P000@0004`00000000000000000003ooooooooooe00002Q0?ooX00001P0000<0000
000002D0000<0000100002P0000<00000`000580001`0@000`0003Woool0000000000000002@0@00
000000L00P9304d0C@190340<0000000000000000000000000000000000000000000000000000000
000000000000000000000000000o000o100005C96010eUL0S<XH0?Ea;WLK03h0M05E0000001@0ED0
F0?G0@00E`0PdUL0`7]G000000040000000005`100400000800000000@5DbAP0000008c:603eLBig
ETEZ1_kooonZ>2YgXS@ZM`00000005L08=9G07hN2Y8000006=9G09c:602:DgMe001E0000002QE7Me
ABADgGhN2Y8PdUL0P07JM@0000180=L1003G0FS:601n7PZBQ<`H001`NGG9ICFXo_oooj5DMgD54]Ie
8=9G0<15F01K8R68000:0<15F03DbQP0G3WFMFAf00P000009@0000`000030000E00005@0002W0P00
2@000=42001f00000@000:^ZhClMan6oeaP006Xb00010000C00000000000000000000?oooooooooo
D00007@0oom@0000600000`0000000009@0000`000040000:00000`000030000DP00070100030000
MOooo`000000000000000901000000001`020T<0C@1=04T0=`000000000000000000000000000000
000000000000000000000000000000000000000000000000000003l003l40000E<TH043FE`2<bQP0
mG4^Ma/0?P1d0ED000000501E@1H0mL1001G023BE`30NeL0000000@000000000G0400@00000P0000
00010EC960000000S<XH0?Ea;WMFAFX6o_ooojXh:WNR=2Yg00000000E`0PdUL0OQh:T`00000HdUL0
W<XH08YCMgD005D000000:5DMgE595CMOQh:Tb3BE`200MYe000004P0e`400=L1J<XH07hN2Y>4c1P0
071iMLUU=JSnooooXEAgM@DBeWDPdUL0`4EH05/R8HP000X0`4EH0=C:601L>MIeI7H02000000U0000
300000<0001D0000E0000<d2003eoooon@80040000010000Zj[Q?ag7hKlO6@00_3800040001<0000
0000000000000000oooooooooom@0000/01gME00000H000030000000000U0000300000@0000X0000
300000<0001B0000L04000<0000ioooo0000000000000000T040000000070082@`1=0580<@0`0000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
?`00?`@0001DbAP0@=IG08c:603eLBig6`0n07@1E@000000D05E05P3e`4005L08=9G0<1kE`000000
10000000001L0@010000020000000041E<TH0000002<bQP0mG4^MeI5JPKnooooZSPZMj8d:WL00000
001G023BE`1n7PZD000001SBE`2LbQP0RU=gM@00E@000000XEAgMDDTE=en7PZD8=9G0801fWD00000
B03G0@00e`5XbQP0OQh:U8C<6000L7UebFDeZ?kooonQE7Me1A;FMB3BE`30AEP0Fb8QR0002P30AEP0
e<XH05`ieWETMP08000002D0000<00000`0005@0001D00000P<000T0000/0`00MP000040002[Z^4o
7LOQ_hDI001Z<P000@0004`00000000000000000003ooooooooooe00000Y0640D00001P0000<0000
000005@0001D0000>`<000T0001U0`00MP000040002[Z^4o7LOQ_o@I001Z<P000@0004`000000000
00000000003ooooooooooe00001c07MeD00001P0000<0000000005@0001D0000I0<000T000240`00
MP000040002[Z^4o7LOQ_d8J001Z<P000@0004`00000000000000000003ooooooooooe00001Y01P0
?00001P0000<0000000005@0001D0000P@<000T000300`00MP000040002[Z^4o7LOQ_gXJ001Z<P00
0@0004`00000000000000000003ooooooooooe00001^0?ooN00001P0000<0000000005@0001D0000
^P<000T0003T0`00MP000040002[Z^4o7LOQ_nPJ001Z<P000@0004`00000000000000000003ooooo
oooooe00000X04T0D00001P0000<0000000002D0000<0000100002P0000<00000`000580001`0@00
0`0003Woool0000000000000002@0@00000000L00P9304d0C@190340<00000000000000000000000
00000000000000000000000000000000000000000000000000000000000o000o100005C96010eUL0
S<XH0?Ea;WLK03h0M05E0000001@0ED0F0?G0@00E`0PdUL0`7]G000000040000000005`100400000
800000000@5DbAP0000008c:603eLBigETEZ1_kooonZ>2YgXS@ZM`00000005L08=9G07hN2YD00000
6=9G09c:602:DgMe001E0000002QE7MeABADgGhN2YDPdUL0P07JM@0000180=L1003G0FS:601n7PZE
Q<`H001`NGG9ICFXo_oooj5DMgD54]Ie8=9G0<15F01K8R68000:0<15F03DbQP0G3WFMFAf00P00000
9@0000`000030000E00005@0003R0`002@000244001f00000@000:^ZhClMan6o=Q/006Xb00010000
C00000000000000000000?ooooooooooD00007P0001h0000600000`0000000009@0000`000040000
:00000`000030000DP00070100030000>Oooo`000000000000000901000000001`020T<0C@1B0340
<0000000000000000000000000000000000000000000000000000000000000000000000000000000
000003l003l40000E<TH043FE`2<bQP0mG4^Ma/0?P1d0ED000000501E@1H0mL1001G023BE`30NeL0
000000@000000000G0400@00000P000000010EC960000000S<XH0?Ea;WMFAFX6o_ooojXh:WNR=2Yg
00000000E`0PdUL0OQh:UP00000HdUL0W<XH08YCMgD005D000000:5DMgE595CMOQh:UR3BE`200MYe
000004P0e`400=L1J<XH07hN2YJ4c1P0071iMLUU=JSnooooXEAgM@DBeWDPdUL0`4EH05/R8HP000X0
`4EH0=C:601L>MIeI7H02000000U0000300000<0001D0000E00001d400090000A`@007H000010000
Zj[Q?ag7hKnX6`00JS800040001<00000000000000000000oooooooooom@0000:@000500000U0000
300000@0000X0000300000<000160000500000P00017A4U30`000280000<0000ooooob80000<0000
ooooobD0000<00003@00P2P0000<00000P0002P0000<000010000280000<0000ooooodH000300@00
]04004E=AR//@000900001P00000080o000000000000080o0000P000080Z@000900001P0003cHRA1
000000000006@b=1^R/RaE]Vd4DT@00030000000000Z@000900001P0002`0R`j00000000002`0R`j
002HZ@004JT[@00030000000000N@0H030000000000Q@0D0300000000008@084600000`000024<3K
000000<0010d@08030000000000N@0T030000000000Z@000900001P0002`0R`j00000000002`0R`j
002HZ@004JTQ@0L030000000000Z@000900001P0002`0R`j00000000002`0R`j002HZ@004JT[@000
30000000000[@00030000000000N@0H030000000000Q@0D0300000000008@0<4600000`000024<3K
000000<0010d@0<030000000000N@0T030000000000Z@000900001P00000080o000000000000080o
00000000000Q@0L030000000001<0000I000000000000000@P@008D000000000000004<400260000
:@2Z0000000000000020?`00000000000020?`000000000000000000000000000000000000000000
8P0000`0003oooooAP0001`0000@0000ADe6:`90000<0000000000h0000D000000000100000D0000

\>"], "Graphics",
  GeneratedCell->False,
  CellAutoOverwrite->False,
  ImageSize->{170.7631578947368, 20.366248189280594`},
  ImageMargins->{{0.625, 0.}, {0., 6.25}}]
}], "Text",
 CellChangeTimes->{{3.633439583415289*^9, 3.6334395909637213`*^9}, {
  3.636904756973955*^9, 3.636904760701168*^9}, {3.6372443229373713`*^9, 
  3.6372443239854317`*^9}, {3.6372443908282547`*^9, 3.637244411443434*^9}, {
  3.637244624301608*^9, 3.6372446392814655`*^9}, {3.6386021058016*^9, 
  3.6386021060495996`*^9}},
 Background->RGBColor[1, 1, 0]],

Cell[BoxData[
 RowBox[{
  RowBox[{"uSol", "[", 
   RowBox[{"x_", ",", "t_", ",", "gamma_"}], "]"}], ":=", 
  RowBox[{
   RowBox[{"Sin", "[", "x", "]"}], "*", 
   RowBox[{"MittagLefflerE", "[", 
    RowBox[{"gamma", ",", "1", ",", 
     RowBox[{"-", 
      RowBox[{"t", "^", "gamma"}]}]}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.55982895496875*^9, 3.559828984796875*^9}, {
  3.589297606934722*^9, 3.589297614521156*^9}, {3.58929766495004*^9, 
  3.5892976659740987`*^9}, {3.636984577724125*^9, 3.6369845787221823`*^9}, {
  3.636984838198024*^9, 3.636984845629449*^9}, {3.6372992202553*^9, 
  3.6372992212393*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"uSol", "[", 
   RowBox[{"x_", ",", "t_", ",", "1"}], "]"}], ":=", 
  RowBox[{
   RowBox[{"Sin", "[", "x", "]"}], "*", 
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{"-", "t"}]]}]}]], "Input",
 CellChangeTimes->{{3.55982895496875*^9, 3.559828984796875*^9}, {
  3.589297606934722*^9, 3.589297614521156*^9}, {3.58929766495004*^9, 
  3.5892976659740987`*^9}, {3.5910154423406*^9, 3.5910154638066*^9}, {
  3.636984581098318*^9, 3.636984581721354*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Source term.  In this example is zero.", "Text",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 CellChangeTimes->{{3.561126817421*^9, 3.5611268309564*^9}, {
  3.636904881452074*^9, 3.636904980035713*^9}, {3.6369050699238544`*^9, 
  3.6369050775552907`*^9}, {3.6369769775634212`*^9, 3.6369769906991725`*^9}, {
  3.6371385049577384`*^9, 3.6371385138497543`*^9}, {3.637245196685347*^9, 
  3.637245198101428*^9}},
 Background->RGBColor[1, 1, 0]],

Cell[BoxData[
 RowBox[{
  RowBox[{"funSource", "[", 
   RowBox[{"x_", ",", "t_", ",", "ga_"}], "]"}], ":=", "0."}]], "Input",
 CellChangeTimes->{{3.591431994688729*^9, 3.5914321084812374`*^9}, {
   3.591451756628047*^9, 3.591451758933179*^9}, {3.625845727689809*^9, 
   3.625845731041814*^9}, {3.625846217702113*^9, 3.6258462469911566`*^9}, {
   3.625847584206174*^9, 3.6258476065492067`*^9}, 3.625848178113057*^9, {
   3.6371374450686765`*^9, 3.637137465738713*^9}, {3.637138662007818*^9, 
   3.6371386623354187`*^9}, 3.6374195761703997`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Order of the fractional derivative: \[Gamma]=gammak. Here we choose \
\[Gamma]=1/4\
\>", "Text",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 CellChangeTimes->{{3.561126817421*^9, 3.5611268309564*^9}, {
  3.6371385902274885`*^9, 3.6371386028323107`*^9}, {3.637244700524968*^9, 
  3.637244706452307*^9}, {3.6372448627442465`*^9, 3.637244876903056*^9}, {
  3.637245133464731*^9, 3.6372451551689725`*^9}},
 Background->RGBColor[1, 1, 0]],

Cell[BoxData[
 RowBox[{
  RowBox[{"gammak", "=", "0.25"}], ";"}]], "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 CellChangeTimes->{
  3.561049517788604*^9, 3.561050679357012*^9, {3.5610903980687075`*^9, 
   3.561090407393154*^9}, 3.5611220939094*^9, 3.5611268309564*^9, {
   3.589270600217*^9, 3.589270601552*^9}, 3.589271184201*^9, {
   3.5892976824570417`*^9, 3.589297690719514*^9}, {3.5895180885616817`*^9, 
   3.589518088921702*^9}, 3.5895191624171023`*^9, {3.5895527656894464`*^9, 
   3.5895527660334663`*^9}, {3.5895546010014205`*^9, 
   3.5895546019304733`*^9}, {3.5896016762995996`*^9, 
   3.5896016765648003`*^9}, {3.589602256472*^9, 3.5896022604751997`*^9}, 
   3.5896030482298*^9, 3.589607261262*^9, 3.5897244193129997`*^9, {
   3.589736570752*^9, 3.58973657109*^9}, {3.589892478189557*^9, 
   3.589892479577959*^9}, {3.589896047289415*^9, 3.5898960476124334`*^9}, {
   3.5900402744212723`*^9, 3.5900402746552725`*^9}, {3.5900407451852994`*^9, 
   3.590040745949701*^9}, {3.5900412475908303`*^9, 3.5900412482928314`*^9}, {
   3.5900423256057243`*^9, 3.590042326089325*^9}, {3.5900685957871857`*^9, 
   3.59006859656723*^9}, 3.59007342585645*^9, 3.59021224751*^9, {
   3.5906711458351727`*^9, 3.5906711462141943`*^9}, {3.5907517913939114`*^9, 
   3.5907517917099295`*^9}, {3.591432157985069*^9, 3.591432180683367*^9}, {
   3.591433432296955*^9, 3.591433436503196*^9}, {3.59145199060743*^9, 
   3.591451992849558*^9}, {3.5914533024744644`*^9, 3.5914533051926203`*^9}, {
   3.5915293458577127`*^9, 3.5915293461947317`*^9}, {3.591536410992815*^9, 
   3.591536413805976*^9}, {3.6019157899983253`*^9, 3.6019157928574886`*^9}, {
   3.625846526613616*^9, 3.625846526953616*^9}, {3.625846592786713*^9, 
   3.625846625234762*^9}, 3.626066770157*^9, 3.6371379698887987`*^9, 
   3.63713800489886*^9, {3.637138089029808*^9, 3.6371380899190097`*^9}, {
   3.637138180102768*^9, 3.637138187356781*^9}, {3.6372445229178095`*^9, 
   3.63724452415388*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 "Spatial discretization:   ",
 Cell[BoxData[
  FormBox["\[CapitalDelta]x", TraditionalForm]]],
 "\[Congruent]deltax=Pi/Np where, in this case, we choose  Np=2Nx=40"
}], "Text",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 CellChangeTimes->{{3.561126817421*^9, 3.5611268309564*^9}, {
  3.637138214220028*^9, 3.63713822105284*^9}, {3.6371382858085537`*^9, 
  3.6371382934681673`*^9}, {3.6372446824849367`*^9, 3.637244688716293*^9}, {
  3.6372455356097326`*^9, 3.6372455512256255`*^9}, {3.6373023353903*^9, 
  3.6373023528543*^9}},
 Background->RGBColor[1, 1, 0]],

Cell[BoxData[
 RowBox[{
  RowBox[{"Nx", "=", "20"}], ";", 
  RowBox[{"Np", "=", 
   RowBox[{"2", "*", "Nx"}]}], ";", 
  RowBox[{"deltax", "=", 
   RowBox[{"Pi", "/", 
    RowBox[{"(", 
     RowBox[{"2.", "*", "Nx"}], ")"}]}]}], ";"}]], "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 CellChangeTimes->{
  3.561049517788604*^9, 3.561050679357012*^9, {3.5610903980687075`*^9, 
   3.561090407393154*^9}, 3.5611220939094*^9, 3.5611268309564*^9, {
   3.589270600217*^9, 3.589270601552*^9}, 3.589271184201*^9, {
   3.5892976824570417`*^9, 3.589297690719514*^9}, {3.5895180885616817`*^9, 
   3.589518088921702*^9}, 3.5895191624171023`*^9, {3.5895527656894464`*^9, 
   3.5895527660334663`*^9}, {3.5895546010014205`*^9, 
   3.5895546019304733`*^9}, {3.5896016762995996`*^9, 
   3.5896016765648003`*^9}, {3.589602256472*^9, 3.5896022604751997`*^9}, 
   3.5896030482298*^9, 3.589607261262*^9, 3.5897244193129997`*^9, {
   3.589736570752*^9, 3.58973657109*^9}, {3.589892478189557*^9, 
   3.589892479577959*^9}, {3.589896047289415*^9, 3.5898960476124334`*^9}, {
   3.5900402744212723`*^9, 3.5900402746552725`*^9}, {3.5900407451852994`*^9, 
   3.590040745949701*^9}, {3.5900412475908303`*^9, 3.5900412482928314`*^9}, {
   3.5900423256057243`*^9, 3.590042326089325*^9}, {3.5900685957871857`*^9, 
   3.59006859656723*^9}, 3.59007342585645*^9, 3.59021224751*^9, {
   3.5906711458351727`*^9, 3.5906711462141943`*^9}, {3.5907517913939114`*^9, 
   3.5907517917099295`*^9}, {3.591432157985069*^9, 3.591432180683367*^9}, {
   3.591433432296955*^9, 3.591433436503196*^9}, {3.59145199060743*^9, 
   3.591451992849558*^9}, {3.5914533024744644`*^9, 3.5914533051926203`*^9}, {
   3.5915293458577127`*^9, 3.5915293461947317`*^9}, {3.591536410992815*^9, 
   3.591536413805976*^9}, {3.6019157899983253`*^9, 3.6019157928574886`*^9}, {
   3.625846526613616*^9, 3.625846526953616*^9}, {3.625846592786713*^9, 
   3.625846625234762*^9}, 3.626066770157*^9, 3.6371379698887987`*^9, 
   3.63713800489886*^9, {3.637138089029808*^9, 3.6371380899190097`*^9}, {
   3.637138206466814*^9, 3.6371382108036222`*^9}, {3.6371382954961705`*^9, 
   3.637138310440997*^9}, 3.637245208360015*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 "We set the initial condition:  ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["U", 
    RowBox[{"(", "0", ")"}]], TraditionalForm]],
  FormatType->"TraditionalForm"],
 "=UmatrixIni "
}], "Text",
 CellChangeTimes->{{3.636905374736289*^9, 3.636905467120573*^9}, {
  3.637237994529871*^9, 3.637237994660878*^9}, {3.6372449459830074`*^9, 
  3.637244989310486*^9}},
 Background->RGBColor[1, 1, 0]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"UmatrixIni", "=", 
  RowBox[{
   RowBox[{"Table", "[", " ", 
    RowBox[{
     RowBox[{"Sin", "[", 
      RowBox[{"j", "*", "deltax"}], "]"}], " ", ",", 
     RowBox[{"{", 
      RowBox[{"j", ",", "0", ",", "Np"}], "}"}]}], "]"}], "//", 
   "N"}]}]], "Input",
 CellChangeTimes->{{3.561048528378299*^9, 3.5610485460302944`*^9}, {
   3.561048578404682*^9, 3.56104860090897*^9}, {3.6371378058077106`*^9, 
   3.6371378183345327`*^9}, 3.6372379946768794`*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "0.`", ",", "0.07845909572784494`", ",", "0.15643446504023087`", ",", 
   "0.2334453638559054`", ",", "0.3090169943749474`", ",", 
   "0.3826834323650898`", ",", "0.45399049973954675`", ",", 
   "0.5224985647159488`", ",", "0.5877852522924731`", ",", 
   "0.6494480483301837`", ",", "0.7071067811865476`", ",", 
   "0.7604059656000309`", ",", "0.8090169943749475`", ",", 
   "0.8526401643540922`", ",", "0.8910065241883678`", ",", 
   "0.9238795325112867`", ",", "0.9510565162951535`", ",", 
   "0.9723699203976766`", ",", "0.9876883405951378`", ",", 
   "0.996917333733128`", ",", "1.`", ",", "0.996917333733128`", ",", 
   "0.9876883405951378`", ",", "0.9723699203976767`", ",", 
   "0.9510565162951536`", ",", "0.9238795325112867`", ",", 
   "0.8910065241883679`", ",", "0.8526401643540923`", ",", 
   "0.8090169943749475`", ",", "0.7604059656000309`", ",", 
   "0.7071067811865476`", ",", "0.6494480483301838`", ",", 
   "0.5877852522924732`", ",", "0.5224985647159489`", ",", 
   "0.45399049973954686`", ",", "0.3826834323650899`", ",", 
   "0.3090169943749475`", ",", "0.23344536385590553`", ",", 
   "0.15643446504023098`", ",", "0.07845909572784507`", ",", 
   "1.2246467991473532`*^-16"}], "}"}]], "Output",
 CellChangeTimes->{3.6385163322548*^9, 3.6386024372946*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Boundary conditions:  u(x=0,t)=uL[t]=0;   u(x=\[Pi],t)=uR[t]=0.", "Text",
 CellChangeTimes->{{3.636977189200526*^9, 3.636977192456712*^9}, {
  3.63724504621074*^9, 3.637245086579049*^9}},
 Background->RGBColor[1, 1, 0]],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"uL", "[", "t_", "]"}], "=", "0."}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"uR", "[", "t_", "]"}], "=", "0."}], ";"}]}], "Input",
 CellChangeTimes->{3.636991916174861*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
\[FilledSquare] Numerical results with the T&E method for tolerance  \
\[Tau]=0.001\
\>", "Subsubsection",
 CellChangeTimes->{{3.633439583415289*^9, 3.6334395909637213`*^9}, {
   3.636904756973955*^9, 3.636904760701168*^9}, 3.637138408549569*^9, {
   3.6372452357805834`*^9, 3.6372452451731205`*^9}, {3.6372463821981544`*^9, 
   3.6372463827581863`*^9}, {3.63724964646486*^9, 3.6372496489360013`*^9}, {
   3.6373006334223003`*^9, 3.6373006462943*^9}, {3.6373012081363*^9, 
   3.6373012093343*^9}, 3.6381088102334003`*^9}],

Cell[CellGroupData[{

Cell[TextData[{
 "uMs is a matrix that contains the full solution ",
 Cell[BoxData[
  FormBox[
   RowBox[{"{", 
    RowBox[{
     SubsuperscriptBox["U", "0", 
      RowBox[{"(", "m", ")"}]], ",", 
     SubsuperscriptBox["U", "1", 
      RowBox[{"(", "m", ")"}]], ",", 
     SubsuperscriptBox["U", "2", 
      RowBox[{"(", "m", ")"}]], ",", 
     RowBox[{"...", " ", 
      SubsuperscriptBox["U", "Np", 
       RowBox[{"(", "m", ")"}]]}]}], "}"}], TraditionalForm]]],
 "  for m=0,1,2,....,numSteps."
}], "Text",
 CellChangeTimes->{{3.6372979828863*^9, 3.6372980614302998`*^9}},
 Background->RGBColor[1, 1, 0.85]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"tolerance", "=", "0.001"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"numSteps", "=", "20"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"CPUtime", "=", 
   RowBox[{"Timing", "[", 
    RowBox[{"uMs", "=", 
     RowBox[{"uMsolutionTE", "[", 
      RowBox[{"numSteps", ",", "tolerance"}], "]"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Print", "[", 
   RowBox[{
   "\"\<Example 1. T&E method. Case with \[Tau]=\>\"", ",", "tolerance", ",", 
    "\"\< for \[Gamma]=\>\"", ",", "gammak", ",", "\"\<, Np=\>\"", ",", "Np", 
    ",", "\"\<,\!\(TraditionalForm\`\(\(\\\ \
\)\*SubscriptBox[\(\[CapitalDelta]\), \(0\)]\)\)=\>\"", ",", "Delta0TE", ",", 
    "\"\<, \!\(TraditionalForm\`\*SubscriptBox[\(\[CapitalDelta]\), \
\(max\)]\)=\>\"", " ", ",", "DeltatcapTE"}], " ", "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Print", "[", 
   RowBox[{"\"\<CPU time=\>\"", ",", 
    RowBox[{"CPUtime", "[", 
     RowBox[{"[", "1", "]"}], "]"}], ",", "\"\< seconds\>\""}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
  "Print", "[", "\"\<The solution is saved in the matrix uMs\>\"", "]"}], 
  ";"}]}], "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 CellChangeTimes->{{3.56061256346875*^9, 3.56061257284375*^9}, {
   3.56061260303125*^9, 3.560612663828125*^9}, {3.5610884668366947`*^9, 
   3.5610884717649765`*^9}, {3.5611210929323997`*^9, 3.5611211203416*^9}, {
   3.5611212573096*^9, 3.5611212593532*^9}, 3.5611216448120003`*^9, {
   3.5611216844625998`*^9, 3.5611216848213997`*^9}, {3.5611217681558*^9, 
   3.5611217684667997`*^9}, {3.5611222944344*^9, 3.5611223196862*^9}, {
   3.5611253416166*^9, 3.5611253440626*^9}, {3.5611260133876*^9, 
   3.5611260138276*^9}, {3.561127402519*^9, 3.5611274579006*^9}, {
   3.561127527574*^9, 3.5611275627130003`*^9}, {3.5902000697948065`*^9, 
   3.5902000708068647`*^9}, {3.590200323138297*^9, 3.590200324873397*^9}, {
   3.5902003709750333`*^9, 3.5902003711460433`*^9}, 3.590200421820942*^9, 
   3.590213289142*^9, {3.5902135189*^9, 3.590213539836*^9}, {
   3.5902135876359997`*^9, 3.590213616165*^9}, {3.590213707484*^9, 
   3.590213707868*^9}, {3.590213768476*^9, 3.590213768955*^9}, 
   3.5902143461549997`*^9, {3.59021447142*^9, 3.590214495682*^9}, 
   3.5903882375313997`*^9, {3.5903932563884*^9, 3.5903932567464*^9}, {
   3.5903932903714*^9, 3.5903933180104*^9}, {3.5903933542194*^9, 
   3.5903933561303997`*^9}, 3.5903933876914*^9, 3.5903934182594*^9, 
   3.5903941132114*^9, 3.60195384860737*^9, {3.601953894449992*^9, 
   3.601953894987023*^9}, {3.6334400976967044`*^9, 3.6334400980167227`*^9}, 
   3.6369936572364435`*^9, {3.636993750675788*^9, 3.6369937637635365`*^9}, 
   3.637004923308416*^9, 3.6370053615804834`*^9, {3.6372402113622026`*^9, 
   3.637240211367203*^9}, {3.6372452960570307`*^9, 3.6372453605797215`*^9}, {
   3.6372453910404634`*^9, 3.637245428304595*^9}, {3.637245470149988*^9, 
   3.6372455167096515`*^9}, {3.6372456161863413`*^9, 3.637245697827011*^9}, {
   3.637245729372815*^9, 3.637245777960594*^9}, {3.63724584310532*^9, 
   3.6372459587629356`*^9}, {3.637246021107501*^9, 3.6372460259367776`*^9}, {
   3.637246091338518*^9, 3.6372460918335466`*^9}, 3.6372463595788608`*^9, 
   3.637246525799368*^9, {3.6372465623644595`*^9, 3.637246581655563*^9}, {
   3.637246817573056*^9, 3.6372468214022756`*^9}, {3.6372470179475174`*^9, 
   3.637247018278536*^9}, {3.6372471839910145`*^9, 3.6372472107335443`*^9}, {
   3.6372472497587757`*^9, 3.637247279316467*^9}, {3.637247390205809*^9, 
   3.6372473996553497`*^9}, {3.637247443785874*^9, 3.6372474491481805`*^9}, {
   3.637247899618946*^9, 3.6372479030021396`*^9}, {3.637247939714239*^9, 
   3.6372479400092564`*^9}, {3.6372482082135963`*^9, 3.637248224762543*^9}, {
   3.637248553257332*^9, 3.6372485587676473`*^9}, 3.6372496070256042`*^9, 
   3.6372975701323*^9, {3.6372979117462997`*^9, 3.6372979144493*^9}, 
   3.6372981329823*^9, 3.6372981646743*^9, {3.6372982614663*^9, 
   3.6372982617132998`*^9}, {3.6373004952983*^9, 3.6373005432813*^9}, 
   3.637367530737097*^9, {3.6373677389200044`*^9, 3.6373677414021463`*^9}, 
   3.6381087104184*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Example 1. T&E method. Case with \[Tau]=\"\>", 
   "\[InvisibleSpace]", "0.001`", 
   "\[InvisibleSpace]", "\<\" for \[Gamma]=\"\>", "\[InvisibleSpace]", 
   "0.25`", "\[InvisibleSpace]", "\<\", Np=\"\>", "\[InvisibleSpace]", "40", 
   "\[InvisibleSpace]", "\<\",\\!\\(TraditionalForm\\`\\(\\(\\\\ \
\\)\\*SubscriptBox[\\(\[CapitalDelta]\\), \\(0\\)]\\)\\)=\"\>", 
   "\[InvisibleSpace]", "0.01`", 
   "\[InvisibleSpace]", "\<\", \\!\\(TraditionalForm\\`\\*SubscriptBox[\\(\
\[CapitalDelta]\\), \\(max\\)]\\)=\"\>", "\[InvisibleSpace]", "1.`*^6"}],
  SequenceForm[
  "Example 1. T&E method. Case with \[Tau]=", 0.001, " for \[Gamma]=", 0.25, 
   ", Np=", 40, 
   ",\!\(TraditionalForm\`\(\(\\ \)\*SubscriptBox[\(\[CapitalDelta]\), \(0\)]\
\)\)=", 0.01, 
   ", \!\(TraditionalForm\`\*SubscriptBox[\(\[CapitalDelta]\), \(max\)]\)=", 
   1.*^6],
  Editable->False]], "Print",
 CellChangeTimes->{3.6385163360028*^9, 3.6386024410586*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"CPU time=\"\>", "\[InvisibleSpace]", "3.588023`", 
   "\[InvisibleSpace]", "\<\" seconds\"\>"}],
  SequenceForm["CPU time=", 3.588023, " seconds"],
  Editable->False]], "Print",
 CellChangeTimes->{3.6385163360028*^9, 3.6386024410626*^9}],

Cell[BoxData["\<\"The solution is saved in the matrix uMs\"\>"], "Print",
 CellChangeTimes->{3.6385163360028*^9, 3.6386024410636*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 "The solution for the m-th timestep is just the m+1 element of this matrix:  \
uMs[[m+1]]=",
 Cell[BoxData[
  FormBox[
   RowBox[{"{", 
    RowBox[{
     SubsuperscriptBox["U", "0", 
      RowBox[{"(", "m", ")"}]], ",", 
     SubsuperscriptBox["U", "1", 
      RowBox[{"(", "m", ")"}]], ",", 
     SubsuperscriptBox["U", "2", 
      RowBox[{"(", "m", ")"}]], ",", 
     RowBox[{"...", " ", 
      SubsuperscriptBox["U", "Np", 
       RowBox[{"(", "m", ")"}]]}]}], "}"}], TraditionalForm]]],
 " "
}], "Text",
 CellChangeTimes->{{3.6372981691743*^9, 3.6372982503743*^9}, {
  3.6372983312943*^9, 3.6372983351903*^9}},
 Background->RGBColor[1, 1, 0.85]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"mStep", "=", "5"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Print", "[", 
   RowBox[{"\"\<The numerical solution at time \>\"", ",", 
    RowBox[{"tt", "[", "mStep", "]"}], ",", "\"\< is:\>\""}], "]"}], ";", 
  RowBox[{"uMs", "[", 
   RowBox[{"[", "mStep", "]"}], "]"}]}]}], "Input",
 CellChangeTimes->{{3.6372983391352997`*^9, 3.6372983412483*^9}, {
  3.6372985221443*^9, 3.6372986028712997`*^9}}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"The numerical solution at time \"\>", "\[InvisibleSpace]", 
   "0.000025796890258789063`", "\[InvisibleSpace]", "\<\" is:\"\>"}],
  SequenceForm[
  "The numerical solution at time ", 0.000025796890258789063`, " is:"],
  Editable->False]], "Print",
 CellChangeTimes->{3.6385163360768003`*^9, 3.6386024411126003`*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"-", "1.2681406054365902`*^-16"}], ",", "0.0744667877927203`", ",",
    "0.14847446307597886`", ",", "0.2215667439216049`", ",", 
   "0.2932929921125353`", ",", "0.3632109914772751`", ",", 
   "0.43088967429964664`", ",", "0.4959117789946042`", ",", 
   "0.5578764226646595`", ",", "0.6164015726762516`", ",", 
   "0.6711264020179718`", ",", "0.7217135139190761`", ",", 
   "0.7678510220127723`", ",", "0.8092544732193847`", ",", 
   "0.8456686014941797`", ",", "0.8768689016274166`", ",", 
   "0.9026630133936216`", ",", "0.9228919075163435`", ",", 
   "0.9374308661365256`", ",", "0.9461902517395804`", ",", 
   "0.9491160598004736`", ",", "0.9461902517395802`", ",", 
   "0.9374308661365252`", ",", "0.9228919075163429`", ",", 
   "0.9026630133936209`", ",", "0.8768689016274159`", ",", 
   "0.845668601494179`", ",", "0.809254473219384`", ",", 
   "0.7678510220127717`", ",", "0.7217135139190755`", ",", 
   "0.6711264020179714`", ",", "0.6164015726762513`", ",", 
   "0.5578764226646593`", ",", "0.4959117789946041`", ",", 
   "0.43088967429964653`", ",", "0.363210991477275`", ",", 
   "0.2932929921125352`", ",", "0.22156674392160483`", ",", 
   "0.14847446307597886`", ",", "0.07446678779272038`", ",", "0.`"}], 
  "}"}]], "Output",
 CellChangeTimes->{3.6385163360797997`*^9, 3.6386024411146*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 "The [[m+1,j+1] element of this matrix is the numerical solution for time ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["t", "m"], TraditionalForm]],
  FormatType->"TraditionalForm"],
 " and position ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["x", "j"], TraditionalForm]],
  FormatType->"TraditionalForm"],
 ":  uMs[[m+1,j+1]]=",
 Cell[BoxData[
  FormBox[
   SubsuperscriptBox["U", "j", 
    RowBox[{"(", "m", ")"}]], TraditionalForm]]],
 " "
}], "Text",
 CellChangeTimes->{{3.6372981691743*^9, 3.6372982503743*^9}, {
  3.6372983312943*^9, 3.6372983351903*^9}, {3.6372983799263*^9, 
  3.6372984925123*^9}},
 Background->RGBColor[1, 1, 0.85]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"mStep", "=", "5"}], ";", 
  RowBox[{"jPos", "=", 
   RowBox[{"Nx", "+", "1"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Print", "[", 
   RowBox[{"\"\<The numerical solution at time t=\>\"", ",", 
    RowBox[{"tt", "[", "mStep", "]"}], ",", "\"\< and position x= \>\"", " ", 
    ",", 
    RowBox[{"jPos", "*", "deltax"}], " ", ",", "\"\< is:\>\""}], "]"}], ";", 
  RowBox[{"uMs", "[", 
   RowBox[{"[", 
    RowBox[{"mStep", ",", "jPos"}], "]"}], "]"}]}]}], "Input",
 CellChangeTimes->{{3.6372983391352997`*^9, 3.6372983412483*^9}, {
  3.6372985221443*^9, 3.6372986028712997`*^9}, {3.6372986373603*^9, 
  3.6372986956313*^9}}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"The numerical solution at time t=\"\>", "\[InvisibleSpace]", 
   "0.000025796890258789063`", 
   "\[InvisibleSpace]", "\<\" and position x= \"\>", "\[InvisibleSpace]", 
   "1.6493361431346414`", "\[InvisibleSpace]", "\<\" is:\"\>"}],
  SequenceForm[
  "The numerical solution at time t=", 0.000025796890258789063`, 
   " and position x= ", 1.6493361431346414`, " is:"],
  Editable->False]], "Print",
 CellChangeTimes->{3.6385163360948*^9, 3.6386024411216*^9}],

Cell[BoxData["0.9491160598004736`"], "Output",
 CellChangeTimes->{3.6385163360968*^9, 3.6386024411236*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 "A plot comparing the numerical and the exact solution at time ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["t", "mStep"], TraditionalForm]],
  FormatType->"TraditionalForm"],
 " "
}], "Text",
 CellChangeTimes->{{3.6372989561913*^9, 3.6372990023753*^9}, {
  3.6372990787602997`*^9, 3.6372990811603003`*^9}},
 Background->RGBColor[1, 1, 0.85]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"mStep", "=", "5"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Print", "[", "\"\<T&E method\>\"", "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Print", "[", 
   RowBox[{
   "\"\<Numerical solution (points) and exact solution (line)  at time \
t=\>\"", ",", 
    RowBox[{"tt", "[", "mStep", "]"}]}], "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{" ", 
  RowBox[{
   RowBox[{"FigNum", "=", 
    RowBox[{"ListPlot", "[", 
     RowBox[{
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"xj", "=", 
           RowBox[{"j", "*", "deltax"}]}], ",", 
          RowBox[{"uMs", "[", 
           RowBox[{"[", 
            RowBox[{
             RowBox[{"mStep", "+", "1"}], ",", 
             RowBox[{"j", "+", "1"}]}], "]"}], "]"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"j", ",", "0", ",", "Np"}], "}"}]}], "]"}], ",", 
      RowBox[{"PlotRange", "\[Rule]", "All"}]}], "]"}]}], ";", 
   RowBox[{"FigExact", "=", 
    RowBox[{"Plot", "[", 
     RowBox[{
      RowBox[{"uSol", "[", 
       RowBox[{"x", ",", 
        RowBox[{"tt", "[", "mStep", "]"}], ",", "gammak"}], "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"x", ",", "0", ",", "Pi"}], "}"}], ",", 
      RowBox[{"PlotRange", "\[Rule]", "All"}]}], "]"}]}], ";", " ", 
   RowBox[{"Show", "[", 
    RowBox[{"FigNum", ",", "FigExact", ",", 
     RowBox[{"Frame", "\[Rule]", "True"}], ",", 
     RowBox[{"FrameLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<x\>\"", ",", "\"\<u\>\""}], "}"}]}]}], 
    "]"}]}]}]}], "Input",
 CellChangeTimes->{{3.6372990098493*^9, 3.6372993557363*^9}, {
   3.6372994017143*^9, 3.6372994018733*^9}, {3.6372994547862997`*^9, 
   3.6372994982653*^9}, {3.6372997348883*^9, 3.6372998253603*^9}, {
   3.6373012862503*^9, 3.6373012895603*^9}, 3.637368667160097*^9, 
   3.6385152363288*^9, {3.6385152673557997`*^9, 3.6385152848128*^9}, 
   3.6385153271028*^9}],

Cell[BoxData["\<\"T&E method\"\>"], "Print",
 CellChangeTimes->{3.6385163361118*^9, 3.6386024411306*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Numerical solution (points) and exact solution (line)  at time \
t=\"\>", "\[InvisibleSpace]", "0.000025796890258789063`"}],
  SequenceForm[
  "Numerical solution (points) and exact solution (line)  at time t=", 
   0.000025796890258789063`],
  Editable->False]], "Print",
 CellChangeTimes->{3.6385163361118*^9, 3.6386024411316*^9}],

Cell[BoxData[
 GraphicsBox[{{{}, {{}, 
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
      0.012833333333333334`], AbsoluteThickness[1.6], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQBGIQDQNOq/b8q5l7bM+DD3PK9KW32Mt3VG+avGyTPYR/
xH7B84XHb08/ZB+Q+drwuMY5e/GSIGnR/aeh8lfsi2yf7nKMvWQvoesS8lvx
pv2lmK7Tf/Zeg6q/Z99r8/3epV+37I8EnWw/Of2hvdbTA7uFee9D9T+x7+gR
0tcsf2j/p68gdeq8Z/bmriZ95j6Poea9tL/X3L/iAtNTe5PT4s6JS1/bcxvz
2TnMeAY1/5394VuXUtm4Xthva46fIBb2wf7KM5OG26EvofZ9tK9ofnZ+c+Ur
+0uKxvU1Nz/ZBxtO23Ko+DXU/i/25fGfG2ud3ti/28+W9yjmq/3bSbPezX3y
Buqeb/aq7wXFVSLf2nPF3YrxePDdvsBvpWDE/LdQ9/20F604IHB621t7tT9r
vdcl/7IvhMpD3PvbXh2q32lWo5XI8z/276HmQ9z/z74San+cRahmVdZ/+xCo
+yD+YXCohLrfNluE58M3BoerKP5jdDgC9b+3VR3zYgsmBx5o+ED8y+RwHxp+
kZwvfoVWMTvAwhfifxYHWPin3wj8xLGHxUEbGj+Q8GB16IfGX+ny3S93/2V1
uAKNX0j4sDmUQOO/uUz1YZ49u4M8NH1AwovdYS00/Ux07b+h2Mjh4AhNX5Dw
43SApUMAKCE9xA==
       "]]}, {}}, {}}, {{}, {}, 
    {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], Opacity[
     1.], LineBox[CompressedData["
1:eJwd2Gk8Vd3bB3BD6aiUDJkakClJRUWF3yYUyRRppCSSJBRu6ZakOVMqikih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      "]]}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->True,
  FrameLabel->{
    FormBox["\"x\"", TraditionalForm], 
    FormBox["\"u\"", TraditionalForm]},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  Method->{},
  PlotRange->{{0, 3.141592653589793}, {-6.276975751215589*^-16, 
    0.9285636260208344}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.6385163364158*^9, 3.6386024424856*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Here we give a table that compares the numerical and exact solution at the \
middle point, x=\[Pi]/2, for the first numSteps timesteps. \
\>", "Text",
 CellChangeTimes->{{3.6372981691743*^9, 3.6372982503743*^9}, {
  3.6372983312943*^9, 3.6372983351903*^9}, {3.6372983799263*^9, 
  3.6372984925123*^9}, {3.6372988496542997`*^9, 3.6372989263983*^9}},
 Background->RGBColor[1, 1, 0.85]],

Cell[BoxData[
 RowBox[{
  RowBox[{"headTE", "=", 
   RowBox[{"{", 
    RowBox[{
    "\"\<step\>\"", ",", "\"\<t\>\"", ",", 
     "\"\<\!\(\*SubscriptBox[\(U\), \(\(T &\) E\)]\)(\[Pi]/2,t)\>\"", ",", 
     "\"\<\!\(\*SubscriptBox[\(u\), \(exact\)]\)(\[Pi]/2,t)\>\"", ",", 
     "\"\<error\>\""}], "}"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.6372462215509663`*^9, 3.6372463423118734`*^9}, {
   3.6372468240104246`*^9, 3.637246824353444*^9}, 3.6381088426504*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"tabTE", "=", 
   RowBox[{
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"m", ",", 
        RowBox[{"tt", "[", "m", "]"}], ",", 
        RowBox[{"uMs", "[", 
         RowBox[{"[", 
          RowBox[{
           RowBox[{"m", "+", "1"}], ",", 
           RowBox[{"Nx", "+", "1"}]}], "]"}], "]"}], ",", 
        RowBox[{"uSol", "[", 
         RowBox[{
          RowBox[{"Pi", "/", "2"}], ",", 
          RowBox[{"tt", "[", "m", "]"}], ",", "gammak"}], "]"}], ",", 
        RowBox[{
         RowBox[{"uMs", "[", 
          RowBox[{"[", 
           RowBox[{
            RowBox[{"m", "+", "1"}], ",", 
            RowBox[{"Nx", "+", "1"}]}], "]"}], "]"}], "-", 
         RowBox[{"uSol", "[", 
          RowBox[{
           RowBox[{"Pi", "/", "2"}], ",", 
           RowBox[{"tt", "[", "m", "]"}], ",", "gammak"}], "]"}]}]}], "}"}], 
      ",", 
      RowBox[{"{", 
       RowBox[{"m", ",", "0", ",", "numSteps"}], "}"}]}], "]"}], "//", 
    "N"}]}], ";", 
  RowBox[{
   RowBox[{"Insert", "[", 
    RowBox[{"tabTE", ",", "headTE", ",", "1"}], "]"}], "//", 
   "TableForm"}]}]], "Input",
 CellChangeTimes->{3.6372987625292997`*^9, 3.6373689102660017`*^9}],

Cell[BoxData[
 TagBox[GridBox[{
    {"\<\"step\"\>", "\<\"t\"\>", "\<\"\\!\\(\\*SubscriptBox[\\(U\\), \\(\\(T \
&\\) E\\)]\\)(\[Pi]/2,t)\"\>", "\<\"\\!\\(\\*SubscriptBox[\\(u\\), \
\\(exact\\)]\\)(\[Pi]/2,t)\"\>", "\<\"error\"\>"},
    {"0.`", "0.`", "1.`", "1.`", "0.`"},
    {"1.`", "9.5367431640625`*^-9", "0.991004045485367`", 
     "0.9892065813331623`", "0.0017974641522047197`"},
    {"2.`", "1.621246337890625`*^-7", "0.97990914840239`", 
     "0.9783075647820929`", "0.0016015836202970535`"},
    {"3.`", "1.3828277587890625`*^-6", "0.9651819283963673`", 
     "0.9634513547674846`", "0.0017305736288827367`"},
    {"4.`", "6.265640258789063`*^-6", "0.9491160598004736`", 
     "0.9474966014356663`", "0.001619458364807369`"},
    {"5.`", "0.000025796890258789063`", "0.9285636260208344`", 
     "0.9267346995999425`", "0.001828926420891941`"},
    {"6.`", "0.00006485939025878907`", "0.9108407954948049`", 
     "0.9093527222214579`", "0.0014880732733469904`"},
    {"7.`", "0.00014298439025878907`", "0.8928801210132037`", 
     "0.8915576460982639`", "0.001322474914939753`"},
    {"8.`", "0.00029923439025878905`", "0.8734815221850879`", 
     "0.8722068470825147`", "0.001274675102573175`"},
    {"9.`", "0.0006117343902587891`", "0.8520044215229889`", 
     "0.8507050302162286`", "0.001299391306760378`"},
    {"10.`", "0.001236734390258789`", "0.8280419910090905`", 
     "0.8266725950243078`", "0.0013693959847826953`"},
    {"11.`", "0.002486734390258789`", "0.8013251371109607`", 
     "0.7998587687856475`", "0.0014663683253131055`"},
    {"12.`", "0.0049867343902587884`", "0.7716956491930757`", 
     "0.7701194108136478`", "0.0015762383794278856`"},
    {"13.`", "0.009986734390258788`", "0.7391049360452376`", 
     "0.7374179427056877`", "0.0016869933395499137`"},
    {"14.`", "0.01998673439025879`", "0.7036224775328701`", 
     "0.7018347707559527`", "0.0017877067769174193`"},
    {"15.`", "0.039986734390258794`", "0.6654457246542532`", 
     "0.663577415818677`", "0.0018683088355762045`"},
    {"16.`", "0.0799867343902588`", "0.6249056234027883`", 
     "0.6229857374908198`", "0.0019198859119685663`"},
    {"17.`", "0.1599867343902588`", "0.5824632417566152`", 
     "0.5805278957349705`", "0.0019353460216446905`"},
    {"18.`", "0.3199867343902588`", "0.5386944834453053`", 
     "0.5367842381660661`", "0.00191024527923922`"},
    {"19.`", "0.6399867343902588`", "0.4942619927286682`", 
     "0.49241847538398614`", "0.0018435173446820774`"},
    {"20.`", "1.279986734390259`", "0.4498759635676727`", 
     "0.44813812667421693`", "0.0017378368934557464`"}
   },
   GridBoxAlignment->{
    "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
     "RowsIndexed" -> {}},
   GridBoxSpacings->{"Columns" -> {
       Offset[0.27999999999999997`], {
        Offset[2.0999999999999996`]}, 
       Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
       Offset[0.2], {
        Offset[0.4]}, 
       Offset[0.2]}, "RowsIndexed" -> {}}],
  Function[BoxForm`e$, 
   TableForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{3.6385163365058002`*^9, 3.6386024431106*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 "A plot comparing the numerical and the exact solution at  position \
x=\[Pi]/2 for times  t  with   0\[LessEqual]t\[LessEqual] ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["t", "numSteps"], TraditionalForm]],
  FormatType->"TraditionalForm"],
 " "
}], "Text",
 CellChangeTimes->{{3.6372989561913*^9, 3.6372990023753*^9}, {
  3.6372990787602997`*^9, 3.6372990811603003`*^9}, {3.6372998614302998`*^9, 
  3.6372998879683*^9}, {3.6373004057753*^9, 3.6373004634223003`*^9}},
 Background->RGBColor[1, 1, 0.85]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"Print", "[", "\"\<T&E method\>\"", "]"}], ";", 
  RowBox[{
  "Print", "[", 
   "\"\<Numerical solution (points) and exact solution (line) at position x=\
\[Pi]/2 vs. time\>\"", "]"}], ";", " ", 
  RowBox[{"FigNum", "=", 
   RowBox[{"ListPlot", "[", 
    RowBox[{
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"tabTE", "[", 
          RowBox[{"[", 
           RowBox[{"n", ",", "2"}], "]"}], "]"}], ",", 
         RowBox[{"tabTE", "[", 
          RowBox[{"[", 
           RowBox[{"n", ",", "3"}], "]"}], "]"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"n", ",", "1", ",", 
         RowBox[{"numSteps", "+", "1"}]}], "}"}]}], "]"}], ",", 
     RowBox[{"PlotRange", "\[Rule]", "All"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"FigExact", "=", 
   RowBox[{"Plot", "[", 
    RowBox[{
     RowBox[{"uSol", "[", 
      RowBox[{
       RowBox[{"Pi", "/", "2"}], ",", "time", ",", "gammak"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"time", ",", "0", ",", 
       RowBox[{"1.1", "*", 
        RowBox[{"tabTE", "[", 
         RowBox[{"[", 
          RowBox[{
           RowBox[{"numSteps", "+", "1"}], ",", "2"}], "]"}], "]"}]}]}], 
      "}"}], ",", 
     RowBox[{"PlotRange", "\[Rule]", "All"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"Show", "[", 
  RowBox[{"FigNum", ",", "FigExact", ",", 
   RowBox[{"Frame", "\[Rule]", "True"}], ",", 
   RowBox[{"FrameLabel", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"\"\<time\>\"", ",", "\"\<u\>\""}], "}"}]}], ",", 
   RowBox[{"PlotRange", "\[Rule]", "All"}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.6372990098493*^9, 3.6372993557363*^9}, {
   3.6372994017143*^9, 3.6372994018733*^9}, {3.6372994547862997`*^9, 
   3.6372994982653*^9}, {3.6372997348883*^9, 3.6372998253603*^9}, {
   3.6372999061773*^9, 3.6372999638333*^9}, {3.6373000656813*^9, 
   3.6373002790032997`*^9}, {3.6373003226673*^9, 3.6373003301463003`*^9}, 
   3.6373012777063*^9, 3.6373013767462997`*^9, 3.6373014286173*^9, 
   3.6373017989203*^9, 3.637321114720934*^9, {3.6373689761797714`*^9, 
   3.637368989716546*^9}, {3.6385153447757998`*^9, 3.6385153486308002`*^9}, 
   3.6385161398198*^9}],

Cell[BoxData["\<\"T&E method\"\>"], "Print",
 CellChangeTimes->{3.6385163365248003`*^9, 3.6386024431205997`*^9}],

Cell[BoxData["\<\"Numerical solution (points) and exact solution (line) at \
position x=\[Pi]/2 vs. time\"\>"], "Print",
 CellChangeTimes->{3.6385163365248003`*^9, 3.6386024431226*^9}],

Cell[BoxData[
 GraphicsBox[{{{}, {{}, 
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
      0.012833333333333334`], AbsoluteThickness[1.6], PointBox[CompressedData["
1:eJxTTMoPSmViYGAQBWIQjQo+2FeLrHN/WOVi94ltk6zftvf2h79qxPQfarXT
F9DLy4p+b28MBtvtDB+pmB199M7e42EVUMctu7+F85ZoxL+zP3sGCHh+24lW
HBA4ve2tfaEt1/XFDIL2nzMmzJit+tb+G8i4vUr2zxkfhFROemO/Q671deAc
Y/t6+7zW/s+v7WfNBAJuF/sXi84fm+f82h6ou8DWOcReXvPxq8D6V/aHgO7h
j0+xjwnTnluy5KU9SPuPnBL7j3+/C+3e+MIeZP2b4hZ7Vh6R1P3LntsvKbDl
Si+fYh9WZ+4p3PLMfgLQAJXKJfYbn4pcDfF+at/2OnAHU9UWeyv7z8JW/x/b
g0KhqOqIPf+Hc587Fz+ytwM6YGXVFftjd+aa/bF5aA90fenRqif2Ilazef8u
vG//JnBH3OWqL/bLnm7sPXLqjj0AwlaheA==
       "]]}, {}}, {}}, {{}, {}, 
    {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], Opacity[
     1.], LineBox[CompressedData["
1:eJwV1Wk8FIgbB3DZQo5qZNuiXMkqiS2SI7+iwxmypcNZqAyNK0dEIUfkqiyt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      "]]}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->True,
  FrameLabel->{
    FormBox["\"time\"", TraditionalForm], 
    FormBox["\"u\"", TraditionalForm]},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  Method->{},
  PlotRange->All,
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.02], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.6385163368478003`*^9, 3.6386024434256*^9}]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 "\[FilledSquare] Numerical results with the ",
 StyleBox["predictive",
  FontSlant->"Italic"],
 " method for tolerance  \[Tau]=0.001"
}], "Subsubsection",
 CellChangeTimes->{{3.633439583415289*^9, 3.6334395909637213`*^9}, {
   3.636904756973955*^9, 3.636904760701168*^9}, 3.637138408549569*^9, {
   3.6372452357805834`*^9, 3.6372452451731205`*^9}, {3.6372463821981544`*^9, 
   3.6372463827581863`*^9}, {3.6372466129283514`*^9, 3.637246617848633*^9}, {
   3.6372496176812134`*^9, 3.637249632328051*^9}, {3.6373012138633003`*^9, 
   3.6373012367823*^9}}],

Cell[CellGroupData[{

Cell[TextData[{
 "uMs is a matrix that contains the full solution ",
 Cell[BoxData[
  FormBox[
   RowBox[{"{", 
    RowBox[{
     SubsuperscriptBox["U", "0", 
      RowBox[{"(", "m", ")"}]], ",", 
     SubsuperscriptBox["U", "1", 
      RowBox[{"(", "m", ")"}]], ",", 
     SubsuperscriptBox["U", "2", 
      RowBox[{"(", "m", ")"}]], ",", 
     RowBox[{"...", " ", 
      SubsuperscriptBox["U", "Np", 
       RowBox[{"(", "m", ")"}]]}]}], "}"}], TraditionalForm]]],
 "  for m=0,1,2,....,numSteps."
}], "Text",
 CellChangeTimes->{{3.6372979828863*^9, 3.6372980614302998`*^9}},
 Background->RGBColor[1, 1, 0.85]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"tolerance", "=", "0.001"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"numSteps", "=", "20"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"CPUtime", "=", 
   RowBox[{"Timing", "[", 
    RowBox[{"uMs", "=", 
     RowBox[{"uMsolutionPredictive", "[", 
      RowBox[{"numSteps", ",", "tolerance"}], "]"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Print", "[", 
   RowBox[{
   "\"\<Example 1. Predictive method. Case with \[Tau]=\>\"", ",", 
    "tolerance", ",", "\"\< for \[Gamma]=\>\"", ",", "gammak", ",", 
    "\"\<, Np=\>\"", ",", "Np", ",", 
    "\"\<,\!\(TraditionalForm\`\(\(\\\ \)\*SubscriptBox[\(\[CapitalDelta]\), \
\(0\)]\)\)=\>\"", ",", "Delta0Predictive", ",", 
    "\"\<, \!\(TraditionalForm\`\*SubscriptBox[\(\[CapitalDelta]\), \
\(max\)]\)=\>\"", " ", ",", "DeltatcapPredictive", "  ", ",", " ", 
    "\"\<,\[Omega]=\>\"", ",", "  ", "omegaParameter", ",", " ", 
    "\"\<,\!\(TraditionalForm\`\(\(\\\ \)\(\[Theta]\)\)\)=\>\"", ",", "  ", 
    "thetaParameter"}], "  ", "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Print", "[", 
   RowBox[{"\"\<CPU time=\>\"", ",", 
    RowBox[{"CPUtime", "[", 
     RowBox[{"[", "1", "]"}], "]"}], ",", "\"\< seconds\>\""}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
  "Print", "[", "\"\<The solution is saved in the matrix uMs\>\"", "]"}], 
  ";"}]}], "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 CellChangeTimes->{{3.56061256346875*^9, 3.56061257284375*^9}, {
   3.56061260303125*^9, 3.560612663828125*^9}, {3.5610884668366947`*^9, 
   3.5610884717649765`*^9}, {3.5611210929323997`*^9, 3.5611211203416*^9}, {
   3.5611212573096*^9, 3.5611212593532*^9}, 3.5611216448120003`*^9, {
   3.5611216844625998`*^9, 3.5611216848213997`*^9}, {3.5611217681558*^9, 
   3.5611217684667997`*^9}, {3.5611222944344*^9, 3.5611223196862*^9}, {
   3.5611253416166*^9, 3.5611253440626*^9}, {3.5611260133876*^9, 
   3.5611260138276*^9}, {3.561127402519*^9, 3.5611274579006*^9}, {
   3.561127527574*^9, 3.5611275627130003`*^9}, {3.5902000697948065`*^9, 
   3.5902000708068647`*^9}, {3.590200323138297*^9, 3.590200324873397*^9}, {
   3.5902003709750333`*^9, 3.5902003711460433`*^9}, 3.590200421820942*^9, 
   3.590213289142*^9, {3.5902135189*^9, 3.590213539836*^9}, {
   3.5902135876359997`*^9, 3.590213616165*^9}, {3.590213707484*^9, 
   3.590213707868*^9}, {3.590213768476*^9, 3.590213768955*^9}, 
   3.5902143461549997`*^9, {3.59021447142*^9, 3.590214495682*^9}, 
   3.5903882375313997`*^9, {3.5903932563884*^9, 3.5903932567464*^9}, {
   3.5903932903714*^9, 3.5903933180104*^9}, {3.5903933542194*^9, 
   3.5903933561303997`*^9}, 3.5903933876914*^9, 3.5903934182594*^9, 
   3.5903941132114*^9, 3.60195384860737*^9, {3.601953894449992*^9, 
   3.601953894987023*^9}, {3.6334400976967044`*^9, 3.6334400980167227`*^9}, 
   3.6369936572364435`*^9, {3.636993750675788*^9, 3.6369937637635365`*^9}, 
   3.637004923308416*^9, 3.6370053615804834`*^9, {3.6372402113622026`*^9, 
   3.637240211367203*^9}, {3.6372452960570307`*^9, 3.6372453605797215`*^9}, {
   3.6372453910404634`*^9, 3.637245428304595*^9}, {3.637245470149988*^9, 
   3.6372455167096515`*^9}, {3.6372456161863413`*^9, 3.637245697827011*^9}, {
   3.637245729372815*^9, 3.637245777960594*^9}, {3.63724584310532*^9, 
   3.6372459587629356`*^9}, {3.637246021107501*^9, 3.6372460259367776`*^9}, {
   3.637246091338518*^9, 3.6372460918335466`*^9}, 3.6372463595788608`*^9, 
   3.637246525799368*^9, {3.6372465623644595`*^9, 3.637246581655563*^9}, {
   3.637246817573056*^9, 3.6372468214022756`*^9}, {3.6372470179475174`*^9, 
   3.637247018278536*^9}, {3.6372471839910145`*^9, 3.6372472107335443`*^9}, {
   3.6372472497587757`*^9, 3.637247279316467*^9}, {3.637247390205809*^9, 
   3.6372473996553497`*^9}, {3.637247443785874*^9, 3.6372474491481805`*^9}, {
   3.637247899618946*^9, 3.6372479030021396`*^9}, {3.637247939714239*^9, 
   3.6372479400092564`*^9}, {3.6372482082135963`*^9, 3.637248224762543*^9}, {
   3.637248553257332*^9, 3.6372485587676473`*^9}, 3.6372496070256042`*^9, 
   3.6372975701323*^9, {3.6372979117462997`*^9, 3.6372979144493*^9}, 
   3.6372981329823*^9, 3.6372981646743*^9, {3.6372982614663*^9, 
   3.6372982617132998`*^9}, {3.6373004952983*^9, 3.6373005432813*^9}, {
   3.6373007987373*^9, 3.6373008130083*^9}, {3.6373043408522997`*^9, 
   3.6373043483543*^9}, 3.63736759268064*^9, 3.637367914082023*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Example 1. Predictive method. Case with \[Tau]=\"\>", 
   "\[InvisibleSpace]", "0.001`", 
   "\[InvisibleSpace]", "\<\" for \[Gamma]=\"\>", "\[InvisibleSpace]", 
   "0.25`", "\[InvisibleSpace]", "\<\", Np=\"\>", "\[InvisibleSpace]", "40", 
   "\[InvisibleSpace]", "\<\",\\!\\(TraditionalForm\\`\\(\\(\\\\ \
\\)\\*SubscriptBox[\\(\[CapitalDelta]\\), \\(0\\)]\\)\\)=\"\>", 
   "\[InvisibleSpace]", "0.01`", 
   "\[InvisibleSpace]", "\<\", \\!\\(TraditionalForm\\`\\*SubscriptBox[\\(\
\[CapitalDelta]\\), \\(max\\)]\\)=\"\>", "\[InvisibleSpace]", "1.`*^6", 
   "\[InvisibleSpace]", "\<\",\[Omega]=\"\>", "\[InvisibleSpace]", "0.5`", 
   "\[InvisibleSpace]", "\<\",\\!\\(TraditionalForm\\`\\(\\(\\\\ \\)\\(\
\[Theta]\\)\\)\\)=\"\>", "\[InvisibleSpace]", "1.5`"}],
  SequenceForm[
  "Example 1. Predictive method. Case with \[Tau]=", 0.001, " for \[Gamma]=", 
   0.25, ", Np=", 40, 
   ",\!\(TraditionalForm\`\(\(\\ \)\*SubscriptBox[\(\[CapitalDelta]\), \(0\)]\
\)\)=", 0.01, 
   ", \!\(TraditionalForm\`\*SubscriptBox[\(\[CapitalDelta]\), \(max\)]\)=", 
   1.*^6, ",\[Omega]=", 0.5, 
   ",\!\(TraditionalForm\`\(\(\\ \)\(\[Theta]\)\)\)=", 1.5],
  Editable->False]], "Print",
 CellChangeTimes->{3.6385163388768*^9, 3.6386024454926*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"CPU time=\"\>", "\[InvisibleSpace]", "2.0436131`", 
   "\[InvisibleSpace]", "\<\" seconds\"\>"}],
  SequenceForm["CPU time=", 2.0436131, " seconds"],
  Editable->False]], "Print",
 CellChangeTimes->{3.6385163388768*^9, 3.6386024454946003`*^9}],

Cell[BoxData["\<\"The solution is saved in the matrix uMs\"\>"], "Print",
 CellChangeTimes->{3.6385163388768*^9, 3.6386024454955997`*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 "The solution for the m-th timestep is just the m+1 element of this matrix:  \
uMs[[m+1]]=",
 Cell[BoxData[
  FormBox[
   RowBox[{"{", 
    RowBox[{
     SubsuperscriptBox["U", "0", 
      RowBox[{"(", "m", ")"}]], ",", 
     SubsuperscriptBox["U", "1", 
      RowBox[{"(", "m", ")"}]], ",", 
     SubsuperscriptBox["U", "2", 
      RowBox[{"(", "m", ")"}]], ",", 
     RowBox[{"...", " ", 
      SubsuperscriptBox["U", "Np", 
       RowBox[{"(", "m", ")"}]]}]}], "}"}], TraditionalForm]]],
 " "
}], "Text",
 CellChangeTimes->{{3.6372981691743*^9, 3.6372982503743*^9}, {
  3.6372983312943*^9, 3.6372983351903*^9}},
 Background->RGBColor[1, 1, 0.85]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"mStep", "=", "5"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Print", "[", 
   RowBox[{"\"\<The numerical solution at time \>\"", ",", 
    RowBox[{"tt", "[", "mStep", "]"}], ",", "\"\< is:\>\""}], "]"}], ";", 
  RowBox[{"uMs", "[", 
   RowBox[{"[", "mStep", "]"}], "]"}]}]}], "Input",
 CellChangeTimes->{{3.6372983391352997`*^9, 3.6372983412483*^9}, {
  3.6372985221443*^9, 3.6372986028712997`*^9}}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"The numerical solution at time \"\>", "\[InvisibleSpace]", 
   "0.00002211856601898225`", "\[InvisibleSpace]", "\<\" is:\"\>"}],
  SequenceForm[
  "The numerical solution at time ", 0.00002211856601898225, " is:"],
  Editable->False]], "Print",
 CellChangeTimes->{3.6385163391698*^9, 3.6386024456216*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "6.887932171516818`*^-16", ",", "0.07428761710449704`", ",", 
   "0.14811722634640476`", ",", "0.22103364363391112`", ",", 
   "0.29258731500726937`", ",", "0.3623370882884525`", ",", 
   "0.4298529329310287`", ",", "0.49471859130148005`", ",", 
   "0.5565341450459323`", ",", "0.6149184807197935`", ",", 
   "0.6695116394788724`", ",", "0.719977036345352`", ",", 
   "0.7660035353661031`", ",", "0.8073073678692985`", ",", 
   "0.8436338819926379`", ",", "0.8747591126967592`", ",", 
   "0.9004911625841822`", ",", "0.920671385010576`", ",", 
   "0.935175362194077`", ",", "0.9439136722922871`", ",", 
   "0.9468324407176677`", ",", "0.9439136722922872`", ",", 
   "0.9351753621940773`", ",", "0.9206713850105764`", ",", 
   "0.9004911625841825`", ",", "0.8747591126967594`", ",", 
   "0.843633881992638`", ",", "0.8073073678692985`", ",", 
   "0.766003535366103`", ",", "0.7199770363453519`", ",", 
   "0.6695116394788724`", ",", "0.6149184807197935`", ",", 
   "0.5565341450459325`", ",", "0.49471859130148016`", ",", 
   "0.42985293293102883`", ",", "0.36233708828845246`", ",", 
   "0.2925873150072692`", ",", "0.22103364363391087`", ",", 
   "0.14811722634640442`", ",", "0.07428761710449655`", ",", "0.`"}], 
  "}"}]], "Output",
 CellChangeTimes->{3.6385163391738*^9, 3.6386024456246*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 "The [[m+1,j+1] element of this matrix is the numerical solution for time ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["t", "m"], TraditionalForm]],
  FormatType->"TraditionalForm"],
 " and position ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["x", "j"], TraditionalForm]],
  FormatType->"TraditionalForm"],
 ":  uMs[[m+1,j+1]]=",
 Cell[BoxData[
  FormBox[
   SubsuperscriptBox["U", "j", 
    RowBox[{"(", "m", ")"}]], TraditionalForm]]],
 " "
}], "Text",
 CellChangeTimes->{{3.6372981691743*^9, 3.6372982503743*^9}, {
  3.6372983312943*^9, 3.6372983351903*^9}, {3.6372983799263*^9, 
  3.6372984925123*^9}},
 Background->RGBColor[1, 1, 0.85]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"mStep", "=", "5"}], ";", 
  RowBox[{"jPos", "=", 
   RowBox[{"Nx", "+", "1"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Print", "[", 
   RowBox[{"\"\<The numerical solution at time t=\>\"", ",", 
    RowBox[{"tt", "[", "mStep", "]"}], ",", "\"\< and position x= \>\"", " ", 
    ",", 
    RowBox[{"jPos", "*", "deltax"}], " ", ",", "\"\< is:\>\""}], "]"}], ";", 
  RowBox[{"uMs", "[", 
   RowBox[{"[", 
    RowBox[{"mStep", ",", "jPos"}], "]"}], "]"}]}]}], "Input",
 CellChangeTimes->{{3.6372983391352997`*^9, 3.6372983412483*^9}, {
  3.6372985221443*^9, 3.6372986028712997`*^9}, {3.6372986373603*^9, 
  3.6372986956313*^9}}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"The numerical solution at time t=\"\>", "\[InvisibleSpace]", 
   "0.00002211856601898225`", 
   "\[InvisibleSpace]", "\<\" and position x= \"\>", "\[InvisibleSpace]", 
   "1.6493361431346414`", "\[InvisibleSpace]", "\<\" is:\"\>"}],
  SequenceForm[
  "The numerical solution at time t=", 0.00002211856601898225, 
   " and position x= ", 1.6493361431346414`, " is:"],
  Editable->False]], "Print",
 CellChangeTimes->{3.6385163391868*^9, 3.6386024456316*^9}],

Cell[BoxData["0.9468324407176677`"], "Output",
 CellChangeTimes->{3.6385163391898003`*^9, 3.6386024456336*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 "A plot comparing the numerical and the exact solution at time ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["t", "mStep"], TraditionalForm]],
  FormatType->"TraditionalForm"],
 " "
}], "Text",
 CellChangeTimes->{{3.6372989561913*^9, 3.6372990023753*^9}, {
  3.6372990787602997`*^9, 3.6372990811603003`*^9}},
 Background->RGBColor[1, 1, 0.85]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"mStep", "=", "5"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Print", "[", "\"\<Predictive method\>\"", "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Print", "[", 
   RowBox[{
   "\"\<Numerical solution (points) and exact solution (line)  at time \
t=\>\"", ",", 
    RowBox[{"tt", "[", "mStep", "]"}]}], "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{" ", 
  RowBox[{
   RowBox[{"FigNum", "=", 
    RowBox[{"ListPlot", "[", 
     RowBox[{
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"xj", "=", 
           RowBox[{"j", "*", "deltax"}]}], ",", 
          RowBox[{"uMs", "[", 
           RowBox[{"[", 
            RowBox[{
             RowBox[{"mStep", "+", "1"}], ",", 
             RowBox[{"j", "+", "1"}]}], "]"}], "]"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"j", ",", "0", ",", "Np"}], "}"}]}], "]"}], ",", 
      RowBox[{"PlotRange", "\[Rule]", "All"}]}], "]"}]}], ";", 
   RowBox[{"FigExact", "=", 
    RowBox[{"Plot", "[", 
     RowBox[{
      RowBox[{"uSol", "[", 
       RowBox[{"x", ",", 
        RowBox[{"tt", "[", "mStep", "]"}], ",", "gammak"}], "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"x", ",", "0", ",", "Pi"}], "}"}], ",", 
      RowBox[{"PlotRange", "\[Rule]", "All"}]}], "]"}]}], ";", " ", 
   RowBox[{"Show", "[", 
    RowBox[{"FigNum", ",", "FigExact", ",", 
     RowBox[{"Frame", "\[Rule]", "True"}], ",", 
     RowBox[{"FrameLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<x\>\"", ",", "\"\<u\>\""}], "}"}]}]}], 
    "]"}]}]}]}], "Input",
 CellChangeTimes->{{3.6372990098493*^9, 3.6372993557363*^9}, {
   3.6372994017143*^9, 3.6372994018733*^9}, {3.6372994547862997`*^9, 
   3.6372994982653*^9}, {3.6372997348883*^9, 3.6372998253603*^9}, 
   3.6373011632593*^9, {3.6373012486103*^9, 3.6373012562163*^9}, 
   3.637368670208271*^9, {3.6385153998778*^9, 3.6385154116868*^9}}],

Cell[BoxData["\<\"Predictive method\"\>"], "Print",
 CellChangeTimes->{3.6385163392028*^9, 3.6386024456406*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Numerical solution (points) and exact solution (line)  at time \
t=\"\>", "\[InvisibleSpace]", "0.00002211856601898225`"}],
  SequenceForm[
  "Numerical solution (points) and exact solution (line)  at time t=", 
   0.00002211856601898225],
  Editable->False]], "Print",
 CellChangeTimes->{3.6385163392028*^9, 3.6386024456426*^9}],

Cell[BoxData[
 GraphicsBox[{{{}, {{}, 
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
      0.012833333333333334`], AbsoluteThickness[1.6], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQBGIQDQMh8o4zT284vefBhzll+tJb7JumvE7Q27jJHsI/
Ym97dJ943qJD9gGZrw2Pa5yznyjyeMvtc6eh8lfsZ5/z2rkp/ZK9hK5LyG/F
m/YLjmxieH3qGlT9Pfuj/30eaXLdtj8SdLL95PSH9ib9muG75e5D9T+xn/9W
Okq88aH9n76C1KnzntkXdJpkGYQ/hpr30v7mJOsnh/ie2pucFndOXPrafqZR
8z+Jpc+g5r+zN5wSkbJR/IX9tub4CWJhH+ynZNtpOae8hNr30b6qTy7zYMcr
+0uKxvU1Nz/ZH28/WBXX/Bpq/xf7B70Fl/qC3ti/28+W9yjmqz3ndedc7q9v
oO75Zi/7wfna5cy39lxxt2I8Hny331ymv1t/w1uo+37aH4xM499w/K292p+1
3uuSf9lvgcpD3PvbXg6q32lWo5XI8z/2XFDzIe7/Z/8Ian+cRahmVdZ/+5NQ
90H8w+BQA3W/bbYIz4dvDA6o/mN00If639uqjnmxBZPDdGj4QPzL5AALv0jO
F79Cq5gdCqHhC/E/i8MCaPin3wj8xLGHxcEMGj+Q8GB1OAGNv9Llu1/u/svq
sBgav5DwYXNYAI3/5jLVh3n27A4LoekDEl7sDv7Q9DPRtf+GYiOHwzpo+oKE
H6cDLB0CADr2PHU=
       "]]}, {}}, {}}, {{}, {}, 
    {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], Opacity[
     1.], LineBox[CompressedData["
1:eJwd2Hk4Vd3bB3BTHKSiOfKgQqJkSAnf0ygqU56UJFSKkmggVIjmMqQilMqQ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      "]]}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->True,
  FrameLabel->{
    FormBox["\"x\"", TraditionalForm], 
    FormBox["\"u\"", TraditionalForm]},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  Method->{},
  PlotRange->{{0, 3.141592653589793}, {-7.685687272399828*^-16, 
    0.9306259442117196}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.6385163393297997`*^9, 3.6386024457886*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Here we give a table that compares the numerical and exact solution at the \
middle point, x=\[Pi]/2, for the first numSteps timesteps. \
\>", "Text",
 CellChangeTimes->{{3.6372981691743*^9, 3.6372982503743*^9}, {
  3.6372983312943*^9, 3.6372983351903*^9}, {3.6372983799263*^9, 
  3.6372984925123*^9}, {3.6372988496542997`*^9, 3.6372989263983*^9}},
 Background->RGBColor[1, 1, 0.85]],

Cell[BoxData[
 RowBox[{
  RowBox[{"headPredictive", "=", 
   RowBox[{"{", 
    RowBox[{
    "\"\<step\>\"", ",", "\"\<t\>\"", ",", 
     "\"\<\!\(\*SubscriptBox[\(U\), \(Predic\)]\)(\[Pi]/2,t)\>\"", ",", 
     "\"\<\!\(\*SubscriptBox[\(u\), \(exact\)]\)(\[Pi]/2,t)\>\"", ",", 
     "\"\<error\>\""}], "}"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.6372462215509663`*^9, 3.6372463423118734`*^9}, {
  3.637246799033996*^9, 3.637246806409418*^9}, {3.637246837090173*^9, 
  3.637246852913078*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"tabPred", "=", 
   RowBox[{
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"m", ",", 
        RowBox[{"tt", "[", "m", "]"}], ",", 
        RowBox[{"uMs", "[", 
         RowBox[{"[", 
          RowBox[{
           RowBox[{"m", "+", "1"}], ",", 
           RowBox[{"Nx", "+", "1"}]}], "]"}], "]"}], ",", 
        RowBox[{"uSol", "[", 
         RowBox[{
          RowBox[{"Pi", "/", "2"}], ",", 
          RowBox[{"tt", "[", "m", "]"}], ",", "gammak"}], "]"}], ",", 
        RowBox[{
         RowBox[{"uMs", "[", 
          RowBox[{"[", 
           RowBox[{
            RowBox[{"m", "+", "1"}], ",", 
            RowBox[{"Nx", "+", "1"}]}], "]"}], "]"}], "-", 
         RowBox[{"uSol", "[", 
          RowBox[{
           RowBox[{"Pi", "/", "2"}], ",", 
           RowBox[{"tt", "[", "m", "]"}], ",", "gammak"}], "]"}]}]}], "}"}], 
      ",", 
      RowBox[{"{", 
       RowBox[{"m", ",", "0", ",", "numSteps"}], "}"}]}], "]"}], "//", 
    "N"}]}], ";", 
  RowBox[{
   RowBox[{"Insert", "[", 
    RowBox[{"tabPred", ",", "headPredictive", ",", "1"}], "]"}], "//", 
   "TableForm"}]}]], "Input",
 CellChangeTimes->{
  3.6372987625292997`*^9, {3.6373009292093*^9, 3.6373009376243*^9}, 
   3.637369037421274*^9}],

Cell[BoxData[
 TagBox[GridBox[{
    {"\<\"step\"\>", "\<\"t\"\>", "\<\"\\!\\(\\*SubscriptBox[\\(U\\), \
\\(Predic\\)]\\)(\[Pi]/2,t)\"\>", "\<\"\\!\\(\\*SubscriptBox[\\(u\\), \
\\(exact\\)]\\)(\[Pi]/2,t)\"\>", "\<\"error\"\>"},
    {"0.`", "0.`", "1.`", "1.`", "0.`"},
    {"1.`", "1.6750524625318832`*^-7", "0.981755488352386`", 
     "0.9781333917929139`", "0.003622096559472099`"},
    {"2.`", "5.916692614982673`*^-7", "0.9720670826557509`", 
     "0.9702469186365417`", "0.0018201640192092583`"},
    {"3.`", "2.1606971117214194`*^-6", "0.960638632279194`", 
     "0.9593006737074965`", "0.001337958571697495`"},
    {"4.`", "7.294450393626869`*^-6", "0.9468324407176677`", 
     "0.9455658501650797`", "0.0012665905525880428`"},
    {"5.`", "0.00002211856601898225`", "0.9306259442117196`", 
     "0.9293164148338766`", "0.0013095293778430106`"},
    {"6.`", "0.0000609235652849902`", "0.9120253841044086`", 
     "0.9106426305394687`", "0.001382753564939887`"},
    {"7.`", "0.00015484907567787226`", "0.8910606753730669`", 
     "0.8896008189844246`", "0.0014598563886423221`"},
    {"8.`", "0.00032232067724357043`", "0.8714196175482255`", 
     "0.870102789989675`", "0.0013168275585504485`"},
    {"9.`", "0.0006410442035956854`", "0.8504783176773268`", 
     "0.849197535795785`", "0.0012807818815417926`"},
    {"10.`", "0.001237970235595781`", "0.8279249332205381`", 
     "0.826636394229489`", "0.0012885389910490819`"},
    {"11.`", "0.002330206181734482`", "0.8037916770664684`", 
     "0.8024822471586269`", "0.0013094299078414418`"},
    {"12.`", "0.00428921404406059`", "0.7781499490656426`", 
     "0.7768176125989519`", "0.0013323364666907311`"},
    {"13.`", "0.007746171802009134`", "0.7510798584115682`", 
     "0.7497271266809177`", "0.001352731730650536`"},
    {"14.`", "0.01376836878322345`", "0.7226690590459371`", 
     "0.7213006290418806`", "0.001368430004056509`"},
    {"15.`", "0.0241574280600911`", "0.6930124852399954`", 
     "0.6916342327328373`", "0.001378252507158062`"},
    {"16.`", "0.04195867851026572`", "0.6622115614367776`", 
     "0.6608300313145586`", "0.0013815301222189769`"},
    {"17.`", "0.07234220138029583`", "0.6303732841022273`", 
     "0.628995404072493`", "0.0013778800297342686`"},
    {"18.`", "0.12415014720939906`", "0.5976093673042517`", 
     "0.5962422749799442`", "0.0013670923243075395`"},
    {"19.`", "0.21266358832019747`", "0.5640355277407948`", 
     "0.5626864597845466`", "0.0013490679562482288`"},
    {"20.`", "0.36465517858628615`", "0.5297709578695435`", 
     "0.52844717531697`", "0.0013237825525734825`"}
   },
   GridBoxAlignment->{
    "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
     "RowsIndexed" -> {}},
   GridBoxSpacings->{"Columns" -> {
       Offset[0.27999999999999997`], {
        Offset[2.0999999999999996`]}, 
       Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
       Offset[0.2], {
        Offset[0.4]}, 
       Offset[0.2]}, "RowsIndexed" -> {}}],
  Function[BoxForm`e$, 
   TableForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{3.6385163393848*^9, 3.6386024458386*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 "A plot comparing the numerical and the exact solution at  position \
x=\[Pi]/2 for times  t  with   0\[LessEqual]t\[LessEqual] ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["t", "numSteps"], TraditionalForm]],
  FormatType->"TraditionalForm"],
 " "
}], "Text",
 CellChangeTimes->{{3.6372989561913*^9, 3.6372990023753*^9}, {
  3.6372990787602997`*^9, 3.6372990811603003`*^9}, {3.6372998614302998`*^9, 
  3.6372998879683*^9}, {3.6373004057753*^9, 3.6373004634223003`*^9}},
 Background->RGBColor[1, 1, 0.85]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"Print", "[", "\"\<Predictive method\>\"", "]"}], ";", 
  RowBox[{
  "Print", "[", 
   "\"\<Numerical solution (points) and exact solution (line) at position x=\
\[Pi]/2 vs. time\>\"", "]"}], ";", " ", 
  RowBox[{"FigNum", "=", 
   RowBox[{"ListPlot", "[", 
    RowBox[{
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"tabPred", "[", 
          RowBox[{"[", 
           RowBox[{"n", ",", "2"}], "]"}], "]"}], ",", 
         RowBox[{"tabPred", "[", 
          RowBox[{"[", 
           RowBox[{"n", ",", "3"}], "]"}], "]"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"n", ",", "1", ",", "numSteps"}], "}"}]}], "]"}], ",", 
     RowBox[{"PlotRange", "\[Rule]", "All"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"FigExact", "=", 
   RowBox[{"Plot", "[", 
    RowBox[{
     RowBox[{"uSol", "[", 
      RowBox[{
       RowBox[{"Pi", "/", "2"}], ",", "time", ",", "gammak"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"time", ",", "0", ",", 
       RowBox[{"1.1", "*", 
        RowBox[{"tabPred", "[", 
         RowBox[{"[", 
          RowBox[{
           RowBox[{"numSteps", "+", "1"}], ",", "2"}], "]"}], "]"}]}]}], 
      "}"}], ",", 
     RowBox[{"PlotRange", "\[Rule]", "All"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"Show", "[", 
  RowBox[{"FigNum", ",", "FigExact", ",", 
   RowBox[{"Frame", "\[Rule]", "True"}], ",", 
   RowBox[{"FrameLabel", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"\"\<time\>\"", ",", "\"\<u\>\""}], "}"}]}], ",", 
   RowBox[{"PlotRange", "\[Rule]", "All"}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.6372990098493*^9, 3.6372993557363*^9}, {
   3.6372994017143*^9, 3.6372994018733*^9}, {3.6372994547862997`*^9, 
   3.6372994982653*^9}, {3.6372997348883*^9, 3.6372998253603*^9}, {
   3.6372999061773*^9, 3.6372999638333*^9}, {3.6373000656813*^9, 
   3.6373002790032997`*^9}, {3.6373003226673*^9, 3.6373003301463003`*^9}, 
   3.6373008969223003`*^9, {3.6373010002263002`*^9, 3.6373010046333*^9}, {
   3.6373011368183002`*^9, 3.6373011439313*^9}, {3.6373013944182997`*^9, 
   3.6373014237132998`*^9}, {3.6373017883363*^9, 3.6373017915923*^9}, 
   3.63732110277325*^9, 3.6373692031327524`*^9, {3.6385154214628*^9, 
   3.6385154317028*^9}}],

Cell[BoxData["\<\"Predictive method\"\>"], "Print",
 CellChangeTimes->{3.6385163394007998`*^9, 3.6386024458515997`*^9}],

Cell[BoxData["\<\"Numerical solution (points) and exact solution (line) at \
position x=\[Pi]/2 vs. time\"\>"], "Print",
 CellChangeTimes->{3.6385163394007998`*^9, 3.6386024458536*^9}],

Cell[BoxData[
 GraphicsBox[{{{}, {{}, 
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
      0.012833333333333334`], AbsoluteThickness[1.6], PointBox[CompressedData["
1:eJxTTMoPSmViYGAQAWIQjQo+2Is98t2VX91mF9SdUtOV9d6+q824PO3WYruo
kwa5OtLv7S3WzDzDr3DI7pLlXKveve/sDQpXOUbPuGeXPPlrd7HPO/unfIUe
GYbf7Q5GpvFvOP7W3uBE7WHWj/z2Baa7b/vrv7VnMGzJu++tYv82OH/txOY3
9kb1DUeWyJvaF545l7L60Wv7mDOPPpYzutq/N+LxkzN/bb/Z2CI7xyPE/ozJ
99yYulf2667/fXVaLNn+VcvOoJU7XtpPyt+uMHFiob3t/cs7Zj17Ya/35YNG
8a56+/u/Jy64wfHCPtJHVXe6UY999L2zd6QUntt/e/ukd+eeGfaGWb9aNHSf
2T/x/TF/dvVSe5Z3b3yuGTy1j+7h2cvSusn+6Pb301l0ntjLXuO75ntiv71L
DPe6ufKP7fkDCqv6LU7b39yhazOF55E9ABwjmNk=
       "]]}, {}}, {}}, {{}, {}, 
    {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], Opacity[
     1.], LineBox[CompressedData["
1:eJwVznk4FAgfB3BJQtTWIpFmHDkiOdoo6Yv0dmAdCdleucaREjmzJamIxTon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      "]]}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0.5422373041278346},
  DisplayFunction->Identity,
  Frame->True,
  FrameLabel->{
    FormBox["\"time\"", TraditionalForm], 
    FormBox["\"u\"", TraditionalForm]},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  Method->{},
  PlotRange->All,
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.6385163395418*^9, 3.6386024459856*^9}]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 "\[FilledSquare] Numerical results with the method with ",
 StyleBox["fixed timesteps",
  FontSlant->"Italic"],
 " for \[CapitalDelta]=0.01=",
 "htFT"
}], "Subsubsection",
 CellChangeTimes->{{3.633439583415289*^9, 3.6334395909637213`*^9}, {
   3.636904756973955*^9, 3.636904760701168*^9}, 3.637138408549569*^9, {
   3.6372452357805834`*^9, 3.6372452451731205`*^9}, {3.6372463821981544`*^9, 
   3.6372463827581863`*^9}, {3.6372466129283514`*^9, 3.637246617848633*^9}, {
   3.6372481231807327`*^9, 3.6372481307011633`*^9}, {3.637249654032293*^9, 
   3.6372496781846743`*^9}, 3.6373014998393*^9, {3.6373015476473*^9, 
   3.6373015576783*^9}, 3.6373021184543*^9}],

Cell[CellGroupData[{

Cell[TextData[{
 "uMs is a matrix that contains the full solution ",
 Cell[BoxData[
  FormBox[
   RowBox[{"{", 
    RowBox[{
     SubsuperscriptBox["U", "0", 
      RowBox[{"(", "m", ")"}]], ",", 
     SubsuperscriptBox["U", "1", 
      RowBox[{"(", "m", ")"}]], ",", 
     SubsuperscriptBox["U", "2", 
      RowBox[{"(", "m", ")"}]], ",", 
     RowBox[{"...", " ", 
      SubsuperscriptBox["U", "Np", 
       RowBox[{"(", "m", ")"}]]}]}], "}"}], TraditionalForm]]],
 "  for m=0,1,2,....,numSteps."
}], "Text",
 CellChangeTimes->{{3.6372979828863*^9, 3.6372980614302998`*^9}},
 Background->RGBColor[1, 1, 0.85]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"htFT", "=", "0.01"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"numSteps", "=", "50"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"CPUtime", "=", 
   RowBox[{"Timing", "[", 
    RowBox[{"uMs", "=", 
     RowBox[{"uMsolutionFixedTimesteps", "[", 
      RowBox[{
       RowBox[{"numSteps", "*", "htFT"}], ",", "htFT"}], "]"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Print", "[", 
   RowBox[{
   "\"\<Example 1. Method with fixed timesteps of size \>\"", ",", "htFT", 
    ",", "\"\< for \[Gamma]=\>\"", ",", "gammak", ",", "\"\<, Np=\>\"", ",", 
    "Np"}], " ", "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Print", "[", 
   RowBox[{"\"\<CPU time=\>\"", ",", 
    RowBox[{"CPUtime", "[", 
     RowBox[{"[", "1", "]"}], "]"}], ",", "\"\< seconds\>\""}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
  "Print", "[", "\"\<The solution is saved in the matrix uMs\>\"", "]"}], 
  ";"}]}], "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 CellChangeTimes->{{3.56061256346875*^9, 3.56061257284375*^9}, {
   3.56061260303125*^9, 3.560612663828125*^9}, {3.5610884668366947`*^9, 
   3.5610884717649765`*^9}, {3.5611210929323997`*^9, 3.5611211203416*^9}, {
   3.5611212573096*^9, 3.5611212593532*^9}, 3.5611216448120003`*^9, {
   3.5611216844625998`*^9, 3.5611216848213997`*^9}, {3.5611217681558*^9, 
   3.5611217684667997`*^9}, {3.5611222944344*^9, 3.5611223196862*^9}, {
   3.5611253416166*^9, 3.5611253440626*^9}, {3.5611260133876*^9, 
   3.5611260138276*^9}, {3.561127402519*^9, 3.5611274579006*^9}, {
   3.561127527574*^9, 3.5611275627130003`*^9}, {3.5902000697948065`*^9, 
   3.5902000708068647`*^9}, {3.590200323138297*^9, 3.590200324873397*^9}, {
   3.5902003709750333`*^9, 3.5902003711460433`*^9}, 3.590200421820942*^9, 
   3.590213289142*^9, {3.5902135189*^9, 3.590213539836*^9}, {
   3.5902135876359997`*^9, 3.590213616165*^9}, {3.590213707484*^9, 
   3.590213707868*^9}, {3.590213768476*^9, 3.590213768955*^9}, 
   3.5902143461549997`*^9, {3.59021447142*^9, 3.590214495682*^9}, 
   3.5903882375313997`*^9, {3.5903932563884*^9, 3.5903932567464*^9}, {
   3.5903932903714*^9, 3.5903933180104*^9}, {3.5903933542194*^9, 
   3.5903933561303997`*^9}, 3.5903933876914*^9, 3.5903934182594*^9, 
   3.5903941132114*^9, 3.60195384860737*^9, {3.601953894449992*^9, 
   3.601953894987023*^9}, {3.6334400976967044`*^9, 3.6334400980167227`*^9}, 
   3.6369936572364435`*^9, {3.636993750675788*^9, 3.6369937637635365`*^9}, 
   3.637004923308416*^9, 3.6370053615804834`*^9, {3.6372402113622026`*^9, 
   3.637240211367203*^9}, {3.6372452960570307`*^9, 3.6372453605797215`*^9}, {
   3.6372453910404634`*^9, 3.637245428304595*^9}, {3.637245470149988*^9, 
   3.6372455167096515`*^9}, {3.6372456161863413`*^9, 3.637245697827011*^9}, {
   3.637245729372815*^9, 3.637245777960594*^9}, {3.63724584310532*^9, 
   3.6372459587629356`*^9}, {3.637246021107501*^9, 3.6372460259367776`*^9}, {
   3.637246091338518*^9, 3.6372460918335466`*^9}, 3.6372463595788608`*^9, 
   3.637246525799368*^9, {3.6372465623644595`*^9, 3.637246581655563*^9}, {
   3.637246817573056*^9, 3.6372468214022756`*^9}, {3.6372470179475174`*^9, 
   3.637247018278536*^9}, {3.6372471839910145`*^9, 3.6372472107335443`*^9}, {
   3.6372472497587757`*^9, 3.637247279316467*^9}, {3.637247390205809*^9, 
   3.6372473996553497`*^9}, {3.637247443785874*^9, 3.6372474491481805`*^9}, {
   3.637247899618946*^9, 3.6372479030021396`*^9}, {3.637247939714239*^9, 
   3.6372479400092564`*^9}, {3.6372482082135963`*^9, 3.637248224762543*^9}, {
   3.637248553257332*^9, 3.6372485587676473`*^9}, 3.6372496070256042`*^9, 
   3.6372975701323*^9, {3.6372979117462997`*^9, 3.6372979144493*^9}, 
   3.6372981329823*^9, 3.6372981646743*^9, {3.6372982614663*^9, 
   3.6372982617132998`*^9}, {3.6373004952983*^9, 3.6373005432813*^9}, {
   3.6373007987373*^9, 3.6373008130083*^9}, {3.6373015293063*^9, 
   3.6373015299783*^9}, {3.6373015669943*^9, 3.6373015860183*^9}, {
   3.6373020142672997`*^9, 3.6373020146973*^9}, 3.6373021292053003`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Example 1. Method with fixed timesteps of size \"\>", 
   "\[InvisibleSpace]", "0.01`", 
   "\[InvisibleSpace]", "\<\" for \[Gamma]=\"\>", "\[InvisibleSpace]", 
   "0.25`", "\[InvisibleSpace]", "\<\", Np=\"\>", "\[InvisibleSpace]", "40"}],
  SequenceForm[
  "Example 1. Method with fixed timesteps of size ", 0.01, " for \[Gamma]=", 
   0.25, ", Np=", 40],
  Editable->False]], "Print",
 CellChangeTimes->{3.6385163408378*^9, 3.6386024474146*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"CPU time=\"\>", "\[InvisibleSpace]", "1.404009`", 
   "\[InvisibleSpace]", "\<\" seconds\"\>"}],
  SequenceForm["CPU time=", 1.404009, " seconds"],
  Editable->False]], "Print",
 CellChangeTimes->{3.6385163408378*^9, 3.6386024474166*^9}],

Cell[BoxData["\<\"The solution is saved in the matrix uMs\"\>"], "Print",
 CellChangeTimes->{3.6385163408378*^9, 3.6386024474175997`*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 "The solution for the m-th timestep is just the m+1 element of this matrix:  \
uMs[[m+1]]=",
 Cell[BoxData[
  FormBox[
   RowBox[{"{", 
    RowBox[{
     SubsuperscriptBox["U", "0", 
      RowBox[{"(", "m", ")"}]], ",", 
     SubsuperscriptBox["U", "1", 
      RowBox[{"(", "m", ")"}]], ",", 
     SubsuperscriptBox["U", "2", 
      RowBox[{"(", "m", ")"}]], ",", 
     RowBox[{"...", " ", 
      SubsuperscriptBox["U", "Np", 
       RowBox[{"(", "m", ")"}]]}]}], "}"}], TraditionalForm]]],
 " "
}], "Text",
 CellChangeTimes->{{3.6372981691743*^9, 3.6372982503743*^9}, {
  3.6372983312943*^9, 3.6372983351903*^9}},
 Background->RGBColor[1, 1, 0.85]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"mStep", "=", "5"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Print", "[", 
   RowBox[{"\"\<The numerical solution at time \>\"", ",", 
    RowBox[{"tt", "[", "mStep", "]"}], ",", "\"\< is:\>\""}], "]"}], ";", 
  RowBox[{"uMs", "[", 
   RowBox[{"[", "mStep", "]"}], "]"}]}]}], "Input",
 CellChangeTimes->{{3.6372983391352997`*^9, 3.6372983412483*^9}, {
  3.6372985221443*^9, 3.6372986028712997`*^9}}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"The numerical solution at time \"\>", "\[InvisibleSpace]", 
   "0.05`", "\[InvisibleSpace]", "\<\" is:\"\>"}],
  SequenceForm["The numerical solution at time ", 0.05, " is:"],
  Editable->False]], "Print",
 CellChangeTimes->{3.6385163409038*^9, 3.6386024474695997`*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"-", "6.371645735168243`*^-15"}], ",", "0.05271891418620385`", ",",
    "0.10511279873563795`", ",", "0.15685862792731411`", ",", 
   "0.2076373715170314`", ",", "0.2571359616649135`", ",", 
   "0.3050492231027472`", ",", "0.3510817546409921`", ",", 
   "0.3949497504153448`", ",", "0.4363827496442676`", ",", 
   "0.4751253041096438`", ",", "0.5109385530799877`", ",", 
   "0.5436016959662834`", ",", "0.5729133536310398`", ",", 
   "0.5986928099576383`", ",", "0.6207811260252862`", ",", 
   "0.6390421200203162`", ",", "0.6533632068423522`", ",", 
   "0.6636560922288917`", ",", "0.6698573171187949`", ",", 
   "0.671928648898499`", ",", "0.6698573171187946`", ",", 
   "0.6636560922288912`", ",", "0.6533632068423516`", ",", 
   "0.6390421200203155`", ",", "0.6207811260252853`", ",", 
   "0.5986928099576372`", ",", "0.5729133536310387`", ",", 
   "0.5436016959662823`", ",", "0.5109385530799866`", ",", 
   "0.4751253041096428`", ",", "0.43638274964426677`", ",", 
   "0.3949497504153443`", ",", "0.35108175464099195`", ",", 
   "0.30504922310274757`", ",", "0.2571359616649145`", ",", 
   "0.20763737151703313`", ",", "0.15685862792731675`", ",", 
   "0.10511279873564164`", ",", "0.05271891418620877`", ",", "0.`"}], 
  "}"}]], "Output",
 CellChangeTimes->{3.6385163409068003`*^9, 3.6386024474726*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 "The [[m+1,j+1] element of this matrix is the numerical solution for time ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["t", "m"], TraditionalForm]],
  FormatType->"TraditionalForm"],
 " and position ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["x", "j"], TraditionalForm]],
  FormatType->"TraditionalForm"],
 ":  uMs[[m+1,j+1]]=",
 Cell[BoxData[
  FormBox[
   SubsuperscriptBox["U", "j", 
    RowBox[{"(", "m", ")"}]], TraditionalForm]]],
 " "
}], "Text",
 CellChangeTimes->{{3.6372981691743*^9, 3.6372982503743*^9}, {
  3.6372983312943*^9, 3.6372983351903*^9}, {3.6372983799263*^9, 
  3.6372984925123*^9}},
 Background->RGBColor[1, 1, 0.85]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"mStep", "=", "5"}], ";", 
  RowBox[{"jPos", "=", 
   RowBox[{"Nx", "+", "1"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Print", "[", 
   RowBox[{"\"\<The numerical solution at time t=\>\"", ",", 
    RowBox[{"tt", "[", "mStep", "]"}], ",", "\"\< and position x= \>\"", " ", 
    ",", 
    RowBox[{"jPos", "*", "deltax"}], " ", ",", "\"\< is:\>\""}], "]"}], ";", 
  RowBox[{"uMs", "[", 
   RowBox[{"[", 
    RowBox[{"mStep", ",", "jPos"}], "]"}], "]"}]}]}], "Input",
 CellChangeTimes->{{3.6372983391352997`*^9, 3.6372983412483*^9}, {
  3.6372985221443*^9, 3.6372986028712997`*^9}, {3.6372986373603*^9, 
  3.6372986956313*^9}}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"The numerical solution at time t=\"\>", "\[InvisibleSpace]", 
   "0.05`", "\[InvisibleSpace]", "\<\" and position x= \"\>", 
   "\[InvisibleSpace]", "1.6493361431346414`", 
   "\[InvisibleSpace]", "\<\" is:\"\>"}],
  SequenceForm[
  "The numerical solution at time t=", 0.05, " and position x= ", 
   1.6493361431346414`, " is:"],
  Editable->False]], "Print",
 CellChangeTimes->{3.6385163409418*^9, 3.6386024474886*^9}],

Cell[BoxData["0.671928648898499`"], "Output",
 CellChangeTimes->{3.6385163409438*^9, 3.6386024474936*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 "A plot comparing the numerical and the exact solution at time ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["t", "mStep"], TraditionalForm]],
  FormatType->"TraditionalForm"],
 " "
}], "Text",
 CellChangeTimes->{{3.6372989561913*^9, 3.6372990023753*^9}, {
  3.6372990787602997`*^9, 3.6372990811603003`*^9}},
 Background->RGBColor[1, 1, 0.85]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"mStep", "=", "5"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Print", "[", "\"\<Method with fixed timesteps\>\"", "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Print", "[", 
   RowBox[{
   "\"\<Numerical solution (points) and exact solution (line)  at time \
t=\>\"", ",", 
    RowBox[{"tt", "[", "mStep", "]"}]}], "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{" ", 
  RowBox[{
   RowBox[{"FigNum", "=", 
    RowBox[{"ListPlot", "[", 
     RowBox[{
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"xj", "=", 
           RowBox[{"j", "*", "deltax"}]}], ",", 
          RowBox[{"uMs", "[", 
           RowBox[{"[", 
            RowBox[{
             RowBox[{"mStep", "+", "1"}], ",", 
             RowBox[{"j", "+", "1"}]}], "]"}], "]"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"j", ",", "0", ",", "Np"}], "}"}]}], "]"}], ",", 
      RowBox[{"PlotRange", "\[Rule]", "All"}]}], "]"}]}], ";", 
   RowBox[{"FigExact", "=", 
    RowBox[{"Plot", "[", 
     RowBox[{
      RowBox[{"uSol", "[", 
       RowBox[{"x", ",", 
        RowBox[{"tt", "[", "mStep", "]"}], ",", "gammak"}], "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"x", ",", "0", ",", "Pi"}], "}"}], ",", 
      RowBox[{"PlotRange", "\[Rule]", "All"}]}], "]"}]}], ";", " ", 
   RowBox[{"Show", "[", 
    RowBox[{"FigNum", ",", "FigExact", ",", 
     RowBox[{"Frame", "\[Rule]", "True"}], ",", 
     RowBox[{"FrameLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<x\>\"", ",", "\"\<u\>\""}], "}"}]}]}], 
    "]"}]}]}]}], "Input",
 CellChangeTimes->{{3.6372990098493*^9, 3.6372993557363*^9}, {
   3.6372994017143*^9, 3.6372994018733*^9}, {3.6372994547862997`*^9, 
   3.6372994982653*^9}, {3.6372997348883*^9, 3.6372998253603*^9}, 
   3.6373011632593*^9, {3.6373012486103*^9, 3.6373012562163*^9}, 
   3.6373686743595085`*^9, {3.6385154468938*^9, 3.6385154613978*^9}}],

Cell[BoxData["\<\"Method with fixed timesteps\"\>"], "Print",
 CellChangeTimes->{3.6385163409888*^9, 3.6386024475106*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Numerical solution (points) and exact solution (line)  at time \
t=\"\>", "\[InvisibleSpace]", "0.05`"}],
  SequenceForm[
  "Numerical solution (points) and exact solution (line)  at time t=", 0.05],
  Editable->False]], "Print",
 CellChangeTimes->{3.6385163409888*^9, 3.6386024475156*^9}],

Cell[BoxData[
 GraphicsBox[{{{}, {{}, 
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
      0.012833333333333334`], AbsoluteThickness[1.6], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQBGIQDQOle5w2RJXw2z74MKdMX3qLfcqt9jf9GavsIfwj
9hfWndi7I3iXfUDma8PjGufs6+Ws2c4tOQyVv2IfJ3dm2j6GU/YSui4hvxVv
2h+/dzTokuQFqPp79vZH+I7flrxsfyToZPvJ6Q/t1376Xbj/91Wo/if2bSdL
N33YdcP+T19B6tR5z+yP7di9SjL4NtS8l/bJgvISSgfu2pucFndOXPraftrX
xpOm/+5DzX9n/6LTOPQpy0P7bc3xE8TCPthrm7ToXH7/EGrfR3vZD4HzC/c9
sr+kaFxfc/OTPfvCnxOq8h9D7f9i3/rXe9o1xif27/az5T2K+Wr/nG3iunkl
T6Du+Wbvzai4Qfb4E3uuuFsxHg++26dVBKdd/PEE6r6f9iKsjPHZnE/t1f6s
9V6X/Ms+FSoPce9vew+ofqdZjVYiz//YP4SaD3H/P/taqP1xFqGaVVn/7f8t
gLgP4h8GByGo+22zRXg+fGNwkEXxH6PDdaj/va3qmBdbMDnkQMMH4l8mBwNo
+EVyvvgVWsXs0AkNX4j/WRysoeGffiPwE8ceFocgaPxAwoPV4cphSPyVLt/9
cvdfVgdvaPxCwofNwV4WEv/NZaoP8+zZHUxlIekDEl7sDtdXQ9LPRNf+G4qN
HA4TLkPSFyT8OB1g6RAALJo+2A==
       "]]}, {}}, {}}, {{}, {}, 
    {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], Opacity[
     1.], LineBox[CompressedData["
1:eJwd2Hk4VG8bB3CNpVGoSKQICUmrRJLvQRuVLe0bWlDJTqnfz5pE2ZLylpJd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      "]]}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->True,
  FrameLabel->{
    FormBox["\"x\"", TraditionalForm], 
    FormBox["\"u\"", TraditionalForm]},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  Method->{},
  PlotRange->{{0, 3.141592653589793}, {0, 0.6573998313471372}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.02], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.6385163411568003`*^9, 3.6386024477056*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Here we give a table that compares the numerical and exact solution at the \
middle point, x=\[Pi]/2, for the first numSteps timesteps. \
\>", "Text",
 CellChangeTimes->{{3.6372981691743*^9, 3.6372982503743*^9}, {
  3.6372983312943*^9, 3.6372983351903*^9}, {3.6372983799263*^9, 
  3.6372984925123*^9}, {3.6372988496542997`*^9, 3.6372989263983*^9}},
 Background->RGBColor[1, 1, 0.85]],

Cell[BoxData[
 RowBox[{
  RowBox[{"headFixedTimesteps", "=", 
   RowBox[{"{", 
    RowBox[{
    "\"\<step\>\"", ",", "\"\<t\>\"", ",", 
     "\"\<\!\(\*SubscriptBox[\(U\), \(Fixed\\\ \
\[CapitalDelta]\)]\)(\[Pi]/2,t)\>\"", ",", 
     "\"\<\!\(\*SubscriptBox[\(u\), \(exact\)]\)(\[Pi]/2,t)\>\"", ",", 
     "\"\<error\>\""}], "}"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.6372462215509663`*^9, 3.6372463423118734`*^9}, {
  3.637246799033996*^9, 3.637246806409418*^9}, {3.637246837090173*^9, 
  3.637246852913078*^9}, {3.6372481343843737`*^9, 3.637248157767711*^9}, {
  3.63724839394522*^9, 3.6372484353835897`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"tabFT", "=", 
   RowBox[{
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"m", ",", 
        RowBox[{"tt", "[", "m", "]"}], ",", 
        RowBox[{"uMs", "[", 
         RowBox[{"[", 
          RowBox[{
           RowBox[{"m", "+", "1"}], ",", 
           RowBox[{"Nx", "+", "1"}]}], "]"}], "]"}], ",", 
        RowBox[{"uSol", "[", 
         RowBox[{
          RowBox[{"Pi", "/", "2"}], ",", 
          RowBox[{"tt", "[", "m", "]"}], ",", "gammak"}], "]"}], ",", 
        RowBox[{
         RowBox[{"uMs", "[", 
          RowBox[{"[", 
           RowBox[{
            RowBox[{"m", "+", "1"}], ",", 
            RowBox[{"Nx", "+", "1"}]}], "]"}], "]"}], "-", 
         RowBox[{"uSol", "[", 
          RowBox[{
           RowBox[{"Pi", "/", "2"}], ",", 
           RowBox[{"tt", "[", "m", "]"}], ",", "gammak"}], "]"}]}]}], "}"}], 
      ",", 
      RowBox[{"{", 
       RowBox[{"m", ",", "0", ",", "numSteps"}], "}"}]}], "]"}], "//", 
    "N"}]}], ";", 
  RowBox[{
   RowBox[{"Insert", "[", 
    RowBox[{"tabFT", ",", "headFixedTimesteps", ",", "1"}], "]"}], "//", 
   "TableForm"}]}]], "Input",
 CellChangeTimes->{
  3.6372987625292997`*^9, {3.6373009292093*^9, 3.6373009376243*^9}, {
   3.6373016236413*^9, 3.6373016256473*^9}, 3.6373017098083*^9, 
   3.637369040685461*^9}],

Cell[BoxData[
 TagBox[GridBox[{
    {"\<\"step\"\>", "\<\"t\"\>", "\<\"\\!\\(\\*SubscriptBox[\\(U\\), \
\\(Fixed\\\\ \[CapitalDelta]\\)]\\)(\[Pi]/2,t)\"\>", \
"\<\"\\!\\(\\*SubscriptBox[\\(u\\), \\(exact\\)]\\)(\[Pi]/2,t)\"\>", \
"\<\"error\"\>"},
    {"0.`", "0.`", "1.`", "1.`", "0.`"},
    {"1.`", "0.01`", "0.7749032260632416`", "0.7373525930303786`", 
     "0.03755063303286299`"},
    {"2.`", "0.02`", "0.7193989170747731`", "0.7017994082245143`", 
     "0.01759950885025885`"},
    {"3.`", "0.03`", "0.6910469968283349`", "0.6797369383975913`", 
     "0.01131005843074362`"},
    {"4.`", "0.04`", "0.671928648898499`", "0.6635585234256908`", 
     "0.008370125472808243`"},
    {"5.`", "0.05`", "0.6573998313471372`", "0.6507291753518241`", 
     "0.006670655995313135`"},
    {"6.`", "0.060000000000000005`", "0.6456365307132964`", 
     "0.640075920109638`", "0.005560610603658422`"},
    {"7.`", "0.07`", "0.63573259022208`", "0.6309555514342341`", 
     "0.004777038787845855`"},
    {"8.`", "0.08`", "0.627169318555923`", "0.622975783299728`", 
     "0.004193535256194925`"},
    {"9.`", "0.09`", "0.6196208049142509`", "0.615879110809877`", 
     "0.0037416941043738605`"},
    {"10.`", "0.09999999999999999`", "0.6128683161487389`", 
     "0.6094871084164821`", "0.003381207732256808`"},
    {"11.`", "0.10999999999999999`", "0.6067576534291782`", 
     "0.6036708994850738`", "0.0030867539441044034`"},
    {"12.`", "0.11999999999999998`", "0.6011758857157037`", 
     "0.5983342764890709`", "0.002841609226632791`"},
    {"13.`", "0.12999999999999998`", "0.5960377440706892`", 
     "0.5934034674991414`", "0.0026342765715478`"},
    {"14.`", "0.13999999999999999`", "0.5912772182802648`", 
     "0.5888206310556748`", "0.002456587224589968`"},
    {"15.`", "0.15`", "0.5868421315534412`", "0.5845395565650103`", 
     "0.0023025749884308944`"},
    {"16.`", "0.16`", "0.5826905071079883`", "0.5805227279500099`", 
     "0.002167779157978389`"},
    {"17.`", "0.17`", "0.5787880585173643`", "0.5767392616911822`", 
     "0.0020487968261820866`"},
    {"18.`", "0.18000000000000002`", "0.5751064099294517`", 
     "0.5731634237082752`", "0.0019429862211765014`"},
    {"19.`", "0.19000000000000003`", "0.5716218047773208`", 
     "0.5697735400474555`", "0.0018482647298653232`"},
    {"20.`", "0.20000000000000004`", "0.5683141500549781`", 
     "0.5665511819634983`", "0.0017629680914797996`"},
    {"21.`", "0.21000000000000005`", "0.5651662964246174`", 
     "0.5634805462622302`", "0.0016857501623871451`"},
    {"22.`", "0.22000000000000006`", "0.5621634874379255`", 
     "0.5605479772141079`", "0.0016155102238176733`"},
    {"23.`", "0.23000000000000007`", "0.5592929322240451`", 
     "0.5577415928441836`", "0.001551339379861516`"},
    {"24.`", "0.24000000000000007`", "0.5565434697790937`", 
     "0.5550509893433931`", "0.001492480435700605`"},
    {"25.`", "0.25000000000000006`", "0.5539053022083602`", 
     "0.5524670047525454`", "0.0014382974558148076`"},
    {"26.`", "0.26000000000000006`", "0.5513697805586876`", 
     "0.5499815281787387`", "0.0013882523799488844`"},
    {"27.`", "0.2700000000000001`", "0.5489292312440258`", 
     "0.5475873443871998`", "0.0013418868568260134`"},
    {"28.`", "0.2800000000000001`", "0.5465768141485976`", 
     "0.545278006163979`", "0.0012988079846185663`"},
    {"29.`", "0.2900000000000001`", "0.5443064056997756`", 
     "0.5430477286888873`", "0.0012586770108883316`"},
    {"30.`", "0.3000000000000001`", "0.5421125018061954`", 
     "0.5408913015075566`", "0.0012212002986388137`"},
    {"31.`", "0.3100000000000001`", "0.5399901367359068`", 
     "0.5388040146910028`", "0.001186122044903981`"},
    {"32.`", "0.3200000000000001`", "0.5379348148868153`", 
     "0.5367815965195545`", "0.0011532183672607887`"},
    {"33.`", "0.3300000000000001`", "0.5359424530616002`", 
     "0.5348201605943421`", "0.0011222924672580348`"},
    {"34.`", "0.34000000000000014`", "0.5340093313605987`", 
     "0.5329161607121357`", "0.0010931706484630377`"},
    {"35.`", "0.35000000000000014`", "0.5321320511905466`", 
     "0.5310663521727131`", "0.001065699017833488`"},
    {"36.`", "0.36000000000000015`", "0.5303074991843425`", 
     "0.5292677584470754`", "0.001039740737267092`"},
    {"37.`", "0.37000000000000016`", "0.5285328160588325`", 
     "0.5275176423377569`", "0.001015173721075624`"},
    {"38.`", "0.38000000000000017`", "0.5268053696197453`", 
     "0.5258134809226286`", "0.0009918886971167495`"},
    {"39.`", "0.3900000000000002`", "0.5251227312670701`", 
     "0.5241529437008398`", "0.0009697875662303401`"},
    {"40.`", "0.4000000000000002`", "0.5234826554689906`", 
     "0.5225338734612648`", "0.0009487820077258569`"},
    {"41.`", "0.4100000000000002`", "0.5218830617646061`", 
     "0.5209542694757222`", "0.0009287922888838729`"},
    {"42.`", "0.4200000000000002`", "0.520322018929928`", 
     "0.5194122726854922`", "0.0009097462444358495`"},
    {"43.`", "0.4300000000000002`", "0.518797731001928`", 
     "0.5179061526035729`", "0.0008915783983551862`"},
    {"44.`", "0.4400000000000002`", "0.5173085249045587`", 
     "0.5164342956992558`", "0.0008742292053028899`"},
    {"45.`", "0.45000000000000023`", "0.5158528394609796`", 
     "0.5149951950678614`", "0.0008576443931181954`"},
    {"46.`", "0.46000000000000024`", "0.5144292156094269`", 
     "0.5135874412184459`", "0.0008417743909809872`"},
    {"47.`", "0.47000000000000025`", "0.5130362876676343`", 
     "0.5122097138371585`", "0.0008265738304757964`"},
    {"48.`", "0.48000000000000026`", "0.5116727755136018`", 
     "0.5108607744046498`", "0.0008120011089519652`"},
    {"49.`", "0.49000000000000027`", "0.5103374775695313`", 
     "0.5095394595632651`", "0.0007980180062662212`"},
    {"50.`", "0.5000000000000002`", "0.5090292644917942`", 
     "0.5082446751443516`", "0.0007845893474426324`"}
   },
   GridBoxAlignment->{
    "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
     "RowsIndexed" -> {}},
   GridBoxSpacings->{"Columns" -> {
       Offset[0.27999999999999997`], {
        Offset[2.0999999999999996`]}, 
       Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
       Offset[0.2], {
        Offset[0.4]}, 
       Offset[0.2]}, "RowsIndexed" -> {}}],
  Function[BoxForm`e$, 
   TableForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{3.6385163412618*^9, 3.6386024477876*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 "A plot comparing the numerical and the exact solution at  position \
x=\[Pi]/2 for times  t  with   0\[LessEqual]t\[LessEqual] ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["t", "numSteps"], TraditionalForm]],
  FormatType->"TraditionalForm"],
 " "
}], "Text",
 CellChangeTimes->{{3.6372989561913*^9, 3.6372990023753*^9}, {
  3.6372990787602997`*^9, 3.6372990811603003`*^9}, {3.6372998614302998`*^9, 
  3.6372998879683*^9}, {3.6373004057753*^9, 3.6373004634223003`*^9}},
 Background->RGBColor[1, 1, 0.85]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"Print", "[", "\"\<Method with fixed timesteps\>\"", "]"}], ";", 
  RowBox[{
  "Print", "[", 
   "\"\<Numerical solution (points) and exact solution (line) at position x=\
\[Pi]/2 vs. time\>\"", "]"}], ";", " ", 
  RowBox[{"FigNum", "=", 
   RowBox[{"ListPlot", "[", 
    RowBox[{
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"tabFT", "[", 
          RowBox[{"[", 
           RowBox[{"n", ",", "2"}], "]"}], "]"}], ",", 
         RowBox[{"tabFT", "[", 
          RowBox[{"[", 
           RowBox[{"n", ",", "3"}], "]"}], "]"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"n", ",", "1", ",", "numSteps"}], "}"}]}], "]"}], ",", 
     RowBox[{"PlotRange", "\[Rule]", "All"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"FigExact", "=", 
   RowBox[{"Plot", "[", 
    RowBox[{
     RowBox[{"uSol", "[", 
      RowBox[{
       RowBox[{"Pi", "/", "2"}], ",", "time", ",", "gammak"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"time", ",", "0", ",", 
       RowBox[{"1.1", "*", 
        RowBox[{"tabFT", "[", 
         RowBox[{"[", 
          RowBox[{
           RowBox[{"numSteps", "+", "1"}], ",", "2"}], "]"}], "]"}]}]}], 
      "}"}], ",", 
     RowBox[{"PlotRange", "\[Rule]", "All"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"Show", "[", 
  RowBox[{"FigNum", ",", "FigExact", ",", 
   RowBox[{"Frame", "\[Rule]", "True"}], ",", 
   RowBox[{"FrameLabel", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"\"\<time\>\"", ",", "\"\<u\>\""}], "}"}]}], ",", 
   RowBox[{"PlotRange", "\[Rule]", "All"}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.6372990098493*^9, 3.6372993557363*^9}, {
   3.6372994017143*^9, 3.6372994018733*^9}, {3.6372994547862997`*^9, 
   3.6372994982653*^9}, {3.6372997348883*^9, 3.6372998253603*^9}, {
   3.6372999061773*^9, 3.6372999638333*^9}, {3.6373000656813*^9, 
   3.6373002790032997`*^9}, {3.6373003226673*^9, 3.6373003301463003`*^9}, 
   3.6373008969223003`*^9, {3.6373010002263002`*^9, 3.6373010046333*^9}, {
   3.6373011368183002`*^9, 3.6373011439313*^9}, {3.6373013944182997`*^9, 
   3.6373014237132998`*^9}, {3.6373017319293003`*^9, 3.6373017582733*^9}, 
   3.6373211053753986`*^9, 3.637369234644555*^9, {3.6385154741358*^9, 
   3.6385154764868*^9}}],

Cell[BoxData["\<\"Method with fixed timesteps\"\>"], "Print",
 CellChangeTimes->{3.6385163412988*^9, 3.6386024477976*^9}],

Cell[BoxData["\<\"Numerical solution (points) and exact solution (line) at \
position x=\[Pi]/2 vs. time\"\>"], "Print",
 CellChangeTimes->{3.6385163412988*^9, 3.6386024477986*^9}],

Cell[BoxData[
 GraphicsBox[{{{}, {{}, 
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
      0.011000000000000001`], AbsoluteThickness[1.6], PointBox[CompressedData["
1:eJxVkmtIU2EcxqehpaLVtEBEQQgZhlneIDQfS2vllzKN/GAzQy2X6CDygyLY
RdIPalEp8zovm1ph0wk602Uz8TIv06nz7nnPti6sUAMrS6POy770wOFwOOd9
/s/z+x/fG9mX0+x5PF7Qv4u7/68N5Hm0CUnuQ6SGKhfsxj7Znp+hRq5iLjl8
RLdPoTWuuxYubpkVbt4fbO+b8C2n6L6kwIJKKadWeDjYJd92skBNv29D+KMD
m66tZnyJ4xzaUedfsGa9arad78Q4f1/q4EEznI2NklPOXSg3y+zXDSZQO6ka
gnrDntpqEwRJZdotQS+GsrSOZWITuqi/Bjkip7DZCBO408bGfviZIt/28U2w
0nnvcP1cZrDGyiKYagBPf1/zyxhibfPf4+Xu97J0OYuBLW7CIGq6ZoqyClm4
0DxDCNDoSs/eZBFPAQxjU6SYVMeyqKL5RtDMOgvqA1mYcjnDUSxH/pEZD7E4
SvOO4VbjifORuwR3uHiScagE0tgeC8Ebmn8C0d7Ho0ImCezoHvRgvbTVFWoC
Oe2jxwP+RsR0E8EFwg2YwkURz2nmMcFX2m8KDU3KltJ8gidarsA0mvOyY7bE
BKG0rwGjCVFxO4kECxSQAeLAY2lSIUE+7T+DV0Ev+ANhBL5cHJ9ZdPNKRyR+
BIOUxyyUeZreysMEGemc5lBRLNOd3EvgSvkYQdCTJfzJoF3IBTTCv/eXou8z
gyuU1zx0P8LXy5cYbNMFziOhUx44Mc6ghvJbgD69pUPUz+A0/QEWoVPGe8Wo
GFgoz0Uw/nNJuQoGxXShS6gu2enYlTIIoHyXMelYUjVawmBqjNMyZO4p+pV7
DO5S3ivYP3zkTEgOA0+urscqPIMV7joxgz7KfxXbqobndckMUji7pDUkdthH
v05g8BezoJFF
       "]]}, {}}, {}}, {{}, {}, 
    {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], Opacity[
     1.], LineBox[CompressedData["
1:eJwV1Hk01ekfB3BJZcZIRTfLFWnQNJSQn/2dEcPML4SkKJVSlrJLlqyRQtai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      "]]}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0.4858543514480079},
  DisplayFunction->Identity,
  Frame->True,
  FrameLabel->{
    FormBox["\"time\"", TraditionalForm], 
    FormBox["\"u\"", TraditionalForm]},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  Method->{},
  PlotRange->All,
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.6385163414337997`*^9, 3.6386024479126*^9}]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[" ", "Text",
 CellChangeTimes->{{3.6373024057792997`*^9, 3.6373024248943*^9}}],

Cell[CellGroupData[{

Cell[TextData[{
 "Example 2\n",
 Cell[GraphicsData["Metafile", "\<\
CF5dJ6E]HGAYHf4PEfU^I6mgLb15CDHPAVmbKF5d0@000=9/0@0006`0003oooooooooof4:000f0P00
00000000003W:`00F0T00215CDH00040K=8009L1000700000000000000000000HA<006PK003B0000
:@400000000000000000050d0`0XR0@0AP0002`0000P0000ADe6:`500@0L00004000008@`=/00000
F08005P200160000O04007010015CDH[7T0500`0000000007d0300`000000000<402010000040000
0020?b501`0<000000000290100<0000000002Y0000T000060000000P3l0000000000000P3l00000
000002]0000<0000000001i01P0<0000000002501@0<0000000001i02@0<0000000002Y0000T0000
60000000P3l0000000000000P3l00000000002501`0<0000000002Y0000T000060000;02;3X00000
00000;02;3X0P8i30414a2]0000<0000000002Y0000T000060000;02;3X0000000000;02;3X0P8i3
0414a2]0000<0000000002Y0000T000060000;02;3X0000000000;02;3X008hW0014Z0Y0080T0000
60000?ooool100000000000000003WM:P9MBBB4000080000HP0000`000010000900002@00000000n
000000000000000n00000000000200009`0001P00001000000000?ooo`0000009@0000`000010000
9@0000`000080020EP000300003oooooooooof0:000f0P001@000?coo?oloj`Ao5:/4OaBo?olooco
9@0000`0000700209@0000`000000020900002@00000001100000000000000110000000000020000
AP000=aT003@I000ADe6:b]0000<0000000001i01P0<0000000002501@0<0000000001i02@0<0000
000002Y0000T000060000;02;3X0000000000;02;3X008hW0014Z2501`0<0000000002]0000<0000
000002Y0000T0000600009:<94400000000005D`947Dj^;4d]7?ABA0100<0000000000Q000G<H`00
`6<0008@`=/200000`000;1S00010000c0000;80001ioOoo/P400:gmoom@6000a:Kooklk000i[_oo
84E=AP000@2`H`00HP4000@0000`0000K000000000201`00/0@00:D2002W0@000000000000000000
eED:0:Ee1P1W06D0KP1U0780H@1d06D0I00P0680N@0P05L0C@1602l0A@1=04H0801R0640H`1[06D0
KP1T0200K`1V0200L01c07@0K`1U06@0J@1d0000J@1^0700M@1d0000000A0000300000H0000:0000
40000000000000004P0000`0000100005P0000`0000H0000600000`000000000DP00070100010000
>Oooo`0000000000000009010000000000020T<0C@1=04T0<@0`0000000000000000000000000000
00000000000000000000000000000000000000000000000010000<S:60000000200000L000000000
SU?HM/S:600`bQP0k;1300@000240000b<XH00000000000030000000000100008<XH000000240000
X0l0008000030000b<XH000000000000?<XH07nN@`3l2^l1P<XH0000@`040000S[E305YT/VbHLnl1
8HQ600000000000000000040001<bQP002m:00c;603PW480RX[]K?koool004<0gKE309Qck`400000
003_0IQck`78bQP00@0003P07P0<0000b<XH09Qck`410`00h7;_0@40002@Lnl1I7H02000000U0000
30000040001D0000E0000;<0001joOoo^@0008Cmool10000Zj[Q?iZIhKoj3@00fc400040001<0000
0000000000000000oooooooooom@0000@00006@0000H000030000000000U0000300000d0080X0000
30000040001B0000L0400040001eoooo0000000000000000T040000000000082@`1=04d0B@0g0000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
=`40=P`000020000<:Hb0<S:600000006`0n07@1;`000000D04_05P3d`4004<0N=0a0=3M<@000000
30000000001L0@01d=da060000000041E<TH08cS/WN<bQP0mG6gMg2W6P3nooooZSRcMj8d/gL00000
000a07S@<@088@ZN0000073@<@2LbQP0RU?/MP00;`000000XEC/MYoR]F`88@ZNN=0a0801^gG`K^l1
B03C0@00d`5XbQP0224:WXC<6000L>if4j=36_kooonQE>af1A:gMGS@<@1h?380CalQI0002P1h?380
e<XH05`i]gETMP08000002D0000<00000@0005@0001D0000^@0007Wmoonm0000Oogoo`40002[Z^4o
VYWQ_fl>000S<P000@0004`00000000000000000003ooooooooooe00002`0000D00001P0000<0000
000002D0000<00003@00P2P0000<00000@000580001`0@000@0003Woool0000000000000002@0@00
000000000P9304d0C@190340<0000000000000000000000000000000000000000000000000000000
000000000000000000000=3M<@0g0@0f300005C9600`YS80S<XH0?Ea]gLK03h0M04_0000001@0Bl0
F0?C0@00<@1hd340d=da0000000<0000000005`1007@gC40H00000000@5DbAP0000008c:603eLKMg
L:LJ0?kooonZ>;=gXSBcM`0000000340N=0a00PQ2Yl00000L=0a09c:602:Dnaf000_0000002QE>af
Wn:eK0PQ2Ymhd340P06kM@0000180=<1003C0FS:60088@ZOQ<`H001`kWHCXd<Jo_oooj5Dk7H54[Me
N=0a07Pl<P1?7b5T000:07Pl<P3DbQP0G3VgMFAf00P000009@0000`000010000E00005@0002n0000
N_gool@00024oOoo0@000:^ZhCnJVN6oePh00=/a00010000C00000000000000000000?oooooooooo
D00007D0001h00009P0001`0000200000000000000000000000002D0000<00000P0002L0000H0000
0`00000000000000000002D0000<00000`0001<0000<00000P0005/0000h0000/`0008Kmooo40000
Q_goo`40000500001@000?`=R35:3hPaBPn@<O`=T37l3HPa600000`000000000E00005@0002d0000
QogookX0002AoOoo0@000:^ZhCnJVN6o40h00<``00010000C00000000000000000000?oooooooooo
D0000400001T0000600000`000000000E00005@0002j0000Qogookh0002AoOoo0@000:^ZhCnJVN6o
Q0h00<``00010000C00000000000000000000?ooooooooooD00007@0001@0000600000`000000000
9@0000`0000=0020:00000`000010000DP00070100010000MOooo`00000000000000090100000000
00020T<0C@1=04T0=`00000000000000000000000000000000000000000000000000000000000000
0000000000000000000003L103H40000^1O_0C2V<P0hK^l1P08001/0?P1d0Bl000000501;`1H0m<1
>07_0GS@<@3@gC40000000@000000000G0400@00000P000000010EC960000000S<XH0?Ea]gM`YaX0
o_ooojXh/gNR=;=g00000000<@1hd340224:X000001`d340W<XH08YCk7H002l000000:5Dk7JOh[E/
224:X7S@<@200K]e3000060Qh@400>41J<XH00PQ2Z24c1P0073^MQ>S@a[nooooXEC/MPDB]gEhd340
N3`b04lO8F@000X0N3`b0=C:601L>KMeI7H02000000U000030000040001D0000E0000;d00028oOoo
`@0008kmool10000Zj[Q?iZIhKo<3P001S400040001<00000000000000000000oooooooooom@0000
/0000500000H000030000000000U0000300000d0080X000030000040001B0000L0400040000ioooo
0000000000000000T040000000000082@`1=0580<@0`000000000000000000000000000000000000
000000000000000000000000000000000000000000000000=`40=P@0001DbAP0<:Hb08c:603eLKMg
6`0n07@1;`000000D04_05P3d`400340N=0a0=3M<@00000010000000001L0@010000020000000041
E<TH0000002<bQP0mG6gMg2W6P3nooooZSRcMj8d/gL00000000a07S@<@088@ZQ0000073@<@2LbQP0
RU?/MP00;`000000XEC/MYoR]F`88@ZQN=0a0801^gD00000H27Q0@00h@5XbQP0224:XHC<6000L>if
4j=36_kooonQE>af1A:gMGS@<@1h?380CalQI0002P1h?380e<XH05`i]gETMP08000002D0000<0000
0@0005@0001D0000b000087mooo@0000Rogoo`40002[Z^4oVYWQ_iL?001E<@000@0004`000000000
00000000003ooooooooooe00000m0000X00001P0000<0000000002D0000<00003@00P2P0000<0000
0@000580001`0@000@0003Woool0000000000000002@0@00000000000P9304d0C@190340<0000000
000000000000000000000000000000000000000000000000000000000000000000000000000g0@0f
100005C9600`YS80S<XH0?Ea]gLK03h0M04_0000001@0Bl0F0?C0@00<@1hd340d=da000000040000
000005`100400000800000000@5DbAP0000008c:603eLKMgL:LJ0?kooonZ>;=gXSBcM`0000000340
N=0a00PQ2Z800000L=0a09c:602:Dnaf000_0000002QE>afWn:eK0PQ2Z9hd340P06kM@00001P8N41
003Q0FS:60088@ZRQ<`H001`kWHCXd<Jo_oooj5Dk7H54[MeN=0a07Pl<P1?7b5T000:07Pl<P3DbQP0
G3VgMFAf00P000009@0000`000010000E00005@0003C0000N_goomT00024oOoo0@000:^ZhCnJVN6o
PA000=/a00010000C00000000000000000000?ooooooooooD0000400001T0000600000`000000000
9@0000`0000=0020:00000`000010000DP00070100010000MOooo`00000000000000090100000000
00020T<0C@1B03L00000000000000000000000000000000000000000000000000000000000000000
0000000000000000000003L103H40000E<TH032V<P2<bQP0mG6gMa/0?P1d0Bl000000501;`1H0m<1
000a07S@<@3@gC40000000@000000000G0400@00000P000000010EC960000000S<XH0?Ea]gM`YaX0
o_ooojXh/gNR=;=g00000000<@1hd340224:X`00001`d340W<XH08YCk7H002l000000:5Dk7JOh[E/
224:XgS@<@200K]e0000060Qh@400>41J<XH00PQ2Z>4c1P0073^MQ>S@a[nooooXEC/MPDB]gEhd340
N3`b04lO8F@000X0N3`b0=C:601L>KMeI7H02000000U000030000040001D0000E0000=T0001ioOoo
g@0007omool10000Zj[Q?iZIhKof40008c800040001<00000000000000000000oooooooooom@0000
<P000500000H000030000000000U0000300000d0080X000030000040001B0000L0400040000ioooo
0000000000000000T040000000000082@`1=04d0B@0a030000000000000000000000000000000000
000000000000000000000000000000000000000000000000=`40=P@0001DbAP0<:Hb08c:603eLKMg
6`0n07@1;`000000D04_05P3d`400340N=0a0=3M<@00000010000000001L0@010000020000000041
E<TH0000002<bQP0mG6gMg2W6P3nooooZSRcMj8d/gL00000000a07S@<@088@ZT0000073@<@2LbQP0
RU?/MP00;`000000XEC/MYoR]F`88@ZTN=0a0801^gD00000H27Q0@00h@5XbQP0224:Y8C<6000L>if
4j=36_kooonQE>af1A:gMGS@<@1h?380CalQI0002P1h?380e<XH05`i]gETMP08000002D0000<0000
0@0005@0001D0000gP0007[moooT0000Q?goo`40002[Z^4oVYWQ_e0A003K<@000@0004`000000000
00000000003ooooooooooe00001e0000N00002D0000<00001`00P2P0000<00000P0002H0000L0000
0P0000000000000000000000000U000030000080000U000030000000080X0000300000<0000W0000
600000<00000000000000000000U0000300000<0000C000030000080001K0000>0000=<00026oOoo
h`0008Kmool100001@0000D0001l48Pa_168<K`AT35l490aO128<AP0000<0000000005@0001D0000
d`0008OmoooI0000TOgoo`40002[Z^4oVYWQ_h4@003<<0000@0004`00000000000000000003ooooo
oooooe0000100000I00001P0000<0000000005@0001D0000f@0008OmoooO0000TOgoo`40002[Z^4o
VYWQ_oH@003<<0000@0004`00000000000000000003ooooooooooe00001h0000N00001P0000<0000
000002D0000<00003@00P2P0000<00000@000580001`0@000@0007Goool0000000000000002@0@00
000000000P9304d0DP0g000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000g0@0f10000;PGk`4`YS80>6k_0H02000K03h0M04_0000001@0Bl0
F0?C0CP1k`5hd340d=da000000040000000005`100400000800000000@5DbAP0000008c:603eLKMg
L:LJ0?kooonZ>;=gXSBcM`0000000340N=0a00PQ2ZD00000L=0a09c:602:Dnaf000_0000002QE>af
Wn:eK0PQ2ZEhd340P06kM@`0001P8N41003Q0FS:60088@ZUQ<`H001`kWHCXd<Jo_oooj5Dk7H54[Me
N=0a07Pl<P1?7b5T000:07Pl<P3DbQP0G3VgMFAf00P000009@0000`000010000E00005@0003O0000
R?goon<0002>oOoo0@000:^ZhCnJVN6oJ14000Ha00010000C00000000000000000000?oooooooooo
D0000380001@0000600000`0000000009@0000`0000=0020:00000`000010000DP00070100010000
>Oooo`0000000000000009010000000000020T<0C@1B0340<0000000000000000000000000000000
000000000000000000000000000000000000000000000000000003L103H40000E<TH032V<P2<bQP0
mG6gMa/0?P1d0Bl000000501;`1H0m<1000a07S@<@3@gC40000000@000000000G0400@00000P0000
00010EC960000000S<XH0?Ea]gM`YaX0o_ooojXh/gNR=;=g00000000<@1hd340224:YP00001`d340
W<XH08YCk7H002l000000:5Dk7JOh[E/224:YWS@<@200K]e0000060Qh@400>41J<XH00PQ2ZJ4c1P0
073^MQ>S@a[nooooXEC/MPDB]gEhd340N3`b04lO8F@000X0N3`b0=C:601L>KMeI7H02000000U0000
30000040001D0000E0000>L00021oOook`0008_mool10000Zj[Q?iZIhKl64P00EC400040001<0000
0000000000000000oooooooooom@0000:`000:00000H000030000000000U0000300000d0080X0000
30000040001B0000L0400040000ioooo0000000000000000T040000000000082@`1=04d0B@0a0300
00000000000000000000000000000000000000000000000000000000000000000000000000000000
=`40=P@0001DbAP0<:Hb08c:603eLKMg6`0n07@1;`000000D04_05P3d`400340N=0a0=3M<@000000
10000000001L0@010000020000000041E<TH0000002<bQP0mG6gMg2W6P3nooooZSRcMj8d/gL00000
000a07S@<@088@ZW0000073@<@2LbQP0RU?/MP00;`000000XEC/MYoR]F`88@ZWN=0a0801^gD00000
H27Q0@00h@5XbQP0224:YhC<6000L>if4j=36_kooonQE>af1A:gMGS@<@1h?380CalQI0002P1h?380
e<XH05`i]gETMP08000002D0000<00000@0005@0001D0000l@00087mooof0000Rogoo`40002[Z^4o
VYWQ_ldB001E<@000@0004`00000000000000000003ooooooooooe00001Q0000I00001P0000<0000
000002D0000<00003@00P2P0000<00000@000580001`0@000@0003Woool0000000000000002@0@00
000000000P9304d0DP0a030000000000000000000000000000000000000000000000000000000000
000000000000000000000000000g0@0f100005C9600`YS80S<XH0?Ea]gLK03h0M04_0000001@0Bl0
F0?C0@00<@1hd340d=da000000040000000005`100400000800000000@5DbAP0000008c:603eLKMg
L:LJ0?kooonZ>;=gXSBcM`0000000340N=0a00PQ2ZP00000L=0a09c:602:Dnaf000_0000002QE>af
Wn:eK0PQ2ZQhd340P06kM@00001P8N41003Q0FS:60088@ZXQ<`H001`kWHCXd<Jo_oooj5Dk7H54[Me
N=0a07Pl<P1?7b5T000:07Pl<P3DbQP0G3VgMFAf00P000009@0000`000010000E00005@0003h0000
POgooo/0002;oOoo0@000:^ZhCnJVN6oF1<005Da00010000C00000000000000000000?oooooooooo
D00005/0000l0000600000`000000000E00005@0003j0000POgoooh0002;oOoo0@000:^ZhCnJVN6o
SQ<005Da00010000C00000000000000000000?ooooooooooD00007<0001@0000600000`000000000
E00005@0003n0000POgoo`41002;oOoo0@000:^ZhCnJVN6og1<005Da00010000C000000000000000
00000?ooooooooooD00006T0000l0000600000`000000000E00005@000010@00POgoo`L1002;oOoo
0@000:^ZhCnJVN6o4a@005Da00010000C00000000000000000000?ooooooooooD00006h0001h0000
600000`000000000E00005@000070@00POgoo`/1002;oOoo0@000:^ZhCnJVN6oPa@005Da00010000
C00000000000000000000?ooooooooooD00002P0001@0000600000`0000000009@0000`0000=0020
:00000`000010000DP00070100010000>Oooo`0000000000000009010000000000020T<0C@1=04T0
<@0`0000000000000000000000000000000000000000000000000000000000000000000000000000
000003L103H40000E<TH032V<P2<bQP0mG6gMa/0?P1d0Bl000000501;`1H0m<1000a07S@<@3@gC40
000000@000000000G0400@00000P000000010EC960000000S<XH0?Ea]gM`YaX0o_ooojXh/gNR=;=g
00000000<@1hd340224:Z@00001`d340W<XH08YCk7H002l000000:5Dk7JOh[E/224:ZGS@<@200K]e
0000060Qh@400>41J<XH00PQ2ZV4c1P0073^MQ>S@a[nooooXEC/MPDB]gEhd340N3`b04lO8F@000X0
N3`b0=C:601L>KMeI7H02000000U000030000040001D0000E00000X10021oOoo3`4008_mool10000
Zj[Q?iZIhKoA5000EC400040001<00000000000000000000oooooooooom@0000^P0006@0000H0000
30000000001D0000E00001010021oOoo504008_mool10000Zj[Q?iZIhKm05@00EC400040001<0000
0000000000000000oooooooooom@0000M0000500000H000030000000000U0000300000d0080X0000
30000040001B0000L0400040000ioooo0000000000000000T040000000000082@`1=0580<@0`0000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
=`40=P@0001DbAP0<:Hb08c:603eLKMg6`0n07@1;`000000D04_05P3d`400340N=0a0=3M<@000000
10000000001L0@010000020000000041E<TH0000002<bQP0mG6gMg2W6P3nooooZSRcMj8d/gL00000
000a07S@<@088@ZZ0000073@<@2LbQP0RU?/MP00;`000000XEC/MYoR]F`88@ZZN=0a0801^gD00000
H27Q0@00h@5XbQP0224:ZXC<6000L>if4j=36_kooonQE>af1A:gMGS@<@1h?380CalQI0002P1h?380
e<XH05`i]gETMP08000002D0000<00000@0005@0001D00005040087moolH0@00Rogoo`40002[Z^4o
VYWQ_hPE001E<@000@0004`00000000000000000003ooooooooooe00000Y0000D00001P0000<0000
000005@0001D00006P40087moolR0@00Rogoo`40002[Z^4oVYWQ_`4F001E<@000@0004`000000000
00000000003ooooooooooe00000[0000X00001P0000<0000000002D0000<00003@00P2P0000<0000
0@000580001`0@000@0003Woool0000000000000002@0@00000000000P9304d0C@190340<0000000
000000000000000000000000000000000000000000000000000000000000000000000000000g0@0f
100005C9600`YS80S<XH0?Ea]gLK03h0M04_0000001@0Bl0F0?C0@00<@1hd340d=da000000040000
000005`100400000800000000@5DbAP0000008c:603eLKMgL:LJ0?kooonZ>;=gXSBcM`0000000340
N=0a00PQ2Z/00000L=0a09c:602:Dnaf000_0000002QE>afWn:eK0PQ2Z]hd340P06kM@00001P8N41
003Q0FS:60088@Z[Q<`H001`kWHCXd<Jo_oooj5Dk7H54[MeN=0a07Pl<P1?7b5T000:07Pl<P3DbQP0
G3VgMFAf00P000009@0000`000010000E00005@0000T0@00POgoobT1002;oOoo0@000:^ZhCnJVN6o
bAH005Da00010000C00000000000000000000?ooooooooooD0000;X0001T0000600000`000000000
9@0000`0000=0020:00000`000010000DP00070100010000MOooo`00000000000000090100000000
00020T<0C@1=04T0=`00000000000000000000000000000000000000000000000000000000000000
0000000000000000000003L103H40000E<TH032V<P2<bQP0mG6gMa/0?P1d0Bl000000501;`1H0m<1
000a07S@<@3@gC40000000@000000000G0400@00000P000000010EC960000000S<XH0?Ea]gM`YaX0
o_ooojXh/gNR=;=g00000000<@1hd340224:[000001`d340W<XH08YCk7H002l000000:5Dk7JOh[E/
224:[7S@<@200K]e0000060Qh@400>41J<XH00PQ2Zb4c1P0073^MQ>S@a[nooooXEC/MPDB]gEhd340
N3`b04lO8F@000X0N3`b0=C:601L>KMeI7H02000000U000030000040001D0000E00002T10020oOoo
;@4008Kmool10000Zj[Q?iZIhKli5`00YS400040001<00000000000000000000oooooooooom@0000
/0000500000H000030000000000U0000300000d0080X000030000040001B0000L0400040000ioooo
0000000000000000T040000000000082@`1=0580<@0`000000000000000000000000000000000000
000000000000000000000000000000000000000000000000=`40=P@0001DbAP0<:Hb08c:603eLKMg
6`0n07@1;`000000D04_05P3d`400340N=0a0=3M<@00000010000000001L0@010000020000000041
E<TH0000002<bQP0mG6gMg2W6P3nooooZSRcMj8d/gL00000000a07S@<@088@Z]0000073@<@2LbQP0
RU?/MP00;`000000XEC/MYoR]F`88@Z]N=0a0801^gD00000H27Q0@00h@5XbQP0224:[HC<6000L>if
4j=36_kooonQE>af1A:gMGS@<@1h?380CalQI0002P1h?380e<XH05`i]gETMP08000002D0000<0000
0@0005@0001D0000<040087moold0@00Rogoo`40002[Z^4oVYWQ_klG001E<@000@0004`000000000
00000000003ooooooooooe00001c0000D00001P0000<0000000005@0001D0000=040087moolg0@00
Rogoo`40002[Z^4oVYWQ_`dH001E<@000@0004`00000000000000000003ooooooooooe00001Y0000
?00001P0000<0000000005@0001D0000=`40087moolm0@00Rogoo`40002[Z^4oVYWQ_d@H001E<@00
0@0004`00000000000000000003ooooooooooe00001^0000N00001P0000<0000000005@0001D0000
?P40087moom20@00Rogoo`40002[Z^4oVYWQ_mHH001E<@000@0004`00000000000000000003ooooo
oooooe00000X0000D00001P0000<0000000002D0000<00003@00P2P0000<00000@000580001`0@00
0@0003Woool0000000000000002@0@00000000000P9304d0C@190340<00000000000000000000000
00000000000000000000000000000000000000000000000000000000000g0@0f100005C9600`YS80
S<XH0?Ea]gLK03h0M04_0000001@0Bl0F0?C0@00<@1hd340d=da000000040000000005`100400000
800000000@5DbAP0000008c:603eLKMgL:LJ0?kooonZ>;=gXSBcM`0000000340N=0a00PQ2Zh00000
L=0a09c:602:Dnaf000_0000002QE>afWn:eK0PQ2Zihd340P06kM@00001P8N41003Q0FS:60088@Z^
Q<`H001`kWHCXd<Jo_oooj5Dk7H54[MeN=0a07Pl<P1?7b5T000:07Pl<P3DbQP0G3VgMFAf00P00000
9@0000`000010000E00005@000120@00POgoodL1002;oOoo0@000:^ZhCnJVN6o8QT005Da00010000
C00000000000000000000?ooooooooooD0000;X0001T0000600000`000000000E00005@000170@00
POgood/1002;oOoo0@000:^ZhCnJVN6oTQT005Da00010000C00000000000000000000?oooooooooo
D00007@0001@0000600000`0000000009@0000`0000=0020:00000`000010000DP00070100010000
>Oooo`0000000000000009010000000000020T<0C@1B0340<0000000000000000000000000000000
000000000000000000000000000000000000000000000000000003L103H40000E<TH032V<P2<bQP0
mG6gMa/0?P1d0Bl000000501;`1H0m<1000a07S@<@3@gC40000000@000000000G0400@00000P0000
00010EC960000000S<XH0?Ea]gM`YaX0o_ooojXh/gNR=;=g00000000<@1hd340224:[`00001`d340
W<XH08YCk7H002l000000:5Dk7JOh[E/224:[gS@<@200K]e0000060Qh@400>41J<XH00PQ2Zn4c1P0
073^MQ>S@a[nooooXEC/MPDB]gEhd340N3`b04lO8F@000X0N3`b0=C:601L>KMeI7H02000000U0000
30000040001D0000E00004d10021oOooE@4008_mool10000Zj[Q?iZIhKl66P00EC400040001<0000
0000000000000000oooooooooom@0000:`000:00000H000030000000000U0000300000d0080X0000
30000040001B0000L0400040000ioooo0000000000000000T040000000000082@`1=04d0B@0a0300
00000000000000000000000000000000000000000000000000000000000000000000000000000000
=`40=P@0001DbAP0<:Hb08c:603eLKMg6`0n07@1;`000000D04_05P3d`400340N=0a0=3M<@000000
10000000001L0@010000020000000041E<TH0000002<bQP0mG6gMg2W6P3nooooZSRcMj8d/gL00000
000a07S@<@088@Z`0000073@<@2LbQP0RU?/MP00;`000000XEC/MYoR]F`88@Z`N=0a0801^gD00000
H27Q0@00h@5XbQP0224:/8C<6000L>if4j=36_kooonQE>af1A:gMGS@<@1h?380CalQI0002P1h?380
e<XH05`i]gETMP08000002D0000<00000@0005@0001D0000E`40087moomL0@00Rogoo`40002[Z^4o
VYWQ_ldJ001E<@000@0004`00000000000000000003ooooooooooe00002`0000I00001P0000<0000
000005@0001D0000G@40087moomS0@00Rogoo`40002[Z^4oVYWQ_clK001E<@000@0004`000000000
00000000003ooooooooooe00002l0000N00001P0000<0000000005@0001D0000H`40087moomX0@00
Rogoo`40002[Z^4oVYWQ_kPK001E<@000@0004`00000000000000000003ooooooooooe00000m0000
I00001P0000<0000000002D0000<00003@00P2P0000<00000@000580001`0@000@0003Woool00000
00000000002@0@00000000000P9304d0DP0a03000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000g0@0f100005C9600`YS80S<XH0?Ea]gLK03h0
M04_0000001@0Bl0F0?C0@00<@1hd340d=da000000040000000005`100400000800000000@5DbAP0
000008c:603eLKMgL:LJ0?kooonZ>;=gXSBcM`0000000340N=0a00PQ2[400000L=0a09c:602:Dnaf
000_0000002QE>afWn:eK0PQ2[5hd340P06kM@00001P8N41003Q0FS:60088@ZaQ<`H001`kWHCXd<J
o_oooj5Dk7H54[MeN=0a07Pl<P1?7b5T000:07Pl<P3DbQP0G3VgMFAf00P000009@0000`000010000
E00005@0001X0@00POgoofd1002;oOoo0@000:^ZhCnJVN6o6a`005Da00010000C000000000000000
00000?ooooooooooD0000380001T0000600000`000000000E00005@0001]0@00POgoog41002;oOoo
0@000:^ZhCnJVN6oOa`005Da00010000C00000000000000000000?ooooooooooD00002T0001@0000
600000`000000000E00005@0001a0@00POgoog@1002;oOoo0@000:^ZhCnJVN6oc1`005Da00010000
C00000000000000000000?ooooooooooD00005d0000l0000600000`0000000009@0000`0000=0020
:00000`000010000DP00070100010000>Oooo`0000000000000009010000000000020T<0C@1=04T0
<@0`0000000000000000000000000000000000000000000000000000000000000000000000000000
000003L103H40000E<TH032V<P2<bQP0mG6gMa/0?P1d0Bl000000501;`1H0m<1000a07S@<@3@gC40
000000@000000000G0400@00000P000000010EC960000000S<XH0?Ea]gM`YaX0o_ooojXh/gNR=;=g
00000000<@1hd340224:/P00001`d340W<XH08YCk7H002l000000:5Dk7JOh[E/224:/WS@<@200K]e
0000060Qh@400>41J<XH00PQ2[:4c1P0073^MQ>S@a[nooooXEC/MPDB]gEhd340N3`b04lO8F@000X0
N3`b0=C:601L>KMeI7H02000000U000030000040001D0000E00007D10021oOooN04008_mool10000
Zj[Q?iZIhKlT7@00EC400040001<00000000000000000000oooooooooom@0000>`0003`0000H0000
30000000000U0000300000d0080X000030000040001B0000L0400040000ioooo0000000000000000
T040000000000082@`1=0580<@0`0000000000000000000000000000000000000000000000000000
00000000000000000000000000000000=`40=P@0001DbAP0<:Hb08c:603eLKMg6`0n07@1;`000000
D04_05P3d`400340N=0a0=3M<@00000010000000001L0@010000020000000041E<TH0000002<bQP0
mG6gMg2W6P3nooooZSRcMj8d/gL00000000a07S@<@088@Zc0000073@<@2LbQP0RU?/MP00;`000000
XEC/MYoR]F`88@ZcN=0a0801^gD00000H27Q0@00h@5XbQP0224:/hC<6000L>if4j=36_kooonQE>af
1A:gMGS@<@1h?380CalQI0002P1h?380e<XH05`i]gETMP08000002D0000<00000@0005@0001D0000
P`40087moon80@00Rogoo`40002[Z^4oVYWQ_d@N001E<@000@0004`00000000000000000003ooooo
oooooe00000`0000I00001P0000<0000000002D0000<00003@00P2P0000<00000@000580001`0@00
0@0003Woool0000000000000002@0@00000000000P9304d0D`1I0340<01?0580B@17000000000000
00000000000000000000000000000000000000000000000000000000000g0@0f100005C9600`YS80
S<XH0?Ea]gLK03h0M04_0000001@0Bl0F0?C0@00<@1hd340d=da000000040000000005`100400000
800000000@5DbAP0000008c:603eLKMgL:LJ0?kooonZ>;=gXSBcM`0000000340N=0a00PQ2[@00000
L=0a09c:602:Dnaf000_0000002QE>afWn:eK0PQ2[Ahd340P06kM@00001P8N41003Q0FS:60088@Zd
Q<`H001`kWHCXd<Jo_oooj5Dk7H54[MeN=0a07Pl<P1?7b5T000:07Pl<P3DbQP0G3VgMFAf00P00000
9@0000`000010000E00005@0002;0@00POgooi<1002BoOoo0@000:^ZhCnJVN6ogah005Da00010000
C00000000000000000000?ooooooooooD0000;L0002P0000600000`0000000009@0000`0000=0020
:00000`000010000DP00070100010000>Oooo`0000000000000009010000000000020T<0C@1=04T0
<@0`0000000000000000000000000000000000000000000000000000000000000000000000000000
000003L103H40000E<TH032V<P2<bQP0mG6gMa/0?P1d0Bl000000501;`1H0m<1000a07S@<@3@gC40
000000@000000000G0400@00000P000000010EC960000000S<XH0?Ea]gM`YaX0o_ooojXh/gNR=;=g
00000000<@1hd340224:]@00001`d340W<XH08YCk7H002l000000:5Dk7JOh[E/224:]GS@<@200K]e
0000060Qh@400>41J<XH00PQ2[F4c1P0073^MQ>S@a[nooooXEC/MPDB]gEhd340N3`b04lO8F@000X0
N3`b0=C:601L>KMeI7H02000000U000030000040001D0000E00009H10021oOooW04008_mool10000
Zj[Q?iZIhKna7`00EC400040001<00000000000000000000oooooooooom@0000N00007P0000H0000
30000000000U0000300000d0080X000030000040001B0000L0400040000ioooo0000000000000000
T040000000000082@`1=05<0F@0a0300C`1B04T0A`00000000000000000000000000000000000000
00000000000000000000000000000000=`40=P@0001DbAP0<:Hb08c:603eLKMg6`0n07@1;`000000
D04_05P3d`400340N=0a0=3M<@00000010000000001L0@010000020000000041E<TH0000002<bQP0
mG6gMg2W6P3nooooZSRcMj8d/gL00000000a07S@<@088@Zf0000073@<@2LbQP0RU?/MP00;`000000
XEC/MYoR]F`88@ZfN=0a0801^gD00000H27Q0@00h@5XbQP0224:]XC<6000L>if4j=36_kooonQE>af
1A:gMGS@<@1h?380CalQI0002P1h?380e<XH05`i]gETMP08000002D0000<00000@0005@0001D0000
WP40087moonV0@00T_goo`40002[Z^4oVYWQ_eXP001E<@000@0004`00000000000000000003ooooo
oooooe00002g0000X00001P0000<0000000002D0000<00003@00P2P0000<00000@000580001`0@00
0@0003Woool0000000000000002@0@00000000000P9304d0C@190340<00000000000000000000000
00000000000000000000000000000000000000000000000000000000000g0@0f100005C9600`YS80
S<XH0?Ea]gLK03h0M04_0000001@0Bl0F0?C0@00<@1hd340d=da000000040000000005`100400000
800000000@5DbAP0000008c:603eLKMgL:LJ0?kooonZ>;=gXSBcM`0000000340N=0a00PQ2[L00000
L=0a09c:602:Dnaf000_0000002QE>afWn:eK0PQ2[Mhd340P06kM@00001P8N41003Q0FS:60088@Zg
Q<`H001`kWHCXd<Jo_oooj5Dk7H54[MeN=0a07Pl<P1?7b5T000:07Pl<P3DbQP0G3VgMFAf00P00000
9@0000`000010000E00005@0002Y0@00POgoojl1002;oOoo0@000:^ZhCnJVN6o;B4005Da00010000
C00000000000000000000?ooooooooooD0000;`0001h0000600000`000000000E00005@0002_0@00
POgook81002;oOoo0@000:^ZhCnJVN6oYR4005Da00010000C00000000000000000000?oooooooooo
D00003/0000l0000600000`000000000E00005@0002b0000U?gookP0002NoOoo0@000:^ZhCnJVN6o
hPd00=D_00010000C00000000000000000000?ooooooooooD00007D0001h0000600000`000000000
9@0000`0000=0020:00000`000010000DP00070100010000>Oooo`00000000000000090100000000
00020T<0C@1B0340<000000000000000000000000000000000000000000000000000000000000000
0000000000000000000003L103H40000E<TH032V<P2<bQP0mG6gMa/0?P1d0Bl000000501;`1H0m<1
000a07S@<@3@gC40000000@000000000G0400@00000P000000010EC960000000S<XH0?Ea]gM`YaX0
o_ooojXh/gNR=;=g00000000<@1hd340224:^000001`d340W<XH08YCk7H002l000000:5Dk7JOh[E/
224:^7S@<@200K]e0000060Qh@400>41J<XH00PQ2[R4c1P0073^MQ>S@a[nooooXEC/MPDB]gEhd340
N3`b04lO8F@000X0N3`b0=C:601L>KMeI7H02000000U000030000040001D0000E0000;L0002DoOoo
^`0009kmool10000Zj[Q?iZIhKmD3P00eBl00040001<00000000000000000000oooooooooom@0000
:0000500000H000030000000000U0000300000d0080X000030000040001B0000L0400040000ioooo
0000000000000000T040000000000082@`1=04d0B@0a030000000000000000000000000000000000
000000000000000000000000000000000000000000000000=`40=P@0001DbAP0<:Hb08c:603eLKMg
6`0n07@1;`000000D04_05P3d`400340N=0a0=3M<@00000010000000001L0@010000020000000041
E<TH0000002<bQP0mG6gMg2W6P3nooooZSRcMj8d/gL00000000a07S@<@088@Zi0000073@<@2LbQP0
RU?/MP00;`000000XEC/MYoR]F`88@ZiN=0a0801^gD00000H27Q0@00h@5XbQP0224:^HC<6000L>if
4j=36_kooonQE>af1A:gMGS@<@1h?380CalQI0002P1h?380e<XH05`i]gETMP08000002D0000<0000
0@0005@0001D0000^`0009Cmooo10000W_goo`40002[Z^4oVYWQ_j8>003E;`000@0004`000000000
00000000003ooooooooooe00001h0000N00001P0000<0000000002D0000<00003@00P2P0000<0000
0@000580001`0@000@0003Woool0000000000000002@0@00000000000P9304d0DP0a030000000000
000000000000000000000000000000000000000000000000000000000000000000000000000g0@0f
100005C9600`YS80S<XH0?Ea]gLK03h0M04_0000001@0Bl0F0?C0@00<@1hd340d=da000000040000
000005`100400000800000000@5DbAP0000008c:603eLKMgL:LJ0?kooonZ>;=gXSBcM`0000000340
N=0a00PQ2[X00000L=0a09c:602:Dnaf000_0000002QE>afWn:eK0PQ2[Yhd340P06kM@00001P8N41
003Q0FS:60088@ZjQ<`H001`kWHCXd<Jo_oooj5Dk7H54[MeN=0a07Pl<P1?7b5T000:07Pl<P3DbQP0
G3VgMFAf00P000009@0000`000010000E00005@000340000U?gool`0002NoOoo0@000:^ZhCnJVN6o
C0l00=D_00010000C00000000000000000000?ooooooooooD00003d0002P0000600000`000000000
E00005@0003>0000U?goom<0002NoOoo0@000:^ZhCnJVN6o7A000=D_00010000C000000000000000
00000?ooooooooooD0000300^gET0000600000`0000000009@0000`0000=0020:00000`000010000
DP00070100010000>Oooo`0000000000000009010000000000020T<0C@1=04T0<@0`000000000000
0000000000000000000000000000000000000000000000000000000000000000000003L103H40000
E<TH032V<P2<bQP0mG6gMa/0?P1d0Bl000000501;`1H0m<1000a07S@<@3@gC40000000@000000000
G0400@00000P000000010EC960000000S<XH0?Ea]gM`YaX0o_ooojXh/gNR=;=g00000000<@1hd340
224:^`00001`d340W<XH08YCk7H002l000000:5Dk7JOh[E/224:^gS@<@200K]e0000060Qh@400>41
J<XH00PQ2[^4c1P0073^MQ>S@a[nooooXEC/MPDB]gEhd340N3`b04lO8F@000X0N3`b0=C:601L>KMe
I7H02000000U000030000040001D0000E0000=<0002DoOooeP0009kmool10000Zj[Q?iZIhKn14000
eBl00040001<00000000000000000000oooooooooom@0000>`3ooc`0000H000030000000001D0000
E0000=P0002DoOoog00009kmool10000Zj[Q?iZIhKoJ4000eBl00040001<00000000000000000000
oooooooooom@0000M0190500000H000030000000000U0000300000d0080X000030000040001B0000
L0400040000ioooo0000000000000000T040000000000082@`1=0580<@0`00000000000000000000
0000000000000000000000000000000000000000000000000000000000000000=`40=P@0001DbAP0
<:Hb08c:603eLKMg6`0n07@1;`000000D04_05P3d`400340N=0a0=3M<@00000010000000001L0@01
0000020000000041E<TH0000002<bQP0mG6gMg2W6P3nooooZSRcMj8d/gL00000000a07S@<@088@Zl
0000073@<@2LbQP0RU?/MP00;`000000XEC/MYoR]F`88@ZlN=0a0801^gD00000H27Q0@00h@5XbQP0
224:_8C<6000L>if4j=36_kooonQE>af1A:gMGS@<@1h?380CalQI0002P1h?380e<XH05`i]gETMP08
000002D0000<00000@0005@0001D0000f`0009CmoooO0000W_goo`40002[Z^4oVYWQ_b8A003E;`00
0@0004`00000000000000000003ooooooooooe00000Y0340D00001P0000<0000000005@0001D0000
hP0009CmoooZ0000W_goo`40002[Z^4oVYWQ_jLA003E;`000@0004`00000000000000000003ooooo
oooooe00000m02l0X00001P0000<0000000002D0000<00003@00P2P0000<00000@000580001`0@00
0@0003Woool0000000000000002@0@00000000000P9304d0C@190340<00000000000000000000000
00000000000000000000000000000000000000000000000000000000000g0@0f100005C9600`YS80
S<XH0?Ea]gLK03h0M04_0000001@0Bl0F0?C0@00<@1hd340d=da000000040000000005`100400000
800000000@5DbAP0000008c:603eLKMgL:LJ0?kooonZ>;=gXSBcM`0000000340N=0a00PQ2[d00000
L=0a09c:602:Dnaf000_0000002QE>afWn:eK0PQ2[ehd340P06kM@00001P8N41003Q0FS:60088@Zm
Q<`H001`kWHCXd<Jo_oooj5Dk7H54[MeN=0a07Pl<P1?7b5T000:07Pl<P3DbQP0G3VgMFAf00P00000
9@0000`000010000E00005@0003/0000U?gooo80002NoOoo0@000:^ZhCnJVN6oNA800=D_00010000
C00000000000000000000?ooooooooooD00007D0;`1h0000600000`0000000009@0000`0000=0020
:00000`000010000DP00070100010000>Oooo`0000000000000009010000000000020T<0C@1B0340
<0000000000000000000000000000000000000000000000000000000000000000000000000000000
000003L103H40000E<TH032V<P2<bQP0mG6gMa/0?P1d0Bl000000501;`1H0m<1000a07S@<@3@gC40
000000@000000000G0400@00000P000000010EC960000000S<XH0?Ea]gM`YaX0o_ooojXh/gNR=;=g
00000000<@1hd340224:_P00001`d340W<XH08YCk7H002l000000:5Dk7JOh[E/224:_WS@<@200K]e
0000060Qh@400>41J<XH00PQ2[j4c1P0073^MQ>S@a[nooooXEC/MPDB]gEhd340N3`b04lO8F@000X0
N3`b0=C:601L>KMeI7H02000000U000030000040001D0000E0000?80002DoOoomP0009kmool10000
Zj[Q?iZIhKo[4P00eBl00040001<00000000000000000000oooooooooom@0000:00_0500000H0000
30000000000U0000300000d0080X000030000040001B0000L0400040000ioooo0000000000000000
T040000000000082@`1=04d0B@0a0300000000000000000000000000000000000000000000000000
00000000000000000000000000000000=`40=P@0001DbAP0<:Hb08c:603eLKMg6`0n07@1;`000000
D04_05P3d`400340N=0a0=3M<@00000010000000001L0@010000020000000041E<TH0000002<bQP0
mG6gMg2W6P3nooooZSRcMj8d/gL00000000a07S@<@088@Zo0000073@<@2LbQP0RU?/MP00;`000000
XEC/MYoR]F`88@ZoN=0a0801^gD00000H27Q0@00h@5XbQP0224:_hC<6000L>if4j=36_kooonQE>af
1A:gMGS@<@1h?380CalQI0002P1h?380e<XH05`i]gETMP08000002D0000<00000@0005@0001D0000
mP0009Cmoool0000W_goo`40002[Z^4oVYWQ_cTC003E;`000@0004`00000000000000000003ooooo
oooooe00001h02l0N00001P0000<0000000002D0000<00003@00P2P0000<00000@000580001`0@00
0@0003Woool0000000000000002@0@00000000000P9304d0DP0a0300000000000000000000000000
00000000000000000000000000000000000000000000000000000000000g0@0f100005C9600`YS80
S<XH0?Ea]gLK03h0M04_0000001@0Bl0F0?C0@00<@1hd340d=da000000040000000005`100400000
800000000@5DbAP0000008c:603eLKMgL:LJ0?kooonZ>;=gXSBcM`0000000340N=0a00PQ2/000000
L=0a09c:602:Dnaf000_0000002QE>afWn:eK0PQ2/1hd340P06kM@00001P8N41003Q0FS:60088@[0
Q<`H001`kWHCXd<Jo_oooj5Dk7H54[MeN=0a07Pl<P1?7b5T000:07Pl<P3DbQP0G3VgMFAf00P00000
9@0000`000010000E00005@0003n0000U?goo`H1002NoOoo0@000:^ZhCnJVN6ohA<00=D_00010000
C00000000000000000000?ooooooooooD00003d0R36P0000600000`0000000009@0000`0000=0020
:00000`000010000DP00070100010000>Oooo`0000000000000009010000000000020T<0C@1=04T0
<@0`0000000000000000000000000000000000000000000000000000000000000000000000000000
000003L103H40000E<TH032V<P2<bQP0mG6gMa/0?P1d0Bl000000501;`1H0m<1000a07S@<@3@gC40
000000@000000000G0400@00000P000000010EC960000000S<XH0?Ea]gM`YaX0o_ooojXh/gNR=;=g
00000000<@1hd340224:`@00001`d340W<XH08YCk7H002l000000:5Dk7JOh[E/224:`GS@<@200K]e
0000060Qh@400>41J<XH00PQ2/64c1P0073^MQ>S@a[nooooXEC/MPDB]gEhd340N3`b04lO8F@000X0
N3`b0=C:601L>KMeI7H02000000U000030000040001D0000E00000T1002DoOoo3`4009kmool10000
Zj[Q?iZIhKnd5000eBl00040001<00000000000000000000oooooooooom@0000_03/MWP0000H0000
30000000001D0000E00000l1002DoOoo4P4009kmool10000Zj[Q?iZIhKl]5@00eBl00040001<0000
0000000000000000oooooooooom@0000>`0H03`0000H000030000000001D0000E00001<1002DoOoo
5`4009kmool10000Zj[Q?iZIhKn55@00eBl00040001<00000000000000000000oooooooooom@0000
M03ooe00000H000030000000000U0000300000d0080X000030000040001B0000L0400040000ioooo
0000000000000000T040000000000082@`1=0580<@0`000000000000000000000000000000000000
000000000000000000000000000000000000000000000000=`40=P@0001DbAP0<:Hb08c:603eLKMg
6`0n07@1;`000000D04_05P3d`400340N=0a0=3M<@00000010000000001L0@010000020000000041
E<TH0000002<bQP0mG6gMg2W6P3nooooZSRcMj8d/gL00000000a07S@<@088@[20000073@<@2LbQP0
RU?/MP00;`000000XEC/MYoR]F`88@[2N=0a0801^gFT?;=gdcbcM`00/7MXbQP0224:`XC<6000L>if
4j=36_kooonQE>af1A:gMGS@<@1h?380CalQI0002P1h?380e<XH05`i]gETMP08000002D0000<0000
0@0005@0001D00005`4009CmoolK0@00W_goo`40002[Z^4oVYWQ_ldE003E;`000@0004`000000000
00000000003ooooooooooe00000Y0?ooD00001P0000<0000000005@0001D00007P4009CmoolV0@00
W_goo`40002[Z^4oVYWQ_e4F003E;`000@0004`00000000000000000003ooooooooooe00000m04T0
X00001P0000<0000000005@0001D0000:04009Cmool]0@00W_goo`40002[Z^4oVYWQ_b<G003E;`00
0@0004`00000000000000000003ooooooooooe00000`02l0I00001P0000<0000000002D0000<0000
3@00P2P0000<00000@000580001`0@000@0003Woool0000000000000002@0@00000000000P9304d0
C@190340<00000000000000000000000000000000000000000000000000000000000000000000000
00000000000g0@0f100005C9600`YS80S<XH0?Ea]gLK03h0M04_0000001@0Bl0F0?C0@00<@1hd340
d=da000000040000000005`100400000800000000@5DbAP0000008c:603eLKMgL:LJ0?kooonZ>;=g
XSBcM`0000000340N=0a00PQ2/<00000L=0a09c:602:Dnaf000_0000002QE>afWn:eK0PQ2/=hd340
P06kM@00003C?;=g002`MfS:60088@[3Q<`H001`kWHCXd<Jo_oooj5Dk7H54[MeN=0a07Pl<P1?7b5T
000:07Pl<P3DbQP0G3VgMFAf00P000009@0000`000010000E00005@0000]0@00U?gooc01002NoOoo
0@000:^ZhCnJVN6oQaL00=D_00010000C00000000000000000000?ooooooooooD00003/0;`0l0000
600000`000000000E00005@0002b0000XogookP0002]oOoo0@000:^ZhCnJVN6ohPd00:X^00010000
C00000000000000000000?ooooooooooD00007D0<@1h0000600000`0000000009@0000`0000=0020
:00000`000010000DP00070100010000>Oooo`0000000000000009010000000000020T<0C@1B0340
<0000000000000000000000000000000000000000000000000000000000000000000000000000000
000003L103H40000E<TH032V<P2<bQP0mG6gMa/0?P1d0Bl000000501;`1H0m<1000a07S@<@3@gC40
000000@000000000G0400@00000P000000010EC960000000S<XH0?Ea]gM`YaX0o_ooojXh/gNR=;=g
00000000<@1hd340224:a000001`d340W<XH08YCk7H002l000000:5Dk7JOh[E/224:a7S@<@200K]e
00000=<l/gL00;1gJ<XH00PQ2/B4c1P0073^MQ>S@a[nooooXEC/MPDB]gEhd340N3`b04lO8F@000X0
N3`b0=C:601L>KMeI7H02000000U000030000040001D0000E0000;L0002SoOoo^`000:gmool10000
Zj[Q?iZIhKmD3P00ZRh00040001<00000000000000000000oooooooooom@0000:03ooe00000H0000
30000000000U0000300000d0080X000030000040001B0000L0400040000ioooo0000000000000000
T040000000000082@`1=04d0B@0a0300000000000000000000000000000000000000000000000000
00000000000000000000000000000000=`40=P@0001DbAP0<:Hb08c:603eLKMg6`0n07@1;`000000
D04_05P3d`400340N=0a0=3M<@00000010000000001L0@010000020000000041E<TH0000002<bQP0
mG6gMg2W6P3nooooZSRcMj8d/gL00000000a07S@<@088@[50000073@<@2LbQP0RU?/MP00;`000000
XEC/MYoR]F`88@[5N=0a0801^gD00000dcbcM`00/7MXbQP0224:aHC<6000L>if4j=36_kooonQE>af
1A:gMGS@<@1h?380CalQI0002P1h?380e<XH05`i]gETMP08000002D0000<00000@0005@0001D0000
^`000:?mooo10000[Ogoo`40002[Z^4oVYWQ_j8>002Z;P000@0004`00000000000000000003ooooo
oooooe00001h01P0N00001P0000<0000000005@0001D0000`@000:?mooo40000[Ogoo`40002[Z^4o
VYWQ_a@?002Z;P000@0004`00000000000000000003ooooooooooe00000k0?oo?00001P0000<0000
000002D0000<00003@00P2P0000<00000@000580001`0@000@0003Woool0000000000000002@0@00
000000000P9304d0DP0a030000000000000000000000000000000000000000000000000000000000
000000000000000000000000000g0@0f100005C9600`YS80S<XH0?Ea]gLK03h0M04_0000001@0Bl0
F0?C0@00<@1hd340d=da000000040000000005`100400000800000000@5DbAP0000008c:603eLKMg
L:LJ0?kooonZ>;=gXSBcM`0000000340N=0a00PQ2/H00000L=0a09c:602:Dnaf000_0000002QE>af
Wn:eK0PQ2/Ihd340P06kM@00003C?;=g002`MfS:60088@[6Q<`H001`kWHCXd<Jo_oooj5Dk7H54[Me
N=0a07Pl<P1?7b5T000:07Pl<P3DbQP0G3VgMFAf00P000009@0000`000010000E00005@000350000
XogoolX0002]oOoo0@000:^ZhCnJVN6oK@l00:X^00010000C00000000000000000000?oooooooooo
D0000300601T0000600000`000000000E00005@0003:0000Xogoolh0002]oOoo0@000:^ZhCnJVN6o
d@l00:X^00010000C00000000000000000000?ooooooooooD00002T0oom@0000600000`000000000
E00005@0003A0000XogoomT0002]oOoo0@000:^ZhCnJVN6oEA000:X^00010000C000000000000000
00000?ooooooooooD00003d0oonP0000600000`000000000E00005@0003L0000Xogoon00002]oOoo
0@000:^ZhCnJVN6o9a400:X^00010000C00000000000000000000?ooooooooooD00007<0B@1@0000
600000`000000000E00005@0003O0000Xogoon80002]oOoo0@000:^ZhCnJVN6oMA400:X^00010000
C00000000000000000000?ooooooooooD00006T0;`0l0000600000`000000000E00005@0003R0000
XogoonP0002]oOoo0@000:^ZhCnJVN6o[1400:X^00010000C00000000000000000000?oooooooooo
D00006h0<@1h0000600000`0000000009@0000`0000=0020:00000`000010000DP00070100010000
>Oooo`0000000000000009010000000000020T<0C@1=04T0<@0`0000000000000000000000000000
000000000000000000000000000000000000000000000000000003L103H40000E<TH032V<P2<bQP0
mG6gMa/0?P1d0Bl000000501;`1H0m<1000a07S@<@3@gC40000000@000000000G0400@00000P0000
00010EC960000000S<XH0?Ea]gM`YaX0o_ooojXh/gNR=;=g00000000<@1hd340224:a`00001`d340
W<XH08YCk7H002l000000:5Dk7JOh[E/224:agS@<@200K]e00000=<l/gL00;1gJ<XH00PQ2/N4c1P0
073^MQ>S@a[nooooXEC/MPDB]gEhd340N3`b04lO8F@000X0N3`b0=C:601L>KMeI7H02000000U0000
30000040001D0000E0000>T0002SoOook`000:gmool10000Zj[Q?iZIhKlm4P00ZRh00040001<0000
0000000000000000oooooooooom@0000N00a07P0000H000030000000001D0000E0000>l0002SoOoo
lP000:gmool10000Zj[Q?iZIhKn_4P00ZRh00040001<00000000000000000000oooooooooom@0000
>P0a03`0000U0000300000L0080X000030000080000U000030000000080X0000300000<0000U0000
300000d0080X000030000040000>000050000000000@0000500000Q00@PT00006000008@`=/10000
0`00000000000000000001]000100000=000004000020000hh<`@j038/C^8853`imL@P<0003SPc13
X0<Ra=mRfD>P0b;4hh<`@j@i5<@Q000020000680000<00000@000240000800008@0000P0001c0000
30000000000L0000200002D0000<00000000P2D0000<00001`00P2D0000<00003P00P1T0000<0000
oooo01P0000<000000000180000<00000P0001<0000<00000@0001@0000<00003@0001D0000<0000
0@0001H0000<0000000000d0000@000000000000000j0000300000X0000K00004000000000000000
8`000200001R82E100000000003Ak2I1[[KSa7E8ddDT00009000068P9D40000000000=7/9T6^]^?4
MDSCA@@0001c000030000000000=00004000000000000000DP00070100020000400000L000000000
00000;`2000000001`828U<0N@1c07@0I@1]00004`2Pn?oolP400000000lgCh2P?Soo`P0F7kkm_oo
00000000000PgCh2P?Sooooo000006P7:55W2E3/I@T@Df<901l00?L3001h:GL7ZBfcMj<P8E0R08X1
N0`00:Xh/gMGNI1g00000000LP0P4FL90P000U3/I@W0g382H<hc00000000000000000?oooooZTP1h
001b0040003eLKMg0`0000P0002Hf6L9V=QW2@00I`T000000P000000LP030000C=4c05CB<`2Xdc<0
mG6gMdMS4@3noooodcbcMohl/gL00040200109;HI`T006L9000001PAI`T18000RWE[KV3I<`00L>if
_;6X5gP<00000000HQ<00N0TJ0L10000R=800HcB<`0_<;MeI7H02000000U00003000008000160000
R00007`00017A4U30P000;40001hoOoo/P400:kmool`0000I`1U06h0I@1b0640M01U06@0801R07T0
801G04d0AP0_04D0C@160200HP1Q06<0J`1U06h0I00P06l0IP0P0700L`1d06l0I@1T06T0M00006T0
KP1`07D0M00000008`000200002V:P@o00000000001GY@Fo[[KSa7E8ddDT000090000:HZ13l00000
000005NU1Kn^]^?4MDSCA@@0000S000080000:HZ13l00000000005NU1Kn^]^?4MDSCAB@0000T0000
YRX4?`0000000000EjD5_jjfhlAeB==510000180000<00000@0001H0000<0000600001P0000<0000
00000580001`0@000`0003Woool0000000000000002@0@00000000L00P9304d0C@190340<0000000
0000000000000000000000000000000000000000000000000000000000000000000000@00038bQP0
000000P000070000000008iCf7K8bQP0<<XH0>b`@`040000Q0000<S:60000000000000`000000000
0@00023:60000000Q0000:0?000200000`000<S:60000000000003c:601oWT<0o0[_0H3:600004<0
100008je@`1JI;9/V7?_0B68AP0000000000000000010000C<XH000_BP0<baP0h9a208Z:kFcnoooo
00130=fe@`2HLnl100000000k`6HLnl1b<XH0040000h01h030000<S:602HLnl10@<00>1bk`410000
T7?_0FAf00P000009@0000`000030000E00005@0000J0000500005@0001k00000@000:^ZhCnJVN6o
nPd00=/a00010000C00000000000000000000?ooooooooooD0000400001T0000600000`000000000
DP00070100040000500000T00000000000000;`2000000001`828U<0N@1c07@0I@1]000000000000
hP000000001/]6`2P?Soo`000000000000000000001@]6`2P?SookZF00000;Me]fBgMJ<P8E000000
00000040001XMfL9S=4c065T]gFS825@00000000001D0000000006QgI`T4dS<0gU6gMJ<P8E303F<9
10000:0cZPQD000000000040000h01h030000<S:602HLnl10@<00>1bk`410000T7?_0@0000P00000
`=`b0V3><`04dS<0;c2gM@CB<`1V<;Me^4EX2@RLI`LU0000000:02a]000hdc<07OYWKZ<P8E0006<9
J7MW2@@0002P<jX8/PYXKW`7^gD00000O0NkMH01^gG<AFP9G=8c02l`]gELdS<0IS2gMAQ6J0T8W6L7
I7H02000000U0000300000@0000X0000300000<0001B0000L04000<0001eoooo0000000000000000
T040000000070082@`1=04d0B@0g0000000000000000000000000000000000000000000000000000
00000000000000000000000000000000=`40=P`000020000<:Hb0<S:600000006`0n07@1;`000000
D04_05P3d`4004<0N=0a0=3M<@00000030000000001L0@01d=da060000000041E<TH08cS/WN<bQP0
mG6gMg2W6P3nooooZSRcMj8d/gL00000000a07S@<@088@ZN0000073@<@2LbQP0RU?/MP00;`000000
XEC/MYoR]F`88@ZNN=0a0801^gG`K^l1B03C0@00d`5XbQP0224:WXC<6000L>if4j=36_kooonQE>af
1A:gMGS@<@1h?380CalQI0002P1h?380e<XH05`i]gETMP08000002D0000<00000`0005@0001D0000
EP0000H000220000C`000040002[Z^4oVYWQ_fl>000S<P000@0004`00000000000000000003ooooo
oooooe00002`0000D00001P0000<0000000002D0000<0000100002P0000<00000`000580001`0@00
0`0003Woool0000000000000002@0@00000000L00P9304d0C@190340<00000000000000000000000
00000000000000000000000000000000000000000000000000000=3M<@0g0@0f300005C9600`YS80
S<XH0?Ea]gLK03h0M04_0000001@0Bl0F0?C0@00<@1hd340d=da0000000<0000000005`1007@gC40
H00000000@5DbAP0000008c:603eLKMgL:LJ0?kooonZ>;=gXSBcM`0000000340N=0a00PQ2Yl00000
L=0a09c:602:Dnaf000_0000002QE>afWn:eK0PQ2Ymhd340P06kM@0000180=<1003C0FS:60088@ZO
Q<`H001`kWHCXd<Jo_oooj5Dk7H54[MeN=0a07Pl<P1?7b5T000:07Pl<P3DbQP0G3VgMFAf00P00000
9@0000`000030000E00005@0002;000050000<T0001k00000@000:^ZhCnJVN6oePh00=/a00010000
C00000000000000000000?ooooooooooD00007D0001h00009P0001`0000500000000000000000000
000002D0000<00001@0002L0000H00001P00000000000000000002D0000<00001P0001<0000<0000
0P0005/0000h00006P0008T000370000SP000040000500001@000?`=R35:3hPaBPn@<O`=T37l3HPa
600000`000000000E00005@0000U0000XP0005l000090@000@000:^ZhCnJVN6o40h00<``00010000
C00000000000000000000?ooooooooooD0000400001T0000600000`000000000E00005@0001Q0000
XP0008/000090@000@000:^ZhCnJVN6oQ0h00<``00010000C00000000000000000000?oooooooooo
D00007@0001@0000600000`0000000009@0000`000040000:00000`000030000DP00070100030000
MOooo`000000000000000901000000001`020T<0C@1=04T0=`000000000000000000000000000000
000000000000000000000000000000000000000000000000000003L103H40000^1O_0C2V<P0hK^l1
P08001/0?P1d0Bl000000501;`1H0m<1>07_0GS@<@3@gC40000000@000000000G0400@00000P0000
00010EC960000000S<XH0?Ea]gM`YaX0o_ooojXh/gNR=;=g00000000<@1hd340224:X000001`d340
W<XH08YCk7H002l000000:5Dk7JOh[E/224:X7S@<@200K]e3000060Qh@400>41J<XH00PQ2Z24c1P0
073^MQ>S@a[nooooXEC/MPDB]gEhd340N3`b04lO8F@000X0N3`b0=C:601L>KMeI7H02000000U0000
300000<0001D0000E00008H0002J0000/P000><000010000Zj[Q?iZIhKo<3P001S400040001<0000
0000000000000000oooooooooom@0000/0000500000H000030000000000U0000300000@0000X0000
300000<0001B0000L04000<0000ioooo0000000000000000T040000000070082@`1=0580<@0`0000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
=`40=P@0001DbAP0<:Hb08c:603eLKMg6`0n07@1;`000000D04_05P3d`400340N=0a0=3M<@000000
10000000001L0@010000020000000041E<TH0000002<bQP0mG6gMg2W6P3nooooZSRcMj8d/gL00000
000a07S@<@088@ZQ0000073@<@2LbQP0RU?/MP00;`000000XEC/MYoR]F`88@ZQN=0a0801^gD00000
H27Q0@00h@5XbQP0224:XHC<6000L>if4j=36_kooonQE>af1A:gMGS@<@1h?380CalQI0002P1h?380
e<XH05`i]gETMP08000002D0000<00000`0005@0001D0000k`0005X000120@00`@000040002[Z^4o
VYWQ_iL?001E<@000@0004`00000000000000000003ooooooooooe00000m0000X00001P0000<0000
000002D0000<0000100002P0000<00000`000580001`0@000`0003Woool0000000000000002@0@00
000000L00P9304d0C@190340<0000000000000000000000000000000000000000000000000000000
000000000000000000000000000g0@0f100005C9600`YS80S<XH0?Ea]gLK03h0M04_0000001@0Bl0
F0?C0@00<@1hd340d=da000000040000000005`100400000800000000@5DbAP0000008c:603eLKMg
L:LJ0?kooonZ>;=gXSBcM`0000000340N=0a00PQ2Z800000L=0a09c:602:Dnaf000_0000002QE>af
Wn:eK0PQ2Z9hd340P06kM@00001P8N41003Q0FS:60088@ZRQ<`H001`kWHCXd<Jo_oooj5Dk7H54[Me
N=0a07Pl<P1?7b5T000:07Pl<P3DbQP0G3VgMFAf00P000009@0000`000030000E00005@0001X0@00
50000:81001k00000@000:^ZhCnJVN6oPA000=/a00010000C00000000000000000000?oooooooooo
D0000400001T0000600000`0000000009@0000`000040000:00000`000030000DP00070100030000
MOooo`000000000000000901000000001`020T<0C@1B03L000000000000000000000000000000000
000000000000000000000000000000000000000000000000000003L103H40000E<TH032V<P2<bQP0
mG6gMa/0?P1d0Bl000000501;`1H0m<1000a07S@<@3@gC40000000@000000000G0400@00000P0000
00010EC960000000S<XH0?Ea]gM`YaX0o_ooojXh/gNR=;=g00000000<@1hd340224:X`00001`d340
W<XH08YCk7H002l000000:5Dk7JOh[E/224:XgS@<@200K]e0000060Qh@400>41J<XH00PQ2Z>4c1P0
073^MQ>S@a[nooooXEC/MPDB]gEhd340N3`b04lO8F@000X0N3`b0=C:601L>KMeI7H02000000U0000
300000<0001D0000E0000:@100060000cP4004l000010000Zj[Q?iZIhKof40008c800040001<0000
0000000000000000oooooooooom@0000<P000500000H000030000000000U0000300000@0000X0000
300000<0001B0000L04000<0000ioooo0000000000000000T040000000070082@`1=04d0B@0a0300
00000000000000000000000000000000000000000000000000000000000000000000000000000000
=`40=P@0001DbAP0<:Hb08c:603eLKMg6`0n07@1;`000000D04_05P3d`400340N=0a0=3M<@000000
10000000001L0@010000020000000041E<TH0000002<bQP0mG6gMg2W6P3nooooZSRcMj8d/gL00000
000a07S@<@088@ZT0000073@<@2LbQP0RU?/MP00;`000000XEC/MYoR]F`88@ZTN=0a0801^gD00000
H27Q0@00h@5XbQP0224:Y8C<6000L>if4j=36_kooonQE>af1A:gMGS@<@1h?380CalQI0002P1h?380
e<XH05`i]gETMP08000002D0000<00000`0005@0001D0000dP4001@0000@0P00N`000040002[Z^4o
VYWQ_e0A003K<@000@0004`00000000000000000003ooooooooooe00001e0000N00002D0000<0000
1`00P2P0000<00001@0002H0000L00001@0000000000000000000000000U0000300000D0000U0000
30000000080X0000300000H0000W0000600000H00000000000000000000U0000300000H0000C0000
30000080001K0000>00006D1002900002`8008h0000100001@0000D0001l48Pa_168<K`AT35l490a
O128<AP0000<0000000005@0001D0000J0400:80002R0@002@400040002[Z^4oVYWQ_h4@003<<000
0@0004`00000000000000000003ooooooooooe0000100000I00001P0000<0000000005@0001D0000
Y0400:80003R0@002@400040002[Z^4oVYWQ_oH@003<<0000@0004`00000000000000000003ooooo
oooooe00001h0000N00001P0000<0000000002D0000<0000100002P0000<00000`000580001`0@00
0`0007Goool0000000000000002@0@00000000L00P9304d0DP0g0000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000g0@0f10000;PGk`4`YS80
>6k_0H02000K03h0M04_0000001@0Bl0F0?C0CP1k`5hd340d=da000000040000000005`100400000
800000000@5DbAP0000008c:603eLKMgL:LJ0?kooonZ>;=gXSBcM`0000000340N=0a00PQ2ZD00000
L=0a09c:602:Dnaf000_0000002QE>afWn:eK0PQ2ZEhd340P06kM@`0001P8N41003Q0FS:60088@ZU
Q<`H001`kWHCXd<Jo_oooj5Dk7H54[MeN=0a07Pl<P1?7b5T000:07Pl<P3DbQP0G3VgMFAf00P00000
9@0000`000030000E00005@0003O0@00VP0000T2003S00000@000:^ZhCnJVN6oJ14000Ha00010000
C00000000000000000000?ooooooooooD0000380001@0000600000`0000000009@0000`000040000
:00000`000030000DP00070100030000>Oooo`000000000000000901000000001`020T<0C@1B0340
<0000000000000000000000000000000000000000000000000000000000000000000000000000000
000003L103H40000E<TH032V<P2<bQP0mG6gMa/0?P1d0Bl000000501;`1H0m<1000a07S@<@3@gC40
000000@000000000G0400@00000P000000010EC960000000S<XH0?Ea]gM`YaX0o_ooojXh/gNR=;=g
00000000<@1hd340224:YP00001`d340W<XH08YCk7H002l000000:5Dk7JOh[E/224:YWS@<@200K]e
0000060Qh@400>41J<XH00PQ2ZJ4c1P0073^MQ>S@a[nooooXEC/MPDB]gEhd340N3`b04lO8F@000X0
N3`b0=C:601L>KMeI7H02000000U0000300000<0001D0000E0000302001J0000P`800<4000010000
Zj[Q?iZIhKl64P00EC400040001<00000000000000000000oooooooooom@0000:`000:00000H0000
30000000000U0000300000@0000X0000300000<0001B0000L04000<0000ioooo0000000000000000
T040000000070082@`1=04d0B@0a0300000000000000000000000000000000000000000000000000
00000000000000000000000000000000=`40=P@0001DbAP0<:Hb08c:603eLKMg6`0n07@1;`000000
D04_05P3d`400340N=0a0=3M<@00000010000000001L0@010000020000000041E<TH0000002<bQP0
mG6gMg2W6P3nooooZSRcMj8d/gL00000000a07S@<@088@ZW0000073@<@2LbQP0RU?/MP00;`000000
XEC/MYoR]F`88@ZWN=0a0801^gD00000H27Q0@00h@5XbQP0224:YhC<6000L>if4j=36_kooonQE>af
1A:gMGS@<@1h?380CalQI0002P1h?380e<XH05`i]gETMP08000002D0000<00000`0005@0001D0000
U`8005X0003;0P00`@000040002[Z^4oVYWQ_ldB001E<@000@0004`00000000000000000003ooooo
oooooe00001Q0?ooI00001P0000<0000000002D0000<0000100002P0000<00000`000580001`0@00
0`0003Woool0000000000000002@0@00000000L00P9304d0DP0a0300000000000000000000000000
00000000000000000000000000000000000000000000000000000000000g0@0f100005C9600`YS80
S<XH0?Ea]gLK03h0M04_0000001@0Bl0F0?C0@00<@1hd340d=da000000040000000005`100400000
800000000@5DbAP0000008c:603eLKMgL:LJ0?kooonZ>;=gXSBcM`0000000340N=0a00PQ2ZP00000
L=0a09c:602:Dnaf000_0000002QE>afWn:eK0PQ2ZQhd340P06kM@00001P8N41003Q0FS:60088@ZX
Q<`H001`kWHCXd<Jo_oooj5Dk7H54[MeN=0a07Pl<P1?7b5T000:07Pl<P3DbQP0G3VgMFAf00P00000
9@0000`000030000E00005@0003O0P00FP000?h2003100000@000:^ZhCnJVN6oF1<005Da00010000
C00000000000000000000?ooooooooooD00005/0ooll0000600000`000000000E00005@0003k0P00
FP0002D3003100000@000:^ZhCnJVN6oSQ<005Da00010000C00000000000000000000?oooooooooo
D00007<0oom@0000600000`000000000E00005@0000S0`00FP000483003100000@000:^ZhCnJVN6o
g1<005Da00010000C00000000000000000000?ooooooooooD00006T0ooll0000600000`000000000
E00005@0000o0`00FP0007d3003100000@000:^ZhCnJVN6o4a@005Da00010000C000000000000000
00000?ooooooooooD00006h0oomh0000600000`000000000E00005@0001i0`00FP000:<300310000
0@000:^ZhCnJVN6oPa@005Da00010000C00000000000000000000?ooooooooooD00002P0oom@0000
600000`0000000009@0000`000040000:00000`000030000DP00070100030000>Oooo`0000000000
00000901000000001`020T<0C@1=04T0<@0`00000000000000000000000000000000000000000000
00000000000000000000000000000000000003L103H40000E<TH032V<P2<bQP0mG6gMa/0?P1d0Bl0
00000501;`1H0m<1000a07S@<@3@gC40000000@000000000G0400@00000P000000010EC960000000
S<XH0?Ea]gM`YaX0o_ooojXh/gNR=;=g00000000<@1hd340224:Z@00001`d340W<XH08YCk7H002l0
00000:5Dk7JOh[E/224:ZGS@<@200K]e0000060Qh@400>41J<XH00PQ2ZV4c1P0073^MQ>S@a[noooo
XEC/MPDB]gEhd340N3`b04lO8F@000X0N3`b0=C:601L>KMeI7H02000000U0000300000<0001D0000
E0000:83001J0000f0<00<4000010000Zj[Q?iZIhKoA5000EC400040001<00000000000000000000
oooooooooom@0000^P3oof@0000H000030000000001D0000E0000=/3001J00001@@00<4000010000
Zj[Q?iZIhKm05@00EC400040001<00000000000000000000oooooooooom@0000M03ooe00000H0000
30000000000U0000300000@0000X0000300000<0001B0000L04000<0000ioooo0000000000000000
T040000000070082@`1=0580<@0`0000000000000000000000000000000000000000000000000000
00000000000000000000000000000000=`40=P@0001DbAP0<:Hb08c:603eLKMg6`0n07@1;`000000
D04_05P3d`400340N=0a0=3M<@00000010000000001L0@010000020000000041E<TH0000002<bQP0
mG6gMg2W6P3nooooZSRcMj8d/gL00000000a07S@<@088@ZZ0000073@<@2LbQP0RU?/MP00;`000000
XEC/MYoR]F`88@ZZN=0a0801^gD00000H27Q0@00h@5XbQP0224:ZXC<6000L>if4j=36_kooonQE>af
1A:gMGS@<@1h?380CalQI0002P1h?380e<XH05`i]gETMP08000002D0000<00000`0005@0001D0000
00@005X0000Z1000`@000040002[Z^4oVYWQ_hPE001E<@000@0004`00000000000000000003ooooo
oooooe00000Y0?ooD00001P0000<0000000005@0001D0000?`@005X0002B1000`@000040002[Z^4o
VYWQ_`4F001E<@000@0004`00000000000000000003ooooooooooe00000[0?ooX00001P0000<0000
000002D0000<0000100002P0000<00000`000580001`0@000`0003Woool0000000000000002@0@00
000000L00P9304d0C@190340<0000000000000000000000000000000000000000000000000000000
000000000000000000000000000g0@0f100005C9600`YS80S<XH0?Ea]gLK03h0M04_0000001@0Bl0
F0?C0@00<@1hd340d=da000000040000000005`100400000800000000@5DbAP0000008c:603eLKMg
L:LJ0?kooonZ>;=gXSBcM`0000000340N=0a00PQ2Z/00000L=0a09c:602:Dnaf000_0000002QE>af
Wn:eK0PQ2Z]hd340P06kM@00001P8N41003Q0FS:60088@Z[Q<`H001`kWHCXd<Jo_oooj5Dk7H54[Me
N=0a07Pl<P1?7b5T000:07Pl<P3DbQP0G3VgMFAf00P000009@0000`000030000E00005@0002V1000
FP000=`4003100000@000:^ZhCnJVN6obAH005Da00010000C00000000000000000000?oooooooooo
D0000;X0oomT0000600000`0000000009@0000`000040000:00000`000030000DP00070100030000
MOooo`000000000000000901000000001`020T<0C@1=04T0=`000000000000000000000000000000
000000000000000000000000000000000000000000000000000003L103H40000E<TH032V<P2<bQP0
mG6gMa/0?P1d0Bl000000501;`1H0m<1000a07S@<@3@gC40000000@000000000G0400@00000P0000
00010EC960000000S<XH0?Ea]gM`YaX0o_ooojXh/gNR=;=g00000000<@1hd340224:[000001`d340
W<XH08YCk7H002l000000:5Dk7JOh[E/224:[7S@<@200K]e0000060Qh@400>41J<XH00PQ2Zb4c1P0
073^MQ>S@a[nooooXEC/MPDB]gEhd340N3`b04lO8F@000X0N3`b0=C:601L>KMeI7H02000000U0000
300000<0001D0000E0000>040017000030D0090000010000Zj[Q?iZIhKli5`00YS400040001<0000
0000000000000000oooooooooom@0000/03ooe00000H000030000000000U0000300000@0000X0000
300000<0001B0000L04000<0000ioooo0000000000000000T040000000070082@`1=0580<@0`0000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
=`40=P@0001DbAP0<:Hb08c:603eLKMg6`0n07@1;`000000D04_05P3d`400340N=0a0=3M<@000000
10000000001L0@010000020000000041E<TH0000002<bQP0mG6gMg2W6P3nooooZSRcMj8d/gL00000
000a07S@<@088@Z]0000073@<@2LbQP0RU?/MP00;`000000XEC/MYoR]F`88@Z]N=0a0801^gD00000
H27Q0@00h@5XbQP0224:[HC<6000L>if4j=36_kooonQE>af1A:gMGS@<@1h?380CalQI0002P1h?380
e<XH05`i]gETMP08000002D0000<00000`0005@0001D00009@D005X0001?1@00`@000040002[Z^4o
VYWQ_klG001E<@000@0004`00000000000000000003ooooooooooe00001c0?ooD00001P0000<0000
000005@0001D0000C@D005X0001/1@00`@000040002[Z^4oVYWQ_`dH001E<@000@0004`000000000
00000000003ooooooooooe00001Y0?oo?00001P0000<0000000005@0001D0000J@D005X0002W1@00
`@000040002[Z^4oVYWQ_d@H001E<@000@0004`00000000000000000003ooooooooooe00001^0?oo
N00001P0000<0000000005@0001D0000]@D005X0003O1@00`@000040002[Z^4oVYWQ_mHH001E<@00
0@0004`00000000000000000003ooooooooooe00000X0?ooD00001P0000<0000000002D0000<0000
100002P0000<00000`000580001`0@000`0003Woool0000000000000002@0@00000000L00P9304d0
C@190340<00000000000000000000000000000000000000000000000000000000000000000000000
00000000000g0@0f100005C9600`YS80S<XH0?Ea]gLK03h0M04_0000001@0Bl0F0?C0@00<@1hd340
d=da000000040000000005`100400000800000000@5DbAP0000008c:603eLKMgL:LJ0?kooonZ>;=g
XSBcM`0000000340N=0a00PQ2Zh00000L=0a09c:602:Dnaf000_0000002QE>afWn:eK0PQ2Zihd340
P06kM@00001P8N41003Q0FS:60088@Z^Q<`H001`kWHCXd<Jo_oooj5Dk7H54[MeN=0a07Pl<P1?7b5T
000:07Pl<P3DbQP0G3VgMFAf00P000009@0000`000030000E00005@0003L1@00FP00018600310000
0@000:^ZhCnJVN6o8QT005Da00010000C00000000000000000000?ooooooooooD0000;X0oomT0000
600000`000000000E00005@0000F1P00FP000406003100000@000:^ZhCnJVN6oTQT005Da00010000
C00000000000000000000?ooooooooooD00007@0oom@0000600000`0000000009@0000`000040000
:00000`000030000DP00070100030000>Oooo`000000000000000901000000001`020T<0C@1B0340
<0000000000000000000000000000000000000000000000000000000000000000000000000000000
000003L103H40000E<TH032V<P2<bQP0mG6gMa/0?P1d0Bl000000501;`1H0m<1000a07S@<@3@gC40
000000@000000000G0400@00000P000000010EC960000000S<XH0?Ea]gM`YaX0o_ooojXh/gNR=;=g
00000000<@1hd340224:[`00001`d340W<XH08YCk7H002l000000:5Dk7JOh[E/224:[gS@<@200K]e
0000060Qh@400>41J<XH00PQ2Zn4c1P0073^MQ>S@a[nooooXEC/MPDB]gEhd340N3`b04lO8F@000X0
N3`b0=C:601L>KMeI7H02000000U0000300000<0001D0000E0000586001J0000Y@H00<4000010000
Zj[Q?iZIhKl66P00EC400040001<00000000000000000000oooooooooom@0000:`000:00000H0000
30000000000U0000300000@0000X0000300000<0001B0000L04000<0000ioooo0000000000000000
T040000000070082@`1=04d0B@0a0300000000000000000000000000000000000000000000000000
00000000000000000000000000000000=`40=P@0001DbAP0<:Hb08c:603eLKMg6`0n07@1;`000000
D04_05P3d`400340N=0a0=3M<@00000010000000001L0@010000020000000041E<TH0000002<bQP0
mG6gMg2W6P3nooooZSRcMj8d/gL00000000a07S@<@088@Z`0000073@<@2LbQP0RU?/MP00;`000000
XEC/MYoR]F`88@Z`N=0a0801^gD00000H27Q0@00h@5XbQP0224:/8C<6000L>if4j=36_kooonQE>af
1A:gMGS@<@1h?380CalQI0002P1h?380e<XH05`i]gETMP08000002D0000<00000`0005@0001D0000
^@H005X0003a1P00`@000040002[Z^4oVYWQ_ldJ001E<@000@0004`00000000000000000003ooooo
oooooe00002`0?ooI00001P0000<0000000005@0001D0000l`H005X0000a1`00`@000040002[Z^4o
VYWQ_clK001E<@000@0004`00000000000000000003ooooooooooe00002l0?ooN00001P0000<0000
000005@0001D0000<PL005X0001V1`00`@000040002[Z^4oVYWQ_kPK001E<@000@0004`000000000
00000000003ooooooooooe00000m0?ooI00001P0000<0000000002D0000<0000100002P0000<0000
0`000580001`0@000`0003Woool0000000000000002@0@00000000L00P9304d0DP0a030000000000
000000000000000000000000000000000000000000000000000000000000000000000000000g0@0f
100005C9600`YS80S<XH0?Ea]gLK03h0M04_0000001@0Bl0F0?C0@00<@1hd340d=da000000040000
000005`100400000800000000@5DbAP0000008c:603eLKMgL:LJ0?kooonZ>;=gXSBcM`0000000340
N=0a00PQ2[400000L=0a09c:602:Dnaf000_0000002QE>afWn:eK0PQ2[5hd340P06kM@00001P8N41
003Q0FS:60088@ZaQ<`H001`kWHCXd<Jo_oooj5Dk7H54[MeN=0a07Pl<P1?7b5T000:07Pl<P3DbQP0
G3VgMFAf00P000009@0000`000030000E00005@0001U1`00FP0009T7003100000@000:^ZhCnJVN6o
6a`005Da00010000C00000000000000000000?ooooooooooD0000380oomT0000600000`000000000
E00005@0002I1`00FP000<<7003100000@000:^ZhCnJVN6oOa`005Da00010000C000000000000000
00000?ooooooooooD00002T0001@0000600000`000000000E00005@000301`00FP000=l700310000
0@000:^ZhCnJVN6oc1`005Da00010000C00000000000000000000?ooooooooooD00005d0ooll0000
600000`0000000009@0000`000040000:00000`000030000DP00070100030000>Oooo`0000000000
00000901000000001`020T<0C@1=04T0<@0`00000000000000000000000000000000000000000000
00000000000000000000000000000000000003L103H40000E<TH032V<P2<bQP0mG6gMa/0?P1d0Bl0
00000501;`1H0m<1000a07S@<@3@gC40000000@000000000G0400@00000P000000010EC960000000
S<XH0?Ea]gM`YaX0o_ooojXh/gNR=;=g00000000<@1hd340224:/P00001`d340W<XH08YCk7H002l0
00000:5Dk7JOh[E/224:/WS@<@200K]e0000060Qh@400>41J<XH00PQ2[:4c1P0073^MQ>S@a[noooo
XEC/MPDB]gEhd340N3`b04lO8F@000X0N3`b0=C:601L>KMeI7H02000000U0000300000<0001D0000
E0000>h7001J00003@P00<4000010000Zj[Q?iZIhKlT7@00EC400040001<00000000000000000000
oooooooooom@0000>`3ooc`0000H000030000000000U0000300000@0000X0000300000<0001B0000
L04000<0000ioooo0000000000000000T040000000070082@`1=0580<@0`00000000000000000000
0000000000000000000000000000000000000000000000000000000000000000=`40=P@0001DbAP0
<:Hb08c:603eLKMg6`0n07@1;`000000D04_05P3d`400340N=0a0=3M<@00000010000000001L0@01
0000020000000041E<TH0000002<bQP0mG6gMg2W6P3nooooZSRcMj8d/gL00000000a07S@<@088@Zc
0000073@<@2LbQP0RU?/MP00;`000000XEC/MYoR]F`88@ZcN=0a0801^gD00000H27Q0@00h@5XbQP0
224:/hC<6000L>if4j=36_kooonQE>af1A:gMGS@<@1h?380CalQI0002P1h?380e<XH05`i]gETMP08
000002D0000<00000`0005@0001D0000PPP005X0002f2000`@000040002[Z^4oVYWQ_d@N001E<@00
0@0004`00000000000000000003ooooooooooe00000`0?ooI00001P0000<0000000002D0000<0000
100002P0000<00000`000580001`0@000`0003Woool0000000000000002@0@00000000L00P9304d0
D`1I0340<01?0580B@17000000000000000000000000000000000000000000000000000000000000
00000000000g0@0f100005C9600`YS80S<XH0?Ea]gLK03h0M04_0000001@0Bl0F0?C0@00<@1hd340
d=da000000040000000005`100400000800000000@5DbAP0000008c:603eLKMgL:LJ0?kooonZ>;=g
XSBcM`0000000340N=0a00PQ2[@00000L=0a09c:602:Dnaf000_0000002QE>afWn:eK0PQ2[Ahd340
P06kM@00001P8N41003Q0FS:60088@ZdQ<`H001`kWHCXd<Jo_oooj5Dk7H54[MeN=0a07Pl<P1?7b5T
000:07Pl<P3DbQP0G3VgMFAf00P000009@0000`000030000E00005@0003B2000E`0002D9000;0@00
0@000:^ZhCnJVN6ogah005Da00010000C00000000000000000000?ooooooooooD0000;L0oonP0000
600000`0000000009@0000`000040000:00000`000030000DP00070100030000>Oooo`0000000000
00000901000000001`020T<0C@1=04T0<@0`00000000000000000000000000000000000000000000
00000000000000000000000000000000000003L103H40000E<TH032V<P2<bQP0mG6gMa/0?P1d0Bl0
00000501;`1H0m<1000a07S@<@3@gC40000000@000000000G0400@00000P000000010EC960000000
S<XH0?Ea]gM`YaX0o_ooojXh/gNR=;=g00000000<@1hd340224:]@00001`d340W<XH08YCk7H002l0
00000:5Dk7JOh[E/224:]GS@<@200K]e0000060Qh@400>41J<XH00PQ2[F4c1P0073^MQ>S@a[noooo
XEC/MPDB]gEhd340N3`b04lO8F@000X0N3`b0=C:601L>KMeI7H02000000U0000300000<0001D0000
E00003l9001J0000O@T00<4000010000Zj[Q?iZIhKna7`00EC400040001<00000000000000000000
oooooooooom@0000N03oogP0000H000030000000000U0000300000@0000X0000300000<0001B0000
L04000<0000ioooo0000000000000000T040000000070082@`1=05<0F@0a0300C`1B04T0A`000000
0000000000000000000000000000000000000000000000000000000000000000=`40=P@0001DbAP0
<:Hb08c:603eLKMg6`0n07@1;`000000D04_05P3d`400340N=0a0=3M<@00000010000000001L0@01
0000020000000041E<TH0000002<bQP0mG6gMg2W6P3nooooZSRcMj8d/gL00000000a07S@<@088@Zf
0000073@<@2LbQP0RU?/MP00;`000000XEC/MYoR]F`88@ZfN=0a0801^gD00000H27Q0@00h@5XbQP0
224:]XC<6000L>if4j=36_kooonQE>af1A:gMGS@<@1h?380CalQI0002P1h?380e<XH05`i]gETMP08
000002D0000<00000`0005@0001D0000UPT005L0003Y2@002`400040002[Z^4oVYWQ_eXP001E<@00
0@0004`00000000000000000003ooooooooooe00002g0?ooX00001P0000<0000000002D0000<0000
100002P0000<00000`000580001`0@000`0003Woool0000000000000002@0@00000000L00P9304d0
C@190340<00000000000000000000000000000000000000000000000000000000000000000000000
00000000000g0@0f100005C9600`YS80S<XH0?Ea]gLK03h0M04_0000001@0Bl0F0?C0@00<@1hd340
d=da000000040000000005`100400000800000000@5DbAP0000008c:603eLKMgL:LJ0?kooonZ>;=g
XSBcM`0000000340N=0a00PQ2[L00000L=0a09c:602:Dnaf000_0000002QE>afWn:eK0PQ2[Mhd340
P06kM@00001P8N41003Q0FS:60088@ZgQ<`H001`kWHCXd<Jo_oooj5Dk7H54[MeN=0a07Pl<P1?7b5T
000:07Pl<P3DbQP0G3VgMFAf00P000009@0000`000030000E00005@000032P00FP00044:00310000
0@000:^ZhCnJVN6o;B4005Da00010000C00000000000000000000?ooooooooooD0000;`0oomh0000
600000`000000000E00005@000122P00FP00064:003100000@000:^ZhCnJVN6oYR4005Da00010000
C00000000000000000000?ooooooooooD00003/0ooll0000600000`000000000E00005@0000=0000
8`4004/0002:0@000@000:^ZhCnJVN6ohPd00=D_00010000C00000000000000000000?oooooooooo
D00007D0oomh0000600000`0000000009@0000`000040000:00000`000030000DP00070100030000
>Oooo`000000000000000901000000001`020T<0C@1B0340<0000000000000000000000000000000
000000000000000000000000000000000000000000000000000003L103H40000E<TH032V<P2<bQP0
mG6gMa/0?P1d0Bl000000501;`1H0m<1000a07S@<@3@gC40000000@000000000G0400@00000P0000
00010EC960000000S<XH0?Ea]gM`YaX0o_ooojXh/gNR=;=g00000000<@1hd340224:^000001`d340
W<XH08YCk7H002l000000:5Dk7JOh[E/224:^7S@<@200K]e0000060Qh@400>41J<XH00PQ2[R4c1P0
073^MQ>S@a[nooooXEC/MPDB]gEhd340N3`b04lO8F@000X0N3`b0=C:601L>KMeI7H02000000U0000
300000<0001D0000E00004P0000S0@00LP0008X100010000Zj[Q?iZIhKmD3P00eBl00040001<0000
0000000000000000oooooooooom@0000:03ooe00000H000030000000000U0000300000@0000X0000
300000<0001B0000L04000<0000ioooo0000000000000000T040000000070082@`1=04d0B@0a0300
00000000000000000000000000000000000000000000000000000000000000000000000000000000
=`40=P@0001DbAP0<:Hb08c:603eLKMg6`0n07@1;`000000D04_05P3d`400340N=0a0=3M<@000000
10000000001L0@010000020000000041E<TH0000002<bQP0mG6gMg2W6P3nooooZSRcMj8d/gL00000
000a07S@<@088@Zi0000073@<@2LbQP0RU?/MP00;`000000XEC/MYoR]F`88@ZiN=0a0801^gD00000
H27Q0@00h@5XbQP0224:^HC<6000L>if4j=36_kooonQE>af1A:gMGS@<@1h?380CalQI0002P1h?380
e<XH05`i]gETMP08000002D0000<00000`0005@0001D0000L00002<1002^0000RP400040002[Z^4o
VYWQ_j8>003E;`000@0004`00000000000000000003ooooooooooe00001h0?ooN00001P0000<0000
000002D0000<0000100002P0000<00000`000580001`0@000`0003Woool0000000000000002@0@00
000000L00P9304d0DP0a030000000000000000000000000000000000000000000000000000000000
000000000000000000000000000g0@0f100005C9600`YS80S<XH0?Ea]gLK03h0M04_0000001@0Bl0
F0?C0@00<@1hd340d=da000000040000000005`100400000800000000@5DbAP0000008c:603eLKMg
L:LJ0?kooonZ>;=gXSBcM`0000000340N=0a00PQ2[X00000L=0a09c:602:Dnaf000_0000002QE>af
Wn:eK0PQ2[Yhd340P06kM@00001P8N41003Q0FS:60088@ZjQ<`H001`kWHCXd<Jo_oooj5Dk7H54[Me
N=0a07Pl<P1?7b5T000:07Pl<P3DbQP0G3VgMFAf00P000009@0000`000030000E00005@000380000
8`4001/1002:0@000@000:^ZhCnJVN6oC0l00=D_00010000C00000000000000000000?oooooooooo
D00003d0oonP0000600000`000000000E00005@0000d0@008`4006P1002:0@000@000:^ZhCnJVN6o
7A000=D_00010000C00000000000000000000?ooooooooooD0000300oomT0000600000`000000000
9@0000`000040000:00000`000030000DP00070100030000>Oooo`00000000000000090100000000
1`020T<0C@1=04T0<@0`000000000000000000000000000000000000000000000000000000000000
0000000000000000000003L103H40000E<TH032V<P2<bQP0mG6gMa/0?P1d0Bl000000501;`1H0m<1
000a07S@<@3@gC40000000@000000000G0400@00000P000000010EC960000000S<XH0?Ea]gM`YaX0
o_ooojXh/gNR=;=g00000000<@1hd340224:^`00001`d340W<XH08YCk7H002l000000:5Dk7JOh[E/
224:^gS@<@200K]e0000060Qh@400>41J<XH00PQ2[^4c1P0073^MQ>S@a[nooooXEC/MPDB]gEhd340
N3`b04lO8F@000X0N3`b0=C:601L>KMeI7H02000000U0000300000<0001D0000E00006P1000S0@00
Q`4008X100010000Zj[Q?iZIhKn14000eBl00040001<00000000000000000000oooooooooom@0000
>`3ooc`0000H000030000000001D0000E00009H1000S0@00`04008X100010000Zj[Q?iZIhKoJ4000
eBl00040001<00000000000000000000oooooooooom@0000M03ooe00000H000030000000000U0000
300000@0000X0000300000<0001B0000L04000<0000ioooo0000000000000000T040000000070082
@`1=0580<@0`00000000000000000000000000000000000000000000000000000000000000000000
0000000000000000=`40=P@0001DbAP0<:Hb08c:603eLKMg6`0n07@1;`000000D04_05P3d`400340
N=0a0=3M<@00000010000000001L0@010000020000000041E<TH0000002<bQP0mG6gMg2W6P3noooo
ZSRcMj8d/gL00000000a07S@<@088@Zl0000073@<@2LbQP0RU?/MP00;`000000XEC/MYoR]F`88@Zl
N=0a0801^gD00000H27Q0@00h@5XbQP0224:_8C<6000L>if4j=36_kooonQE>af1A:gMGS@<@1h?380
CalQI0002P1h?380e<XH05`i]gETMP08000002D0000<00000`0005@0001D0000^`4002<1003U0@00
RP400040002[Z^4oVYWQ_b8A003E;`000@0004`00000000000000000003ooooooooooe00000Y0?oo
D00001P0000<0000000005@0001D0000o`4002<1001B0P00RP400040002[Z^4oVYWQ_jLA003E;`00
0@0004`00000000000000000003ooooooooooe00000m0?ooX00001P0000<0000000002D0000<0000
100002P0000<00000`000580001`0@000`0003Woool0000000000000002@0@00000000L00P9304d0
C@190340<00000000000000000000000000000000000000000000000000000000000000000000000
00000000000g0@0f100005C9600`YS80S<XH0?Ea]gLK03h0M04_0000001@0Bl0F0?C0@00<@1hd340
d=da000000040000000005`100400000800000000@5DbAP0000008c:603eLKMgL:LJ0?kooonZ>;=g
XSBcM`0000000340N=0a00PQ2[d00000L=0a09c:602:Dnaf000_0000002QE>afWn:eK0PQ2[ehd340
P06kM@00001P8N41003Q0FS:60088@ZmQ<`H001`kWHCXd<Jo_oooj5Dk7H54[MeN=0a07Pl<P1?7b5T
000:07Pl<P3DbQP0G3VgMFAf00P000009@0000`000030000E00005@0001/0P008`400:X2002:0@00
0@000:^ZhCnJVN6oNA800=D_00010000C00000000000000000000?ooooooooooD00007D0oomh0000
600000`0000000009@0000`000040000:00000`000030000DP00070100030000>Oooo`0000000000
00000901000000001`020T<0C@1B0340<00000000000000000000000000000000000000000000000
00000000000000000000000000000000000003L103H40000E<TH032V<P2<bQP0mG6gMa/0?P1d0Bl0
00000501;`1H0m<1000a07S@<@3@gC40000000@000000000G0400@00000P000000010EC960000000
S<XH0?Ea]gM`YaX0o_ooojXh/gNR=;=g00000000<@1hd340224:_P00001`d340W<XH08YCk7H002l0
00000:5Dk7JOh[E/224:_WS@<@200K]e0000060Qh@400>41J<XH00PQ2[j4c1P0073^MQ>S@a[noooo
XEC/MPDB]gEhd340N3`b04lO8F@000X0N3`b0=C:601L>KMeI7H02000000U0000300000<0001D0000
E0000:L2000S0@00d@8008X100010000Zj[Q?iZIhKo[4P00eBl00040001<00000000000000000000
oooooooooom@0000:03ooe00000H000030000000000U0000300000@0000X0000300000<0001B0000
L04000<0000ioooo0000000000000000T040000000070082@`1=04d0B@0a03000000000000000000
0000000000000000000000000000000000000000000000000000000000000000=`40=P@0001DbAP0
<:Hb08c:603eLKMg6`0n07@1;`000000D04_05P3d`400340N=0a0=3M<@00000010000000001L0@01
0000020000000041E<TH0000002<bQP0mG6gMg2W6P3nooooZSRcMj8d/gL00000000a07S@<@088@Zo
0000073@<@2LbQP0RU?/MP00;`000000XEC/MYoR]F`88@ZoN=0a0801^gD00000H27Q0@00h@5XbQP0
224:_hC<6000L>if4j=36_kooonQE>af1A:gMGS@<@1h?380CalQI0002P1h?380e<XH05`i]gETMP08
000002D0000<00000`0005@0001D0000c`8002<1000=0`00RP400040002[Z^4oVYWQ_cTC003E;`00
0@0004`00000000000000000003ooooooooooe00001h0?ooN00001P0000<0000000002D0000<0000
100002P0000<00000`000580001`0@000`0003Woool0000000000000002@0@00000000L00P9304d0
DP0a0300000000000000000000000000000000000000000000000000000000000000000000000000
00000000000g0@0f100005C9600`YS80S<XH0?Ea]gLK03h0M04_0000001@0Bl0F0?C0@00<@1hd340
d=da000000040000000005`100400000800000000@5DbAP0000008c:603eLKMgL:LJ0?kooonZ>;=g
XSBcM`0000000340N=0a00PQ2/000000L=0a09c:602:Dnaf000_0000002QE>afWn:eK0PQ2/1hd340
P06kM@00001P8N41003Q0FS:60088@[0Q<`H001`kWHCXd<Jo_oooj5Dk7H54[MeN=0a07Pl<P1?7b5T
000:07Pl<P3DbQP0G3VgMFAf00P000009@0000`000030000E00005@0000V0`008`4007T3002:0@00
0@000:^ZhCnJVN6ohA<00=D_00010000C00000000000000000000?ooooooooooD00003d0oonP0000
600000`0000000009@0000`000040000:00000`000030000DP00070100030000>Oooo`0000000000
00000901000000001`020T<0C@1=04T0<@0`00000000000000000000000000000000000000000000
00000000000000000000000000000000000003L103H40000E<TH032V<P2<bQP0mG6gMa/0?P1d0Bl0
00000501;`1H0m<1000a07S@<@3@gC40000000@000000000G0400@00000P000000010EC960000000
S<XH0?Ea]gM`YaX0o_ooojXh/gNR=;=g00000000<@1hd340224:`@00001`d340W<XH08YCk7H002l0
00000:5Dk7JOh[E/224:`GS@<@200K]e0000060Qh@400>41J<XH00PQ2/64c1P0073^MQ>S@a[noooo
XEC/MPDB]gEhd340N3`b04lO8F@000X0N3`b0=C:601L>KMeI7H02000000U0000300000<0001D0000
E00009<3000S0@00d@<008X100010000Zj[Q?iZIhKnd5000eBl00040001<00000000000000000000
oooooooooom@0000_03oogP0000H000030000000001D0000E0000=43000S0@00l0<008X100010000
Zj[Q?iZIhKl]5@00eBl00040001<00000000000000000000oooooooooom@0000>`3ooc`0000H0000
30000000001D0000E0000?l3000S0@00:@@008X100010000Zj[Q?iZIhKn55@00eBl00040001<0000
0000000000000000oooooooooom@0000M03ooe00000H000030000000000U0000300000@0000X0000
300000<0001B0000L04000<0000ioooo0000000000000000T040000000070082@`1=0580<@0`0000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
=`40=P@0001DbAP0<:Hb08c:603eLKMg6`0n07@1;`000000D04_05P3d`400340N=0a0=3M<@000000
10000000001L0@010000020000000041E<TH0000002<bQP0mG6gMg2W6P3nooooZSRcMj8d/gL00000
000a07S@<@088@[20000073@<@2LbQP0RU?/MP00;`000000XEC/MYoR]F`88@[2N=0a0801^gFT?;=g
dcbcM`00/7MXbQP0224:`XC<6000L>if4j=36_kooonQE>af1A:gMGS@<@1h?380CalQI0002P1h?380
e<XH05`i]gETMP08000002D0000<00000`0005@0001D000090@002<1001>1000RP400040002[Z^4o
VYWQ_ldE003E;`000@0004`00000000000000000003ooooooooooe00000Y0?ooD00001P0000<0000
000005@0001D0000J0@002<1002k1000RP400040002[Z^4oVYWQ_e4F003E;`000@0004`000000000
00000000003ooooooooooe00000m0?ooX00001P0000<0000000005@0001D0000e0@002<100081@00
RP400040002[Z^4oVYWQ_b<G003E;`000@0004`00000000000000000003ooooooooooe00000`0?oo
I00001P0000<0000000002D0000<0000100002P0000<00000`000580001`0@000`0003Woool00000
00000000002@0@00000000L00P9304d0C@190340<000000000000000000000000000000000000000
0000000000000000000000000000000000000000000g0@0f100005C9600`YS80S<XH0?Ea]gLK03h0
M04_0000001@0Bl0F0?C0@00<@1hd340d=da000000040000000005`100400000800000000@5DbAP0
000008c:603eLKMgL:LJ0?kooonZ>;=gXSBcM`0000000340N=0a00PQ2/<00000L=0a09c:602:Dnaf
000_0000002QE>afWn:eK0PQ2/=hd340P06kM@00003C?;=g002`MfS:60088@[3Q<`H001`kWHCXd<J
o_oooj5Dk7H54[MeN=0a07Pl<P1?7b5T000:07Pl<P3DbQP0G3VgMFAf00P000009@0000`000030000
E00005@000081@008`4002L5002:0@000@000:^ZhCnJVN6oQaL00=D_00010000C000000000000000
00000?ooooooooooD00003/0ooll0000600000`000000000E00005@0000=0000_`4004/0000V0P00
0@000:^ZhCnJVN6ohPd00:X^00010000C00000000000000000000?ooooooooooD00007D0oomh0000
600000`0000000009@0000`000040000:00000`000030000DP00070100030000>Oooo`0000000000
00000901000000001`020T<0C@1B0340<00000000000000000000000000000000000000000000000
00000000000000000000000000000000000003L103H40000E<TH032V<P2<bQP0mG6gMa/0?P1d0Bl0
00000501;`1H0m<1000a07S@<@3@gC40000000@000000000G0400@00000P000000010EC960000000
S<XH0?Ea]gM`YaX0o_ooojXh/gNR=;=g00000000<@1hd340224:a000001`d340W<XH08YCk7H002l0
00000:5Dk7JOh[E/224:a7S@<@200K]e00000=<l/gL00;1gJ<XH00PQ2/B4c1P0073^MQ>S@a[noooo
XEC/MPDB]gEhd340N3`b04lO8F@000X0N3`b0=C:601L>KMeI7H02000000U0000300000<0001D0000
E00004P0002o0@00LP0002H200010000Zj[Q?iZIhKmD3P00ZRh00040001<00000000000000000000
oooooooooom@0000:03ooe00000H000030000000000U0000300000@0000X0000300000<0001B0000
L04000<0000ioooo0000000000000000T040000000070082@`1=04d0B@0a03000000000000000000
0000000000000000000000000000000000000000000000000000000000000000=`40=P@0001DbAP0
<:Hb08c:603eLKMg6`0n07@1;`000000D04_05P3d`400340N=0a0=3M<@00000010000000001L0@01
0000020000000041E<TH0000002<bQP0mG6gMg2W6P3nooooZSRcMj8d/gL00000000a07S@<@088@[5
0000073@<@2LbQP0RU?/MP00;`000000XEC/MYoR]F`88@[5N=0a0801^gD00000dcbcM`00/7MXbQP0
224:aHC<6000L>if4j=36_kooonQE>af1A:gMGS@<@1h?380CalQI0002P1h?380e<XH05`i]gETMP08
000002D0000<00000`0005@0001D0000L0000;l1002^00009P800040002[Z^4oVYWQ_j8>002Z;P00
0@0004`00000000000000000003ooooooooooe00001h0?ooN00001P0000<0000000005@0001D0000
Z`000;l1003:00009P800040002[Z^4oVYWQ_a@?002Z;P000@0004`00000000000000000003ooooo
oooooe00000k0?oo?00001P0000<0000000002D0000<0000100002P0000<00000`000580001`0@00
0`0003Woool0000000000000002@0@00000000L00P9304d0DP0a0300000000000000000000000000
00000000000000000000000000000000000000000000000000000000000g0@0f100005C9600`YS80
S<XH0?Ea]gLK03h0M04_0000001@0Bl0F0?C0@00<@1hd340d=da000000040000000005`100400000
800000000@5DbAP0000008c:603eLKMgL:LJ0?kooonZ>;=gXSBcM`0000000340N=0a00PQ2/H00000
L=0a09c:602:Dnaf000_0000002QE>afWn:eK0PQ2/Ihd340P06kM@00003C?;=g002`MfS:60088@[6
Q<`H001`kWHCXd<Jo_oooj5Dk7H54[MeN=0a07Pl<P1?7b5T000:07Pl<P3DbQP0G3VgMFAf00P00000
9@0000`000030000E00005@0003I0000_`4000d1000V0P000@000:^ZhCnJVN6oK@l00:X^00010000
C00000000000000000000?ooooooooooD0000300oomT0000600000`000000000E00005@0000=0@00
_`4003L1000V0P000@000:^ZhCnJVN6od@l00:X^00010000C00000000000000000000?oooooooooo
D00002T0oom@0000600000`000000000E00005@0001A0@00_`400:@1000V0P000@000:^ZhCnJVN6o
EA000:X^00010000C00000000000000000000?ooooooooooD00003d0oonP0000600000`000000000
E00005@0002m0@00_`400>L1000V0P000@000:^ZhCnJVN6o9a400:X^00010000C000000000000000
00000?ooooooooooD00007<0oom@0000600000`000000000E00005@0003V0@00_`4000D2000V0P00
0@000:^ZhCnJVN6oMA400:X^00010000C00000000000000000000?ooooooooooD00006T0ooll0000
600000`000000000E00005@000020P00_`400402000V0P000@000:^ZhCnJVN6o[1400:X^00010000
C00000000000000000000?ooooooooooD00006h0oomh0000600000`0000000009@0000`000040000
:00000`000030000DP00070100030000>Oooo`000000000000000901000000001`020T<0C@1=04T0
<@0`0000000000000000000000000000000000000000000000000000000000000000000000000000
000003L103H40000E<TH032V<P2<bQP0mG6gMa/0?P1d0Bl000000501;`1H0m<1000a07S@<@3@gC40
000000@000000000G0400@00000P000000010EC960000000S<XH0?Ea]gM`YaX0o_ooojXh/gNR=;=g
00000000<@1hd340224:a`00001`d340W<XH08YCk7H002l000000:5Dk7JOh[E/224:agS@<@200K]e
00000=<l/gL00;1gJ<XH00PQ2/N4c1P0073^MQ>S@a[nooooXEC/MPDB]gEhd340N3`b04lO8F@000X0
N3`b0=C:601L>KMeI7H02000000U0000300000<0001D0000E00004d2002o0@00R`8002H200010000
Zj[Q?iZIhKlm4P00ZRh00040001<00000000000000000000oooooooooom@0000N03oogP0000H0000
30000000001D0000E00008P2002o0@00Y`8002H200010000Zj[Q?iZIhKn_4P00ZRh00040001<0000
0000000000000000oooooooooom@0000>P3ooc`0000U0000300000L0080X0000300000D0000U0000
30000000080X0000300000H0000U0000300000@0000X0000300000<000160000500000P00017A4U3
0`000280000<0000ooooob80000<0000ooooobD0000<00003@00P2P0000<00000P0002P0000<0000
10000280000<0000ooooodH000300@00]04004E=AR//@000900001P00000080o000000000000080o
0000P000080Z@000900001P0002BS2A100000000001E<2A1e>[Ra=;AcdDT@00030000000000Z@000
900001P0002`0R`j00000000002`0R`j002>9`00A:P[@00030000000000N@0H030000000000Q@0D0
300000000008@084600000`000024<3K000000<0010d@08030000000000N@0T030000000000Z@000
900001P0002`0R`j00000000002`0R`j002>9`00A:PQ@0L030000000000Z@000900001P0002`0R`j
00000000002`0R`j002>9`00A:P[@00030000000000[@00030000000000N@0H030000000000Q@0D0
300000000008@0<4600000`000024<3K000000<0010d@0<030000000000N@0T030000000000Z@000
900001P00000080o000000000000080o00000000000Q@0L030000000001<0000I000000000000000
G`X003D2000000000000060:000f0P00:@2Z0000000000000020?`00000000000020?`0000000000
000000000000000000000000000000008P0000`0003oooooAP0001`0000@0000ADe6:`90000<0000
000000h0000D000000000100000D0000
\>"], "Graphics",
  GeneratedCell->False,
  CellAutoOverwrite->False,
  ImageSize->{529.421052631579, 112.66399048468632`},
  ImageMargins->{{22.4, 0.}, {0., 111.19999999999997`}}]
}], "Subchapter",
 CellChangeTimes->{{3.6371524922410097`*^9, 3.63715252674827*^9}, {
   3.6372440832236605`*^9, 3.6372440871428847`*^9}, 3.637244169179577*^9, {
   3.637244299470029*^9, 3.6372443032602463`*^9}, {3.6372453817689333`*^9, 
   3.637245384542092*^9}, 3.6373024456233*^9, {3.6373030333073*^9, 
   3.6373030333083*^9}, {3.6373032594343*^9, 3.6373032619173*^9}, {
   3.6381743774306*^9, 3.6381744079416*^9}, {3.6386019984035997`*^9, 
   3.6386019985266*^9}}],

Cell[CellGroupData[{

Cell["\<\
Here we provide the parameters of the problem and its exact solution\
\>", "Subsubsection",
 CellChangeTimes->{{3.633439583415289*^9, 3.6334395909637213`*^9}, {
   3.636904756973955*^9, 3.636904760701168*^9}, 3.637138408549569*^9, {
   3.6373022788703003`*^9, 3.6373023184623003`*^9}},
 Background->RGBColor[1, 1, 0]],

Cell[CellGroupData[{

Cell[TextData[{
 "Parameters:  ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["K", "\[Gamma]"], TraditionalForm]]],
 "=Kg=1, \[Nu]=nu=2*Pi;  ",
 StyleBox["a",
  FontFamily->"Times New Roman",
  FontSlant->"Italic"],
 "=aParameter=1/10"
}], "Text",
 CellChangeTimes->{{3.6371384131203775`*^9, 3.6371384241807966`*^9}, 
   3.637138525300174*^9, {3.637244470420807*^9, 3.63724447152387*^9}, {
   3.6373025854383*^9, 3.6373025856303*^9}, {3.6373030572462997`*^9, 
   3.6373030970383*^9}},
 Background->RGBColor[1, 1, 0]],

Cell[BoxData[
 RowBox[{
  RowBox[{"Kg", "=", "1."}], ";", 
  RowBox[{"nu", "=", 
   RowBox[{"2.", "*", "Pi"}]}], ";", 
  RowBox[{"aParameter", "=", "0.1"}], ";"}]], "Input",
 CellChangeTimes->{{3.6371380791081905`*^9, 3.6371380857850027`*^9}, 
   3.6371383766475134`*^9, {3.6373027211833*^9, 3.6373027594632998`*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 "Exact solution:  ",
 Cell[GraphicsData["Metafile", "\<\
CF5dJ6E]HGAYHf4PEfU^I6mgLb15CDHPAVmbKF5d0@0005Ed0@0006`0003ooooomOoooe0600330000
00000000002d6P00<`800215CDH00040M5D00;D0000500000000000000000000HA<006PK003B0000
:@400000000000000000050d0`0XR0@0AP0002`0000P0000ADe6:`500@0L00004000008@`=/00000
F08005P200160000O04007010015CDH[7T0500`0000000007d0300`000000000<402010000040000
0020?b501`0<000000000290100<0000000002Y0000T000060000000P3l0000000000000P3l00000
000002]0000<0000000001i01P0<0000000002501@0<0000000001i02@0<0000000002Y0000T0000
60000000P3l0000000000000P3l00000000002501`0<0000000002Y0000T000060000;02;3X00000
00000;02;3X0n9750<0SaB]0000<0000000002Y0000T000060000;02;3X0000000000;02;3X0n975
0<0SaB]0000<0000000002Y0000T000060000;02;3X0000000000;02;3X009:Y000TZ@Y0080T0000
6000003oool10000000000000000DAI:06i7B24000080000HP0000`000010000900002@00000080m
000000000000080m00000000000200009`0001P00001000000000?oo000000009@0000`000010000
9@0000`000080020EP000300003ooooooooooe06002600001@000?Son?ohoeP8n6AH2?QTn?ohooSo
9@0000`0000700209@0000`000000020900002@00000081100000000000008110000000000020000
AP00060V001D9P00ADe6:b]0000<0000000001i01P0<0000000002501@0<0000000001i02@0<0000
000002Y0000T000060000;02;3X0000000000;02;3X009:Y000TZB501`0<0000000002]0000<0000
000002Y0000T0000600000Eh94400000000009lT8d61;Q;5SfW@ABA0100<0000000000Q000E@9@00
A2D0008@`=/200000`0003@U00010000c0000>D0001boOooO`4008CmoomG7`00l:Goom/d002LYooo
84E=AP000@0d9@00P0000080000`0000K000000000201`00/0@00:D2002W0@000000000000000000
eED:0:Ee1P1W06D0KP1U0780H@1d06D0I00P0680N@0P05L0C@1602l0A@1=04H0801R0640H`1[06D0
KP1T0200K`1V0200L01c07@0K`1U06@0J@1d0000J@1^0700M@1d0000000A0000300000H0000:0000
40000000000000004P0000`0000100005P0000`0000H0000600000`000000000DP00070100010000
>Oooo`0000000000000009010000000000020T<0C@1=04T0<@0`0000000000000000000000000000
00000000000000000000000000000000000000000000000010000<S:60000000200000L000000000
SU?HM/S:600`bQP0k;1300@000240000b<XH00000000000030000000000100008<XH000000240000
X0l0008000030000b<XH000000000000?<XH07nN@`3l2P02P<XH0000@`040000S[E307a];lZHL`02
8HQ600000000000000000040001<bQP002m:00c;603PW480[8=`b_koool004<0gKE309Qc00800000
00000YQc00;8bQP00@0003P07P0<0000b<XH09Qc00810`00h7800P40002@L`02I7H02000000U0000
30000040001D0000E0000>D0001coOooj`0007gmool10000Zj[Q?iZIhKoN4@00JS800040001<0000
0000000000000000oooooooooom@0000M@0007P0000H000030000000000U0000300000d0080X0000
30000040001B0000L0400040000ioooo0000000000000000T040000000000082@`1=0580<@0`0000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
=`40=P`000020000<:IT0<S:600000006`0n07@1H@000000D05Q05P3B`0004<0N=1S0=3MH`000000
30000000001L0@01d=eS060000000041E<TH08cS/WN<bQP0mG6gMlX85P3nooooZSRcMj8d/gL00000
001S07S@H`1]80X@0000073@H`2LbQP0RU?/MP00H@000000XEC/MR5Z;/Y]80X@N=1S0801^gG`KP02
B01;0000B`1XbQP0KB0:48C<6000L>if[B_H_?kooonQE>af1A:gMGS@H`1h?6@09B4Q;@002P1h?6@0
e<XH05`i]gETMP08000002D0000<00000@0005@0001D0000jP0007?mooo^0000OOgoo`40002[Z^4o
VYWQ_e0B001Z<P000@0004`00000000000000000003ooooooooooe00000X0000D00001P0000<0000
000002D0000<00003@00P2P0000<00000@000580001`0@000@0003Woool0000000000000002@0@00
000000000P9304d0C@190340<0000000000000000000000000000000000000000000000000000000
000000000000000000000=3MH`0g0@0f300005C9600`YV@0S<XH0?Ea]gLK03h0M05Q0000001@0F40
F0=;0000H`1hd6<0d=eS0000000<0000000005`1007@gF<0H00000000@5DbAP0000008c:603eLKMg
bPPF0?kooonZ>;=gXSBcM`00000006<0N=1S06dP2Q400000L=1S09c:602:Dnaf001Q0000002QE>af
8FX^bVdP2Q5hd6<0P06kM@00001804/0001;06S:601]80XAQ<`H001`kWJ]:mRlo_oooj5Dk7H54[Me
N=1S07PlI00U8B4]000:07PlI03DbQP0G3VgMFAf00P000009@0000`000010000E00005@0003^0000
Logooo@0001moOoo0@000:^ZhCnJVN6oWQ8006Xb00010000C00000000000000000000?oooooooooo
D00007P0001h0000600000`000000000E00005@0003d0000LogoooL0001moOoo0@000:^ZhCnJVN6o
41<006Xb00010000C00000000000000000000?ooooooooooD00003/0000l0000600000`000000000
E00005@0003h0000Logooo`0001moOoo0@000:^ZhCnJVN6oJA<006Xb00010000C000000000000000
00000?ooooooooooD00007@0001@0000600000`0000000009@0000`0000=0020:00000`000010000
DP00070100010000>Oooo`0000000000000009010000000000020T<0C@1B0340<000000000000000
0000000000000000000000000000000000000000000000000000000000000000d=eS03L103H<0000
E<TH032VI02<bQP0mG6gMa/0?P1d0F4000000501H@1H0d/0001S07S@H`3@gF<0000000`000000000
G0400M3MH`1P000000010EC960000000S<XH0?Ea]gO:21H0o_ooojXh/gNR=;=g00000000H`1hd6<0
KB0:4P00001`d6<0W<XH08YCk7H0064000000:5Dk7HQJRk:KB0:4WS@H`200K]e000004P0B`0004/0
J<XH06dP2Q:4c1P0073^MZd[f;cnooooXEC/MPDB]gEhd6<0N3aT02DQ8Bd000X0N3aT0=C:601L>KMe
I7H02000000U000030000040001D0000E0000?`0001coOoo004007gmool10000Zj[Q?iZIhKna4`00
JS800040001<00000000000000000000oooooooooom@0000:@000500000H000030000000001D0000
E00000<1001coOoo2`4007gmool10000Zj[Q?iZIhKle5000JS800040001<00000000000000000000
oooooooooom@0000?@000:00000H000030000000001D0000E00000d1001coOoo404007gmool10000
Zj[Q?iZIhKl75@00JS800040001<00000000000000000000oooooooooom@0000F`0003`0000H0000
30000000000U0000300000d0080X000030000040001B0000L0400040000ioooo0000000000000000
T040000000000082@`1=04d0B@0a0300000000000000000000000000000000000000000000000000
000000000000000000000000003@gF<0=`40=P`0001DbAP0<:IT08c:603eLKMg6`0n07@1H@000000
D05Q05P3B`0006<0N=1S0=3MH`00000030000000001L0@01d=eS060000000041E<TH0000002<bQP0
mG6gMlX85P3nooooZSRcMj8d/gL00000001S07S@H`1]80XC0000073@H`2LbQP0RU?/MP00H@000000
XEC/MR5Z;/Y]80XCN=1S0801^gD00000B01;0000B`1XbQP0KB0:4hC<6000L>if[B_H_?kooonQE>af
1A:gMGS@H`1h?6@09B4Q;@002P1h?6@0e<XH05`i]gETMP08000002D0000<00000@0005@0001D0000
404007?moolH0@00OOgoo`40002[Z^4oVYWQ_chE001Z<P000@0004`00000000000000000003ooooo
oooooe0000150000S00001P0000<0000000002D0000<00003@00P2P0000<00000@000580001`0@00
0@0007Goool0000000000000002@0@00000000000P9304d0C@1903L0000000000000000000000000
00000000000000000000000000000000000000000000000000000=3MH`0g0@0f300005C9600`YV@0
S<XH0?Ea]gLK03h0M05Q0000001@0F40F0=;0000H`1hd6<0d=eS0000000<0000000005`1007@gF<0
H00000000@5DbAP0000008c:603eLKMgbPPF0?kooonZ>;=gXSBcM`00000006<0N=1S06dP2Q@00000
L=1S09c:602:Dnaf001Q0000002QE>af8FX^bVdP2QAhd6<0P06kM@00001804/0001;06S:601]80XD
Q<`H001`kWJ]:mRlo_oooj5Dk7H54[MeN=1S07PlI00U8B4]000:07PlI03DbQP0G3VgMFAf00P00000
9@0000`000010000E00005@0000G0@00Mogooa/1001moOoo0@000:^ZhCnJVN6odQD004`b00010000
C00000000000000000000?ooooooooooD0000;00001@0000600000`0000000009@0000`0000=0020
:00000`000010000DP00070100010000>Oooo`0000000000000009010000000000020T<0C@1B0340
<0000000000000000000000000000000000000000000000000000000000000000000000000000000
d=eS03L103H<0000E<TH032VI02<bQP0mG6gMa/0?P1d0F4000000501H@1H0d/0001S07S@H`3@gF<0
000000`000000000G0400M3MH`1P000000010EC960000000S<XH0?Ea]gO:21H0o_ooojXh/gNR=;=g
00000000H`1hd6<0KB0:5@00001`d6<0W<XH08YCk7H0064000000:5Dk7HQJRk:KB0:5GS@H`200K]e
000004P0B`0004/0J<XH06dP2QF4c1P0073^MZd[f;cnooooXEC/MPDB]gEhd6<0N3aT02DQ8Bd000X0
N3aT0=C:601L>KMeI7H02000000U000030000040001D0000E00001`1001coOoo804007gmool10000
Zj[Q?iZIhKlh5P00JS800040001<00000000000000000000oooooooooom@0000:0000500000H0000
30000000000U0000300000d0080X000030000040001B0000L0400040000ioooo0000000000000000
T040000000000082@`1=05<0F@0a0300C`1B04T0A`00000000000000000000000000000000000000
000000000000000000000000003@gF<0=`40=P`0001DbAP0<:IT08c:603eLKMg6`0n07@1H@000000
D05Q05P3B`0006<0N=1S0=3MH`00000030000000001L0@01d=eS060000000041E<TH0000002<bQP0
mG6gMlX85P3nooooZSRcMj8d/gL00000001S07S@H`1]80XF0000073@H`2LbQP0RU?/MP00H@000000
XEC/MR5Z;/Y]80XFN=1S0801^gD00000B01;0000B`1XbQP0KB0:5XC<6000L>if[B_H_?kooonQE>af
1A:gMGS@H`1h?6@09B4Q;@002P1h?6@0e<XH05`i]gETMP08000002D0000<00000@0005@0001D0000
804007?moolX0@00Q?goo`40002[Z^4oVYWQ_hHF001Z<P000@0004`00000000000000000003ooooo
oooooe00002Q0000X00001P0000<0000000002D0000<00003@00P2P0000<00000@000580001`0@00
0@0003Woool0000000000000002@0@00000000000P9304d0C@190340<00000000000000000000000
00000000000000000000000000000000000000000000000000000=3MH`0g0@0f300005C9600`YV@0
S<XH0?Ea]gLK03h0M05Q0000001@0F40F0=;0000H`1hd6<0d=eS0000000<0000000005`1007@gF<0
H00000000@5DbAP0000008c:603eLKMgbPPF0?kooonZ>;=gXSBcM`00000006<0N=1S06dP2QL00000
L=1S09c:602:Dnaf001Q0000002QE>af8FX^bVdP2QMhd6<0P06kM@00001804/0001;06S:601]80XG
Q<`H001`kWJ]:mRlo_oooj5Dk7H54[MeN=1S07PlI00U8B4]000:07PlI03DbQP0G3VgMFAf00P00000
9@0000`000010000E00005@0000X0@00Logoob`1001moOoo0@000:^ZhCnJVN6o8AL006Xb00010000
C00000000000000000000?ooooooooooD00007@0001@0000600000`0000000009@0000`0000=0020
:00000`000010000DP00070100010000MOooo`0000000000000009010000000000020T<0C@1=04T0
=`000000000000000000000000000000000000000000000000000000000000000000000000000000
d=eS03L103H<0000E<TH032VI02<bQP0mG6gMa/0?P1d0F4000000501H@1H0d/0001S07S@H`3@gF<0
000000`000000000G0400M3MH`1P000000010EC960000000S<XH0?Ea]gO:21H0o_ooojXh/gNR=;=g
00000000H`1hd6<0KB0:6000001`d6<0W<XH08YCk7H0064000000:5Dk7HQJRk:KB0:67S@H`200K]e
000004P0B`0004/0J<XH06dP2QR4c1P0073^MZd[f;cnooooXEC/MPDB]gEhd6<0N3aT02DQ8Bd000X0
N3aT0=C:601L>KMeI7H02000000U000030000040001D0000E00002`1001boOoo<04007Smool10000
Zj[Q?iZIhKmY5`00_3800040001<00000000000000000000oooooooooom@0000/0000500000H0000
30000000000U0000300000d0080X000030000040001B0000L0400040000ioooo0000000000000000
T040000000000082@`1=0580<@0`0000000000000000000000000000000000000000000000000000
000000000000000000000000003@gF<0=`40=P`0001DbAP0<:IT08c:603eLKMg6`0n07@1H@000000
D05Q05P3B`0006<0N=1S0=3MH`00000030000000001L0@01d=eS060000000041E<TH0000002<bQP0
mG6gMlX85P3nooooZSRcMj8d/gL00000001S07S@H`1]80XI0000073@H`2LbQP0RU?/MP00H@000000
XEC/MR5Z;/Y]80XIN=1S0801^gD00000B01;0000B`1XbQP0KB0:6HC<6000L>if[B_H_?kooonQE>af
1A:gMGS@H`1h?6@09B4Q;@002P1h?6@0e<XH05`i]gETMP08000002D0000<00000@0005@0001D0000
<@4007?moole0@00OOgoo`40002[Z^4oVYWQ_llG001Z<P000@0004`00000000000000000003ooooo
oooooe00000Y0000D00001P0000<0000000005@0001D0000=`4007?moolo0@00OOgoo`40002[Z^4o
VYWQ_dPH001Z<P000@0004`00000000000000000003ooooooooooe00000[0000X00001P0000<0000
000002D0000<00003@00P2P0000<00000@000580001`0@000@0003Woool0000000000000002@0@00
000000000P9304d0C@190340<0000000000000000000000000000000000000000000000000000000
000000000000000000000=3MH`0g0@0f300005C9600`YV@0S<XH0?Ea]gLK03h0M05Q0000001@0F40
F0=;0000H`1hd6<0d=eS0000000<0000000005`1007@gF<0H00000000@5DbAP0000008c:603eLKMg
bPPF0?kooonZ>;=gXSBcM`00000006<0N=1S06dP2QX00000L=1S09c:602:Dnaf001Q0000002QE>af
8FX^bVdP2QYhd6<0P06kM@00001804/0001;06S:601]80XJQ<`H001`kWJ]:mRlo_oooj5Dk7H54[Me
N=1S07PlI00U8B4]000:07PlI03DbQP0G3VgMFAf00P000009@0000`000010000E00005@000110@00
LogoodH1001moOoo0@000:^ZhCnJVN6o41T006Xb00010000C00000000000000000000?oooooooooo
D0000640001T0000600000`0000000009@0000`0000=0020:00000`000010000DP00070100010000
>Oooo`0000000000000009010000000000020T<0C@1B0340<0000000000000000000000000000000
000000000000000000000000000000000000000000000000d=eS03L103H<0000E<TH032VI02<bQP0
mG6gMa/0?P1d0F4000000501H@1H0d/0001S07S@H`3@gF<0000000`000000000G0400M3MH`1P0000
00010EC960000000S<XH0?Ea]gO:21H0o_ooojXh/gNR=;=g00000000H`1hd6<0KB0:6`00001`d6<0
W<XH08YCk7H0064000000:5Dk7HQJRk:KB0:6gS@H`200K]e000004P0B`0004/0J<XH06dP2Q^4c1P0
073^MZd[f;cnooooXEC/MPDB]gEhd6<0N3aT02DQ8Bd000X0N3aT0=C:601L>KMeI7H02000000U0000
30000040001D0000E00004P1001coOooC04007gmool10000Zj[Q?iZIhKnK6@00JS800040001<0000
0000000000000000oooooooooom@0000L`000500000H000030000000001D0000E00004`1001coOoo
C`4007gmool10000Zj[Q?iZIhKoY6@00JS800040001<00000000000000000000oooooooooom@0000
J@0003`0000H000030000000001D0000E00004h1001coOooE04007gmool10000Zj[Q?iZIhKlQ6P00
JS800040001<00000000000000000000oooooooooom@0000KP0007P0000H000030000000001D0000
E00005@1001coOooF04007gmool10000Zj[Q?iZIhKn?6P00JS800040001<00000000000000000000
oooooooooom@0000:0000500000H000030000000000U0000300000d0080X000030000040001B0000
L0400040000ioooo0000000000000000T040000000000082@`1=04d0B@0a03000000000000000000
00000000000000000000000000000000000000000000000000000000003@gF<0=`40=P`0001DbAP0
<:IT08c:603eLKMg6`0n07@1H@000000D05Q05P3B`0006<0N=1S0=3MH`00000030000000001L0@01
d=eS060000000041E<TH0000002<bQP0mG6gMlX85P3nooooZSRcMj8d/gL00000001S07S@H`1]80XL
0000073@H`2LbQP0RU?/MP00H@000000XEC/MR5Z;/Y]80XLN=1S0801^gD00000B01;0000B`1XbQP0
KB0:78C<6000L>if[B_H_?kooonQE>af1A:gMGS@H`1h?6@09B4Q;@002P1h?6@0e<XH05`i]gETMP08
000002D0000<00000@0005@0001D0000F04007?moomM0@00OOgoo`40002[Z^4oVYWQ_mdJ001Z<P00
0@0004`00000000000000000003ooooooooooe00002j0000I00001P0000<0000000005@0001D0000
G@4007?moomQ0@00OOgoo`40002[Z^4oVYWQ_d`K001Z<P000@0004`00000000000000000003ooooo
oooooe00001d0000D00001P0000<0000000002D0000<00003@00P2P0000<00000@000580001`0@00
0@0003Woool0000000000000002@0@00000000000P9304d0DP0a0300000000000000000000000000
00000000000000000000000000000000000000000000000000000=3MH`0g0@0f300005C9600`YV@0
S<XH0?Ea]gLK03h0M05Q0000001@0F40F0=;0000H`1hd6<0d=eS0000000<0000000005`1007@gF<0
H00000000@5DbAP0000008c:603eLKMgbPPF0?kooonZ>;=gXSBcM`00000006<0N=1S06dP2Qd00000
L=1S09c:602:Dnaf001Q0000002QE>af8FX^bVdP2Qehd6<0P06kM@00001804/0001;06S:601]80XM
Q<`H001`kWJ]:mRlo_oooj5Dk7H54[MeN=1S07PlI00U8B4]000:07PlI03DbQP0G3VgMFAf00P00000
9@0000`000010000E00005@0001Q0@00LogoofD1001moOoo0@000:^ZhCnJVN6oU1/006Xb00010000
C00000000000000000000?ooooooooooD00002T0001@0000600000`000000000E00005@0001U0@00
LogoofP1001moOoo0@000:^ZhCnJVN6ohQ/006Xb00010000C00000000000000000000?oooooooooo
D00005d0000l0000600000`000000000E00005@0001[0@00Logoofl1001moOoo0@000:^ZhCnJVN6o
FQ`006Xb00010000C00000000000000000000?ooooooooooD00007<0001@0000600000`000000000
E00005@0001_0@00Logoog81001moOoo0@000:^ZhCnJVN6oZ1`006Xb00010000C000000000000000
00000?ooooooooooD00006T0000l0000600000`000000000E00005@0001b0@00LogoogP1001moOoo
0@000:^ZhCnJVN6oga`006Xb00010000C00000000000000000000?ooooooooooD00006h0001h0000
600000`0000000009@0000`0000=0020:00000`000010000DP00070100010000>Oooo`0000000000
000009010000000000020T<0C@1=04T0<@0`00000000000000000000000000000000000000000000
00000000000000000000000000000000d=eS03L103H<0000E<TH032VI02<bQP0mG6gMa/0?P1d0F40
00000501H@1H0d/0001S07S@H`3@gF<0000000`000000000G0400M3MH`1P000000010EC960000000
S<XH0?Ea]gO:21H0o_ooojXh/gNR=;=g00000000H`1hd6<0KB0:7P00001`d6<0W<XH08YCk7H00640
00000:5Dk7HQJRk:KB0:7WS@H`200K]e000004P0B`0004/0J<XH06dP2Qj4c1P0073^MZd[f;cnoooo
XEC/MPDB]gEhd6<0N3aT02DQ8Bd000X0N3aT0=C:601L>KMeI7H02000000U000030000040001D0000
E00007T1001coOooO`4007gmool10000Zj[Q?iZIhKma7@00JS800040001<00000000000000000000
oooooooooom@0000N00007P0000U0000300000d0080X000030000040000>000050000000000@0000
500000Q00@PT00006000008@`=/100000`00000000000000000001]000100000=000004000020000
6XUS@hV48lB9=Ae3ndAB@@<0000JRF=3RH@Sa55O`4>9Q2?46XUS@gHk8<@Q000020000680000<0000
0@000240000800008@0000P0001c000030000000000L0000200002D0000<00000000P2D0000<0000
1`00P2D0000<00003P00P1T0000<0000oooo01P0000<000000000180000<00000P0001<0000<0000
0@0001@0000<00003@0001D0000<00000@0001H0000<0000000000d0000@000000000000000j0000
300000X0000K000040000000000000008`000200001BJbE100000000003m@Rm1a0HCaLSTgdDT0000
9000059[9D40000000000?e2;d741Q?5b>COA@@0001c000030000000000=00004000000000000000
DP00070100020000400000L00000000000000;`2000000001`828U<0N@1c07@0I@1]00004`2Pn?oo
lP400000000lgCh2P?Soo`P0F7kkm_oo00000000000PgCh2P?Sooooo000006P7691b0000080@dC<0
6oI<?DCB<`20:7L7bBbcMg8A8B@R08X1600000000008W6L720000<nY94400<LmR8<g0P000030g382
H<hc00000000000000000?oooooDdC<00=8c0?3L<`3eLKMg[gTA0?kooon<hk9gl^2bM`00Z`Pho000
0P000000000P0000<=8c05CB<`3[F>af001b00P0500VF^afX>QeH@000008W6L7ooooo`<000000000
00000000000LdS<0RWE[KV3I<`00L>if_;6X5okooolVF^afHQ>gMF0QJ0L10000R=8c08cB<`0_<;Me
I7H02000000U00003000008000160000R00007`00017A4U30P000>@0001boOooP04007kmool`0000
I`1U06h0I@1b0640M01U06@0801R07T0801G04d0AP0_04D0C@160200HP1Q06<0J`1U06h0I00P06l0
IP0P0700L`1d06l0I@1T06T0M00006T0KP1`07D0M00000008`000200002PIP@o000000000008DPbo
a0HCaLSTgdDT000090000:1V13l00000000000QB3;o41Q?5b>COA@@0000S000080000:1V13l00000
000000QB3;o41Q?5b>COAB@0000T0000X6H4?`0000000000258<_l@64lG8i=m510000180000<0000
0@0001H0000<0000600001P0000<000000000580001`0@000`0003Woool0000000000000002@0@00
000000L00P9304d0C@190340<0000000000000000000000000000000000000000000000000000000
0000000000000000000000@00038bQP0000000P000070000000008iCf7K8bQP0<<XH0>b`@`040000
Q0000<S:60000000000000`0000000000@00023:60000000Q0000:0?000200000`000<S:60000000
000003c:601oWT<0o0X00X3:600004<0100008je@`1lKBo:V7<00R68AP0000000000000000010000
C<XH000_BP0<baP0h9a20:b3L<[noooo00130=fe@`2HL`020000000000:HL`02b<XH0040000h01h0
30000<S:602HL`020@<00>1b00810000T7<00VAf00P000009@0000`000030000E00005@0000=0000
2@0004`0001f00000@000:^ZhCnJVN6ogQ4006Xb00010000C00000000000000000000?oooooooooo
D00007D0oomh0000600000`000000000DP00070100040000500000T00000000000000;`200000000
1`828U<0N@1c07@0I@1]000000000000hP000000001/]6`2P?Soo`000000000000000000001@]6`2
P?SookZF00000;Me]fBgMG8A8B@0000000000040001PY6<9S=4c065T]gEb4B4T00000000001D0000
0000062TH`T4dS<0gU6gMG8A8BCX7V<70P0009Qa@09D000000000040000h01h030000<S:602HL`02
0@<00>1b00810000T7<00P0000P00000`=`b0V3><`04dS<0;c2gM@CB<`1V<;MeS:UO2@RLI`LU0000
000:0;0^000hdc<07OYWKW8A8B@006<7H:AS2@80002HLD02/PYXKZP6^gD00000Z0JkMH01^gFPZEl9
G=8c02l`]gELdS<0IS2gMNbYG`T8W6L7I7H02000000U0000300000@0000X0000300000<0001B0000
L04000<0000ioooo0000000000000000T040000000070082@`1=0580<@0`00000000000000000000
0000000000000000000000000000000000000000000000000000000000000000=`40=P`000020000
<:IT0<S:600000006`0n07@1H@000000D05Q05P3B`0004<0N=1S0=3MH`00000030000000001L0@01
d=eS060000000041E<TH08cS/WN<bQP0mG6gMlX85P3nooooZSRcMj8d/gL00000001S07S@H`1]80X@
0000073@H`2LbQP0RU?/MP00H@000000XEC/MR5Z;/Y]80X@N=1S0801^gG`KP02B01;0000B`1XbQP0
KB0:48C<6000L>if[B_H_?kooonQE>af1A:gMGS@H`1h?6@09B4Q;@002P1h?6@0e<XH05`i]gETMP08
000002D0000<00000`0005@0001D0000B00000T0001b0000MP000040002[Z^4oVYWQ_e0B001Z<P00
0@0004`00000000000000000003ooooooooooe00000X0000D00001P0000<0000000002D0000<0000
100002P0000<00000`000580001`0@000`0003Woool0000000000000002@0@00000000L00P9304d0
C@190340<00000000000000000000000000000000000000000000000000000000000000000000000
00000=3MH`0g0@0f300005C9600`YV@0S<XH0?Ea]gLK03h0M05Q0000001@0F40F0=;0000H`1hd6<0
d=eS0000000<0000000005`1007@gF<0H00000000@5DbAP0000008c:603eLKMgbPPF0?kooonZ>;=g
XSBcM`00000006<0N=1S06dP2Q400000L=1S09c:602:Dnaf001Q0000002QE>af8FX^bVdP2Q5hd6<0
P06kM@00001804/0001;06S:601]80XAQ<`H001`kWJ]:mRlo_oooj5Dk7H54[MeN=1S07PlI00U8B4]
000:07PlI03DbQP0G3VgMFAf00P000009@0000`000030000E00005@0001a00002@000;00001f0000
0@000:^ZhCnJVN6oWQ8006Xb00010000C00000000000000000000?ooooooooooD00007P0001h0000
600000`000000000E00005@0002[00002@000</0001f00000@000:^ZhCnJVN6o41<006Xb00010000
C00000000000000000000?ooooooooooD00003/0000l0000600000`000000000E00005@0003J0000
2@0000@1001f00000@000:^ZhCnJVN6oJA<006Xb00010000C00000000000000000000?oooooooooo
D00007@0001@0000600000`0000000009@0000`000040000:00000`000030000DP00070100030000
>Oooo`000000000000000901000000001`020T<0C@1B0340<0000000000000000000000000000000
000000000000000000000000000000000000000000000000d=eS03L103H<0000E<TH032VI02<bQP0
mG6gMa/0?P1d0F4000000501H@1H0d/0001S07S@H`3@gF<0000000`000000000G0400M3MH`1P0000
00010EC960000000S<XH0?Ea]gO:21H0o_ooojXh/gNR=;=g00000000H`1hd6<0KB0:4P00001`d6<0
W<XH08YCk7H0064000000:5Dk7HQJRk:KB0:4WS@H`200K]e000004P0B`0004/0J<XH06dP2Q:4c1P0
073^MZd[f;cnooooXEC/MPDB]gEhd6<0N3aT02DQ8Bd000X0N3aT0=C:601L>KMeI7H02000000U0000
300000<0001D0000E0000?l000090000:@4007H000010000Zj[Q?iZIhKna4`00JS800040001<0000
0000000000000000oooooooooom@0000:@000500000H000030000000001D0000E00004<100090000
UP4007H000010000Zj[Q?iZIhKle5000JS800040001<00000000000000000000oooooooooom@0000
?@3ooj00000H000030000000001D0000E0000;0100090000d04007H000010000Zj[Q?iZIhKl75@00
JS800040001<00000000000000000000oooooooooom@0000F`3ooc`0000H000030000000000U0000
300000@0000X0000300000<0001B0000L04000<0000ioooo0000000000000000T040000000070082
@`1=04d0B@0a03000000000000000000000000000000000000000000000000000000000000000000
00000000003@gF<0=`40=P`0001DbAP0<:IT08c:603eLKMg6`0n07@1H@000000D05Q05P3B`0006<0
N=1S0=3MH`00000030000000001L0@01d=eS060000000041E<TH0000002<bQP0mG6gMlX85P3noooo
ZSRcMj8d/gL00000001S07S@H`1]80XC0000073@H`2LbQP0RU?/MP00H@000000XEC/MR5Z;/Y]80XC
N=1S0801^gD00000B01;0000B`1XbQP0KB0:4hC<6000L>if[B_H_?kooonQE>af1A:gMGS@H`1h?6@0
9B4Q;@002P1h?6@0e<XH05`i]gETMP08000002D0000<00000`0005@0001D0000c04000T0000K0P00
MP000040002[Z^4oVYWQ_chE001Z<P000@0004`00000000000000000003ooooooooooe0000150?oo
S00001P0000<0000000002D0000<0000100002P0000<00000`000580001`0@000`0007Goool00000
00000000002@0@00000000L00P9304d0C@1903L00000000000000000000000000000000000000000
0000000000000000000000000000000000000=3MH`0g0@0f300005C9600`YV@0S<XH0?Ea]gLK03h0
M05Q0000001@0F40F0=;0000H`1hd6<0d=eS0000000<0000000005`1007@gF<0H00000000@5DbAP0
000008c:603eLKMgbPPF0?kooonZ>;=gXSBcM`00000006<0N=1S06dP2Q@00000L=1S09c:602:Dnaf
001Q0000002QE>af8FX^bVdP2QAhd6<0P06kM@00001804/0001;06S:601]80XDQ<`H001`kWJ]:mRl
o_oooj5Dk7H54[MeN=1S07PlI00U8B4]000:07PlI03DbQP0G3VgMFAf00P000009@0000`000030000
E00005@0000I0P00<P0004D2001m00000@000:^ZhCnJVN6odQD004`b00010000C000000000000000
00000?ooooooooooD0000;00001@0000600000`0000000009@0000`000040000:00000`000030000
DP00070100030000>Oooo`000000000000000901000000001`020T<0C@1B0340<000000000000000
0000000000000000000000000000000000000000000000000000000000000000d=eS03L103H<0000
E<TH032VI02<bQP0mG6gMa/0?P1d0F4000000501H@1H0d/0001S07S@H`3@gF<0000000`000000000
G0400M3MH`1P000000010EC960000000S<XH0?Ea]gO:21H0o_ooojXh/gNR=;=g00000000H`1hd6<0
KB0:5@00001`d6<0W<XH08YCk7H0064000000:5Dk7HQJRk:KB0:5GS@H`200K]e000004P0B`0004/0
J<XH06dP2QF4c1P0073^MZd[f;cnooooXEC/MPDB]gEhd6<0N3aT02DQ8Bd000X0N3aT0=C:601L>KMe
I7H02000000U0000300000<0001D0000E00004d200090000M`8007H000010000Zj[Q?iZIhKlh5P00
JS800040001<00000000000000000000oooooooooom@0000:0000500000H000030000000000U0000
300000@0000X0000300000<0001B0000L04000<0000ioooo0000000000000000T040000000070082
@`1=05<0F@0a0300C`1B04T0A`000000000000000000000000000000000000000000000000000000
00000000003@gF<0=`40=P`0001DbAP0<:IT08c:603eLKMg6`0n07@1H@000000D05Q05P3B`0006<0
N=1S0=3MH`00000030000000001L0@01d=eS060000000041E<TH0000002<bQP0mG6gMlX85P3noooo
ZSRcMj8d/gL00000001S07S@H`1]80XF0000073@H`2LbQP0RU?/MP00H@000000XEC/MR5Z;/Y]80XF
N=1S0801^gD00000B01;0000B`1XbQP0KB0:5XC<6000L>if[B_H_?kooonQE>af1A:gMGS@H`1h?6@0
9B4Q;@002P1h?6@0e<XH05`i]gETMP08000002D0000<00000`0005@0001D0000MP8000H000390P00
``000040002[Z^4oVYWQ_hHF001Z<P000@0004`00000000000000000003ooooooooooe00002Q0000
X00001P0000<0000000002D0000<0000100002P0000<00000`000580001`0@000`0003Woool00000
00000000002@0@00000000L00P9304d0C@190340<000000000000000000000000000000000000000
0000000000000000000000000000000000000=3MH`0g0@0f300005C9600`YV@0S<XH0?Ea]gLK03h0
M05Q0000001@0F40F0=;0000H`1hd6<0d=eS0000000<0000000005`1007@gF<0H00000000@5DbAP0
000008c:603eLKMgbPPF0?kooonZ>;=gXSBcM`00000006<0N=1S06dP2QL00000L=1S09c:602:Dnaf
001Q0000002QE>af8FX^bVdP2QMhd6<0P06kM@00001804/0001;06S:601]80XGQ<`H001`kWJ]:mRl
o_oooj5Dk7H54[MeN=1S07PlI00U8B4]000:07PlI03DbQP0G3VgMFAf00P000009@0000`000030000
E00005@000360P002@000?02001f00000@000:^ZhCnJVN6o8AL006Xb00010000C000000000000000
00000?ooooooooooD00007@0001@0000600000`0000000009@0000`000040000:00000`000030000
DP00070100030000MOooo`000000000000000901000000001`020T<0C@1=04T0=`00000000000000
0000000000000000000000000000000000000000000000000000000000000000d=eS03L103H<0000
E<TH032VI02<bQP0mG6gMa/0?P1d0F4000000501H@1H0d/0001S07S@H`3@gF<0000000`000000000
G0400M3MH`1P000000010EC960000000S<XH0?Ea]gO:21H0o_ooojXh/gNR=;=g00000000H`1hd6<0
KB0:6000001`d6<0W<XH08YCk7H0064000000:5Dk7HQJRk:KB0:67S@H`200K]e000004P0B`0004/0
J<XH06dP2QR4c1P0073^MZd[f;cnooooXEC/MPDB]gEhd6<0N3aT02DQ8Bd000X0N3aT0=C:601L>KMe
I7H02000000U0000300000<0001D0000E0000>/2003eoooo5`<0040000010000Zj[Q?iZIhKmY5`00
_3800040001<00000000000000000000oooooooooom@0000/0000500000H000030000000000U0000
300000@0000X0000300000<0001B0000L04000<0000ioooo0000000000000000T040000000070082
@`1=0580<@0`00000000000000000000000000000000000000000000000000000000000000000000
00000000003@gF<0=`40=P`0001DbAP0<:IT08c:603eLKMg6`0n07@1H@000000D05Q05P3B`0006<0
N=1S0=3MH`00000030000000001L0@01d=eS060000000041E<TH0000002<bQP0mG6gMlX85P3noooo
ZSRcMj8d/gL00000001S07S@H`1]80XI0000073@H`2LbQP0RU?/MP00H@000000XEC/MR5Z;/Y]80XI
N=1S0801^gD00000B01;0000B`1XbQP0KB0:6HC<6000L>if[B_H_?kooonQE>af1A:gMGS@H`1h?6@0
9B4Q;@002P1h?6@0e<XH05`i]gETMP08000002D0000<00000`0005@0001D000080<000T0001:0`00
MP000040002[Z^4oVYWQ_llG001Z<P000@0004`00000000000000000003ooooooooooe00000Y0000
D00001P0000<0000000005@0001D0000GP<000T0002a0`00MP000040002[Z^4oVYWQ_dPH001Z<P00
0@0004`00000000000000000003ooooooooooe00000[0000X00001P0000<0000000002D0000<0000
100002P0000<00000`000580001`0@000`0003Woool0000000000000002@0@00000000L00P9304d0
C@190340<00000000000000000000000000000000000000000000000000000000000000000000000
00000=3MH`0g0@0f300005C9600`YV@0S<XH0?Ea]gLK03h0M05Q0000001@0F40F0=;0000H`1hd6<0
d=eS0000000<0000000005`1007@gF<0H00000000@5DbAP0000008c:603eLKMgbPPF0?kooonZ>;=g
XSBcM`00000006<0N=1S06dP2QX00000L=1S09c:602:Dnaf001Q0000002QE>af8FX^bVdP2QYhd6<0
P06kM@00001804/0001;06S:601]80XJQ<`H001`kWJ]:mRlo_oooj5Dk7H54[MeN=1S07PlI00U8B4]
000:07PlI03DbQP0G3VgMFAf00P000009@0000`000030000E00005@000360`002@000?X3001f0000
0@000:^ZhCnJVN6o41T006Xb00010000C00000000000000000000?ooooooooooD0000640001T0000
600000`0000000009@0000`000040000:00000`000030000DP00070100030000>Oooo`0000000000
00000901000000001`020T<0C@1B0340<00000000000000000000000000000000000000000000000
00000000000000000000000000000000d=eS03L103H<0000E<TH032VI02<bQP0mG6gMa/0?P1d0F40
00000501H@1H0d/0001S07S@H`3@gF<0000000`000000000G0400M3MH`1P000000010EC960000000
S<XH0?Ea]gO:21H0o_ooojXh/gNR=;=g00000000H`1hd6<0KB0:6`00001`d6<0W<XH08YCk7H00640
00000:5Dk7HQJRk:KB0:6gS@H`200K]e000004P0B`0004/0J<XH06dP2Q^4c1P0073^MZd[f;cnoooo
XEC/MPDB]gEhd6<0N3aT02DQ8Bd000X0N3aT0=C:601L>KMeI7H02000000U0000300000<0001D0000
E00000h400090000>0@007H000010000Zj[Q?iZIhKnK6@00JS800040001<00000000000000000000
oooooooooom@0000L`000500000H000030000000001D0000E00003H400090000EP@007H000010000
Zj[Q?iZIhKoY6@00JS800040001<00000000000000000000oooooooooom@0000J@0003`0000H0000
30000000001D0000E00005<400090000TP@007H000010000Zj[Q?iZIhKlQ6P00JS800040001<0000
0000000000000000oooooooooom@0000KP0007P0000H000030000000001D0000E00008`400090000
]P@007H000010000Zj[Q?iZIhKn?6P00JS800040001<00000000000000000000oooooooooom@0000
:0000500000H000030000000000U0000300000@0000X0000300000<0001B0000L04000<0000ioooo
0000000000000000T040000000070082@`1=04d0B@0a030000000000000000000000000000000000
0000000000000000000000000000000000000000003@gF<0=`40=P`0001DbAP0<:IT08c:603eLKMg
6`0n07@1H@000000D05Q05P3B`0006<0N=1S0=3MH`00000030000000001L0@01d=eS060000000041
E<TH0000002<bQP0mG6gMlX85P3nooooZSRcMj8d/gL00000001S07S@H`1]80XL0000073@H`2LbQP0
RU?/MP00H@000000XEC/MR5Z;/Y]80XLN=1S0801^gD00000B01;0000B`1XbQP0KB0:78C<6000L>if
[B_H_?kooonQE>af1A:gMGS@H`1h?6@09B4Q;@002P1h?6@0e<XH05`i]gETMP08000002D0000<0000
0`0005@0001D0000]0@000T0003Z1000MP000040002[Z^4oVYWQ_mdJ001Z<P000@0004`000000000
00000000003ooooooooooe00002j0000I00001P0000<0000000005@0001D0000kP@000T0000H1@00
MP000040002[Z^4oVYWQ_d`K001Z<P000@0004`00000000000000000003ooooooooooe00001d0000
D00001P0000<0000000002D0000<0000100002P0000<00000`000580001`0@000`0003Woool00000
00000000002@0@00000000L00P9304d0DP0a03000000000000000000000000000000000000000000
0000000000000000000000000000000000000=3MH`0g0@0f300005C9600`YV@0S<XH0?Ea]gLK03h0
M05Q0000001@0F40F0=;0000H`1hd6<0d=eS0000000<0000000005`1007@gF<0H00000000@5DbAP0
000008c:603eLKMgbPPF0?kooonZ>;=gXSBcM`00000006<0N=1S06dP2Qd00000L=1S09c:602:Dnaf
001Q0000002QE>af8FX^bVdP2Qehd6<0P06kM@00001804/0001;06S:601]80XMQ<`H001`kWJ]:mRl
o_oooj5Dk7H54[MeN=1S07PlI00U8B4]000:07PlI03DbQP0G3VgMFAf00P000009@0000`000030000
E00005@0000C1@002@0003d5001f00000@000:^ZhCnJVN6oU1/006Xb00010000C000000000000000
00000?ooooooooooD00002T0001@0000600000`000000000E00005@0000k1@002@0005/5001f0000
0@000:^ZhCnJVN6ohQ/006Xb00010000C00000000000000000000?ooooooooooD00005d0000l0000
600000`000000000E00005@0001i1@002@000:<5001f00000@000:^ZhCnJVN6oFQ`006Xb00010000
C00000000000000000000?ooooooooooD00007<0001@0000600000`000000000E00005@0002R1@00
2@000<85001f00000@000:^ZhCnJVN6oZ1`006Xb00010000C00000000000000000000?oooooooooo
D00006T0000l0000600000`000000000E00005@0002n1@002@000?d5001f00000@000:^ZhCnJVN6o
ga`006Xb00010000C00000000000000000000?ooooooooooD00006h0001h0000600000`000000000
9@0000`000040000:00000`000030000DP00070100030000>Oooo`00000000000000090100000000
1`020T<0C@1=04T0<@0`000000000000000000000000000000000000000000000000000000000000
0000000000000000d=eS03L103H<0000E<TH032VI02<bQP0mG6gMa/0?P1d0F4000000501H@1H0d/0
001S07S@H`3@gF<0000000`000000000G0400M3MH`1P000000010EC960000000S<XH0?Ea]gO:21H0
o_ooojXh/gNR=;=g00000000H`1hd6<0KB0:7P00001`d6<0W<XH08YCk7H0064000000:5Dk7HQJRk:
KB0:7WS@H`200K]e000004P0B`0004/0J<XH06dP2Qj4c1P0073^MZd[f;cnooooXEC/MPDB]gEhd6<0
N3aT02DQ8Bd000X0N3aT0=C:601L>KMeI7H02000000U0000300000<0001D0000E00000X600090000
B@H007H000010000Zj[Q?iZIhKma7@00JS800040001<00000000000000000000oooooooooom@0000
N00007P0000U0000300000@0000X0000300000<000160000500000P00017A4U30`000280000<0000
ooooob80000<0000ooooobD0000<00003@00P2P0000<00000P0002P0000<000010000280000<0000
ooooodH000300@00]04004E=AR//@000900001P00000080o000000000000080o0000P000080Z@000
900001P00005N2A100000000002O92=1PBhBaHmYd4DT@00030000000000Z@000900001P0002`0R`j
00000000002`0R`j002BZ@009:T[@00030000000000N@0H030000000000Q@0D0300000000008@084
600000`000024<3K000000<0010d@08030000000000N@0T030000000000Z@000900001P0002`0R`j
00000000002`0R`j002BZ@009:TQ@0L030000000000Z@000900001P0002`0R`j00000000002`0R`j
002BZ@009:T[@00030000000000[@00030000000000N@0H030000000000Q@0D0300000000008@0<4
600000`000024<3K000000<0010d@0<030000000000N@0T030000000000Z@000900001P00000080o
000000000000080o00000000000Q@0L030000000001<0000I000000000000000C`H008D000000000
0000050600260000:@2Z0000000000000020?`00000000000020?`00000000000000000000000000
00000000000000008P0000`0003oooooAP0001`0000@0000ADe6:`90000<0000000000h0000D0000
00000100000D0000
\>"], "Graphics",
  GeneratedCell->False,
  CellAutoOverwrite->False,
  ImageSize->{249.21710526315803`, 20.060819618706233`},
  ImageMargins->{{2.1052631578947367`, 0.}, {0., 8.355263157894736}}]
}], "Text",
 CellChangeTimes->{{3.633439583415289*^9, 3.6334395909637213`*^9}, {
  3.636904756973955*^9, 3.636904760701168*^9}, {3.6372443229373713`*^9, 
  3.6372443239854317`*^9}, {3.6372443908282547`*^9, 3.637244411443434*^9}, {
  3.637244624301608*^9, 3.6372446392814655`*^9}, {3.6373025625952997`*^9, 
  3.6373025659023*^9}, {3.6373030348303003`*^9, 3.6373030488623*^9}, {
  3.6386021202906*^9, 3.6386021237116003`*^9}},
 Background->RGBColor[1, 1, 0]],

Cell[BoxData[
 RowBox[{
  RowBox[{"uSol", "[", 
   RowBox[{"x_", ",", "t_", ",", "ga_"}], "]"}], ":=", 
  RowBox[{
   RowBox[{"Sin", "[", "x", "]"}], "*", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"MittagLefflerE", "[", 
      RowBox[{"ga", ",", 
       RowBox[{"-", 
        RowBox[{"t", "^", "ga"}]}]}], "]"}], "+", 
     RowBox[{"aParameter", "*", 
      RowBox[{"Sin", "[", 
       RowBox[{"nu", "*", "t"}], "]"}]}]}], ")"}]}]}]], "Input",
 CellChangeTimes->{{3.55982895496875*^9, 3.559828984796875*^9}, {
   3.589297606934722*^9, 3.589297614521156*^9}, {3.58929766495004*^9, 
   3.5892976659740987`*^9}, {3.636984577724125*^9, 3.6369845787221823`*^9}, {
   3.636984838198024*^9, 3.636984845629449*^9}, {3.6372992202553*^9, 
   3.6372992212393*^9}, {3.6373025530093*^9, 3.6373025721913*^9}, 
   3.6373027142993*^9, 3.6373027458922997`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 "Source term:  ",
 Cell[GraphicsData["Metafile", "\<\
CF5dJ6E]HGAYHf4PEfU^I6mgLb15CDHPAVmbKF5d0@0005B<0@0006`0003ooooom?oooo<600250000
00000000001V7@00;`800215CDH00040S5@00;L0000500000000000000000000HA<006PK003B0000
:@400000000000000000050d0`0XR0@0AP0002`0000P0000ADe6:`500@0L00004000008@`=/00000
F08005P200160000O04007010015CDH[7T0500`0000000007d0300`000000000<402010000040000
0020?b501`0<000000000290100<0000000002Y0000T000060000000P3l0000000000000P3l00000
000002]0000<0000000001i01P0<0000000002501@0<0000000001i02@0<0000000002Y0000T0000
60000000P3l0000000000000P3l00000000002501`0<0000000002Y0000T000060000;02;3X00000
00000;02;3X0<4;5043Na2]0000<0000000002Y0000T000060000;02;3X0000000000;02;3X0<4;5
043Na2]0000<0000000002Y0000T000060000;02;3X0000000000;02;3X004:Y003NZ0Y0080T0000
6000003oool1000000000000001`NRE:0?55B24000080000HP0000`000010000900002@00000080m
000000000000080m00000000000200009`0001P00001000000000?oo000000009@0000`000010000
9@0000`000080020EP000300003ooooooooooo<6002500001@000?Son?ohodP8:6m822Q_n?ohooSo
9@0000`0000700209@0000`000000020900002@00000081100000000000008110000000000020000
AP000>`U003P9@00ADe6:b]0000<0000000001i01P0<0000000002501@0<0000000001i02@0<0000
000002Y0000T000060000;02;3X0000000000;02;3X004:Y003NZ2501`0<0000000002]0000<0000
000002Y0000T0000600006mF9440000000000?;/8D5HkPc5IM_>ABA0100<0000000000Q000GL9000
d2@0008@`=/200000`000<0T00010000c0000=`0001boOooR04007gmoolm7P00l:GoooDe002LYooo
84E=AP000@309000PP000080000`0000K000000000201`00/0@00:D2002W0@000000000000000000
eED:0:Ee1P1W06D0KP1U0780H@1d06D0I00P0680N@0P05L0C@1602l0A@1=04H0801R0640H`1[06D0
KP1T0200K`1V0200L01c07@0K`1U06@0J@1d0000J@1^0700M@1d0000000A0000300000H0000:0000
40000000000000004P0000`0000100005P0000`0000H0000600000`000000000DP00070100010000
>Oooo`0000000000000009010000000000020T<0C@1=04T0<@0`0000000000000000000000000000
00000000000000000000000000000000000000000000000010000<S:60000000200000L000000000
SU?HM/S:600`bQP0k;1300@000240000b<XH00000000000030000000000100008<XH000000240000
X0l0008000030000b<XH000000000000?<XH07nN@`3l2RT0P<XH0000@`040000S[E300iAMEnHLbT0
8HQ600000000000000000040001<bQP002m:00c;603PW480g[lZGokoool004<0gKE309Qc:@000000
000Y09Qc:@38bQP00@0003P07P0<0000b<XH09Qc:@010`00h78Y0040002@LbT0I7H02000000U0000
30000040001D0000E0000=`0001coOoohP0007gmool10000Zj[Q?iZIhKl^4@00JS800040001<0000
0000000000000000oooooooooom@0000IP0006@0000H000030000000000U0000300000d0080X0000
30000040001B0000L0400040000ioooo0000000000000000T040000000000082@`1=0580<@0`0000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
=`40=P`000020000<:I[0<S:600000006`0n07@1J0000000D05X05P3d@4004<0N=1Z0=3MJP000000
30000000001L0@01d=eZ060000000041E<TH08cS/WN<bQP0mG6gMiV/6`3nooooZSRcMj8d/gL00000
001Z07S@JP3;60Z50000073@JP2LbQP0RU?/MP00J0000000XEC/MW/`M5o;60Z5N=1Z0801^gG`KRT0
B03A0@00d@5XbQP0baP:QHC<6000L>ifmg62:OkooonQE>af1A:gMGS@JP1h?6/0a20Q/0002P1h?6/0
e<XH05`i]gETMP08000002D0000<00000@0005@0001D0000hP0007?moooV0000OOgoo`40002[Z^4o
VYWQ_jDA001Z<P000@0004`00000000000000000003ooooooooooe00000X0000D00001P0000<0000
000002D0000<00003@00P2P0000<00000@000580001`0@000@0003Woool0000000000000002@0@00
000000000P9304d0C@190340<0000000000000000000000000000000000000000000000000000000
000000000000000000000=3MJP0g0@0f300005C9600`YV/0S<XH0?Ea]gLK03h0M05X0000001@0FP0
F0?A0@00JP1hd6X0d=eZ0000000<0000000005`1007@gFX0H00000000@5DbAP0000008c:603eLKMg
VJ`K0?kooonZ>;=gXSBcM`00000006X0N=1Z0</H2XH00000L=1Z09c:602:Dnaf001X0000002QE>af
Nc1dGl/H2XIhd6X0P06kM@0000180=41003A0FS:603;60Z6Q<`H001`kWKgLH8Yo_oooj5Dk7H54[Me
N=1Z07PlJ`34826`000:07PlJ`3DbQP0G3VgMFAf00P000009@0000`000010000E00005@0003V0000
Logoon`0001moOoo0@000:^ZhCnJVN6ola4006Xb00010000C00000000000000000000?oooooooooo
D00007P0001h0000600000`000000000E00005@0003[0000Logoonh0001moOoo0@000:^ZhCnJVN6o
IA8006Xb00010000C00000000000000000000?ooooooooooD00003/0000l0000600000`000000000
E00005@0003`0000Logooo@0001moOoo0@000:^ZhCnJVN6o_Q8006Xb00010000C000000000000000
00000?ooooooooooD00007@0001@0000600000`0000000009@0000`0000=0020:00000`000010000
DP00070100010000>Oooo`0000000000000009010000000000020T<0C@1B0340<000000000000000
0000000000000000000000000000000000000000000000000000000000000000d=eZ03L103H<0000
E<TH032VJ`2<bQP0mG6gMa/0?P1d0FP000000501J01H0m41001Z07S@JP3@gFX0000000`000000000
G0400M3MJP1P000000010EC960000000S<XH0?Ea]gNI[1/0o_ooojXh/gNR=;=g00000000JP1hd6X0
baP:Q`00001`d6X0W<XH08YCk7H006P000000:5Dk7Ik<7AObaP:QgS@JP200K]e000004P0d@400=41
J<XH0</H2XN4c1P0073^M_MaPRWnooooXEC/MPDB]gEhd6X0N3a[0<@P8K0000X0N3a[0=C:601L>KMe
I7H02000000U000030000040001D0000E0000?<0001coOoom`0007gmool10000Zj[Q?iZIhKl54`00
JS800040001<00000000000000000000oooooooooom@0000:@000500000H000030000000001D0000
E0000?X0001coOoo0P4007gmool10000Zj[Q?iZIhKn94`00JS800040001<00000000000000000000
oooooooooom@0000?@000:00000H000030000000000U0000300000d0080X000030000040001B0000
L0400040000ioooo0000000000000000T040000000000082@`1=04d0B@0a03000000000000000000
00000000000000000000000000000000000000000000000000000000003@gFX0=`40=P`0001DbAP0
<:I[08c:603eLKMg6`0n07@1J0000000D05X05P3d@4006X0N=1Z0=3MJP00000030000000001L0@01
d=eZ060000000041E<TH0000002<bQP0mG6gMiV/6`3nooooZSRcMj8d/gL00000001Z07S@JP3;60Z8
0000073@JP2LbQP0RU?/MP00J0000000XEC/MW/`M5o;60Z8N=1Z0801^gD00000B03A0@00d@5XbQP0
baP:R8C<6000L>ifmg62:OkooonQE>af1A:gMGS@JP1h?6/0a20Q/0002P1h?6/0e<XH05`i]gETMP08
000002D0000<00000@0005@0001D00001@4007?mool:0@00OOgoo`40002[Z^4oVYWQ_e/D001Z<P00
0@0004`00000000000000000003ooooooooooe00001Q0000I00001P0000<0000000002D0000<0000
3@00P2P0000<00000@000580001`0@000@0003Woool0000000000000002@0@00000000000P9304d0
DP0a0300000000000000000000000000000000000000000000000000000000000000000000000000
00000=3MJP0g0@0f300005C9600`YV/0S<XH0?Ea]gLK03h0M05X0000001@0FP0F0?A0@00JP1hd6X0
d=eZ0000000<0000000005`1007@gFX0H00000000@5DbAP0000008c:603eLKMgVJ`K0?kooonZ>;=g
XSBcM`00000006X0N=1Z0</H2XT00000L=1Z09c:602:Dnaf001X0000002QE>afNc1dGl/H2XUhd6X0
P06kM@0000180=41003A0FS:603;60Z9Q<`H001`kWKgLH8Yo_oooj5Dk7H54[MeN=1Z07PlJ`34826`
000:07PlJ`3DbQP0G3VgMFAf00P000009@0000`000010000E00005@0000<0@00Logoo`l1001moOoo
0@000:^ZhCnJVN6oia@006Xb00010000C00000000000000000000?ooooooooooD00005/0000l0000
600000`000000000E00005@0000>0@00Logooa81001moOoo0@000:^ZhCnJVN6o7QD006Xb00010000
C00000000000000000000?ooooooooooD00007<0001@0000600000`000000000E00005@0000B0@00
LogooaD1001moOoo0@000:^ZhCnJVN6oK1D006Xb00010000C00000000000000000000?oooooooooo
D00006T0000l0000600000`000000000E00005@0000E0@00Logooa/1001moOoo0@000:^ZhCnJVN6o
XaD006Xb00010000C00000000000000000000?ooooooooooD00006h0001h0000600000`000000000
E00005@0000K0@00Logooal1001moOoo0@000:^ZhCnJVN6o4QH006Xb00010000C000000000000000
00000?ooooooooooD00002P0001@0000600000`0000000009@0000`0000=0020:00000`000010000
DP00070100010000>Oooo`0000000000000009010000000000020T<0C@1=04T0<@0`000000000000
0000000000000000000000000000000000000000000000000000000000000000d=eZ03L103H<0000
E<TH032VJ`2<bQP0mG6gMa/0?P1d0FP000000501J01H0m41001Z07S@JP3@gFX0000000`000000000
G0400M3MJP1P000000010EC960000000S<XH0?Ea]gNI[1/0o_ooojXh/gNR=;=g00000000JP1hd6X0
baP:RP00001`d6X0W<XH08YCk7H006P000000:5Dk7Ik<7AObaP:RWS@JP200K]e000004P0d@400=41
J<XH0</H2XZ4c1P0073^M_MaPRWnooooXEC/MPDB]gEhd6X0N3a[0<@P8K0000X0N3a[0=C:601L>KMe
I7H02000000U000030000040001D0000E00001h1001coOoo8`4007gmool10000Zj[Q?iZIhKmP5P00
JS800040001<00000000000000000000oooooooooom@0000^P0006@0000H000030000000001D0000
E00002@1001coOoo:04007gmool10000Zj[Q?iZIhKo@5P00JS800040001<00000000000000000000
oooooooooom@0000M0000500000H000030000000000U0000300000d0080X000030000040001B0000
L0400040000ioooo0000000000000000T040000000000082@`1=0580<@0`00000000000000000000
00000000000000000000000000000000000000000000000000000000003@gFX0=`40=P`0001DbAP0
<:I[08c:603eLKMg6`0n07@1J0000000D05X05P3d@4006X0N=1Z0=3MJP00000030000000001L0@01
d=eZ060000000041E<TH0000002<bQP0mG6gMiV/6`3nooooZSRcMj8d/gL00000001Z07S@JP3;60Z;
0000073@JP2LbQP0RU?/MP00J0000000XEC/MW/`M5o;60Z;N=1Z0801^gD00000B03A0@00d@5XbQP0
baP:RhC<6000L>ifmg62:OkooonQE>af1A:gMGS@JP1h?6/0a20Q/0002P1h?6/0e<XH05`i]gETMP08
000002D0000<00000@0005@0001D0000:04007?mool/0@00OOgoo`40002[Z^4oVYWQ_aPG001Z<P00
0@0004`00000000000000000003ooooooooooe00000Y0000D00001P0000<0000000005@0001D0000
;P4007?moolf0@00OOgoo`40002[Z^4oVYWQ_i0G001Z<P000@0004`00000000000000000003ooooo
oooooe00000[0000X00001P0000<0000000002D0000<00003@00P2P0000<00000@000580001`0@00
0@0003Woool0000000000000002@0@00000000000P9304d0C@190340<00000000000000000000000
00000000000000000000000000000000000000000000000000000=3MJP0g0@0f300005C9600`YV/0
S<XH0?Ea]gLK03h0M05X0000001@0FP0F0?A0@00JP1hd6X0d=eZ0000000<0000000005`1007@gFX0
H00000000@5DbAP0000008c:603eLKMgVJ`K0?kooonZ>;=gXSBcM`00000006X0N=1Z0</H2X`00000
L=1Z09c:602:Dnaf001X0000002QE>afNc1dGl/H2Xahd6X0P06kM@0000180=41003A0FS:603;60Z<
Q<`H001`kWKgLH8Yo_oooj5Dk7H54[MeN=1Z07PlJ`34826`000:07PlJ`3DbQP0G3VgMFAf00P00000
9@0000`000010000E00005@0000h0@00Logoocd1001moOoo0@000:^ZhCnJVN6oEaP006Xb00010000
C00000000000000000000?ooooooooooD0000;X0001T0000600000`0000000009@0000`0000=0020
:00000`000010000DP00070100010000MOooo`0000000000000009010000000000020T<0C@1=04T0
=`000000000000000000000000000000000000000000000000000000000000000000000000000000
d=eZ03L103H<0000E<TH032VJ`2<bQP0mG6gMa/0?P1d0FP000000501J01H0m41001Z07S@JP3@gFX0
000000`000000000G0400M3MJP1P000000010EC960000000S<XH0?Ea]gNI[1/0o_ooojXh/gNR=;=g
00000000JP1hd6X0baP:S@00001`d6X0W<XH08YCk7H006P000000:5Dk7Ik<7AObaP:SGS@JP200K]e
000004P0d@400=41J<XH0</H2Xf4c1P0073^M_MaPRWnooooXEC/MPDB]gEhd6X0N3a[0<@P8K0000X0
N3a[0=C:601L>KMeI7H02000000U000030000040001D0000E00003d1001boOoo@@4007Smool10000
Zj[Q?iZIhKo76000_3800040001<00000000000000000000oooooooooom@0000/0000500000H0000
30000000000U0000300000d0080X000030000040001B0000L0400040000ioooo0000000000000000
T040000000000082@`1=0580<@0`0000000000000000000000000000000000000000000000000000
000000000000000000000000003@gFX0=`40=P`0001DbAP0<:I[08c:603eLKMg6`0n07@1J0000000
D05X05P3d@4006X0N=1Z0=3MJP00000030000000001L0@01d=eZ060000000041E<TH0000002<bQP0
mG6gMiV/6`3nooooZSRcMj8d/gL00000001Z07S@JP3;60Z>0000073@JP2LbQP0RU?/MP00J0000000
XEC/MW/`M5o;60Z>N=1Z0801^gFT?;=gdcbcM`00/GMXbQP0baP:SXC<6000L>ifmg62:OkooonQE>af
1A:gMGS@JP1h?6/0a20Q/0002P1h?6/0e<XH05`i]gETMP08000002D0000<00000@0005@0001D0000
A04007?moom80@00OOgoo`40002[Z^4oVYWQ_dlI001Z<P000@0004`00000000000000000003ooooo
oooooe00001c0000D00001P0000<0000000005@0001D0000B04007?moom;0@00OOgoo`40002[Z^4o
VYWQ_idI001Z<P000@0004`00000000000000000003ooooooooooe00001Y0000?00001P0000<0000
000005@0001D0000B`4007?moomA0@00OOgoo`40002[Z^4oVYWQ_m@I001Z<P000@0004`000000000
00000000003ooooooooooe00001^0000N00001P0000<0000000005@0001D0000DP4007?moomF0@00
OOgoo`40002[Z^4oVYWQ_f@J001Z<P000@0004`00000000000000000003ooooooooooe00000X0000
D00001P0000<0000000002D0000<00003@00P2P0000<00000@000580001`0@000@0003Woool00000
00000000002@0@00000000000P9304d0C@190340<000000000000000000000000000000000000000
0000000000000000000000000000000000000=3MJP0g0@0f300005C9600`YV/0S<XH0?Ea]gLK03h0
M05X0000001@0FP0F0?A0@00JP1hd6X0d=eZ0000000<0000000005`1007@gFX0H00000000@5DbAP0
000008c:603eLKMgVJ`K0?kooonZ>;=gXSBcM`00000006X0N=1Z0</H2Xl00000L=1Z09c:602:Dnaf
001X0000002QE>afNc1dGl/H2Xmhd6X0P06kM@00003C?;=g002aMfS:603;60Z?Q<`H001`kWKgLH8Y
o_oooj5Dk7H54[MeN=1Z07PlJ`34826`000:07PlJ`3DbQP0G3VgMFAf00P000009@0000`000010000
E00005@0001F0@00Logooe/1001moOoo0@000:^ZhCnJVN6o/QX006Xb00010000C000000000000000
00000?ooooooooooD0000;X0001T0000600000`000000000E00005@0001K0@00Logooel1001moOoo
0@000:^ZhCnJVN6o8A/006Xb00010000C00000000000000000000?ooooooooooD00007@0001@0000
600000`0000000009@0000`0000=0020:00000`000010000DP00070100010000>Oooo`0000000000
000009010000000000020T<0C@1B0340<00000000000000000000000000000000000000000000000
00000000000000000000000000000000d=eZ03L103H<0000E<TH032VJ`2<bQP0mG6gMa/0?P1d0FP0
00000501J01H0m41001Z07S@JP3@gFX0000000`000000000G0400M3MJP1P000000010EC960000000
S<XH0?Ea]gNI[1/0o_ooojXh/gNR=;=g00000000JP1hd6X0baP:T000001`d6X0W<XH08YCk7H006P0
00000:5Dk7Ik<7AObaP:T7S@JP200K]e00000=<l/gL00;5gJ<XH0</H2Y24c1P0073^M_MaPRWnoooo
XEC/MPDB]gEhd6X0N3a[0<@P8K0000X0N3a[0=C:601L>KMeI7H02000000U000030000040001D0000
E0000641001coOooJ@4007gmool10000Zj[Q?iZIhKnD6`00JS800040001<00000000000000000000
oooooooooom@0000:`000:00000H000030000000000U0000300000d0080X000030000040001B0000
L0400040000ioooo0000000000000000T040000000000082@`1=04d0B@0a03000000000000000000
00000000000000000000000000000000000000000000000000000000003@gFX0=`40=P`0001DbAP0
<:I[08c:603eLKMg6`0n07@1J0000000D05X05P3d@4006X0N=1Z0=3MJP00000030000000001L0@01
d=eZ060000000041E<TH0000002<bQP0mG6gMiV/6`3nooooZSRcMj8d/gL00000001Z07S@JP3;60ZA
0000073@JP2LbQP0RU?/MP00J0000000XEC/MW/`M5o;60ZAN=1Z0801^gD00000dcbcM`00/GMXbQP0
baP:THC<6000L>ifmg62:OkooonQE>af1A:gMGS@JP1h?6/0a20Q/0002P1h?6/0e<XH05`i]gETMP08
000002D0000<00000@0005@0001D0000J`4007?moom`0@00OOgoo`40002[Z^4oVYWQ_e`L001Z<P00
0@0004`00000000000000000003ooooooooooe00002`0000I00001P0000<0000000005@0001D0000
L@4007?moomg0@00OOgoo`40002[Z^4oVYWQ_ldL001Z<P000@0004`00000000000000000003ooooo
oooooe00002l0000N00001P0000<0000000005@0001D0000M`4007?mooml0@00OOgoo`40002[Z^4o
VYWQ_dHM001Z<P000@0004`00000000000000000003ooooooooooe00000m0000I00001P0000<0000
000002D0000<00003@00P2P0000<00000@000580001`0@000@0003Woool0000000000000002@0@00
000000000P9304d0DP0a030000000000000000000000000000000000000000000000000000000000
000000000000000000000=3MJP0g0@0f300005C9600`YV/0S<XH0?Ea]gLK03h0M05X0000001@0FP0
F0?A0@00JP1hd6X0d=eZ0000000<0000000005`1007@gFX0H00000000@5DbAP0000008c:603eLKMg
VJ`K0?kooonZ>;=gXSBcM`00000006X0N=1Z0</H2Y800000L=1Z09c:602:Dnaf001X0000002QE>af
Nc1dGl/H2Y9hd6X0P06kM@00003C?;=g002aMfS:603;60ZBQ<`H001`kWKgLH8Yo_oooj5Dk7H54[Me
N=1Z07PlJ`34826`000:07PlJ`3DbQP0G3VgMFAf00P000009@0000`000010000E00005@0001l0@00
Logooh41001moOoo0@000:^ZhCnJVN6oZQd006Xb00010000C00000000000000000000?oooooooooo
D0000380001T0000600000`000000000E00005@000210@00LogoohD1001moOoo0@000:^ZhCnJVN6o
3Ah006Xb00010000C00000000000000000000?ooooooooooD00002T0001@0000600000`000000000
E00005@000250@00LogoohP1001moOoo0@000:^ZhCnJVN6oFah006Xb00010000C000000000000000
00000?ooooooooooD00005d0000l00009@0000`0000=0020:00000`0000100003P0001@000000000
400001@00008@048900001P000024<3K0@0000<00000000000000000000K@000@00003@000010000
0P000;F9Fd>9Q2?4Dc@]@o]4DT430000]HUK@hV48l@4GlA3RH@Sa;F9Fd=f>b348@0000P0001R0000
30000040000Q00002000024000080000L`0000`000000000700000P0000U000030000000080U0000
300000L0080U0000300000h0080I000030000?ooo`0H000030000000000B000030000080000C0000
30000040000D0000300000d0000E000030000040000F000030000000000=00004000000000000000
>P0000`0000:00006`00010000000000000002<0000P0000l38U@@0000000000Y?4]@G>[3LGD=Mi5
900002@0003`<RE100000000002TlBe1Lj/=aM@egTD40000L`0000`0000000003@00010000000000
00000580001`0@000P0001000007000000000000002l0P00000000L20R9C07T0L`1d06D0K@0001<0
X?Sooo8100000000?=dn0X3hool805QnnoKoo`00000000008=dn0X3hooooo`00001[1aR@LP000020
4=4c01_fC3e4dS<0N2Ug1lT//gNa827_8P2:0AP00000000029aW1`P0003?ZBA10037?HR3=`800000
`=`b0V3><`00000000000000003oooooe=4c003B<`3`g3<0mG6gMjmi4@3nooooS>>bMo;P/WL00;X8
>?`00080000000008000033B<`1DdS<0jeS/MP00LP0801@09U[/MZ3XMF40000029aW1oooool30000
00000000000000007=8c08YeJfiPfC<0073^M[baZ1Onoooo9U[/MV8C]gEHUV/70@0008SB<`2<dS<0
;c2gMFAf00P000009@0000`000020000AP0008P0001l0000AdA9@`80003L0000L_goohP1001noOoo
<00006L0I@1^06D0LP1Q07@0I@1T0200HP1i0200E`1=04H0;`1504d0AP0P0680H@1S06/0I@1^06@0
801_06H0801`07<0M01_06D0I01Y07@0001Y06h0L01e07@0000002<0000P0000P3T4?`0000000000
l4<;_g>[3LGD=Mi5900002@00020>@@o00000000003`@`^oLj/=aM@egTD400008`0002000020>@@o
00000000003`@`^oLj/=aM@egTDT00009000080i13l0000000000?132kmcZ`g5e3GNA@@0000B0000
30000040000F0000300001P0000H000030000000001B0000L04000<0000ioooo0000000000000000
T040000000070082@`1=04d0B@0a0300000000000000000000000000000000000000000000000000
00000000000000000000000000040000b<XH0000000800001`000000002>DmQfb<XH033:603//4<0
100008@00038bQP000000000000<000000000040000PbQP0000008@0002P3`000P0000<00038bQP0
00000000000lbQP0Oii30?`::@20bQP0001300@0002>]D<03U5eGiQc:@0QR4H00000000000000000
0@0004c:6000;dX03</H0>2L@P3N_bYOo_ooo`00@`3M]D<0V7<Y0000000002T0V7<Y0<S:60010000
>00N00`00038bQP0V7<Y0043003PLRT00@00091c:@1TMP08000002D0000<00000`0005@0001D0000
1@0000T0000n0000M0000040002[Z^4oVYWQ_bhA001Z<P000@0004`00000000000000000003ooooo
oooooe00001V0000I00001P0000<000000000580001`0@00100001@00009000000000000002l0P00
000000L20R9C07T0L`1d06D0K@00000000000>8000000000K;A/0X3hool000000000000000000000
D;A/0X3hoonjUP00002gMKMT]gFa827_0000000000010000Z1=W2HcA<`1QI;Me/B0Qk`0000000000
E0000000002X4fL91=8c0=iA]gFa827_n>ES1`80001`]VL3E000000000010000>00N00`00038bQP0
V7<Y0043003PLRT00@00091c:@00000800000<3L<P9PcS<01=8c02l`]gD4dS<0IS2gMLP6J0T8W6L7
9@0000002P0l;P00>=<c01gjIfja827_001S1jPCI`T20000L;IW0k8:J6jH1[]e000009P6^gF00K]e
g0IX2EcB<`0_<;MeG=8c06H`]gDX1fP929aW1fAf00P000009@0000`000040000:00000`000030000
DP00070100030000>Oooo`000000000000000901000000001`020T<0C@1B0340<000000000000000
0000000000000000000000000000000000000000000000000000000000000000000003L103H<0000
0P00032VJ`38bQP0000001/0?P1d0FP000000501J01H0m41001307S@JP3@gFX0000000`000000000
G0400M3MJP1P000000010EC9602<hk9gS<XH0?Ea]gNI[1/0o_ooojXh/gNR=;=g00000000JP1hd6X0
baP:Q@00001`d6X0W<XH08YCk7H006P000000:5Dk7Ik<7AObaP:QGS@JP200K]el6hY04P0d@400=41
J<XH0</H2XF4c1P0073^M_MaPRWnooooXEC/MPDB]gEhd6X0N3a[0<@P8K0000X0N3a[0=C:601L>KMe
I7H02000000U0000300000<0001D0000E000048000090000K00007@000010000Zj[Q?iZIhKnU4@00
JS800040001<00000000000000000000oooooooooom@0000:0000500000H000030000000000U0000
300000@0000X0000300000<0001B0000L04000<0000ioooo0000000000000000T040000000070082
@`1=04d0B@0a03000000000000000000000000000000000000000000000000000000000000000000
00000000003@gFX0=`40=P`0001DbAP0<:I[08c:603eLKMg6`0n07@1J0000000D05X05P3d@4006X0
N=1Z0=3MJP00000030000000001L0@01d=eZ060000000041E<TH0000002<bQP0mG6gMiV/6`3noooo
ZSRcMj8d/gL00000001Z07S@JP3;60Z60000073@JP2LbQP0RU?/MP00J0000000XEC/MW/`M5o;60Z6
N=1Z0801^gD00000B03A0@00d@5XbQP0baP:QXC<6000L>ifmg62:OkooonQE>af1A:gMGS@JP1h?6/0
a20Q/0002P1h?6/0e<XH05`i]gETMP08000002D0000<00000`0005@0001D0000J`0000T0002Y0000
M0000040002[Z^4oVYWQ_o<A001Z<P000@0004`00000000000000000003ooooooooooe00001h01P0
N00001P0000<0000000005@0001D0000YP0000T000350000M0000040002[Z^4oVYWQ_fDB001Z<P00
0@0004`00000000000000000003ooooooooooe00000k0>41?00001P0000<0000000005@0001D0000
e00000T0003n0000M0000040002[Z^4oVYWQ_khB001Z<P000@0004`00000000000000000003ooooo
oooooe00001d0000D00001P0000<0000000002D0000<0000100002P0000<00000`000580001`0@00
0`0003Woool0000000000000002@0@00000000L00P9304d0DP0a0300000000000000000000000000
00000000000000000000000000000000000000000000000000000=3MJP0g0@0f300005C9600`YV/0
S<XH0?Ea]gLK03h0M05X0000001@0FP0F0?A0@00JP1hd6X0d=eZ0000000<0000000005`1007@gFX0
H00000000@5DbAP0000008c:603eLKMgVJ`K0?kooonZ>;=gXSBcM`00000006X0N=1Z0</H2XL00000
L=1Z09c:602:Dnaf001X0000002QE>afNc1dGl/H2XMhd6X0P06kM@0000180=41003A0FS:603;60Z7
Q<`H001`kWKgLH8Yo_oooj5Dk7H54[MeN=1Z07PlJ`34826`000:07PlJ`3DbQP0G3VgMFAf00P00000
9@0000`000030000E00005@0003h00002@000281001d00000@000:^ZhCnJVN6o1A<006Xb00010000
C00000000000000000000?ooooooooooD00002T0601@0000600000`000000000E00005@0000l0@00
2@0008l1001d00000@000:^ZhCnJVN6oRA<006Xb00010000C00000000000000000000?oooooooooo
D00003d0h@6P0000600000`0000000009@0000`000040000:00000`000030000DP00070100030000
>Oooo`000000000000000901000000001`020T<0C@1=04T0<@0`0000000000000000000000000000
000000000000000000000000000000000000000000000000d=eZ03L103H<0000E<TH032VJ`2<bQP0
mG6gMa/0?P1d0FP000000501J01H0m41001Z07S@JP3@gFX0000000`000000000G0400M3MJP1P0000
00010EC960000000S<XH0?Ea]gNI[1/0o_ooojXh/gNR=;=g00000000JP1hd6X0baP:R000001`d6X0
W<XH08YCk7H006P000000:5Dk7Ik<7AObaP:R7S@JP200K]e000004P0d@400=41J<XH0</H2XR4c1P0
073^M_MaPRWnooooXEC/MPDB]gEhd6X0N3a[0<@P8K0000X0N3a[0=C:601L>KMeI7H02000000U0000
300000<0001D0000E0000:T100090000g@4007@000010000Zj[Q?iZIhKmK5000JS800040001<0000
0000000000000000oooooooooom@0000H@3Q0F@0000H000030000000000U0000300000@0000X0000
300000<0001B0000L04000<0000ioooo0000000000000000T040000000070082@`1=0580<@0`0000
000000000000000000000000000000000000000000000000000000000000000000000000003@gFX0
=`40=P`0001DbAP0<:I[08c:603eLKMg6`0n07@1J0000000D05X05P3d@4006X0N=1Z0=3MJP000000
30000000001L0@01d=eZ060000000041E<TH0000002<bQP0mG6gMiV/6`3nooooZSRcMj8d/gL00000
001Z07S@JP3;60Z90000073@JP2LbQP0RU?/MP00J0000000XEC/MW/`M5o;60Z9N=1Z0801^gD00000
B03A0@00d@5XbQP0baP:RHC<6000L>ifmg62:OkooonQE>af1A:gMGS@JP1h?6/0a20Q/0002P1h?6/0
e<XH05`i]gETMP08000002D0000<00000`0005@0001D0000l@4000T0000@0P00M0000040002[Z^4o
VYWQ_nLD001Z<P000@0004`00000000000000000003ooooooooooe00001K0>41?00001P0000<0000
000005@0001D00003P8000T0000h0P00M0000040002[Z^4oVYWQ_ahE001Z<P000@0004`000000000
00000000003ooooooooooe00001c0000D00001P0000<0000000005@0001D0000=P8000T0001E0P00
M0000040002[Z^4oVYWQ_f`E001Z<P000@0004`00000000000000000003ooooooooooe00001Y0020
?00001P0000<0000000005@0001D0000DP8000T0002@0P00M0000040002[Z^4oVYWQ_j<E001Z<P00
0@0004`00000000000000000003ooooooooooe00001^0000N00001P0000<0000000005@0001D0000
S08000T0002f0P00M0000040002[Z^4oVYWQ_a8F001Z<P000@0004`00000000000000000003ooooo
oooooe00000X0000D00001P0000<0000000002D0000<0000100002P0000<00000`000580001`0@00
0`0003Woool0000000000000002@0@00000000L00P9304d0C@190340<00000000000000000000000
00000000000000000000000000000000000000000000000000000=3MJP0g0@0f300005C9600`YV/0
S<XH0?Ea]gLK03h0M05X0000001@0FP0F0?A0@00JP1hd6X0d=eZ0000000<0000000005`1007@gFX0
H00000000@5DbAP0000008c:603eLKMgVJ`K0?kooonZ>;=gXSBcM`00000006X0N=1Z0</H2XX00000
L=1Z09c:602:Dnaf001X0000002QE>afNc1dGl/H2XYhd6X0P06kM@0000180=41003A0FS:603;60Z:
Q<`H001`kWKgLH8Yo_oooj5Dk7H54[MeN=1Z07PlJ`34826`000:07PlJ`3DbQP0G3VgMFAf00P00000
9@0000`000030000E00005@0002d0P002@000>X2001d00000@000:^ZhCnJVN6oH1H006Xb00010000
C00000000000000000000?ooooooooooD0000;X0001T0000600000`000000000E00005@0003^0P00
2@0001P3001d00000@000:^ZhCnJVN6od1H006Xb00010000C00000000000000000000?oooooooooo
D00007@0]Fa@0000600000`0000000009@0000`000040000:00000`000030000DP00070100030000
>Oooo`000000000000000901000000001`020T<0C@1B0340<0000000000000000000000000000000
000000000000000000000000000000000000000000000000d=eZ03L103H<0000E<TH032VJ`2<bQP0
mG6gMa/0?P1d0FP000000501J01H0m41001Z07S@JP3@gFX0000000`000000000G0400M3MJP1P0000
00010EC960000000S<XH0?Ea]gNI[1/0o_ooojXh/gNR=;=g00000000JP1hd6X0baP:R`00001`d6X0
W<XH08YCk7H006P000000:5Dk7Ik<7AObaP:RgS@JP200K]e000004P0d@400=41J<XH0</H2X^4c1P0
073^M_MaPRWnooooXEC/MPDB]gEhd6X0N3a[0<@P8K0000X0N3a[0=C:601L>KMeI7H02000000U0000
300000<0001D0000E00001<300090000?@<007@000010000Zj[Q?iZIhKlH5`00JS800040001<0000
0000000000000000oooooooooom@0000:@000500000H000030000000001D0000E000054300090000
Y0<007@000010000Zj[Q?iZIhKn@5`00JS800040001<00000000000000000000oooooooooom@0000
:`000:00000H000030000000000U0000300000@0000X0000300000<0001B0000L04000<0000ioooo
0000000000000000T040000000070082@`1=04d0B@0a030000000000000000000000000000000000
0000000000000000000000000000000000000000003@gFX0=`40=P`0001DbAP0<:I[08c:603eLKMg
6`0n07@1J0000000D05X05P3d@4006X0N=1Z0=3MJP00000030000000001L0@01d=eZ060000000041
E<TH0000002<bQP0mG6gMiV/6`3nooooZSRcMj8d/gL00000001Z07S@JP3;60Z<0000073@JP2LbQP0
RU?/MP00J0000000XEC/MW/`M5o;60Z<N=1Z0801^gD00000B03A0@00d@5XbQP0baP:S8C<6000L>if
mg62:OkooonQE>af1A:gMGS@JP1h?6/0a20Q/0002P1h?6/0e<XH05`i]gETMP08000002D0000<0000
0`0005@0001D0000^0<000T0003^0`00M0000040002[Z^4oVYWQ_eLH001Z<P000@0004`000000000
00000000003ooooooooooe00002j03L2I00001P0000<0000000002D0000<0000100002P0000<0000
0`000580001`0@000`0007Goool0000000000000002@0@00000000L00P9304d0C@1903L000000000
000000000000000000000000000000000000000000000000000000000000000000000=3MJP0g0@0f
300005C9600`YV/0S<XH0?Ea]gLK03h0M05X0000001@0FP0F0?A0@00JP1hd6X0d=eZ0000000<0000
000005`1007@gFX0H00000000@5DbAP0000008c:603eLKMgVJ`K0?kooonZ>;=gXSBcM`00000006X0
N=1Z0</H2Xd00000L=1Z09c:602:Dnaf001X0000002QE>afNc1dGl/H2Xehd6X0P06kM@0000180=41
003A0FS:603;60Z=Q<`H001`kWKgLH8Yo_oooj5Dk7H54[MeN=1Z07PlJ`34826`000:07PlJ`3DbQP0
G3VgMFAf00P000009@0000`000030000E00005@0003b0`00m?oooah4000o00000@000:^ZhCnJVN6o
aaP00;`b00010000C00000000000000000000?ooooooooooD0000;0000Q@0000600000`000000000
9@0000`000040000:00000`000030000DP00070100030000>Oooo`00000000000000090100000000
1`020T<0C@1B0340<000000000000000000000000000000000000000000000000000000000000000
0000000000000000d=eZ03L103H<0000E<TH032VJ`2<bQP0mG6gMa/0?P1d0FP000000501J01H0m41
001Z07S@JP3@gFX0000000`000000000G0400M3MJP1P000000010EC960000000S<XH0?Ea]gNI[1/0
o_ooojXh/gNR=;=g00000000JP1hd6X0baP:SP00001`d6X0W<XH08YCk7H006P000000:5Dk7Ik<7AO
baP:SWS@JP200K]eY3bcMm<l/gL00;5gJ<XH0</H2Xj4c1P0073^M_MaPRWnooooXEC/MPDB]gEhd6X0
N3a[0<@P8K0000X0N3a[0=C:601L>KMeI7H02000000U0000300000<0001D0000E00003P400090000
HP@007@000010000Zj[Q?iZIhKm?6@00JS800040001<00000000000000000000oooooooooom@0000
L`000500000H000030000000001D0000E000060400090000O`@007@000010000Zj[Q?iZIhKnM6@00
JS800040001<00000000000000000000oooooooooom@0000J@0003`0000H000030000000001D0000
E00007`400090000^P@007@000010000Zj[Q?iZIhKoD6@00JS800040001<00000000000000000000
oooooooooom@0000KP2Z07P0000H000030000000001D0000E0000<L400090000l@@007@000010000
Zj[Q?iZIhKmT6P00JS800040001<00000000000000000000oooooooooom@0000:0000500000H0000
30000000000U0000300000@0000X0000300000<0001B0000L04000<0000ioooo0000000000000000
T040000000070082@`1=04d0B@0a0300000000000000000000000000000000000000000000000000
000000000000000000000000003@gFX0=`40=P`0001DbAP0<:I[08c:603eLKMg6`0n07@1J0000000
D05X05P3d@4006X0N=1Z0=3MJP00000030000000001L0@01d=eZ060000000041E<TH0000002<bQP0
mG6gMiV/6`3nooooZSRcMj8d/gL00000001Z07S@JP3;60Z?0000073@JP2LbQP0RU?/MP00J0000000
XEC/MW/`M5o;60Z?N=1Z0801^gD00000dcbcM`00/GMXbQP0baP:ShC<6000L>ifmg62:OkooonQE>af
1A:gMGS@JP1h?6/0a20Q/0002P1h?6/0e<XH05`i]gETMP08000002D0000<00000`0005@0001D0000
k`@000T0000U1@00M0000040002[Z^4oVYWQ_k8J001Z<P000@0004`00000000000000000003ooooo
oooooe00002j0000I00001P0000<0000000005@0001D0000:0D000T0001B1@00M0000040002[Z^4o
VYWQ_b4K001Z<P000@0004`00000000000000000003ooooooooooe00001d0000D00001P0000<0000
000002D0000<0000100002P0000<00000`000580001`0@000`0003Woool0000000000000002@0@00
000000L00P9304d0DP0a030000000000000000000000000000000000000000000000000000000000
000000000000000000000=3MJP0g0@0f300005C9600`YV/0S<XH0?Ea]gLK03h0M05X0000001@0FP0
F0?A0@00JP1hd6X0d=eZ0000000<0000000005`1007@gFX0H00000000@5DbAP0000008c:603eLKMg
VJ`K0?kooonZ>;=gXSBcM`00000006X0N=1Z0</H2Y000000L=1Z09c:602:Dnaf001X0000002QE>af
Nc1dGl/H2Y1hd6X0P06kM@00003C?;=g002aMfS:603;60Z@Q<`H001`kWKgLH8Yo_oooj5Dk7H54[Me
N=1Z07PlJ`34826`000:07PlJ`3DbQP0G3VgMFAf00P000009@0000`000030000E00005@0001T1@00
2@000;L5001d00000@000:^ZhCnJVN6oU1/006Xb00010000C00000000000000000000?oooooooooo
D00002/0002P0000600000`0000000009@0000`000040000:00000`000030000DP00070100030000
>Oooo`000000000000000901000000001`020T<0C@1=04T0<@0`0000000000000000000000000000
000000000000000000000000000000000000000000000000d=eZ03L103H<0000E<TH032VJ`2<bQP0
mG6gMa/0?P1d0FP000000501J01H0m41001Z07S@JP3@gFX0000000`000000000G0400M3MJP1P0000
00010EC960000000S<XH0?Ea]gNI[1/0o_ooojXh/gNR=;=g00000000JP1hd6X0baP:T@00001`d6X0
W<XH08YCk7H006P000000:5Dk7Ik<7AObaP:TGS@JP200K]e00000=<l/gL00;5gJ<XH0</H2Y64c1P0
073^M_MaPRWnooooXEC/MPDB]gEhd6X0N3a[0<@P8K0000X0N3a[0=C:601L>KMeI7H02000000U0000
300000<0001D0000E0000</5000900000`H007@000010000Zj[Q?iZIhKmL7000JS800040001<0000
0000000000000000oooooooooom@0000/02eK6@0000H000030000000001D0000E00000H600090000
A0H007@000010000Zj[Q?iZIhKo=7000JS800040001<00000000000000000000oooooooooom@0000
_00007P0000H000030000000001D0000E00004@600090000N0H007@000010000Zj[Q?iZIhKm67@00
JS800040001<00000000000000000000oooooooooom@0000?@0006@0000H000030000000000U0000
300000@0000X0000300000<0001B0000L04000<0000ioooo0000000000000000T040000000070082
@`1=0580<@0`00000000000000000000000000000000000000000000000000000000000000000000
00000000003@gFX0=`40=P`0001DbAP0<:I[08c:603eLKMg6`0n07@1J0000000D05X05P3d@4006X0
N=1Z0=3MJP00000030000000001L0@01d=eZ060000000041E<TH0000002<bQP0mG6gMiV/6`3noooo
ZSRcMj8d/gL00000001Z07S@JP3;60ZB0000073@JP2LbQP0RU?/MP00J0000000XEC/MW/`M5o;60ZB
N=1Z0801^gD00000dcbcM`00/GMXbQP0baP:TXC<6000L>ifmg62:OkooonQE>af1A:gMGS@JP1h?6/0
a20Q/0002P1h?6/0e<XH05`i]gETMP08000002D0000<00000`0005@0001D0000N0H000T0002/1P00
M0000040002[Z^4oVYWQ_jXM001Z<P000@0004`00000000000000000003ooooooooooe00000b0000
I00001P0000<0000000005@0001D0000Z`H000T0003E1P00M0000040002[Z^4oVYWQ_`dN001Z<P00
0@0004`00000000000000000003ooooooooooe00000Y0000D00001P0000<0000000005@0001D0000
d`H000T0003b1P00M0000040002[Z^4oVYWQ_e/N001Z<P000@0004`00000000000000000003ooooo
oooooe00001M0340?00002D0000<0000100002P0000<00000`0004H0000D0000200004M4BD<30000
8P0000`0003ooooo8P0000`0003ooooo9@0000`0000=0020:00000`000020000:00000`000040000
8P0000`0003oooooAP000<01002d0@00ADe6:ba0000T000060000000P3l0000000000000P3l00020
0000P2Y0000T0000600006mF9440000000000?;/8D5HkPc5IM_>ABA0000<0000000002Y0000T0000
60000;02;3X0000000000;02;3X004:Y003NZ2]0000<0000000001i01P0<0000000002501@0<0000
000000Q00P@H00003000008@`=/000000`0043A00P0<0000000001i02@0<0000000002Y0000T0000
60000;02;3X0000000000;02;3X004:Y003NZ2501`0<0000000002Y0000T000060000;02;3X00000
00000;02;3X004:Y003NZ2]0000<0000000002]0000<0000000001i01P0<0000000002501@0<0000
000000Q00`@H00003000008@`=/000000`0043A00`0<0000000001i02@0<0000000002Y0000T0000
60000000P3l0000000000000P3l00000000002501`0<0000000004`0001T000000000000003b1P00
Q000000000000000l`H008D0000Y0:X0000000000000080o000000000000080o0000000000000000
000000000000000000000000000R000030000?oooom60000700001000015CDH[0T0000`000000000
3P0001@000000000400001@0
\>"], "Graphics",
  GeneratedCell->False,
  CellAutoOverwrite->False,
  ImageSize->{261.9736842105263, 19.18680504077094},
  ImageMargins->{{1.25, 0.}, {0., 8.026315789473683}}]
}], "Text",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 CellChangeTimes->{{3.561126817421*^9, 3.5611268309564*^9}, {
  3.636904881452074*^9, 3.636904980035713*^9}, {3.6369050699238544`*^9, 
  3.6369050775552907`*^9}, {3.6369769775634212`*^9, 3.6369769906991725`*^9}, {
  3.6371385049577384`*^9, 3.6371385138497543`*^9}, {3.637245196685347*^9, 
  3.637245198101428*^9}, {3.6373032697103*^9, 3.6373032726043*^9}, {
  3.6373033181033*^9, 3.6373033255663*^9}, {3.6386021292506*^9, 
  3.6386021297026*^9}},
 Background->RGBColor[1, 1, 0]],

Cell[BoxData[
 RowBox[{
  RowBox[{"funSource", "[", 
   RowBox[{"x_", ",", "t_", ",", "ga_"}], "]"}], ":=", 
  RowBox[{"aParameter", "*", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"nu", "^", "ga"}], "*", 
      RowBox[{"Sin", "[", 
       RowBox[{
        RowBox[{"nu", "*", "t"}], "+", 
        RowBox[{"ga", "*", 
         RowBox[{"Pi", "/", "2"}]}]}], "]"}]}], "+", 
     RowBox[{"Sin", "[", 
      RowBox[{"nu", "*", "t"}], "]"}]}], ")"}], "*", " ", 
   RowBox[{"Sin", "[", "x", "]"}]}]}]], "Input",
 CellChangeTimes->{{3.591431994688729*^9, 3.5914321084812374`*^9}, {
   3.591451756628047*^9, 3.591451758933179*^9}, {3.625845727689809*^9, 
   3.625845731041814*^9}, {3.625846217702113*^9, 3.6258462469911566`*^9}, {
   3.625847584206174*^9, 3.6258476065492067`*^9}, 3.625848178113057*^9, {
   3.6371374450686765`*^9, 3.637137465738713*^9}, {3.637138662007818*^9, 
   3.6371386623354187`*^9}, 3.6373024750803003`*^9, {3.6373027844403*^9, 
   3.6373028005043*^9}, 3.6374195782594*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Order of the fractional derivative: \[Gamma]=gammak. Here we choose \
\[Gamma]=1/4\
\>", "Text",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 CellChangeTimes->{{3.561126817421*^9, 3.5611268309564*^9}, {
  3.6371385902274885`*^9, 3.6371386028323107`*^9}, {3.637244700524968*^9, 
  3.637244706452307*^9}, {3.6372448627442465`*^9, 3.637244876903056*^9}, {
  3.637245133464731*^9, 3.6372451551689725`*^9}},
 Background->RGBColor[1, 1, 0]],

Cell[BoxData[
 RowBox[{
  RowBox[{"gammak", "=", "0.25"}], ";"}]], "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 CellChangeTimes->{
  3.561049517788604*^9, 3.561050679357012*^9, {3.5610903980687075`*^9, 
   3.561090407393154*^9}, 3.5611220939094*^9, 3.5611268309564*^9, {
   3.589270600217*^9, 3.589270601552*^9}, 3.589271184201*^9, {
   3.5892976824570417`*^9, 3.589297690719514*^9}, {3.5895180885616817`*^9, 
   3.589518088921702*^9}, 3.5895191624171023`*^9, {3.5895527656894464`*^9, 
   3.5895527660334663`*^9}, {3.5895546010014205`*^9, 
   3.5895546019304733`*^9}, {3.5896016762995996`*^9, 
   3.5896016765648003`*^9}, {3.589602256472*^9, 3.5896022604751997`*^9}, 
   3.5896030482298*^9, 3.589607261262*^9, 3.5897244193129997`*^9, {
   3.589736570752*^9, 3.58973657109*^9}, {3.589892478189557*^9, 
   3.589892479577959*^9}, {3.589896047289415*^9, 3.5898960476124334`*^9}, {
   3.5900402744212723`*^9, 3.5900402746552725`*^9}, {3.5900407451852994`*^9, 
   3.590040745949701*^9}, {3.5900412475908303`*^9, 3.5900412482928314`*^9}, {
   3.5900423256057243`*^9, 3.590042326089325*^9}, {3.5900685957871857`*^9, 
   3.59006859656723*^9}, 3.59007342585645*^9, 3.59021224751*^9, {
   3.5906711458351727`*^9, 3.5906711462141943`*^9}, {3.5907517913939114`*^9, 
   3.5907517917099295`*^9}, {3.591432157985069*^9, 3.591432180683367*^9}, {
   3.591433432296955*^9, 3.591433436503196*^9}, {3.59145199060743*^9, 
   3.591451992849558*^9}, {3.5914533024744644`*^9, 3.5914533051926203`*^9}, {
   3.5915293458577127`*^9, 3.5915293461947317`*^9}, {3.591536410992815*^9, 
   3.591536413805976*^9}, {3.6019157899983253`*^9, 3.6019157928574886`*^9}, {
   3.625846526613616*^9, 3.625846526953616*^9}, {3.625846592786713*^9, 
   3.625846625234762*^9}, 3.626066770157*^9, 3.6371379698887987`*^9, 
   3.63713800489886*^9, {3.637138089029808*^9, 3.6371380899190097`*^9}, {
   3.637138180102768*^9, 3.637138187356781*^9}, {3.6372445229178095`*^9, 
   3.63724452415388*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 "Spatial discretization:   ",
 Cell[BoxData[
  FormBox["\[CapitalDelta]x", TraditionalForm]]],
 "\[Congruent]deltax=Pi/Np where, in this case, we choose  Np=2Nx=40"
}], "Text",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 CellChangeTimes->{{3.561126817421*^9, 3.5611268309564*^9}, {
  3.637138214220028*^9, 3.63713822105284*^9}, {3.6371382858085537`*^9, 
  3.6371382934681673`*^9}, {3.6372446824849367`*^9, 3.637244688716293*^9}, {
  3.6372455356097326`*^9, 3.6372455512256255`*^9}, {3.6373023353903*^9, 
  3.6373023528543*^9}},
 Background->RGBColor[1, 1, 0]],

Cell[BoxData[
 RowBox[{
  RowBox[{"Nx", "=", "20"}], ";", 
  RowBox[{"Np", "=", 
   RowBox[{"2", "*", "Nx"}]}], ";", 
  RowBox[{"deltax", "=", 
   RowBox[{"Pi", "/", 
    RowBox[{"(", 
     RowBox[{"2.", "*", "Nx"}], ")"}]}]}], ";"}]], "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 CellChangeTimes->{
  3.561049517788604*^9, 3.561050679357012*^9, {3.5610903980687075`*^9, 
   3.561090407393154*^9}, 3.5611220939094*^9, 3.5611268309564*^9, {
   3.589270600217*^9, 3.589270601552*^9}, 3.589271184201*^9, {
   3.5892976824570417`*^9, 3.589297690719514*^9}, {3.5895180885616817`*^9, 
   3.589518088921702*^9}, 3.5895191624171023`*^9, {3.5895527656894464`*^9, 
   3.5895527660334663`*^9}, {3.5895546010014205`*^9, 
   3.5895546019304733`*^9}, {3.5896016762995996`*^9, 
   3.5896016765648003`*^9}, {3.589602256472*^9, 3.5896022604751997`*^9}, 
   3.5896030482298*^9, 3.589607261262*^9, 3.5897244193129997`*^9, {
   3.589736570752*^9, 3.58973657109*^9}, {3.589892478189557*^9, 
   3.589892479577959*^9}, {3.589896047289415*^9, 3.5898960476124334`*^9}, {
   3.5900402744212723`*^9, 3.5900402746552725`*^9}, {3.5900407451852994`*^9, 
   3.590040745949701*^9}, {3.5900412475908303`*^9, 3.5900412482928314`*^9}, {
   3.5900423256057243`*^9, 3.590042326089325*^9}, {3.5900685957871857`*^9, 
   3.59006859656723*^9}, 3.59007342585645*^9, 3.59021224751*^9, {
   3.5906711458351727`*^9, 3.5906711462141943`*^9}, {3.5907517913939114`*^9, 
   3.5907517917099295`*^9}, {3.591432157985069*^9, 3.591432180683367*^9}, {
   3.591433432296955*^9, 3.591433436503196*^9}, {3.59145199060743*^9, 
   3.591451992849558*^9}, {3.5914533024744644`*^9, 3.5914533051926203`*^9}, {
   3.5915293458577127`*^9, 3.5915293461947317`*^9}, {3.591536410992815*^9, 
   3.591536413805976*^9}, {3.6019157899983253`*^9, 3.6019157928574886`*^9}, {
   3.625846526613616*^9, 3.625846526953616*^9}, {3.625846592786713*^9, 
   3.625846625234762*^9}, 3.626066770157*^9, 3.6371379698887987`*^9, 
   3.63713800489886*^9, {3.637138089029808*^9, 3.6371380899190097`*^9}, {
   3.637138206466814*^9, 3.6371382108036222`*^9}, {3.6371382954961705`*^9, 
   3.637138310440997*^9}, 3.637245208360015*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 "We set the initial condition:  ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["U", 
    RowBox[{"(", "0", ")"}]], TraditionalForm]]],
 "=UmatrixIni "
}], "Text",
 CellChangeTimes->{{3.636905374736289*^9, 3.636905467120573*^9}, {
  3.637237994529871*^9, 3.637237994660878*^9}, {3.6372449459830074`*^9, 
  3.637244989310486*^9}},
 Background->RGBColor[1, 1, 0]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"UmatrixIni", "=", 
  RowBox[{
   RowBox[{"Table", "[", " ", 
    RowBox[{
     RowBox[{"Sin", "[", 
      RowBox[{"j", "*", "deltax"}], "]"}], " ", ",", 
     RowBox[{"{", 
      RowBox[{"j", ",", "0", ",", "Np"}], "}"}]}], "]"}], "//", 
   "N"}]}]], "Input",
 CellChangeTimes->{{3.561048528378299*^9, 3.5610485460302944`*^9}, {
   3.561048578404682*^9, 3.56104860090897*^9}, {3.6371378058077106`*^9, 
   3.6371378183345327`*^9}, 3.6372379946768794`*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "0.`", ",", "0.07845909572784494`", ",", "0.15643446504023087`", ",", 
   "0.2334453638559054`", ",", "0.3090169943749474`", ",", 
   "0.3826834323650898`", ",", "0.45399049973954675`", ",", 
   "0.5224985647159488`", ",", "0.5877852522924731`", ",", 
   "0.6494480483301837`", ",", "0.7071067811865476`", ",", 
   "0.7604059656000309`", ",", "0.8090169943749475`", ",", 
   "0.8526401643540922`", ",", "0.8910065241883678`", ",", 
   "0.9238795325112867`", ",", "0.9510565162951535`", ",", 
   "0.9723699203976766`", ",", "0.9876883405951378`", ",", 
   "0.996917333733128`", ",", "1.`", ",", "0.996917333733128`", ",", 
   "0.9876883405951378`", ",", "0.9723699203976767`", ",", 
   "0.9510565162951536`", ",", "0.9238795325112867`", ",", 
   "0.8910065241883679`", ",", "0.8526401643540923`", ",", 
   "0.8090169943749475`", ",", "0.7604059656000309`", ",", 
   "0.7071067811865476`", ",", "0.6494480483301838`", ",", 
   "0.5877852522924732`", ",", "0.5224985647159489`", ",", 
   "0.45399049973954686`", ",", "0.3826834323650899`", ",", 
   "0.3090169943749475`", ",", "0.23344536385590553`", ",", 
   "0.15643446504023098`", ",", "0.07845909572784507`", ",", 
   "1.2246467991473532`*^-16"}], "}"}]], "Output",
 CellChangeTimes->{3.6385163414938*^9, 3.6386024479505997`*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Boundary conditions:  u(x=0,t)=uL[t]=0;   u(x=\[Pi],t)=uR[t]=0.", "Text",
 CellChangeTimes->{{3.636977189200526*^9, 3.636977192456712*^9}, {
  3.63724504621074*^9, 3.637245086579049*^9}},
 Background->RGBColor[1, 1, 0]],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"uL", "[", "t_", "]"}], "=", "0."}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"uR", "[", "t_", "]"}], "=", "0."}], ";"}]}], "Input",
 CellChangeTimes->{3.636991916174861*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
\[FilledSquare] Numerical results with the T&E method for tolerance  \
\[Tau]=0.001\
\>", "Subsubsection",
 CellChangeTimes->{{3.633439583415289*^9, 3.6334395909637213`*^9}, {
   3.636904756973955*^9, 3.636904760701168*^9}, 3.637138408549569*^9, {
   3.6372452357805834`*^9, 3.6372452451731205`*^9}, {3.6372463821981544`*^9, 
   3.6372463827581863`*^9}, {3.63724964646486*^9, 3.6372496489360013`*^9}, {
   3.6373006334223003`*^9, 3.6373006462943*^9}, {3.6373012081363*^9, 
   3.6373012093343*^9}, 3.6381087243094*^9}],

Cell[CellGroupData[{

Cell[TextData[{
 "uMs is a matrix that contains the full solution ",
 Cell[BoxData[
  FormBox[
   RowBox[{"{", 
    RowBox[{
     SubsuperscriptBox["U", "0", 
      RowBox[{"(", "m", ")"}]], ",", 
     SubsuperscriptBox["U", "1", 
      RowBox[{"(", "m", ")"}]], ",", 
     SubsuperscriptBox["U", "2", 
      RowBox[{"(", "m", ")"}]], ",", 
     RowBox[{"...", " ", 
      SubsuperscriptBox["U", "Np", 
       RowBox[{"(", "m", ")"}]]}]}], "}"}], TraditionalForm]]],
 "  for m=0,1,2,....,numSteps."
}], "Text",
 CellChangeTimes->{{3.6372979828863*^9, 3.6372980614302998`*^9}},
 Background->RGBColor[1, 1, 0.85]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"tolerance", "=", "0.001"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"numSteps", "=", "40"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"CPUtime", "=", 
   RowBox[{"Timing", "[", 
    RowBox[{"uMs", "=", 
     RowBox[{"uMsolutionTE", "[", 
      RowBox[{"numSteps", ",", "tolerance"}], "]"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Print", "[", 
   RowBox[{
   "\"\<Example 2. T&E method. Case with \[Tau]=\>\"", ",", "tolerance", ",", 
    "\"\< for \[Gamma]=\>\"", ",", "gammak", ",", "\"\<, Np=\>\"", ",", "Np", 
    ",", "\"\<,\!\(TraditionalForm\`\(\(\\\ \
\)\*SubscriptBox[\(\[CapitalDelta]\), \(0\)]\)\)=\>\"", ",", "Delta0TE", ",", 
    "\"\<, \!\(TraditionalForm\`\*SubscriptBox[\(\[CapitalDelta]\), \
\(max\)]\)=\>\"", " ", ",", "DeltatcapTE"}], " ", "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Print", "[", 
   RowBox[{"\"\<CPU time=\>\"", ",", 
    RowBox[{"CPUtime", "[", 
     RowBox[{"[", "1", "]"}], "]"}], ",", "\"\< seconds\>\""}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
  "Print", "[", "\"\<The solution is saved in the matrix uMs\>\"", "]"}], 
  ";"}]}], "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 CellChangeTimes->{{3.56061256346875*^9, 3.56061257284375*^9}, {
   3.56061260303125*^9, 3.560612663828125*^9}, {3.5610884668366947`*^9, 
   3.5610884717649765`*^9}, {3.5611210929323997`*^9, 3.5611211203416*^9}, {
   3.5611212573096*^9, 3.5611212593532*^9}, 3.5611216448120003`*^9, {
   3.5611216844625998`*^9, 3.5611216848213997`*^9}, {3.5611217681558*^9, 
   3.5611217684667997`*^9}, {3.5611222944344*^9, 3.5611223196862*^9}, {
   3.5611253416166*^9, 3.5611253440626*^9}, {3.5611260133876*^9, 
   3.5611260138276*^9}, {3.561127402519*^9, 3.5611274579006*^9}, {
   3.561127527574*^9, 3.5611275627130003`*^9}, {3.5902000697948065`*^9, 
   3.5902000708068647`*^9}, {3.590200323138297*^9, 3.590200324873397*^9}, {
   3.5902003709750333`*^9, 3.5902003711460433`*^9}, 3.590200421820942*^9, 
   3.590213289142*^9, {3.5902135189*^9, 3.590213539836*^9}, {
   3.5902135876359997`*^9, 3.590213616165*^9}, {3.590213707484*^9, 
   3.590213707868*^9}, {3.590213768476*^9, 3.590213768955*^9}, 
   3.5902143461549997`*^9, {3.59021447142*^9, 3.590214495682*^9}, 
   3.5903882375313997`*^9, {3.5903932563884*^9, 3.5903932567464*^9}, {
   3.5903932903714*^9, 3.5903933180104*^9}, {3.5903933542194*^9, 
   3.5903933561303997`*^9}, 3.5903933876914*^9, 3.5903934182594*^9, 
   3.5903941132114*^9, 3.60195384860737*^9, {3.601953894449992*^9, 
   3.601953894987023*^9}, {3.6334400976967044`*^9, 3.6334400980167227`*^9}, 
   3.6369936572364435`*^9, {3.636993750675788*^9, 3.6369937637635365`*^9}, 
   3.637004923308416*^9, 3.6370053615804834`*^9, {3.6372402113622026`*^9, 
   3.637240211367203*^9}, {3.6372452960570307`*^9, 3.6372453605797215`*^9}, {
   3.6372453910404634`*^9, 3.637245428304595*^9}, {3.637245470149988*^9, 
   3.6372455167096515`*^9}, {3.6372456161863413`*^9, 3.637245697827011*^9}, {
   3.637245729372815*^9, 3.637245777960594*^9}, {3.63724584310532*^9, 
   3.6372459587629356`*^9}, {3.637246021107501*^9, 3.6372460259367776`*^9}, {
   3.637246091338518*^9, 3.6372460918335466`*^9}, 3.6372463595788608`*^9, 
   3.637246525799368*^9, {3.6372465623644595`*^9, 3.637246581655563*^9}, {
   3.637246817573056*^9, 3.6372468214022756`*^9}, {3.6372470179475174`*^9, 
   3.637247018278536*^9}, {3.6372471839910145`*^9, 3.6372472107335443`*^9}, {
   3.6372472497587757`*^9, 3.637247279316467*^9}, {3.637247390205809*^9, 
   3.6372473996553497`*^9}, {3.637247443785874*^9, 3.6372474491481805`*^9}, {
   3.637247899618946*^9, 3.6372479030021396`*^9}, {3.637247939714239*^9, 
   3.6372479400092564`*^9}, {3.6372482082135963`*^9, 3.637248224762543*^9}, {
   3.637248553257332*^9, 3.6372485587676473`*^9}, 3.6372496070256042`*^9, 
   3.6372975701323*^9, {3.6372979117462997`*^9, 3.6372979144493*^9}, 
   3.6372981329823*^9, 3.6372981646743*^9, {3.6372982614663*^9, 
   3.6372982617132998`*^9}, {3.6373004952983*^9, 3.6373005432813*^9}, {
   3.6373033665233*^9, 3.6373033817303*^9}, 3.6373675308291025`*^9, 
   3.637367747513496*^9, 3.6381088470674*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Example 2. T&E method. Case with \[Tau]=\"\>", 
   "\[InvisibleSpace]", "0.001`", 
   "\[InvisibleSpace]", "\<\" for \[Gamma]=\"\>", "\[InvisibleSpace]", 
   "0.25`", "\[InvisibleSpace]", "\<\", Np=\"\>", "\[InvisibleSpace]", "40", 
   "\[InvisibleSpace]", "\<\",\\!\\(TraditionalForm\\`\\(\\(\\\\ \
\\)\\*SubscriptBox[\\(\[CapitalDelta]\\), \\(0\\)]\\)\\)=\"\>", 
   "\[InvisibleSpace]", "0.01`", 
   "\[InvisibleSpace]", "\<\", \\!\\(TraditionalForm\\`\\*SubscriptBox[\\(\
\[CapitalDelta]\\), \\(max\\)]\\)=\"\>", "\[InvisibleSpace]", "1.`*^6"}],
  SequenceForm[
  "Example 2. T&E method. Case with \[Tau]=", 0.001, " for \[Gamma]=", 0.25, 
   ", Np=", 40, 
   ",\!\(TraditionalForm\`\(\(\\ \)\*SubscriptBox[\(\[CapitalDelta]\), \(0\)]\
\)\)=", 0.01, 
   ", \!\(TraditionalForm\`\*SubscriptBox[\(\[CapitalDelta]\), \(max\)]\)=", 
   1.*^6],
  Editable->False]], "Print",
 CellChangeTimes->{3.6385163520118*^9, 3.6386024579926*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"CPU time=\"\>", "\[InvisibleSpace]", "10.0152642`", 
   "\[InvisibleSpace]", "\<\" seconds\"\>"}],
  SequenceForm["CPU time=", 10.0152642, " seconds"],
  Editable->False]], "Print",
 CellChangeTimes->{3.6385163520118*^9, 3.6386024579946003`*^9}],

Cell[BoxData["\<\"The solution is saved in the matrix uMs\"\>"], "Print",
 CellChangeTimes->{3.6385163520118*^9, 3.6386024579955997`*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 "The solution for the m-th timestep is just the m+1 element of this matrix:  \
uMs[[m+1]]=",
 Cell[BoxData[
  FormBox[
   RowBox[{"{", 
    RowBox[{
     SubsuperscriptBox["U", "0", 
      RowBox[{"(", "m", ")"}]], ",", 
     SubsuperscriptBox["U", "1", 
      RowBox[{"(", "m", ")"}]], ",", 
     SubsuperscriptBox["U", "2", 
      RowBox[{"(", "m", ")"}]], ",", 
     RowBox[{"...", " ", 
      SubsuperscriptBox["U", "Np", 
       RowBox[{"(", "m", ")"}]]}]}], "}"}], TraditionalForm]]],
 " "
}], "Text",
 CellChangeTimes->{{3.6372981691743*^9, 3.6372982503743*^9}, {
  3.6372983312943*^9, 3.6372983351903*^9}},
 Background->RGBColor[1, 1, 0.85]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"mStep", "=", "5"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Print", "[", 
   RowBox[{"\"\<The numerical solution at time \>\"", ",", 
    RowBox[{"tt", "[", "mStep", "]"}], ",", "\"\< is:\>\""}], "]"}], ";", 
  RowBox[{"uMs", "[", 
   RowBox[{"[", "mStep", "]"}], "]"}]}]}], "Input",
 CellChangeTimes->{{3.6372983391352997`*^9, 3.6372983412483*^9}, {
  3.6372985221443*^9, 3.6372986028712997`*^9}}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"The numerical solution at time \"\>", "\[InvisibleSpace]", 
   "0.000025796890258789063`", "\[InvisibleSpace]", "\<\" is:\"\>"}],
  SequenceForm[
  "The numerical solution at time ", 0.000025796890258789063`, " is:"],
  Editable->False]], "Print",
 CellChangeTimes->{3.6385163521038*^9, 3.6386024580326*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "2.219246059514033`*^-16", ",", "0.07470882984345835`", ",", 
   "0.1489570549077247`", ",", "0.22228691019523777`", ",", 
   "0.29424629276349873`", ",", "0.3643915490900512`", ",", 
   "0.43229021034397747`", ",", "0.49752365870005105`", ",", 
   "0.5596897082568338`", ",", "0.6184050846464991`", ",", 
   "0.6733077880487605`", ",", "0.7240593250401416`", ",", 
   "0.7703467955184921`", ",", "0.8118848218361668`", ",", 
   "0.848417308248122`", ",", "0.8797190198273435`", ",", 
   "0.9055969711130699`", ",", "0.9258916159303331`", ",", 
   "0.94047783104518`", ",", "0.9492656875910189`", ",", 
   "0.9522010055099862`", ",", "0.9492656875910189`", ",", 
   "0.9404778310451799`", ",", "0.9258916159303329`", ",", 
   "0.9055969711130698`", ",", "0.8797190198273431`", ",", 
   "0.8484173082481217`", ",", "0.8118848218361663`", ",", 
   "0.7703467955184915`", ",", "0.7240593250401413`", ",", 
   "0.6733077880487602`", ",", "0.6184050846464989`", ",", 
   "0.5596897082568338`", ",", "0.497523658700051`", ",", 
   "0.43229021034397747`", ",", "0.3643915490900512`", ",", 
   "0.2942462927634987`", ",", "0.22228691019523775`", ",", 
   "0.14895705490772462`", ",", "0.07470882984345822`", ",", "0.`"}], 
  "}"}]], "Output",
 CellChangeTimes->{3.6385163521088*^9, 3.6386024580355997`*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 "The [[m+1,j+1] element of this matrix is the numerical solution for time ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["t", "m"], TraditionalForm]],
  FormatType->"TraditionalForm"],
 " and position ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["x", "j"], TraditionalForm]],
  FormatType->"TraditionalForm"],
 ":  uMs[[m+1,j+1]]=",
 Cell[BoxData[
  FormBox[
   SubsuperscriptBox["U", "j", 
    RowBox[{"(", "m", ")"}]], TraditionalForm]]],
 " "
}], "Text",
 CellChangeTimes->{{3.6372981691743*^9, 3.6372982503743*^9}, {
  3.6372983312943*^9, 3.6372983351903*^9}, {3.6372983799263*^9, 
  3.6372984925123*^9}},
 Background->RGBColor[1, 1, 0.85]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"mStep", "=", "5"}], ";", 
  RowBox[{"jPos", "=", 
   RowBox[{"Nx", "+", "1"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Print", "[", 
   RowBox[{"\"\<The numerical solution at time t=\>\"", ",", 
    RowBox[{"tt", "[", "mStep", "]"}], ",", "\"\< and position x= \>\"", " ", 
    ",", 
    RowBox[{"jPos", "*", "deltax"}], " ", ",", "\"\< is:\>\""}], "]"}], ";", 
  RowBox[{"uMs", "[", 
   RowBox[{"[", 
    RowBox[{"mStep", ",", "jPos"}], "]"}], "]"}]}]}], "Input",
 CellChangeTimes->{{3.6372983391352997`*^9, 3.6372983412483*^9}, {
  3.6372985221443*^9, 3.6372986028712997`*^9}, {3.6372986373603*^9, 
  3.6372986956313*^9}}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"The numerical solution at time t=\"\>", "\[InvisibleSpace]", 
   "0.000025796890258789063`", 
   "\[InvisibleSpace]", "\<\" and position x= \"\>", "\[InvisibleSpace]", 
   "1.6493361431346414`", "\[InvisibleSpace]", "\<\" is:\"\>"}],
  SequenceForm[
  "The numerical solution at time t=", 0.000025796890258789063`, 
   " and position x= ", 1.6493361431346414`, " is:"],
  Editable->False]], "Print",
 CellChangeTimes->{3.6385163521468*^9, 3.6386024580446*^9}],

Cell[BoxData["0.9522010055099862`"], "Output",
 CellChangeTimes->{3.6385163521498003`*^9, 3.6386024580466003`*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 "A plot comparing the numerical and the exact solution at time ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["t", "mStep"], TraditionalForm]],
  FormatType->"TraditionalForm"],
 " "
}], "Text",
 CellChangeTimes->{{3.6372989561913*^9, 3.6372990023753*^9}, {
  3.6372990787602997`*^9, 3.6372990811603003`*^9}},
 Background->RGBColor[1, 1, 0.85]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"mStep", "=", "5"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Print", "[", "\"\<T&E method\>\"", "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Print", "[", 
   RowBox[{
   "\"\<Numerical solution (points) and exact solution (line)  at time \
t=\>\"", ",", 
    RowBox[{"tt", "[", "mStep", "]"}]}], "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{" ", 
  RowBox[{
   RowBox[{"FigNum", "=", 
    RowBox[{"ListPlot", "[", 
     RowBox[{
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"xj", "=", 
           RowBox[{"j", "*", "deltax"}]}], ",", 
          RowBox[{"uMs", "[", 
           RowBox[{"[", 
            RowBox[{
             RowBox[{"mStep", "+", "1"}], ",", 
             RowBox[{"j", "+", "1"}]}], "]"}], "]"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"j", ",", "0", ",", "Np"}], "}"}]}], "]"}], ",", 
      RowBox[{"PlotRange", "\[Rule]", "All"}]}], "]"}]}], ";", 
   RowBox[{"FigExact", "=", 
    RowBox[{"Plot", "[", 
     RowBox[{
      RowBox[{"uSol", "[", 
       RowBox[{"x", ",", 
        RowBox[{"tt", "[", "mStep", "]"}], ",", "gammak"}], "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"x", ",", "0", ",", "Pi"}], "}"}], ",", 
      RowBox[{"PlotRange", "\[Rule]", "All"}]}], "]"}]}], ";", " ", 
   RowBox[{"Show", "[", 
    RowBox[{"FigNum", ",", "FigExact", ",", 
     RowBox[{"Frame", "\[Rule]", "True"}], ",", 
     RowBox[{"FrameLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<x\>\"", ",", "\"\<u\>\""}], "}"}]}]}], 
    "]"}]}]}]}], "Input",
 CellChangeTimes->{{3.6372990098493*^9, 3.6372993557363*^9}, {
   3.6372994017143*^9, 3.6372994018733*^9}, {3.6372994547862997`*^9, 
   3.6372994982653*^9}, {3.6372997348883*^9, 3.6372998253603*^9}, {
   3.6373012862503*^9, 3.6373012895603*^9}, 3.637368677271675*^9, {
   3.6385154916218*^9, 3.6385155029178*^9}}],

Cell[BoxData["\<\"T&E method\"\>"], "Print",
 CellChangeTimes->{3.6385163521858*^9, 3.6386024580536003`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Numerical solution (points) and exact solution (line)  at time \
t=\"\>", "\[InvisibleSpace]", "0.000025796890258789063`"}],
  SequenceForm[
  "Numerical solution (points) and exact solution (line)  at time t=", 
   0.000025796890258789063`],
  Editable->False]], "Print",
 CellChangeTimes->{3.6385163521858*^9, 3.6386024580546*^9}],

Cell[BoxData[
 GraphicsBox[{{{}, {{}, 
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
      0.012833333333333334`], AbsoluteThickness[1.6], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQBGIQDQPeBn9u9t2YafPgw5wyfekt9jUSAkK392yyh/CP
2DN8DpokuO6QfUDma8PjGufsW8Qef7J8cBoqf8We44Vhq2HxJXsJXZeQ34o3
7bUyL4So37wGVX/P/s+ujW680rftjwSdbD85/aG9fJGsirbRfaj+J/YyLmpy
bD0P7f/0FaROnffMnr+x6JRL8mOoeS/tI28/O/9S+qm9yWlx58Slr+2Tkpo3
225+BjX/nb18O9uEvWov7Lc1x08QC/tg33h9Po98yUuofR/ttxom/Qqe+cr+
kqJxfc3NT/bzjh+Y1DvlNdT+L/bztH4E2qe8sX+3ny3vUcxX+/6eRxmK7G+h
7vlmf6Eo+pBRzVt7rrhbMR4Pvtuvt2eauevQW6j7ftpbq92e5Xnrrb3an7Xe
65J/2W+AykPc+9v+MlS/06xGK5Hnf+wnQs2HuP+f/Xyo/XEWoZpVWf/t50Ld
B/EPg8MWqPtts0V4PnxjcED1H6ODItT/3lZ1zIstmBxSoeED8S+TQww0/CI5
X/wKrWJ2EIKGL8T/LA6y0PBPvxH4iWMPi4MiNH4g4cHqwLAbEn+ly3e/3P2X
1UEHGr+Q8GFz4ITGf3OZ6sM8e3aHVmj6gIQXuwMs/Ux07b+h2MjhUAlNX5Dw
43SApUMApT4v0w==
       "]]}, {}}, {}}, {{}, {}, 
    {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], Opacity[
     1.], LineBox[CompressedData["
1:eJwd2Hk8Vdv7B3BTOioVGUqROdctmUoJn+NUQhOSZlNoQMaQ6hZKySwRIgmp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      "]]}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->True,
  FrameLabel->{
    FormBox["\"x\"", TraditionalForm], 
    FormBox["\"u\"", TraditionalForm]},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  Method->{},
  PlotRange->{{0, 3.141592653589793}, {0, 0.9328964256794231}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.02], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.6385163523887997`*^9, 3.6386024581646*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Here we give a table that compares the numerical and exact solution at the \
middle point, x=\[Pi]/2, for the first numSteps timesteps. \
\>", "Text",
 CellChangeTimes->{{3.6372981691743*^9, 3.6372982503743*^9}, {
  3.6372983312943*^9, 3.6372983351903*^9}, {3.6372983799263*^9, 
  3.6372984925123*^9}, {3.6372988496542997`*^9, 3.6372989263983*^9}},
 Background->RGBColor[1, 1, 0.85]],

Cell[BoxData[
 RowBox[{
  RowBox[{"headTE", "=", 
   RowBox[{"{", 
    RowBox[{
    "\"\<step\>\"", ",", "\"\<t\>\"", ",", 
     "\"\<\!\(\*SubscriptBox[\(U\), \(\(T &\) E\)]\)(\[Pi]/2,t)\>\"", ",", 
     "\"\<\!\(\*SubscriptBox[\(u\), \(exact\)]\)(\[Pi]/2,t)\>\"", ",", 
     "\"\<error\>\""}], "}"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.6372462215509663`*^9, 3.6372463423118734`*^9}, {
   3.6372468240104246`*^9, 3.637246824353444*^9}, 3.6381088507623997`*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"tabTE", "=", 
   RowBox[{
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"m", ",", 
        RowBox[{"tt", "[", "m", "]"}], ",", 
        RowBox[{"uMs", "[", 
         RowBox[{"[", 
          RowBox[{
           RowBox[{"m", "+", "1"}], ",", 
           RowBox[{"Nx", "+", "1"}]}], "]"}], "]"}], ",", 
        RowBox[{"uSol", "[", 
         RowBox[{
          RowBox[{"Pi", "/", "2"}], ",", 
          RowBox[{"tt", "[", "m", "]"}], ",", "gammak"}], "]"}], ",", 
        RowBox[{
         RowBox[{"uMs", "[", 
          RowBox[{"[", 
           RowBox[{
            RowBox[{"m", "+", "1"}], ",", 
            RowBox[{"Nx", "+", "1"}]}], "]"}], "]"}], "-", 
         RowBox[{"uSol", "[", 
          RowBox[{
           RowBox[{"Pi", "/", "2"}], ",", 
           RowBox[{"tt", "[", "m", "]"}], ",", "gammak"}], "]"}]}]}], "}"}], 
      ",", 
      RowBox[{"{", 
       RowBox[{"m", ",", "0", ",", "numSteps"}], "}"}]}], "]"}], "//", 
    "N"}]}], ";", 
  RowBox[{
   RowBox[{"Insert", "[", 
    RowBox[{"tabTE", ",", "headTE", ",", "1"}], "]"}], "//", 
   "TableForm"}]}]], "Input",
 CellChangeTimes->{3.6372987625292997`*^9, 3.6373690439886503`*^9}],

Cell[BoxData[
 TagBox[GridBox[{
    {"\<\"step\"\>", "\<\"t\"\>", "\<\"\\!\\(\\*SubscriptBox[\\(U\\), \\(\\(T \
&\\) E\\)]\\)(\[Pi]/2,t)\"\>", "\<\"\\!\\(\\*SubscriptBox[\\(u\\), \
\\(exact\\)]\\)(\[Pi]/2,t)\"\>", "\<\"error\"\>"},
    {"0.`", "0.`", "1.`", "1.`", "0.`"},
    {"1.`", "9.5367431640625`*^-9", "0.9915493702760976`", 
     "0.9892065873252748`", "0.002342782950822797`"},
    {"2.`", "1.621246337890625`*^-7", "0.9811270377680427`", 
     "0.9783076666480046`", "0.00281937112003805`"},
    {"3.`", "1.3828277587890625`*^-6", "0.9672926253618318`", 
     "0.9634522236237902`", "0.0038404017380415656`"},
    {"4.`", "6.265640258789063`*^-6", "0.9522010055099862`", 
     "0.9475005382535466`", "0.004700467256439578`"},
    {"5.`", "0.000025796890258789063`", "0.9328964256794231`", 
     "0.926750908264056`", "0.006145517415367063`"},
    {"6.`", "0.00006485939025878907`", "0.9162529893850949`", 
     "0.9093934745771206`", "0.00685951480797431`"},
    {"7.`", "0.00014298439025878907`", "0.8993932987489794`", 
     "0.8916474858281818`", "0.007745812920797679`"},
    {"8.`", "0.00029923439025878905`", "0.8811995867102201`", 
     "0.8723948614841722`", "0.008804725226047916`"},
    {"9.`", "0.0006117343902587891`", "0.8610922686470969`", 
     "0.8510893933231013`", "0.010002875323995575`"},
    {"10.`", "0.001236734390258789`", "0.838740244221057`", 
     "0.8274496503391107`", "0.01129059388194631`"},
    {"11.`", "0.002486734390258789`", "0.8140076673511057`", 
     "0.8014211665112332`", "0.01258650083987256`"},
    {"12.`", "0.0049867343902587884`", "0.7870114900998432`", 
     "0.773252155794971`", "0.013759334304872195`"},
    {"13.`", "0.009986734390258788`", "0.7583017670407389`", 
     "0.7436886760556705`", "0.014613090985068466`"},
    {"14.`", "0.01998673439025879`", "0.7292498519834323`", 
     "0.7143598247646235`", "0.014890027218808832`"},
    {"15.`", "0.039986734390258794`", "0.7027530316454154`", 
     "0.6884383312806093`", "0.014314700364806088`"},
    {"16.`", "0.0799867343902588`", "0.6838160508765981`", 
     "0.6711538006925718`", "0.012662250184026336`"},
    {"17.`", "0.2399867343902588`", "0.6612160329471721`", 
     "0.6548566352019893`", "0.006359397745182793`"},
    {"18.`", "0.3199867343902588`", "0.6321087703247281`", 
     "0.6272704919808566`", "0.004838278343871516`"},
    {"19.`", "0.39998673439025884`", "0.5852904254393856`", 
     "0.5813212628928124`", "0.003969162546573202`"},
    {"20.`", "0.5599867343902588`", "0.46789665863307206`", 
     "0.4641761087354874`", "0.003720549897584635`"},
    {"21.`", "0.6399867343902588`", "0.4194905477643231`", 
     "0.4153724643211204`", "0.004118083443202691`"},
    {"22.`", "0.7199867343902587`", "0.3911002155943357`", 
     "0.3866412629375121`", "0.0044589526568236115`"},
    {"23.`", "0.7999867343902587`", "0.38759545471245777`", 
     "0.3830114229253167`", "0.004584031787141063`"},
    {"24.`", "0.8799867343902587`", "0.40794336464760705`", 
     "0.40356008282864375`", "0.004383281818963303`"},
    {"25.`", "1.0399867343902587`", "0.4899956406148468`", 
     "0.4862122293610563`", "0.003783411253790503`"},
    {"26.`", "1.1199867343902588`", "0.5275348684726735`", 
     "0.5250770577310946`", "0.002457810741578914`"},
    {"27.`", "1.1999867343902588`", "0.548814239085478`", 
     "0.5473413636074447`", "0.0014728754780333198`"},
    {"28.`", "1.279986734390259`", "0.5471674510313838`", 
     "0.546368413234456`", "0.000799037796927804`"},
    {"29.`", "1.359986734390259`", "0.5218641104936989`", 
     "0.5213495214406343`", "0.0005145890530645625`"},
    {"30.`", "1.439986734390259`", "0.47813295821579105`", 
     "0.47749368331896236`", "0.0006392748968286899`"},
    {"31.`", "1.599986734390259`", "0.3774297568296779`", 
     "0.37524655107137617`", "0.0021832057583017206`"},
    {"32.`", "1.679986734390259`", "0.3431000646466393`", 
     "0.34046512522604616`", "0.0026349394205931187`"},
    {"33.`", "1.759986734390259`", "0.33126883652266476`", 
     "0.3282149649227582`", "0.0030538715999065547`"},
    {"34.`", "1.8399867343902592`", "0.3439768641890859`", 
     "0.3407895326867782`", "0.003187331502307711`"},
    {"35.`", "1.9199867343902592`", "0.3773301190946704`", 
     "0.37437599740036964`", "0.0029541216943007598`"},
    {"36.`", "2.079986734390259`", "0.46730532956170595`", 
     "0.46572101786264064`", "0.0015843116990653106`"},
    {"37.`", "2.1599867343902592`", "0.5003924685912815`", 
     "0.4996268681867468`", "0.0007656004045347164`"},
    {"38.`", "2.2399867343902593`", "0.5128281526951403`", 
     "0.5127355599604598`", "0.00009259273468043006`"},
    {"39.`", "2.3199867343902594`", "0.5009602085437482`", 
     "0.501237509530466`", 
     RowBox[{"-", "0.0002773009867177434`"}]},
    {"40.`", "2.3999867343902594`", "0.4671681536719947`", 
     "0.46743168029194965`", 
     RowBox[{"-", "0.00026352661995493465`"}]}
   },
   GridBoxAlignment->{
    "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
     "RowsIndexed" -> {}},
   GridBoxSpacings->{"Columns" -> {
       Offset[0.27999999999999997`], {
        Offset[2.0999999999999996`]}, 
       Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
       Offset[0.2], {
        Offset[0.4]}, 
       Offset[0.2]}, "RowsIndexed" -> {}}],
  Function[BoxForm`e$, 
   TableForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{3.6385163526548*^9, 3.6386024584546003`*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 "A plot comparing the numerical and the exact solution at  position \
x=\[Pi]/2 for times  t  with   0\[LessEqual]t\[LessEqual] ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["t", "numSteps"], TraditionalForm]],
  FormatType->"TraditionalForm"],
 " "
}], "Text",
 CellChangeTimes->{{3.6372989561913*^9, 3.6372990023753*^9}, {
  3.6372990787602997`*^9, 3.6372990811603003`*^9}, {3.6372998614302998`*^9, 
  3.6372998879683*^9}, {3.6373004057753*^9, 3.6373004634223003`*^9}},
 Background->RGBColor[1, 1, 0.85]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"Print", "[", "\"\<T&E method\>\"", "]"}], ";", 
  RowBox[{
  "Print", "[", 
   "\"\<Numerical solution (points) and exact solution (line) at position x=\
\[Pi]/2 vs. time\>\"", "]"}], ";", " ", 
  RowBox[{"FigNum", "=", 
   RowBox[{"ListPlot", "[", 
    RowBox[{
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"tabTE", "[", 
          RowBox[{"[", 
           RowBox[{"n", ",", "2"}], "]"}], "]"}], ",", 
         RowBox[{"tabTE", "[", 
          RowBox[{"[", 
           RowBox[{"n", ",", "3"}], "]"}], "]"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"n", ",", "1", ",", "numSteps"}], "}"}]}], "]"}], ",", 
     RowBox[{"PlotRange", "\[Rule]", "All"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"FigExact", "=", 
   RowBox[{"Plot", "[", 
    RowBox[{
     RowBox[{"uSol", "[", 
      RowBox[{
       RowBox[{"Pi", "/", "2"}], ",", "time", ",", "gammak"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"time", ",", "0", ",", 
       RowBox[{"1.1", "*", 
        RowBox[{"tabTE", "[", 
         RowBox[{"[", 
          RowBox[{
           RowBox[{"numSteps", "+", "1"}], ",", "2"}], "]"}], "]"}]}]}], 
      "}"}], ",", 
     RowBox[{"PlotRange", "\[Rule]", "All"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"Show", "[", 
  RowBox[{"FigNum", ",", "FigExact", ",", 
   RowBox[{"Frame", "\[Rule]", "True"}], ",", 
   RowBox[{"FrameLabel", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"\"\<time\>\"", ",", "\"\<u\>\""}], "}"}]}], ",", 
   RowBox[{"PlotRange", "\[Rule]", "All"}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.6372990098493*^9, 3.6372993557363*^9}, {
   3.6372994017143*^9, 3.6372994018733*^9}, {3.6372994547862997`*^9, 
   3.6372994982653*^9}, {3.6372997348883*^9, 3.6372998253603*^9}, {
   3.6372999061773*^9, 3.6372999638333*^9}, {3.6373000656813*^9, 
   3.6373002790032997`*^9}, {3.6373003226673*^9, 3.6373003301463003`*^9}, 
   3.6373012777063*^9, 3.6373013767462997`*^9, 3.6373014286173*^9, 
   3.6373017989203*^9, 3.6373211076755304`*^9, 3.6373691707248993`*^9, {
   3.6385155091837997`*^9, 3.6385155261108*^9}, 3.6385161398487997`*^9}],

Cell[BoxData["\<\"T&E method\"\>"], "Print",
 CellChangeTimes->{3.6385163527047997`*^9, 3.6386024584666*^9}],

Cell[BoxData["\<\"Numerical solution (points) and exact solution (line) at \
position x=\[Pi]/2 vs. time\"\>"], "Print",
 CellChangeTimes->{3.6385163527047997`*^9, 3.6386024584676*^9}],

Cell[BoxData[
 GraphicsBox[{{{}, {{}, 
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
      0.012833333333333334`], AbsoluteThickness[1.6], PointBox[CompressedData["
1:eJxVUF1IUwEY3WZozpEJ5ktmamVLC2GzInP3DBqp5UNLS4ypFFpIYTMX5k2F
xB9EahpZzaQeZohlWia6hPYwGTJN+/Fvm5m7Zk2925w/MzWL7q2nDnx8fA/n
nO+csAtXT2fzOByOkBl2/w83bga2xlOkjDhe26k3ds+jxyNUqA3lRKrjdmVW
9jzEf9FFTMwuNvsvu5BAkQzDSiTHxxG5N1wYeMdA8JM4GjFen2h1Ik/CH9Ny
AvDxxea+BbkTK6zc23CE91Wrhnsd0IWU0/IGMdJzjIUmkQP1GgZ+Miy01WUG
3KHBsJWSYykoeWDu9YzOwcD845+ZhWJaP5gmmANLX72iArcnTyeKngVr78gv
wz4BEcCTzaBRKeFfKrgH/aFgk9dZO2oYgd2FjfB+wnMuFX1HBS3X8cgO2Ecm
RZ+obyAYw6muQXREaitahf/uZnIYCXbu/rjYaaSrDZ7zGgtC7xZvtHdPsXmT
cmgKuRFtQ5sWJ8Cku24kp9GPGcpltoKRfxzGt0NAj4tMPhYwbfUWa2ZxMqMs
Mn3QDN8xrdsidGDF+1qRfrsVTJlhJq0b+ml7S5BiktU7WEAv4OHk4kANZWPz
nNgjXsIz5RZqSk3BIddlDJHLWH2Vfyq7lEKMWJx/y+CB1uJWBL+2oSiwtTKa
/wOdSc/XuzVf4DemfVmtWUPVm8pd7/eakawLMR6h1pF6OXYtzTOCRxqNxS7c
QP/OnphS8Qi+koGuOuUvfFbVVnV5jSJKoebJdL9xriU59kCEme1j2wctR9rU
7mxImZkAl8MJbYrnSodVq1sPe9nwVCmJLKG50qiLvveDcmxIpMiYM2qedEeG
b8eEjw1/APqsPkw=
       "]]}, {}}, {}}, {{}, {}, 
    {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], Opacity[
     1.], LineBox[CompressedData["
1:eJwVl3k81N8Xxs2gaFGWVFosiRaJb0Si50OokEqW0CKkhEioVCopWihbabUk
pbKGpBIhshUZxj6DsRVhhsLQ7/7+8nq/fObee855znPvkXf0tDhCFxAQWCco
IPD/v7Um8/YyfrlvqaUFm7md+Y1VfxnPr4SYIGKXkHnMcD9ELdZW7wixw1Tr
hGz0mn78+6HZtarbCQ8NnVzfve7DxLQVWyXkOMKDd+ld30VYarPnomgvaPIO
KegL9+HMmgoPme5TwKNJF7fSXozC3n2p1mmU+11u847ohbfVz+PLQ/yxacvF
EgXnXvw+fs5VrvECzg03bhPe3IuNBcIa4tGXkPFH8OQCafL78p0bIvQCobw3
5WI0rwdZjOj/JLuvQDX62cAYowferFb1qLCr2EB7X1vxrgfqP1eqL9AKxpZV
+mEfY3uQKpCzfmHIDfw08F816NUD99nTqjFqt7B5WMelxL4Ha6WNVRc3hqLj
75+5nG09qFvgdndu9B0sXX0/78KKHmgsmSdt7hqOu+nycz5L9CBS7k10mF4E
/r4+V9hJ74HF2smoed2REH4QWHSa040MtVip3XlRODUuF1zR0I35G7dG3QmL
hrkI629+eTe+UTcjxbXu4UO2Y9q+zG6YWS+JkAx5AJnhtAT74G68sv8kbrn/
IdTT6ZufX+jGrMNO4VFqjyD26aP9Hp9ufHV7dWdB42OoKkcUvXbsxqqTu+Zb
pzzBwzW0Wku7boT4cW/fvRyLimM7O7ZbdONpwePS2dFx6JO6umbG1m5YFHnO
VPkXB7NAp4dlm7tB/6K/zcw1HjE950591eiGYwXnyy29BIwaJqueU+6GXP26
L3O7n6Juzb11dvO68Z35T1h1dyLmnNqQ91W0G5eaa4zM8xIxwZjvcESoG+0s
35KwsGd4PHdgrcwEB09+fiyep/UcB6KyZXf1cGA+eFtILf45xB7ek+R1cDA1
dNhw9+wXKFxc8+xdGwf7x4SL77S/QJSrk2pCPQdLaOZF4iEvwTS4eKCylAPt
wysNZCdfwn6m6Pb5xRxYF/ILVE68gl3hXqeTBRxEXH6Vv83yNcpk1PWC33GQ
zg7Usyp9jQPhw7I6ORxU6dt9cNRJQUyxv/+MNxyI0EXzLsil4t/tjaa9rzlQ
cmRp34xMxftySp2fzMHWz2/fxsxIw3qjMg+l5xwEBLpkv/mVBr992rLv4znw
pzkyfVrSsc3IyOzHPQ6uZ1Tdm1yQAYmTbTHB0RzEHN5kE7grA4YyF3bsjOQg
u3B+/e3PGbhqE1Ay6zYHxSfPR0vzMxByLiySFspBrXyv5WPNTDTPu1M+8yYH
Q5c//Xj5IhPHV4glUcEc/FNfG6nekYlPj//z8L7KgVjHXYvcJW+w+4B+R8YV
DtYanKgpCXuD/mP91L5LHLjQl31j+WRhhqPjEW1/DnwzQ8KOpmYhf9nYoqoz
HAQ58nYO9mTBV3jogftpDuI/V1RO2mXjIbW0otyH5M9b61ZgVDbe/7VoDznF
Qb7CU1PR6my4d1eE7vbmoCXQv1xaPweHWL8fTnpy8PO/7uuP/XOw5Oblk20n
OJjo2LNDMSsHt5WmK796cLBw6+oydeW3SC96IfXOjQMLQWaJ2dxcJJXf0uIe
5eDwm61Xfxjnoitm9mVJwl5OaYZ2l3Lx4Wyir44LB6FF14qOcnMhoVZz66Ez
B2VXNAsDG98h9pP0YOJhDho2xF8SlcwD57cZfdSBg+7OOdQdszwE7LinbUJY
0LAr//GnPDQtzLYTPMTBFqHID7nP3qNwwfIfr/ZzsD3LOtyz+T3e2872XE3Y
wlnGRUn8A/p5iS4v7Tk4Uhw/L+r8B1Q+vDWYbcfBraB0R8+9H8GUvqo8tI+D
uxo+WkrXP6KPNdfpKuG4Lq05rfkfkfLASXIZ4SzDT9kma/JB3+x0bK8NB81C
1SJKtE/Q0Bpa0GjFQVdWeGvLxk8YOVKhdJHwoLNVZqQ74dSznUqE6SUt9jTm
J2Rn+Qmes+Qg+rOvzQmbAnBXHTq2YS8HHwKDXu5QLURG0ErN2t0cFNp1S63c
UYi0LmNmCOEv/22/KOBciIvMmCYQ/t4x2/Lt/UJcUZmdlbqLg06DyClF4c8o
VFlbEWrOwSzBhN0CLZ/hN+9Ki4EZB/OaBd83j32GIfOwxx9TDqTeHFn5VrwI
oRtmWL8ivNxp9YTHtiJs9jbnzSf8X1H60+bMIvDMjRtqdnBge+XTWM71YmRx
9A8v30b650xd4OzEYtx/sKOqyJiDRx59Yg75xWgRCKk4SphlI6ksyi3GoWVj
e14ZcXBU5aiN/f4SCJy3sJI15CBE/nxnml8J8LhSLncrBy+lwz2Fwkug3BOx
ahfhQYH3wSklJYgevlx82oDonyGW+0/1C2TaVBdnUqRe5SsMLXd8wfRJ94zN
hHM/aX9/4fQFrEPi2kXggJ/s2Lsn5gtm6f/4WbGFgysBOYsSaaUQ1VMb+azL
QbjywbPb60oREbh5EtocZC49Jfx4sBSJXZ7OiVoc1ImHhA+LlCFAZZfmDMKL
+BnJD/TKUHG88XehJgex34WbfiWVQfBX3fiiDRwUlMi46BeWIdDnRM3R/zjo
yFs/Et1chmybF/Vv1Ik/PbOdhflfkb3vhflWNQ5SzqbohJ/9igcRu3WwjoPq
E5+/cCK/QmT0S5GfCvEPpwYLndSvyPjrYvxqLQca5jS3zo6vGF3nv3z2Gg7e
K1g91DQrh6XWp5PPlDj4WsGfbFxeAcNLlxMhy4Hxoh8NrpsrUO9edUN1OfEr
5+Q34zYVaP296/TiZcQPpqzcFodX4OWCtzs6ZUj869Oa9glWIl8sZ5WxNKln
5OF3DT2VuKx4r3jrHA4Ws7SijwpVQdPQzHRoFsm/itjJP3JV8P+0LiBGlOSz
JG/VQrsqrI1WZDTP4ODaH8kY68oq/Ei+UbKORvzA/osfI70atjxjzgSvCwPP
H1kcqarGnZUFixy4XTjO81Yd7avGq1JadsFwF46EynZLrfiGuIbexT6DXbD7
dMbKMvobLvfStJ/2dCEhfMGDPt3vOJdSv1SusQs3R0vPHJOvQZuw5ZYruV0o
WyLq/kG1BnSJzaO+OV2YYWByaL5uDfYejHFzzurCpbBKo1zrGgSvnhmpkd4F
P+UaCZFbNdj8pj47/nkXHGybXj8fq4GEqtGn1OgubPz4i9VdUYs7zWbyESe6
4NO5rk6nsRbXb/NGJt26kCHqWRrWXYuX4rMuHnbtgor1cMpG2g/4VS/4Kuvc
Bfnfo/7XNv5AQcCRTa62XZgj/09KKf4HlDxTrNW2dqEjSHzHEb868C3kN8ZI
dqHKekNXfVAdvB4W3NCe34XcVVYXt0fWQWOaPrduThfCKmOy16bXYU1sUyJf
uAubpeQURvrqoLupxUPqbyeinqpOBhxgYPPMJq5DcyeMPpumxBjWw7VNefHV
J5148e+qeKUEE+4MgYa2hZ1QcLisNyHHxNLCFo/zkp14WHDeddV6JpoP+DhK
z+tE2OVThUGmTLzUuOCPGZ3wETx8Ui+IiTNHYv+58DpAzdStSR1lYnB1gMn8
7x1gio3cCWc2InuGqcJoUAdElx+cb/OkGd0F/Ss9utlYopvj3PmrDaM+hur5
r1ioTnjEdNdnQ/9hvVH38zawXrBKl29n45FnfabykzZwUxXffjdnI2OlRIB7
VBsWvX8drbGfjYapxCMCl9tw+McHC74fG2aKC0ct7NrAE2ytvPmajS9OD7pS
57ZB5siywpcLO5Cnec419nQrjio/Se4d6EBGml+5tn0LCnjm7DMkDrva++Od
Fi2Q+fxvkehkB7pEDvpHm7Sgev/hkNUindjnsPrxbJ0WaEQoHj2u0IktW60f
GS1ugcDUS8Vf1p1IYnkLTzCb8aD2bezvT53YXuVxO/VAM3ixxxoufunExZcN
WdrWzdjpsXje/KpOeD++fK7cvBkCIucC1Jo6oZmbIilMNeOo3pYDJ3mdGHt1
LqBBoRkaL4pluKu64Chrdnu8rwnVF2qix8K7oKunG+sd0ITpOO/4Bfe7sH+e
mPnp001YXyyZohHXBXbT/Z3XvJpwZ5Z1sXdqF9J/vThW5NgEi3tNI4PlXTi2
cFr1/bYm1Kd37uoRJO+CtqlPyZJNmFEXZD9jNge7gvW0981tgtaflUdXSpB7
JeJ+rPjMJsToHQtwkuPAO/Smw7OJRtiV/3rdTnx1y/JVyXs6GtHaOSrK9CU+
AD+BkjeNEJt5b8Gf88QnlX9FKKU2YssabXnpIPIuWlrwJPJFI554+WtbRhDf
69U0uPO4EQ5T0y7fUzn4cyo6XCqkEV3SIsVl5B0qPVeDsetQI6R0kr/1DJJ7
lS8Y4m7XCKMDJs0zxjiQb9RYHW3ViKSnt0YMybv2496J3bPMGnFMTVy+UK4b
bYbjvUGbGvFrh0zAO9tuPFm5NqRAuhFLPVxuHXTohmrTwaMciUaY3cl8IHi0
G9aKS/hS8xrxut7k7U7yjr8dN2QdNbMRbk7nhthh3XhDRWyVGmei/3yL46zi
bnhPLzNd2saETNyqk2lkbvBWd7IabGLCpMjnomVNN/TXGu2uaCB9JDr30ZO2
blT1aykm1TDheleP8d94N6wybO+1lzDRm/Zkm71qD/LnJwk6pzOx6Ee/lYBm
DwTnDTp3pzCxfWyj87PNPYjOmcc69YqJF7rfLv3e3gP/xzlr05OYOPr137sr
Tj34ctPPNPUxE3d/mZatOt6Dnw8GU68/ZOLLvJj6KjJXPaCkdLzuM6FkrcZd
GNAD4Y9/Kg9GM9Hd4aDyOqYH8gdni3wOZUJ6RorOHjKXxdbaV47dZMJ49fj2
sWdk7hp5VLjxBhPPPMOPUG960HZ/owHzGhN1Ea2nOGSuGx4S/LbpKhNCOasD
bxT04NmdV7eTrjDhzC98UlfVgxyj5NT4S0xEyYqlnK3rAUuLPVftIhPFBnbv
lzcTXv024esFJhSvjzQc6+1B6PWNJ5afY6JzwQrxKXovHlzZddvcj+Q/7BBX
bVYvdjrLxMn6MjE08xHDWbwXN9TetEydYmJ6XOpBpWwvcuLvNLBPkvOc2nNe
QLkXm6pzonq8mJj9K/SghmovLMY8zk14kny3zVjxSLcXfW06n7edYELWZqvw
9629EBpzkQv0IPn6frFH0LQXT3J3J351Z0Jlx4evWha9mGguMltOeMPnv6/c
bHvByPZedMmNCZ3NmmGxDr2I2jIm/Ps4E1TWSa8fR3uhKFkt6UZ427pUi5me
vYg/7UDxXJkwT+rX2OzXi/u2E9dvELaSVV7oeaEX0nu/Da4jvD/GaTwhqBen
U8bd244x4Sge11x/sxeXnf3pjwi73mj5OCuyFzPXbEpxIewluDhuy4NerHAV
cttC2O+8VaB3fC+2mYRvWkH4wmi4c9KLXvBzzkkvIBx0otq4Ka0XageN/0kS
vtkza7XY214E5NoNyxKOcNg22yC/F6w5ov3ahGMarwz4lvTCxDek+yDhWIuC
b8mVvcjrHOsMJ5xUwc9o/dGLQ8q27TWEXxtuihJv7kXX8APGchLPm4++fkYd
vVjdGlZ0hnDexsx9Z/t68dtr8Fk74cK0QZ2UoV4krrI7u5fkq2zV2mXsP71o
OWurU0e4Ov7oP6l/vfBqsuMcJvlmyCSyt8/og1zpGz8+4ZZIVtH5uX0wLI/r
f0rq0zFnWVK6VB/GAo309pF6Dk1HH1+0og9VCmUneki9/5yuNTNb0we1IS+j
z0QP00Ni6y+p96HB/Gh/8v/10hnM7UEf7OoLQ2O9mZDYX8xYsq0PQ7lrrqQQ
vS1iCOTuMu9DX3q/RpkP0Uvp2fNv9/chYPbxvBWnmVhH5Rz86dSH2yKuQc5n
mNB4N0LJuvXBw3HLn4yzTOi/chMOPtuHzuetn73Pk3rfPhBmfbcPL3dn7L8Z
SOot8sDrxuM+7K+pYaqRe9j1cr1FfiJZ76d6bQfpN79TuxYqvSH7BS9a6X6d
iXAb/bjRb32wb50XLxnORNu9/vKZDX1oOn36vUQk0S8zcnRxWx8KRW6mLSP9
X7av22TLrz78Cr0z24b4g4DdzdFrIv2wT9Nrs04g+nygIXd/Xj++x5eJZyUy
8aip1eSVdD/OBZ7tX/qcCW17tbhviv3o3eDmKf6a6G8/w2SRfj98dif9C8ph
Iv9RgO+a7f24pyweveUdE3NaleN0d/VjZVBKtOAH4mcH/EcdDvSjOKLvXVoh
E6yDsnHJZ/uxMObHm9tVTOw67Dqqk9kPOflne4/2kP3jJeR2vutH27Kw5h/9
xA/Y700OFfRj2cFOE9NBJq45isVdqe5HSK3YBzvyTsl3emNS2d8PW9rTvgnB
Rqi6TMUeWPETv3W5m7RXNGKuW7jJpaifUGw0G3RwJffbK87pRQ9/Yv8PBX6J
RyNe/Nz0LD3+J0J4Gz02eDfCwL3jHyv1Jw7dsbNUPteIMx4bsvW//sRrPaf/
vEMb0eHJkBWc/omYBbdYN8l9+NZn8ejVo7/g2yc1fl24CYcD4mNv6gwg8fjc
xYfzm3BNqjsuU38ACk9tvkuVNOHlyzUJjdsHQBsuoL5VNGGk/k2iss0ApgO9
5+1rbELg+i/JRacG4Lhf8c1bXhMSWf1vJl+T9a59coxXaUaPgUaZm+wgQscN
QlLjmuExs3TIVOg3UmuKxuffbcGq7dZ+X2yGcP+T2IsQ3zas3GLs6Gw/hFJl
5eiEC21Q0NhoTj80hAuhXr15V9uwTE5aaYvLEOaPPj3THd0Gib8MRrbPELyK
K/SVc9rAf26l+Sx8CJ0jifcw1oZvM614VyqGUPi91n2nTzv8Svd662MYy/LO
tND/Y2GhvH9gtcEwah4oiFzTZCHXPy7C3ngYgWEHrGZsYmF83UCm785hyLf0
ak6DhfNR17jJ9sMo+LdTp3wnC1cOv/ORODOMABnhD5XHWLgzufx0Z/owEqQ/
7Nn+iAV1K6Ngr6xhJJar7Dkcy0Jtqtu9qbfDCHf1ue6XwIKkY+7bhZ+GQd9h
dD36BQt3y/b8Na0axqeFRSLPslh4HB10NqtvGDT7E1pClSy8XN9/7qrCCNYu
KQ24+4cFE1GXUMbKETwPe9g+Nc7Czw72k5WrR3Cu/pnxYT4LKncbC0vWj0Cs
8b7UUhobqfyymTP0RrBzTEP18Cw2Mr8+j7xmM4LaD70OK5eyYfF0xbN6uxF8
12YKmC5ng3s+Nkfp4Ai+Bq485C7HhobavcYvziOI2dxulKDIRs7da7IzvUfI
OzzauEmFjTynI6+Cb42ge2/+ldO6bNjpsT803B7BovuJS2y2sDEpfaBaOXIE
ql7O6v9RbOiWWw6X3h+BANOutGkrG/lqhloiz0cwJ11Pc9SEjc9TCkUhhSMw
iLnDNd3HhmPDkzpm8QgunC7KYtuyIZgh072qbASGlbPfe9uzYegsIfq1egQ8
3+Lr1w6Sd3g5bZdoywhEX/AYPs5sVNxjNV0fG0F+6U5fV082rB9ZWstPjID+
1jKwyouNjriymtypEXwI9vuy1puNieT0sh4hLvznz+iu92FjzYdLOUaSXBzT
LVboOUviL+Cpt0pz4axSELL0HBsGJcdSfGS48FT5N8vsPIm/enfiU3kuOmTf
29wPYOMGSy6CpsZFssTfD78C2ZDmRM29v4GL3MJraSNX2EjoE7mupkV+X3sm
aSSI5HNk6OKhLVxsCzl3l3WNjX6hQo+PZlzEqezW8LnBhp+oZp/lbi7mBU5M
77jJBl0s2fnXXi4oN5V3i2+xIbMw3H6JPRezA+NGkkLZ2LH68I6zruT76fJN
Z+6wUbeOUTzfg4vjHw5Qy8LZcPhvB/XCiwv3Qy8VPxA+s1ldq+E0FycTfAJ6
ItgQop5lnjjHhV2rxNCpSDbuGC5WnXGRi306r7UmCL/YSVupeY0LsfkP9HlR
RC8WvnGV17kIOuctcCyajQLrviXOoVzsHN0ZxiBsZn/g3uQdLroeh/bp3mWD
eahGIjKKizDx2PlPCDs7G4WtieHivBufNk546Ng70c8PuSjYrvJh5z02znus
u2oby8WSikK9R4RFvOMFhhO4aHu4/2oX4Si/BedDkri4PPgiXCmGDblz1//I
vuRi65VDhx0Jv7445f02hYunyUbce4S1g04OmmdwUWKwzriUcHEIx7U7i4uc
It6+IcK7Q205F3K5eKIVvEbyPhst4VUOCz5w0aLf8m494WN39Vtef+JCSO6v
sDFh3oNsG8MiLj6++jnXmvCl2NU/mr9wEbO/7vshwnMSH5ufKif/39Gy04lw
zAvx8lnVXFxdqxPkQFgx5apRQg0X9APqp2wIp2eMF2xicHGoVVxmO2HdHA/d
GiYXG/Zon/mPcGke++2xFi6yBMVCpQlb4JVGUTsXl7qqqsfI+duKfDKWdXIx
V7oyqobw8e1bVM90c/Gu5lVbEuGxypmvavu4+DG0+LUf4cA9NcrrBrhYPFDJ
pwjPrX+QGDzEhTo76Lsw4Rg7Z/kOLqn39dnKJSTfiu3rnuj+4cLIQEPgIuF0
pz8y9ya42D6nxX4DYd3egnvDU1y8DOnb1EHquXd4b3iSEA/VOwQurCfc5rtM
jCbCwy/+jI4qoo/jE9037GfzMAcnvroQDhT0D5ovwUOeYZFsCNGXWMhWmtsC
HkavTYbNJ3x/ztyAkkU8DFuuvhxJ9Ji+IO60vywP6wKcf4cQ/eo+cOXVKZD1
Dom6TxJ9ly3fcHK9Eg8MRq37McLtyl+Od6nw4O3izlcn/XH89e2eLWrk95Ny
t8Juk/yo2Trf38DD4OKieE4Y2V/n1wFzHR4uxtIPXyH9pWsmsSd3Gw9t0/3U
BdKfZd+bqyRMedhabSieep3Ea/XMxMOch5UD/e6NIWT9g9qGClY8bLl6+ats
MDm/10GtW448KJllq7sRP1AcVc7qPsLDnbzZfl7EL9LPDqvpu/Kg9vjkTq/L
ZP3AoDVjnjyYHKfnHbpIzhf1cpnDBR7svh1/PeVP8rXY50HeJR6SW1VeNRC/
mvtEb+GCIB60Tilse32GrP/8+/zyGySfC0/sN/Ij53s3JqgRw4OhrYCy1kmy
X6tB/8w3PLxVeJkq40LyU2Jwc08Oif9rUWES8VOxVAOVh+94KBkdKFznxIZH
gMEJ1QIeagelw1UciF/KGoxYVvEg4SeWMED8OtFBfyK+h4eBS4JHLpqx8WO7
/sOf/Tzs6mrAe+L3dHV9Xc1BHsT05NaMbGfjME0/oIzHw6f4io17jNhYnkDR
f9NGMXku2q9Oj+ivE7N0l46CI27QPLyO6L8Cr67KjuLZUFlH+1qSjzcw+6Yw
ioiMs4pfV7NhFYQwx9Wj2DN/hWPoSjYkVkLi+sZRSKi2yrSS+++WyxaZ+t2j
WL4CWx6R+/Fin+4ar6ujCBXy+JrewcIDvoYm7fooMgbuldW2s5A1bx0VcWsU
4h1vXv5uYaFfc5l1VuQobOPy1so0sGAZOHX5b/wovkcuTvuvgoU1S/IbL+WP
wvv4KTO/TBbqzHA9/M8oMvfpup64QP6frt+b6ToG+4ebPHxmsGC49TZvhscY
ar2ueRTQWThU3yJg7zWGDxHLH0tMtyOKf3qx4Okx5D3dGrXidzumtqea7A0a
w/emZff439vxnS2Twn0yhlkBUVbRkeT9I8k7qVE3hszk7pEcqXYU+iVNZm/5
A8rX8dtl0TZo/F0QGrnyL2aMzvo9ndhMkrVcRUdkHL77aPMW7muEltBQafDs
cQjVZub/3tUI1rNCJ4bYOLav+1ZZua0R//U5P/RaMI4qGXutKK1GNHi+mvVc
YRwatMRk24WNkLug3SepN46Vu/ki5Q1MZNyzSBo4OY6iDUs23tvPhN0mRYPN
vuOgtwQ1SVqRebl5tDXkzDiZL4663N3JhPXy+wsUL45D9J2DU8oWJiYS24Ps
bo3jrvt+LUV5Jgwy3Z1Kk8bBrhzfhZ4G1FVek4tvHodLbqTN2TMNOHZ/t9LG
9nHMHLIP1D7ZgKkjMioVHePIH/wFgeMNUPqXojXaN44TnpPPk+0bcEadYb7j
7zjMcsVjjqABS++uuDAsNYGwgWD5UJEGHDlU0KhvPoF3Z8pOD8XXY2Ltjfb6
PRPw2OyysulhPcL+7uW4WU1Axmtrb1V0PXLDe4ai90/gWfbixh/X6zGrWEyk
//gEXN+6RNh51yN11YGNEcETWNeQ4b/fqB5jw+MRHQUTsHrm8MiPy8CNLYsf
6BRPwLPPYXLGbwaW39SOjyidQJy00vr4fga2KZ5OM6ieAJfzbj2XzUCMNa8i
oXkCwTknzMRqGNB5PyjkNDaBP+qmp5UyGKieKTbn/fgEmjx15G1SGHC0XCcp
OTWBDOMlghHJDNwccJMvEpyEh7jsVaUEBlpk+/RWiE9iZGjvkopIBi4Edfp1
rp2EzufrsjPPMiBRQw/YvH4Sl/qqi1t9GUhapnA18r9JJI6+4eZ7k/1yHCK3
bpoEh20tEO9Ozt/XmvbUeBKrohrNuxwYyNScypncMYmJx77v5x1kwDhwaf7e
nZMQHa34YWTPgOcS+0pBy0kMnrJbWGvFQMFOZq/T4UnMXcra62bKgOWDP7/f
O09CoCot5Nd2Bnq7pf9IHpvEiTmfr50xZkD8kpVw8YlJVC6U+pWuT+LNrJVX
PD+Jf1Wrs59qMzA2Pbzq/MVJeD01CTu3keTbVFytLnASYzb3dhzUYOBN164t
Qdcnke1aetJQjQGhhVV2XXcnwf48VBO5igHdUoVrax9M4griJSqVGPA5fSbD
+/EkGEvQIraSgc6GFSK0xEmo7b4okSXPwOcY/+xlGZP41kzuiyUMTGz/znLO
msTb4X3/RGUY+G985ZzXbyeh2nzMKn4RAwm2NY46+ZPI3H6h+vcCBi7LrJpv
UzGJU8vmL5kjzkBu+YXNT6pJvc4++Tgwj4Eh/x8unJpJuJ9QojeJMeDQHPDx
FHMSty7QfWvnEH3crOvNa56E3SmZZ22zGfi+eY0UvX0Sj3Pe+I/OYoB6xDh+
hzOJr8Nqi7eKMnDGbO3dhl5Sr5NmnWdFGEjnXypc/ovk23Sf1fuZJN+v638d
+U30cajYcyZh2QMqi1JGJqFN+/3fwRkMWM8N3MobnUTPb8XYT8IMhH1sOLF5
nNRnf3zWWsLTy66UfP03Cc2H9JYVQgxsrGYOzRfkQ/iv8GCaIAMnAlSX7pvB
R1DPrWRjwkmqQdtiRflYXuQv1ktnoK2t0bt7Dh9fLOKXRhGWvr3+ybr5fByu
KvhhQtgcV7/6SPIh1Ri8YQ7ha7+beO+l+Wi8GbmZSWPgY6yanKAMH3w3z5+p
hHm7rpmaLONjwiva4A5hFYEWv3A5PgyFTlDnCTunqycwV/ChRt/d5U34kUNw
lawyH3LvL63zIVw3v/Wvyxo+EnkbllwiPKfwP8XUdXzk9t98fZew4cmQXaNq
fBjvuc96S/i8fJu/rgYf6Vb2OZ2Es2o2JF3R4sM87pOKDDnvr8vXa8p1+Nhv
nWBgT1jxv3a++BY+spZUjyURtu/QWGWrz0eLFH/bFOGIiBt74wz5WNT3Q+Mg
yVe5ASugZxsfCcU/338lTOdqvlQ15WPYrqwZJN86T28yfM1JPH0tEQWEvfey
BT7u4YOhfbPdlNTnpaCWipAVH0oJKwrYhGWcOwIj7Pnwm+ZrriP1tpDSTm08
SPa7FlzaQfhGcWijnCMfP6xvcxKIXsYVN6mlHePjaFp/vgHR11KB4BI9dz5U
w2T5mkR/VHOdXaUnyRe/4IEm0ee1cK+rfX58PP10bMiW6DfZPV/mjD8fH7MN
4gOIviu3zUmfEcDH3Rtqz9PmMyA5/bxpxVUSX0ZP4kZJop/GUc/MED5KtUui
b0kxYJe1VVj/Fh8LpdurBkn/xB1vX38wko/zU31CTNJf6xqkr8bEk/rnLZLX
k2Vgd6azjPIzUg8V3XaeHOnn0My07Bd8bDQ4XZyrwEDeVvOm2jQ+olIcRpxJ
v29Lv7p+bj4fuzUl7MxVGTh+80fxw0I+OkuTv7kQvwhzkbdbU0LqdWKX8c3/
iD6WfgzaVsnHQXkhhb/Ebw5f5zVebuJjz6F3fAeKgSBnA8/5bXzorJ/NYRow
8AJ3hGLZfCxRuJ2w34iBwdG16z/08vE78PrVYBMGzjk6BY2N8XFNvpI6Tvwx
enOtqpvkFOYOLB884EH8QVqueFx6CoWtBpp3vIifD3vYhshMQZL2ubfqFAMK
L0SDnslPIe7ZzdNu/gykSek3tq+fQu6CMEfVEAa+DqRdsTSbwp+C2JjKZ0SP
2/fKJO2aQsrdLR0nyH0hljiW/sdiClcvBqfJkPvE0k6v7YHtFOSuc3PDshhg
fSnXZrtMwUksL7+niIG/sZwBj8tTyI4zXm7TxcAqiyX7gnOm0DPgrc9bWw/T
lPxB5rspfPbboJWrVo8TIo5X13ycwuDeXxlBmvXIyn+RWVU0hY+ngyW0UA9q
7ca5UjVT8GqeeUVgbz1shPZ8jvs5hZDCdSLLz9fjWs41lTy5aZwSqJ1D1dUj
Sldh3V7Fadx6+vtmQFM9nn7+uO6X8jRUjps8KWHVo6Cap7p8/TTWPkwy9hio
x3i3o3qg3jQc7ZnK8jMb4L4QG03spiG3UFl4nm4DLM78QVPkNJKyDXKfvGrA
cp1jeydm/EPUIXvbzU+YePox+dtE6z8k3unxULjThJkLPqs47hOgpot+YFdg
C6zba3zW2glQK+dtNQy60YLEZPYHnr0AJeSa3pUd0QKDLbSdwYcEKL2qsGyx
py04f5TyeO0iQMVxlT5GFbVg6F1+ypiPAFV08dHLTsFWMA++V70ZLkDtUz7c
vehyK5RWV/hZRgpQ2k5FkoUhrfDlNuUvixagbMcXVjndaYVEyIR5egz5PmZh
YkxsK8wyNnkyYgWoN9H7Vud/bEWhYG6abKoA5YGPnP6/rXj5Ikstq1yASlzg
stPheBv+/uc5frBSgGriftQq9WrDto+rP4tWC1CZPbc+KJ9uQ1fNk72HagQo
myrZo4wrbVg2GeI3iylAPX7sP8V+1IY7Ow98cOAIUH5z7iKnqg2nR4S3zxWg
UetPj4pNr27Hl/MF83NpNOrIQb+kwPXtkJp5rtFRkEZFvY4490+jHelLho7n
zqBRfxQscsi0gn7DplCnuTSK7Vljvc2qHQfvpf54J0Oj1tKm34YFtMNQ1+aQ
iyaN2m3z4nJleTtEWua2amjRqFjWSPGzb+2oPFdsJ7iJRgU9/3Tbp64dlu/V
reN0aZTJlbrwkdZ2HNGZs7NpK40yjzJW8hxqxzXtQh1zCxrFPUvjpIuyYMI8
nbvUkny/bp9j6WwWxM6obvxpRda7QVky57Jw9+1D9RBbwi7nr/SJs/B8o9+q
zw406pejZETZYhbKNNZKb/SkUZRKzgvfVSzcqmNHCp2kUY+9Zzqqr2Fht0+M
+A9vGvX5+6Bpz1oWmG+E53r50aiBCOkE/fUs9P3HEnx5gUYpegQMpmmykFp7
9/KZizTKJqXjs64WC97eO/8ZX6ZRf023vCzSZmEiI2+iM4hGnXg9+PTTZhZm
qUcPL7tFo44N2HV56rNQ/d3U81cojTJy2zlcacBChBd9IO82jer6fXdshSEL
MumevTaRNEr1YEnrJ2Myz6w3aQ9/QKMC5WzLU01ZGKwWOODwiEZ1C5wxajZj
IfPE2ybVJzRKb69tPM2cBZ1UxfqKeBolr3hlaPNuFkzX/asUTib7+4k+dbFk
gTX9vaXiJY0asgu1PGDFgt/3hF/hr2lUvkPebHNrFhJOGc9Znk7qqaIXuGwf
C9pGi5Z2ZdCoreXGenzC1dL9a1++IXoyODxaZ0vifRdquvEtjVq+NMPSx56F
OzcP2fNzaVT29J8/OvtZUDqg7vY5j0YJFXvfmSRsIcC4YZ5Poz7sfHH/+EEW
XhovLXcpoVFZOkot/xxYoBYNNqqU0ijd0so/0YdZqO/71DdSRtb7rTC50pEF
eqiT6MVKotdRfuYGJxZiDmouNqom9RtPcc4grKo2c/Xs7zSK9evY31XOLNj+
eLn93g8a9aqjsUD4CMlf4vl9Bxg0atJ6Kfc44SA/82MrGmjUpoTL9HLCMtvl
zvQxif4bBgYUXFhIXzwSnNZEo74J7MnyJWz8s+iebwuN8l/63PIz4ZYP0c83
t5F4VvytEjlK9BB29C2NRaNMZ+2T3UFYxGFTaSmbRt0v6N52hfAT9dkNoZ00
6oLmd+O3hDUEW7v3cmhUuY3ZEg7h8rrUscU9NKptYWzxnGMsOCRdmsHqpVEz
XRcZqBIeO20hndRPoyoNpCJ3EL61Q1HJ/ReN0k6YyDlIWGHJmOZ/g+T8N5Di
QTj3V6nR3980ylXEydePsHn+fav8YRp1R3VY7CzhrttuR4K4RL8ygWd9Cfsf
1vM1GaVRvqPvstwIz98w7+r8PzSqaWh7gT3hJCF2VP1fkn/Tnw+NCOvWZyY+
mqBRsrtdt60mXPs8KMuRT6MCrO59nkH46Fnr4lXTNCrkk9XcNhIf32RV3eA/
opd/d5TTCEcsnejMotGpfRH64v6EVw1WcP0F6dQtIffyLYTzPz0W1BemU0aD
cnunSL4twz0lZ86kU7Kj519lE+531F9RJUK+r3jx4yhh6RkcA9s5dEr7t3nU
O1LP1w05FrJidGp7m/U6W8IGySGOnHl06mL7jnsjRB8nzFQCT0rSqUO1d9ol
CAstnw7XWkCnFuXW5t8nenrw+1v8lDSdMr7b7CVD+EvEqcLrMnRKyDdhlyjR
437FoT3qS+nUfTEv/8tEryPZ7h3MZXRKBle38YielzUeEVwlT6c8b82u+HqI
9OvxjshvCnRqkMsIVCG8nX9Q8bQinXK4+qD9OukHH9l9Rl+U6VRI5KqbGgeI
f2TUMTxWEx6ObL5M+ifOYI/LgrV0avcmvbqvpN8qjpgEO6vSqQTOUOEOO1L/
17pf6Zp0qjT4+EtRG1J/vXe2LzfSqaJYyX0qpL/Nv2n279GmUxOaGjk7SP+f
HVGdHb+ZTmn1Pg3x2cvCd235nTCgU0PJr5Nv7GIhoES45twuOqUrhAV5xI+k
bAIPr9hDp+zVDrqHGJH+7Z0eLregU03dCjf3EP9izP4rIWNNp3hfY5XqiN+p
WPRb5u6nU3lbXUUe6rLQ1FbN5LnSqbE9Mirq6ix4eZm6PnKjU+FOMh2vid/O
oJeNb/WgU5kTxRdXqLKgvrJQJtKLTsVfNj1HI/4c4vZmv/ppUt+V+7MvKbKg
9fceyyOITtWduOUUJk3qGztfadM1OqWumT0VLkXiNb7uJhRCp5Jk3cpvS7Dg
HOU/9uAmnVoyd0TUX4zoT+3AnLIIOsVQl7kuOoP4wzEFbYV4OpVv68JY39uO
iXkPLwwk0KncsOqBS53tEH4rWZSbSKdOtlF9X9rasVRY2HzXC1KfqzWv1Bnt
MInvcTqfRqfOOuy1vlLYjqTG17frP9Ip1zCmnmxMOzIvrWTEf6JTQX/fFHyO
aMdH5ScyHoV0qnjOyzz70HbU+d5+JlhCp3xfMTafCGwHXcL7vVolnXr00+i2
tDu5f020em400SlboYEnF/TaIf2+cAv+0Cnh+QIJI8w2yCtwhH79pVPRlL1Z
eW0bVK6LVMRM0Cmne//9u1/Zhq02u2xGpsh+R74kyRe0wYvb4vlMSJByb7q7
5EdSGyrW/o2bLSFIsbU/5JZ6t+HSI1VBpoog9U2p2HKrcBt+XnhY6uUoSCVW
WJ8QWdiKDdn6DdcqBKm+yP0r2WLN6NsxsPKGnhB1wbU2Wy2fCd3c2jcbIETl
aZ47kZzNRJhSrn4rJUTtFvbcrpjCJP535YCaoRD1cse8GLlHTAR8WBRdbyJE
6SQZqmj6MyG13lBoxT4hSjct37RpIxOQetjx3luI2vLaP9QnswHRbdtjB54L
UXrBgm4N2fVIPbT/VVmyEMXvqeg9nFKPLyzPt09fCVFhliIbuIn1+Ntx95tt
mhB1TcL15Jqoeuzv6fpXkiNEDfUc9R7wrofC0CWHJyVC1GPX99p16vVIp72T
39UpRNW94K+9l03e74GV69ZwhKha+h7jJakMdAiyNgn3kPOGy214kUTmpxkz
Ld73C1HtU0cLWu4x4DfLKlB5RIjyesA1ySTzgJ7kcMc/AWGKZ3Th5xIyj1hH
Cf1uogtT+x6vlNLYTObzBYsms4WEqfkH7f9YaZD5aiEk3UWEKb0vOYpvyXwk
tDR0K3OeMJVYEnV/iMx7yx7H7XojLkx1HYhdsI/MkxuXZ9mHSQpT1M9nuV+n
63BUrvmU4UJh6qyVyYuK4Tpcih+8KLtYmBKpFJy3/2cdYhTotyZkhKnkDUPf
x7rqkPF0QQxjqTB1Ir974mFbHcoVVyemLxemoqJf3Ddl1uF/k1A2uQ==
      "]]}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->True,
  FrameLabel->{
    FormBox["\"time\"", TraditionalForm], 
    FormBox["\"u\"", TraditionalForm]},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  Method->{},
  PlotRange->All,
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.02], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.6385163559838*^9, 3.6386024616366*^9}]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 "\[FilledSquare] Numerical results with the ",
 StyleBox["predictive",
  FontSlant->"Italic"],
 " method for tolerance  \[Tau]=0.001"
}], "Subsubsection",
 CellChangeTimes->{{3.633439583415289*^9, 3.6334395909637213`*^9}, {
   3.636904756973955*^9, 3.636904760701168*^9}, 3.637138408549569*^9, {
   3.6372452357805834`*^9, 3.6372452451731205`*^9}, {3.6372463821981544`*^9, 
   3.6372463827581863`*^9}, {3.6372466129283514`*^9, 3.637246617848633*^9}, {
   3.6372496176812134`*^9, 3.637249632328051*^9}, {3.6373012138633003`*^9, 
   3.6373012367823*^9}}],

Cell[CellGroupData[{

Cell[TextData[{
 "uMs is a matrix that contains the full solution ",
 Cell[BoxData[
  FormBox[
   RowBox[{"{", 
    RowBox[{
     SubsuperscriptBox["U", "0", 
      RowBox[{"(", "m", ")"}]], ",", 
     SubsuperscriptBox["U", "1", 
      RowBox[{"(", "m", ")"}]], ",", 
     SubsuperscriptBox["U", "2", 
      RowBox[{"(", "m", ")"}]], ",", 
     RowBox[{"...", " ", 
      SubsuperscriptBox["U", "Np", 
       RowBox[{"(", "m", ")"}]]}]}], "}"}], TraditionalForm]]],
 "  for m=0,1,2,....,numSteps."
}], "Text",
 CellChangeTimes->{{3.6372979828863*^9, 3.6372980614302998`*^9}},
 Background->RGBColor[1, 1, 0.85]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"tolerance", "=", "0.001"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"numSteps", "=", "40"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"CPUtime", "=", 
   RowBox[{"Timing", "[", 
    RowBox[{"uMs", "=", 
     RowBox[{"uMsolutionPredictive", "[", 
      RowBox[{"numSteps", ",", "tolerance"}], "]"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Print", "[", 
   RowBox[{
   "\"\<Example 2. Predictive method. Case with \[Tau]=\>\"", ",", 
    "tolerance", ",", "\"\< for \[Gamma]=\>\"", ",", "gammak", ",", 
    "\"\<, Np=\>\"", ",", "Np", ",", 
    "\"\<,\!\(TraditionalForm\`\(\(\\\ \)\*SubscriptBox[\(\[CapitalDelta]\), \
\(0\)]\)\)=\>\"", ",", "Delta0Predictive", ",", 
    "\"\<, \!\(TraditionalForm\`\*SubscriptBox[\(\[CapitalDelta]\), \
\(max\)]\)=\>\"", " ", ",", "DeltatcapPredictive", " ", ",", "  ", 
    "\"\<,\[Omega]=\>\"", ",", "  ", "omegaParameter", ",", " ", 
    "\"\<,\!\(TraditionalForm\`\(\(\\\ \)\(\[Theta]\)\)\)=\>\"", ",", "  ", 
    "thetaParameter"}], "  ", "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Print", "[", 
   RowBox[{"\"\<CPU time=\>\"", ",", 
    RowBox[{"CPUtime", "[", 
     RowBox[{"[", "1", "]"}], "]"}], ",", "\"\< seconds\>\""}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
  "Print", "[", "\"\<The solution is saved in the matrix uMs\>\"", "]"}], 
  ";"}]}], "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 CellChangeTimes->{{3.56061256346875*^9, 3.56061257284375*^9}, {
   3.56061260303125*^9, 3.560612663828125*^9}, {3.5610884668366947`*^9, 
   3.5610884717649765`*^9}, {3.5611210929323997`*^9, 3.5611211203416*^9}, {
   3.5611212573096*^9, 3.5611212593532*^9}, 3.5611216448120003`*^9, {
   3.5611216844625998`*^9, 3.5611216848213997`*^9}, {3.5611217681558*^9, 
   3.5611217684667997`*^9}, {3.5611222944344*^9, 3.5611223196862*^9}, {
   3.5611253416166*^9, 3.5611253440626*^9}, {3.5611260133876*^9, 
   3.5611260138276*^9}, {3.561127402519*^9, 3.5611274579006*^9}, {
   3.561127527574*^9, 3.5611275627130003`*^9}, {3.5902000697948065`*^9, 
   3.5902000708068647`*^9}, {3.590200323138297*^9, 3.590200324873397*^9}, {
   3.5902003709750333`*^9, 3.5902003711460433`*^9}, 3.590200421820942*^9, 
   3.590213289142*^9, {3.5902135189*^9, 3.590213539836*^9}, {
   3.5902135876359997`*^9, 3.590213616165*^9}, {3.590213707484*^9, 
   3.590213707868*^9}, {3.590213768476*^9, 3.590213768955*^9}, 
   3.5902143461549997`*^9, {3.59021447142*^9, 3.590214495682*^9}, 
   3.5903882375313997`*^9, {3.5903932563884*^9, 3.5903932567464*^9}, {
   3.5903932903714*^9, 3.5903933180104*^9}, {3.5903933542194*^9, 
   3.5903933561303997`*^9}, 3.5903933876914*^9, 3.5903934182594*^9, 
   3.5903941132114*^9, 3.60195384860737*^9, {3.601953894449992*^9, 
   3.601953894987023*^9}, {3.6334400976967044`*^9, 3.6334400980167227`*^9}, 
   3.6369936572364435`*^9, {3.636993750675788*^9, 3.6369937637635365`*^9}, 
   3.637004923308416*^9, 3.6370053615804834`*^9, {3.6372402113622026`*^9, 
   3.637240211367203*^9}, {3.6372452960570307`*^9, 3.6372453605797215`*^9}, {
   3.6372453910404634`*^9, 3.637245428304595*^9}, {3.637245470149988*^9, 
   3.6372455167096515`*^9}, {3.6372456161863413`*^9, 3.637245697827011*^9}, {
   3.637245729372815*^9, 3.637245777960594*^9}, {3.63724584310532*^9, 
   3.6372459587629356`*^9}, {3.637246021107501*^9, 3.6372460259367776`*^9}, {
   3.637246091338518*^9, 3.6372460918335466`*^9}, 3.6372463595788608`*^9, 
   3.637246525799368*^9, {3.6372465623644595`*^9, 3.637246581655563*^9}, {
   3.637246817573056*^9, 3.6372468214022756`*^9}, {3.6372470179475174`*^9, 
   3.637247018278536*^9}, {3.6372471839910145`*^9, 3.6372472107335443`*^9}, {
   3.6372472497587757`*^9, 3.637247279316467*^9}, {3.637247390205809*^9, 
   3.6372473996553497`*^9}, {3.637247443785874*^9, 3.6372474491481805`*^9}, {
   3.637247899618946*^9, 3.6372479030021396`*^9}, {3.637247939714239*^9, 
   3.6372479400092564`*^9}, {3.6372482082135963`*^9, 3.637248224762543*^9}, {
   3.637248553257332*^9, 3.6372485587676473`*^9}, 3.6372496070256042`*^9, 
   3.6372975701323*^9, {3.6372979117462997`*^9, 3.6372979144493*^9}, 
   3.6372981329823*^9, 3.6372981646743*^9, {3.6372982614663*^9, 
   3.6372982617132998`*^9}, {3.6373004952983*^9, 3.6373005432813*^9}, {
   3.6373007987373*^9, 3.6373008130083*^9}, {3.6373034194023*^9, 
   3.6373034304823*^9}, {3.6373034651153*^9, 3.6373034655383*^9}, {
   3.6373035025413*^9, 3.6373035583803*^9}, {3.6373036204123*^9, 
   3.6373036352023*^9}, 3.6373042230362997`*^9, {3.6373043002433*^9, 
   3.6373043131063004`*^9}, {3.637321205769141*^9, 3.637321206067158*^9}, 
   3.6373675926856403`*^9, 3.637367918524277*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Example 2. Predictive method. Case with \[Tau]=\"\>", 
   "\[InvisibleSpace]", "0.001`", 
   "\[InvisibleSpace]", "\<\" for \[Gamma]=\"\>", "\[InvisibleSpace]", 
   "0.25`", "\[InvisibleSpace]", "\<\", Np=\"\>", "\[InvisibleSpace]", "40", 
   "\[InvisibleSpace]", "\<\",\\!\\(TraditionalForm\\`\\(\\(\\\\ \
\\)\\*SubscriptBox[\\(\[CapitalDelta]\\), \\(0\\)]\\)\\)=\"\>", 
   "\[InvisibleSpace]", "0.01`", 
   "\[InvisibleSpace]", "\<\", \\!\\(TraditionalForm\\`\\*SubscriptBox[\\(\
\[CapitalDelta]\\), \\(max\\)]\\)=\"\>", "\[InvisibleSpace]", "1.`*^6", 
   "\[InvisibleSpace]", "\<\",\[Omega]=\"\>", "\[InvisibleSpace]", "0.5`", 
   "\[InvisibleSpace]", "\<\",\\!\\(TraditionalForm\\`\\(\\(\\\\ \\)\\(\
\[Theta]\\)\\)\\)=\"\>", "\[InvisibleSpace]", "1.5`"}],
  SequenceForm[
  "Example 2. Predictive method. Case with \[Tau]=", 0.001, " for \[Gamma]=", 
   0.25, ", Np=", 40, 
   ",\!\(TraditionalForm\`\(\(\\ \)\*SubscriptBox[\(\[CapitalDelta]\), \(0\)]\
\)\)=", 0.01, 
   ", \!\(TraditionalForm\`\*SubscriptBox[\(\[CapitalDelta]\), \(max\)]\)=", 
   1.*^6, ",\[Omega]=", 0.5, 
   ",\!\(TraditionalForm\`\(\(\\ \)\(\[Theta]\)\)\)=", 1.5],
  Editable->False]], "Print",
 CellChangeTimes->{3.6385163630488*^9, 3.6386024684166*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"CPU time=\"\>", "\[InvisibleSpace]", "6.7236431`", 
   "\[InvisibleSpace]", "\<\" seconds\"\>"}],
  SequenceForm["CPU time=", 6.7236431, " seconds"],
  Editable->False]], "Print",
 CellChangeTimes->{3.6385163630488*^9, 3.6386024684186*^9}],

Cell[BoxData["\<\"The solution is saved in the matrix uMs\"\>"], "Print",
 CellChangeTimes->{3.6385163630488*^9, 3.6386024684216003`*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 "The solution for the m-th timestep is just the m+1 element of this matrix:  \
uMs[[m+1]]=",
 Cell[BoxData[
  FormBox[
   RowBox[{"{", 
    RowBox[{
     SubsuperscriptBox["U", "0", 
      RowBox[{"(", "m", ")"}]], ",", 
     SubsuperscriptBox["U", "1", 
      RowBox[{"(", "m", ")"}]], ",", 
     SubsuperscriptBox["U", "2", 
      RowBox[{"(", "m", ")"}]], ",", 
     RowBox[{"...", " ", 
      SubsuperscriptBox["U", "Np", 
       RowBox[{"(", "m", ")"}]]}]}], "}"}], TraditionalForm]]],
 " "
}], "Text",
 CellChangeTimes->{{3.6372981691743*^9, 3.6372982503743*^9}, {
  3.6372983312943*^9, 3.6372983351903*^9}},
 Background->RGBColor[1, 1, 0.85]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"mStep", "=", "5"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Print", "[", 
   RowBox[{"\"\<The numerical solution at time \>\"", ",", 
    RowBox[{"tt", "[", "mStep", "]"}], ",", "\"\< is:\>\""}], "]"}], ";", 
  RowBox[{"uMs", "[", 
   RowBox[{"[", "mStep", "]"}], "]"}]}]}], "Input",
 CellChangeTimes->{{3.6372983391352997`*^9, 3.6372983412483*^9}, {
  3.6372985221443*^9, 3.6372986028712997`*^9}}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"The numerical solution at time \"\>", "\[InvisibleSpace]", 
   "0.000027343896323029062`", "\[InvisibleSpace]", "\<\" is:\"\>"}],
  SequenceForm[
  "The numerical solution at time ", 0.000027343896323029062`, " is:"],
  Editable->False]], "Print",
 CellChangeTimes->{3.6385163630938*^9, 3.6386024684556*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"-", "1.188930078808245`*^-16"}], ",", "0.0743465888376462`", ",", 
   "0.14823480623235888`", ",", "0.22120910675357391`", ",", 
   "0.2928195795721607`", ",", "0.36262472231029397`", ",", 
   "0.4301941630504277`", ",", "0.49511131372127987`", ",", 
   "0.5569759385018215`", ",", "0.6154066214082051`", ",", 
   "0.6700431178501394`", ",", "0.7205485756585808`", ",", 
   "0.7666116118913715`", ",", "0.8079482326126222`", ",", 
   "0.8443035838097652`", ",", "0.8754535226532894`", ",", 
   "0.9012059994118184`", ",", "0.9214022415025687`", ",", 
   "0.9359177323771183`", ",", "0.9446629792073352`", ",", 
   "0.9475840646384216`", ",", "0.9446629792073354`", ",", 
   "0.9359177323771185`", ",", "0.9214022415025689`", ",", 
   "0.9012059994118189`", ",", "0.8754535226532898`", ",", 
   "0.8443035838097657`", ",", "0.8079482326126224`", ",", 
   "0.7666116118913715`", ",", "0.7205485756585809`", ",", 
   "0.6700431178501395`", ",", "0.6154066214082052`", ",", 
   "0.5569759385018216`", ",", "0.49511131372128003`", ",", 
   "0.43019416305042785`", ",", "0.362624722310294`", ",", 
   "0.2928195795721607`", ",", "0.22120910675357391`", ",", 
   "0.14823480623235888`", ",", "0.07434658883764626`", ",", "0.`"}], 
  "}"}]], "Output",
 CellChangeTimes->{3.6385163630968*^9, 3.6386024684586*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 "The [[m+1,j+1] element of this matrix is the numerical solution for time ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["t", "m"], TraditionalForm]],
  FormatType->"TraditionalForm"],
 " and position ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["x", "j"], TraditionalForm]],
  FormatType->"TraditionalForm"],
 ":  uMs[[m+1,j+1]]=",
 Cell[BoxData[
  FormBox[
   SubsuperscriptBox["U", "j", 
    RowBox[{"(", "m", ")"}]], TraditionalForm]]],
 " "
}], "Text",
 CellChangeTimes->{{3.6372981691743*^9, 3.6372982503743*^9}, {
  3.6372983312943*^9, 3.6372983351903*^9}, {3.6372983799263*^9, 
  3.6372984925123*^9}},
 Background->RGBColor[1, 1, 0.85]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"mStep", "=", "5"}], ";", 
  RowBox[{"jPos", "=", 
   RowBox[{"Nx", "+", "1"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Print", "[", 
   RowBox[{"\"\<The numerical solution at time t=\>\"", ",", 
    RowBox[{"tt", "[", "mStep", "]"}], ",", "\"\< and position x= \>\"", " ", 
    ",", 
    RowBox[{"jPos", "*", "deltax"}], " ", ",", "\"\< is:\>\""}], "]"}], ";", 
  RowBox[{"uMs", "[", 
   RowBox[{"[", 
    RowBox[{"mStep", ",", "jPos"}], "]"}], "]"}]}]}], "Input",
 CellChangeTimes->{{3.6372983391352997`*^9, 3.6372983412483*^9}, {
  3.6372985221443*^9, 3.6372986028712997`*^9}, {3.6372986373603*^9, 
  3.6372986956313*^9}}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"The numerical solution at time t=\"\>", "\[InvisibleSpace]", 
   "0.000027343896323029062`", 
   "\[InvisibleSpace]", "\<\" and position x= \"\>", "\[InvisibleSpace]", 
   "1.6493361431346414`", "\[InvisibleSpace]", "\<\" is:\"\>"}],
  SequenceForm[
  "The numerical solution at time t=", 0.000027343896323029062`, 
   " and position x= ", 1.6493361431346414`, " is:"],
  Editable->False]], "Print",
 CellChangeTimes->{3.6385163631428003`*^9, 3.6386024684656*^9}],

Cell[BoxData["0.9475840646384216`"], "Output",
 CellChangeTimes->{3.6385163631448*^9, 3.6386024684676*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 "A plot comparing the numerical and the exact solution at time ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["t", "mStep"], TraditionalForm]],
  FormatType->"TraditionalForm"],
 " "
}], "Text",
 CellChangeTimes->{{3.6372989561913*^9, 3.6372990023753*^9}, {
  3.6372990787602997`*^9, 3.6372990811603003`*^9}},
 Background->RGBColor[1, 1, 0.85]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"mStep", "=", "5"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Print", "[", "\"\<Predictive method\>\"", "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Print", "[", 
   RowBox[{
   "\"\<Numerical solution (points) and exact solution (line)  at time \
t=\>\"", ",", 
    RowBox[{"tt", "[", "mStep", "]"}]}], "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{" ", 
  RowBox[{
   RowBox[{"FigNum", "=", 
    RowBox[{"ListPlot", "[", 
     RowBox[{
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"xj", "=", 
           RowBox[{"j", "*", "deltax"}]}], ",", 
          RowBox[{"uMs", "[", 
           RowBox[{"[", 
            RowBox[{
             RowBox[{"mStep", "+", "1"}], ",", 
             RowBox[{"j", "+", "1"}]}], "]"}], "]"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"j", ",", "0", ",", "Np"}], "}"}]}], "]"}], ",", 
      RowBox[{"PlotRange", "\[Rule]", "All"}]}], "]"}]}], ";", 
   RowBox[{"FigExact", "=", 
    RowBox[{"Plot", "[", 
     RowBox[{
      RowBox[{"uSol", "[", 
       RowBox[{"x", ",", 
        RowBox[{"tt", "[", "mStep", "]"}], ",", "gammak"}], "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"x", ",", "0", ",", "Pi"}], "}"}], ",", 
      RowBox[{"PlotRange", "\[Rule]", "All"}]}], "]"}]}], ";", " ", 
   RowBox[{"Show", "[", 
    RowBox[{"FigNum", ",", "FigExact", ",", 
     RowBox[{"Frame", "\[Rule]", "True"}], ",", 
     RowBox[{"FrameLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<x\>\"", ",", "\"\<u\>\""}], "}"}]}]}], 
    "]"}]}]}]}], "Input",
 CellChangeTimes->{{3.6372990098493*^9, 3.6372993557363*^9}, {
   3.6372994017143*^9, 3.6372994018733*^9}, {3.6372994547862997`*^9, 
   3.6372994982653*^9}, {3.6372997348883*^9, 3.6372998253603*^9}, 
   3.6373011632593*^9, {3.6373012486103*^9, 3.6373012562163*^9}, 
   3.637368680192842*^9, {3.6385155346308002`*^9, 3.6385155474378*^9}, {
   3.6385155955657997`*^9, 3.6385155980698*^9}}],

Cell[BoxData["\<\"Predictive method\"\>"], "Print",
 CellChangeTimes->{3.6385163631918*^9, 3.6386024684736*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Numerical solution (points) and exact solution (line)  at time \
t=\"\>", "\[InvisibleSpace]", "0.000027343896323029062`"}],
  SequenceForm[
  "Numerical solution (points) and exact solution (line)  at time t=", 
   0.000027343896323029062`],
  Editable->False]], "Print",
 CellChangeTimes->{3.6385163631918*^9, 3.6386024684756002`*^9}],

Cell[BoxData[
 GraphicsBox[{{{}, {{}, 
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
      0.012833333333333334`], AbsoluteThickness[1.6], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQBGIQDQM3y5a0zk1dYPPgw5wyfekt9vvvHu+6s3WTPYR/
xN4slH+CxPJD9gGZrw2Pa5yz7/gXZHzp6mmo/BV7JuanNX45l+wldF1Cfive
tN8nvohpwYVrUPX37B93zld4L3Db/kjQyfaT0x/a12g6KLWp3Yfqf2Lf/vJi
fGXrQ/s/fQWpU+c9s3+8RUuVI+Yx1LyX9g2x+9dziDy1Nzkt7py49LU9v6dW
x5FVz6Dmv7P/EqO8c6fsC/ttzfETxMI+2O//vv3IvKyXUPs+2htsTnZI639l
f0nRuL7m5id7v4xwIaeu11D7v9gLTb/otSzyjf27/Wx5j2K+2u/i4Zzq/ecN
1D3f7AvKzlsbFr6154q7FePx4Lu9b+meffO2v4W676f9022JX1XOv7VX+7PW
e13yL7g8xL2/7Quh+p1mNVqJPP8DNx/i/n/2AlD74yxCNauy/tt7Qd0H8Q+D
gw7U/bbZIjwfvjE47EbxH6PDR6j/va3qmBdbMDnwQsMH4l8mh3po+EVyvvgV
WsXs8BAavhD/szi0QcM//UbgJ449LA610PiBhAerAyz+Spfvfrn7L6sDLH4h
4cPmAIv/5jLVh3n27A5t0PQBCS92B2No+pno2n9DsZHDYSc0fUHCj9MBlg4B
IUU3Qg==
       "]]}, {}}, {}}, {{}, {}, 
    {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], Opacity[
     1.], LineBox[CompressedData["
1:eJwd2HlYTdv/B/A6hRMiaTKlDKFbNN0m6X2qm0SohCRJxtBMJYWiFGkSylCR
Rs0UGlBSIWSsVDRPZ2/3Up1z9mn6rd/3r/28nvXsvdbz+az1+axnK7t42B5k
iYiIiImKiPzv+Xz6+66/vYzrM6fdCG3zMFaSU1JRvLoVax56dI4YbsZIW8yW
5ri9mOtQaVZsuAftJq87S+I8kCH6uDHW0A1ffXpy0uLOomXTUJ6PYRAaIofm
3ImLxoz33z5oGV7B5sSA6oS4ZKw9J6W/yeAOIhc/u3M9Lh/fw/qHSv/OxSB/
6qSJzwvE3j1SULL3GfTHY60fetbBI2HThSlBNXj9w/48a2kDBhI/S9ZHvwPH
1G403eULps9SWtB75RMcPC3/K97VBAPR/OFUkW94pqwa8iKtFYuVYs/V3m+G
XYJqapt7O6Ivyy5VXdCGBVMqzGIOdSJmifwpz4XtuKj9quhFeDdkR89MWJR1
wNxio3N6WC+kHp2K2K/WhVcRwyoXAvpRV1Md/uZ8NwavyJT/TBhE5N4f42s7
e7DPrzD6vzgK+cECH8W5fQhaUq159vEv1LEuHlz0Tz9WTwTxWK7/4bBvTOoJ
uwHU7rEfUjrwG28Fn4L0DQahmeTWGHTiD9y9pCPqZbiYoAKKff3/wGOHV0uN
PBdv1oZf9Qj8A9m99iHP53Ph0nxv674Lf1DnIfbugRIX8TJNtf/E/0GCy0Nr
TzUueJdMn8x4RMY/TPZnmnFR6iefmDj0B8XZnYqNnlz8Y1PpUOw9hOvKbWKK
NeT9y8d0xPyGcLv/39zOOi66XsnOsjk9hHtOG7enveUixPBoJXV+CDN/S9xa
9pGLyqVzVy67NoTz7OXj01u5MOYdGIl7PIRkk4Z/fX9zoX+LHeM5NoRzjQ26
b+ZT+Ktn66u/wobh7+M/xe4whSZXteiDl4Zht6eRFelKIewXe1dy1DDis1vE
q45RaOdXUtI3hqGeriu30pNC/HQdGWHGMPbvo11b/SmMrVHYX/d6GFZakQ97
Iii8D2gXOSg5goTPlnWnsimcnix/kzRnBNpjoVLeORRWXkiMb5IdQeevcvsj
eRRCrtiutFIcQZhmdP+WIgp6KdVbtdeMQIMnEBUvpZDyKjNJ1GYEvqtGxiVf
U/CW8jJKih9BnkGYVkoPhcGoN57RCSP4uJuuMuyj4CK5LO3c7RG06y2P+9xP
wWZ6o+T++yNoG0qlJrkUNMTX/VzxaAShm9Wjzf5Q+MVnhxR+HkF6jsVJ3wkK
R3+m1FZL8zB7E1/5kiyNzj3C0WI5HkoPejlRcjQcWrdpZMznQWpK4zcrBRqW
zVMTI5bwYLpj9mn2AhorPx8/ukWLhw9dXVFHlWj01uhLNtnwsLRx6GOzKo39
eQ223BgeYDrT8IAxDSeF2hDNazxYUFk16SDfD6ko8kvkYdJ0yKiPQ8N6R7a0
+D0eVqWq9+4zo2E0cf7Twoc8zMOblcYbaMhs0bPd8pWH56lHdsfZ0Jj9RD0k
vpmHu3aO/g9taUxfsqzoexsPugXJQZ+20RDhSUkf7uWBTn7Jmb6DBnVn8ONZ
Pg8GG60ynB1oVNN3bArn8SF/Y113pguN5zvjg/mL+Oio6gnM3E+jtPJS4bol
fLh8zBhLO0Cj4JrfnDeqfGQ6axbePETj9jqbj51r+VDSdKWOHqVx8oq4jYwT
H9J5zrfTvWioqB+z9rvHh480z+vSGTJ/zI/BE+l8GGsW7DU8S6No2CbUO5vM
F/vAr594Xbl+qVsRH+LdhioIpmG3aeqyA1V8PH1+NfDbeRrBrnf51p18oHPz
lNxwGuvfycRt6eXjp9+GOETQmKkZrmY1yIdcefeGBuIEgfs+iz98rD72Q4u6
RCPvotHbdSwBLC92CCSv0GhNa0xSXSKASttPcyaGxj2JTQYrVQRIXTh+xD2W
xhG3Z5+XqwrAKjUo7iAe0kljK2sJoHR6uK4qjsS72ttb3lSA6/55re7xNBpW
9M6UXS9A/VrxDV+Jr1/elSG9UYD5GmatBtdoKG/jtEraCmBXtf/sOLF+p+R6
cRcBBuIu5rvfoDFhHtwuekiAg/Jn9tUQV2cNB0y6CvB4aLXRwgQaW71a8oVe
Avx9IvtYFfEhkax5v4MF+MYJKBIk0lA7sPDRr1ABJPc/yjK5SeN3bfQWKkIA
Rfvg1+HEgdG+5/tiBfBdXhUy5xaNq4r/0G13BRC7d7Rl5m0aJfUDfrVpAlxJ
jeWZE38PiGYVZgkgLQi2CiJWavwuf6GQxO9UYWYvsVnouXtuxQI47hrMU7hD
1qOtor7zqQArh37+u4E4J9rLVLVSgKruEeX7xB/Wyb+b+0qA8jqpuR+I/3DL
d47XCVBzps1YQGywge3W0CBAaGrIevMkGo68XP7TLwLo+e1Y4kp87v62kNQm
AXi9n/QvE9eIJN/wbRegLKpC9g3xQN4/S5y7ST7EV7b2Es/cM5hj2S/A8jjt
NtFkGhozYvS0KQHkbv5QWEC87enfVQv/E0D75opoLWLfwy1WU4cFcP5LkrOB
+KZscOO/fAGSRKP+ciSueKni0jwqAJvKtHEnbveqp6omBfj6xbHoDLGYkrdf
jhgD+8rMzVeIVd7Ls65PY8D6dHnpTeKNgRWRZ2cwcDCdopNG7Ka6X951NoPp
rjJn84hjmtj3bOcy+Pj4iXgJ8aOwPDUjeQYxZb+ry4gbdeweL1/AgLPw+fPn
xMJOxmT2YgbMbaWRSuJFscn1giUMqAVyB6uIOTDf2anC4HBc8uz/Hz9AD3a8
VWXwVaZiuIL44q2Y48WrGVR8cpd5SpxtqctP0mJQKVfsXkT8nt8SHK7LIGl9
jFg28e+04Jnehgw0ukQ+JxPL2K24sduYgVv4tLarxHqsd8rmpmQ++r5yGLFD
gXfO6vUMrLqbU3yJg5wU9BQ2MjjkkOFwkDhl5rNK0S0M5tvP2mpL/LJ0vxXX
hsGgiNSZdcS9RyQav2xn4HM1t0+FWP2VHZWxh8EDfuXRYZJfax+hb+w+Bove
r73QRHxCOUX09EEG72/sbColLg3iym1xY5CiH6gRQNz2V+xdPS8Gu+lwnZ3E
It911ZRPMoi2ho8W8XrdEJPhQBKPaUUpXWQ/unavqG87x2CVtE/0U+LIuHc7
ai8w+K3X9+QK8edfCsdvRjK4dXyoTIPYOSP/Ouc2g8UR3JB95HxMNfmz8GwK
g5pdcFtGnPtdJ7XiPgNHoaZpDzl/QsnSfMNcBi4JU3KcieNPVNfpPGPQJ+Ce
NSbn1XDWtK0+VQxshkqf/0fOd0eG5dfCGgZnD1sPphCvbnnfsfoDgym7eyaF
pB7UmTQLV7YzKB3eo36d1A/3lgXBh7sZpBpNrdYjlj3pNC29n4GXRLp543Ua
Lpldc5f+ZjD1XJ+EFPHYrF9qi1hCqBoY3DhC6pdGK2vvnGVCXEp797aY1Mdv
J817tq4UYtV0D1ld4qDZ4cei1IRYpxq28VE0jTemkv4z/hZi10ZDv+wost+y
5GOnrBfCf7SqJSiS1GNftZfMYSE6rip8f3GRhrGUh6X+cSHmXsv/uZi4J6vw
g6+nECKizh8Dw2hotem2DvkLsX3p2lMaoTTqzUxG6AghPCSWt54JIfmbs2NF
5wMhTjRdYx4H0vC6L6vQlC/EbZHVDSziTr2v7PcPhWhYhqZNp0k9dbIbfFom
RMkOJrDpFI2IHNvc2LdCyFrOmt/qS0N6w1ZtE64QTimKuZGeNJad3YAU1VGU
qLyOvkr64zVptsb11aNYctcp9/4+kt/0WqVIrVHolE6feOhMo79+PcvfcBSa
XR3675xIvuebv9q6cRRrhGvkBkm/1S0x2TTpOgoDldrAd6RfW9KGO52yRrFu
T8SxtSYkHsdvmGXljuJnfpyikNwPtLhDa4YLR/GYlVxSQu4P8wdy2JdKR+FO
L7q+yoj0027F0uK3o3ihuVGWp0vqRytrkeSvUSgGhq1SVSP5evums0xrDJ0S
HxwmZUh+Nq74MFVvDBnbTX4EzCX9/vX5Mpu1Y9gUP2g5PIdGZq1RfJ/ZGKJC
bb+3z6IR8DLPfO72Mdztje9MYZP6UhaXedRvDFbnLLLLRykcyHZwn1c+Bv7H
QwP72ymU+AxstH4xhgTJI6JpPyiw1/mvuFg9hsM/chS6WynkfLjWPlw/hrW8
IHPHZgrDww22DW1jKKjOu6XzicJ5WOhdnBzDRJL5jtCXFO590RYZMR2Hff4B
bsZ9Ch0TM+MaXo/DUN3GlHGmMFGp0Pzs3ThC8aSnw4nC/NBlSrkfxzFcV/2p
zpGC3QyjvIjmcfwrbn0p1p5CjfyxN6YD4xg3q/SeZU0hW+M1q5g9gaN3eeYl
xhROuIT6JFpM4Kf5ts5n5P48tWbczuXVBDK26eeVveNi0m3VpNa3SbCWX0mv
mM2FdbXlMo+jIpwit8K9900HYbNowwfTPhHO6/o7ixydB1De20UXu4tybKrP
+kVt7cfpAUVHOVqU0786dpavfh9SHfnr5HxZnAflZw7u+68HShIeHmI8FmfQ
Uv+AdUY3tohqZLj7iHHCk+abPrDuQo9rlO2pUTGOiL1RtWxdBxpmRG72ChDn
/OYeOBZu0Y7liivK2eJTOMKWzXFXVrVBNXCGpuLlKZy+VclHFB4248Lc6BEl
iamczxYtSZudvsFiQYH6y9ipnGnbZ2kYZX2Ck6Nnse2caZyl6/dyv+I9VAZO
mTlHEReU6Sdq12Jnr5K5pByb42h+io4cfIa2hYevZ8SzOcWPtI877izAjuVG
Pa3X2Zxju7p+K8gVoEF9jo50IpuzyPPO6cysfFQZl30MvMPm0BIB/lH388g9
crakbTqbU6XqV2F8Mwfe9x+fH3vM5lQ8sFplEJqJaWpsL5sWNsff+bVuy64U
nNNpex7Wxubk36vV0spLhtCoaFb5TzbHK1Ey6kFmEqjNjjkq3WyOwDV4x407
t/HJo6BvlGJzslNYe7ZfTMDth/ZO6RNkPR7lBYEOMZAtV89tEZHgrLBg7SnJ
ikJUNWtMSkyC4xF1kuWVFIngrzmJp6dJcIzbrw7+vBiOQ3yRr9ZSEpwW+9mR
mQ7n0D75dWmYtASn0DzyUF5SIHaxH3iXyUhwZCIrwiTC/WE1b7uUyjwJzhez
w6dLHTzxSll17+4FEhwX7fIfyuFHYKw6mRuzSIJzoUi1v97BGU+0voy9WizB
6cjTPEg7WENzbdamUWUJDlYz//s/8H8uljva
      "]]}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->True,
  FrameLabel->{
    FormBox["\"x\"", TraditionalForm], 
    FormBox["\"u\"", TraditionalForm]},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  Method->{},
  PlotRange->{{0, 3.141592653589793}, {0, 0.9315361778842229}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.02], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.6385163633658*^9, 3.6386024685916*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Here we give a table that compares the numerical and exact solution at the \
middle point, x=\[Pi]/2, for the first numSteps timesteps. \
\>", "Text",
 CellChangeTimes->{{3.6372981691743*^9, 3.6372982503743*^9}, {
  3.6372983312943*^9, 3.6372983351903*^9}, {3.6372983799263*^9, 
  3.6372984925123*^9}, {3.6372988496542997`*^9, 3.6372989263983*^9}},
 Background->RGBColor[1, 1, 0.85]],

Cell[BoxData[
 RowBox[{
  RowBox[{"headPredictive", "=", 
   RowBox[{"{", 
    RowBox[{
    "\"\<step\>\"", ",", "\"\<t\>\"", ",", 
     "\"\<\!\(\*SubscriptBox[\(U\), \(Predic\)]\)(\[Pi]/2,t)\>\"", ",", 
     "\"\<\!\(\*SubscriptBox[\(u\), \(exact\)]\)(\[Pi]/2,t)\>\"", ",", 
     "\"\<error\>\""}], "}"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.6372462215509663`*^9, 3.6372463423118734`*^9}, {
  3.637246799033996*^9, 3.637246806409418*^9}, {3.637246837090173*^9, 
  3.637246852913078*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"tabPred", "=", 
   RowBox[{
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"m", ",", 
        RowBox[{"tt", "[", "m", "]"}], ",", 
        RowBox[{"uMs", "[", 
         RowBox[{"[", 
          RowBox[{
           RowBox[{"m", "+", "1"}], ",", 
           RowBox[{"Nx", "+", "1"}]}], "]"}], "]"}], ",", 
        RowBox[{"uSol", "[", 
         RowBox[{
          RowBox[{"Pi", "/", "2"}], ",", 
          RowBox[{"tt", "[", "m", "]"}], ",", "gammak"}], "]"}], ",", 
        RowBox[{
         RowBox[{"uMs", "[", 
          RowBox[{"[", 
           RowBox[{
            RowBox[{"m", "+", "1"}], ",", 
            RowBox[{"Nx", "+", "1"}]}], "]"}], "]"}], "-", 
         RowBox[{"uSol", "[", 
          RowBox[{
           RowBox[{"Pi", "/", "2"}], ",", 
           RowBox[{"tt", "[", "m", "]"}], ",", "gammak"}], "]"}]}]}], "}"}], 
      ",", 
      RowBox[{"{", 
       RowBox[{"m", ",", "0", ",", "numSteps"}], "}"}]}], "]"}], "//", 
    "N"}]}], ";", 
  RowBox[{
   RowBox[{"Insert", "[", 
    RowBox[{"tabPred", ",", "headPredictive", ",", "1"}], "]"}], "//", 
   "TableForm"}]}]], "Input",
 CellChangeTimes->{
  3.6372987625292997`*^9, {3.6373009292093*^9, 3.6373009376243*^9}, 
   3.6373690471088285`*^9}],

Cell[BoxData[
 TagBox[GridBox[{
    {"\<\"step\"\>", "\<\"t\"\>", "\<\"\\!\\(\\*SubscriptBox[\\(U\\), \
\\(Predic\\)]\\)(\[Pi]/2,t)\"\>", "\<\"\\!\\(\\*SubscriptBox[\\(u\\), \
\\(exact\\)]\\)(\[Pi]/2,t)\"\>", "\<\"error\"\>"},
    {"0.`", "0.`", "1.`", "1.`", "0.`"},
    {"1.`", "1.991582780781724`*^-7", "0.9821179966470339`", 
     "0.97718704866213`", "0.0049309479849038995`"},
    {"2.`", "7.113595171815076`*^-7", "0.9725545566133961`", 
     "0.9688855465498852`", "0.003669010063510836`"},
    {"3.`", "2.6260430605598073`*^-6", "0.9612504329274276`", 
     "0.9573493392263155`", "0.003901093701112135`"},
    {"4.`", "8.946004447808648`*^-6", "0.9475840646384216`", 
     "0.9428737950850267`", "0.00471026955339493`"},
    {"5.`", "0.000027343896323029062`", "0.9315361778842229`", 
     "0.9257519014311733`", "0.005784276453049686`"},
    {"6.`", "0.00007587949484304874`", "0.913119697415966`", 
     "0.9060925071735623`", "0.007027190242403725`"},
    {"7.`", "0.00019426336541056318`", "0.8923782476495066`", 
     "0.8839850378102556`", "0.008393209839250959`"},
    {"8.`", "0.00040644383321258534`", "0.8730017515353565`", 
     "0.8636008979226384`", "0.00940085361271814`"},
    {"9.`", "0.0008126159969381912`", "0.8524079754043254`", 
     "0.8418734512659597`", "0.010534524138365753`"},
    {"10.`", "0.001577817981147861`", "0.8303554974670833`", 
     "0.8186556745140625`", "0.011699822953020744`"},
    {"11.`", "0.0029861431771416955`", "0.8070043263645926`", 
     "0.7942077016510215`", "0.012796624713571125`"},
    {"12.`", "0.0055259613595135745`", "0.78266502058714`", 
     "0.7689448433328504`", "0.013720177254289645`"},
    {"13.`", "0.010028707531393167`", "0.7578584126208666`", 
     "0.7435084861715249`", "0.014349926449341743`"},
    {"14.`", "0.017898115026902875`", "0.7334594405684839`", 
     "0.7189047541242666`", "0.014554686444217313`"},
    {"15.`", "0.03150131090905581`", "0.7108975622075143`", 
     "0.6966844164955666`", "0.014213145711947761`"},
    {"16.`", "0.05495343361495635`", "0.6923137906906974`", 
     "0.6790744371903836`", "0.0132393535003138`"},
    {"17.`", "0.09673997774121537`", "0.6801548477246223`", 
     "0.6686113617015738`", "0.011543486023048555`"},
    {"18.`", "0.2732032743364034`", "0.650121941076324`", 
     "0.6457777913411741`", "0.00434414973514996`"},
    {"19.`", "0.41349101247540226`", "0.574131531487625`", 
     "0.5721297070026398`", "0.002001824484985204`"},
    {"20.`", "0.6404452017290696`", "0.42059552717004056`", 
     "0.4151432332189733`", "0.005452293951067277`"},
    {"21.`", "0.7536190793768581`", "0.3878727587911701`", 
     "0.381969251384633`", "0.005903507406537112`"},
    {"22.`", "0.8667929570246466`", "0.4046363560965445`", 
     "0.3987256744944499`", "0.005910681602094625`"},
    {"23.`", "0.9799668346724352`", "0.4573831657610607`", 
     "0.45259053535490595`", "0.004792630406154741`"},
    {"24.`", "1.1666063129616195`", "0.5407161268150537`", 
     "0.5406161559073582`", "0.0000999709076954236`"},
    {"25.`", "1.272598120021009`", "0.5469538585455632`", 
     "0.547499296722879`", 
     RowBox[{"-", "0.0005454381773157824`"}]},
    {"26.`", "1.3785899270803985`", "0.5117304607372546`", 
     "0.5125299020485409`", 
     RowBox[{"-", "0.0007994413112862864`"}]},
    {"27.`", "1.484581734139788`", "0.44829880929795857`", 
     "0.4484171655097801`", 
     RowBox[{"-", "0.00011835621182154643`"}]},
    {"28.`", "1.6562148816518922`", "0.3520496426180608`", 
     "0.34870693795443414`", "0.0033427046636266833`"},
    {"29.`", "1.7799629562985742`", "0.3336801279916803`", 
     "0.3290759166128156`", "0.0046042113788646866`"},
    {"30.`", "1.903711030945256`", "0.37089922965533806`", 
     "0.36621568473077404`", "0.00468354492456402`"},
    {"31.`", "2.1638193803567063`", "0.49950642027099873`", 
     "0.5007822691116726`", 
     RowBox[{"-", "0.0012758488406738322`"}]},
    {"32.`", "2.285195166872744`", "0.5070910854339249`", 
     "0.5092552964147974`", 
     RowBox[{"-", "0.002164210980872494`"}]},
    {"33.`", "2.4065709533887816`", "0.46167639272667027`", 
     "0.4638656949711377`", 
     RowBox[{"-", "0.0021893022444674504`"}]},
    {"34.`", "2.6289822543356705`", "0.33225337924572673`", 
     "0.33054738559046126`", "0.0017059936552654698`"},
    {"35.`", "2.743278623739848`", "0.30357565592583585`", 
     "0.30046846720256976`", "0.0031071887232660966`"},
    {"36.`", "2.8575749931440253`", "0.32357024691680625`", 
     "0.3198525927540743`", "0.0037176541627319537`"},
    {"37.`", "2.9718713625482027`", "0.3808919929130419`", 
     "0.3778747922426061`", "0.00301720067043576`"},
    {"38.`", "3.13659443526414`", "0.46761499165752635`", 
     "0.4678205331416848`", 
     RowBox[{"-", "0.00020554148415846685`"}]},
    {"39.`", "3.2579815756231696`", "0.48785616561025447`", 
     "0.48970394336795564`", 
     RowBox[{"-", "0.0018477777577011745`"}]},
    {"40.`", "3.3793687159821992`", "0.4539534592334065`", 
     "0.45634160237096855`", 
     RowBox[{"-", "0.0023881431375620266`"}]}
   },
   GridBoxAlignment->{
    "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
     "RowsIndexed" -> {}},
   GridBoxSpacings->{"Columns" -> {
       Offset[0.27999999999999997`], {
        Offset[2.0999999999999996`]}, 
       Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
       Offset[0.2], {
        Offset[0.4]}, 
       Offset[0.2]}, "RowsIndexed" -> {}}],
  Function[BoxForm`e$, 
   TableForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{3.6385163636408*^9, 3.6386024688306*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 "A plot comparing the numerical and the exact solution at  position \
x=\[Pi]/2 for times  t  with   0\[LessEqual]t\[LessEqual] ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["t", "numSteps"], TraditionalForm]],
  FormatType->"TraditionalForm"],
 " "
}], "Text",
 CellChangeTimes->{{3.6372989561913*^9, 3.6372990023753*^9}, {
  3.6372990787602997`*^9, 3.6372990811603003`*^9}, {3.6372998614302998`*^9, 
  3.6372998879683*^9}, {3.6373004057753*^9, 3.6373004634223003`*^9}},
 Background->RGBColor[1, 1, 0.85]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"Print", "[", "\"\<Predictive method\>\"", "]"}], ";", 
  RowBox[{
  "Print", "[", 
   "\"\<Numerical solution (points) and exact solution (line) at position x=\
\[Pi]/2 vs. time\>\"", "]"}], ";", " ", 
  RowBox[{"FigNum", "=", 
   RowBox[{"ListPlot", "[", 
    RowBox[{
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"tabPred", "[", 
          RowBox[{"[", 
           RowBox[{"n", ",", "2"}], "]"}], "]"}], ",", 
         RowBox[{"tabPred", "[", 
          RowBox[{"[", 
           RowBox[{"n", ",", "3"}], "]"}], "]"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"n", ",", "1", ",", "numSteps"}], "}"}]}], "]"}], ",", 
     RowBox[{"PlotRange", "\[Rule]", "All"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"FigExact", "=", 
   RowBox[{"Plot", "[", 
    RowBox[{
     RowBox[{"uSol", "[", 
      RowBox[{
       RowBox[{"Pi", "/", "2"}], ",", "time", ",", "gammak"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"time", ",", "0", ",", 
       RowBox[{"1.1", "*", 
        RowBox[{"tabPred", "[", 
         RowBox[{"[", 
          RowBox[{
           RowBox[{"numSteps", "+", "1"}], ",", "2"}], "]"}], "]"}]}]}], 
      "}"}], ",", 
     RowBox[{"PlotRange", "\[Rule]", "All"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"Show", "[", 
  RowBox[{"FigNum", ",", "FigExact", ",", 
   RowBox[{"Frame", "\[Rule]", "True"}], ",", 
   RowBox[{"FrameLabel", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"\"\<time\>\"", ",", "\"\<u\>\""}], "}"}]}], ",", 
   RowBox[{"PlotRange", "\[Rule]", "All"}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.6372990098493*^9, 3.6372993557363*^9}, {
   3.6372994017143*^9, 3.6372994018733*^9}, {3.6372994547862997`*^9, 
   3.6372994982653*^9}, {3.6372997348883*^9, 3.6372998253603*^9}, {
   3.6372999061773*^9, 3.6372999638333*^9}, {3.6373000656813*^9, 
   3.6373002790032997`*^9}, {3.6373003226673*^9, 3.6373003301463003`*^9}, 
   3.6373008969223003`*^9, {3.6373010002263002`*^9, 3.6373010046333*^9}, {
   3.6373011368183002`*^9, 3.6373011439313*^9}, {3.6373013944182997`*^9, 
   3.6373014237132998`*^9}, {3.6373017883363*^9, 3.6373017915923*^9}, 
   3.6373211095106354`*^9, 3.637369208196042*^9, {3.6385156057438*^9, 
   3.6385156202478*^9}}],

Cell[BoxData["\<\"Predictive method\"\>"], "Print",
 CellChangeTimes->{3.6385163636758003`*^9, 3.6386024688416*^9}],

Cell[BoxData["\<\"Numerical solution (points) and exact solution (line) at \
position x=\[Pi]/2 vs. time\"\>"], "Print",
 CellChangeTimes->{3.6385163636758003`*^9, 3.6386024688436003`*^9}],

Cell[BoxData[
 GraphicsBox[{{{}, {{}, 
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
      0.012833333333333334`], AbsoluteThickness[1.6], PointBox[CompressedData["
1:eJwBkQJu/SFib1JlAgAAACgAAAACAAAAAAAAAAAAAAAAAAAAAADwP85leL0G
u4o+gC+NuIJt7z+6KRAfiN6nPsFex7sqH+8/3PencGIHxj52DZZEkMLuPy82
M33ZwuI+D6b60JtS7j9MQEs/Eqz8PuW2YfUkz+0/zw2Pyy/kEz8JhbfMRjjt
PwdYPZpldik/HCCq01yO7D/Es6f4/qI6Pww+hl6h7+s/I3HGkLegSj++wSYX
7UbrP+ZPMijZ2Vk/Dpk1sUWS6j+UFC9pZXZoPwvtrrz60uk/GNEW9WOidj9L
o2SDlwvpP/qm8lbuiYQ/JZAmSWBA6D+EaM0q4lOSPxnkxe5/eOc/PGNFmPAg
oD/HmI8+rL/mP9e4W0DbIqw/QcMyQG8n5j/6QZ2A88O4P/stZhnUw+U/h9Yb
lil80T8Zt2qHzM3kP9tk8QGjdto/kO/qFklf4j+ozonvhn7kP1CCgoAJ69o/
ZRZywqUd6D+gHIFD6NLYPyJeWpXEvOs/5UMN44/l2T/fpUJo41vvPyvSqwrE
Rd0/AqOXYWuq8j/r5CLoi03hP6IPp9iPXPQ/e/nbYKWA4T9CfLZPtA72PwB5
J48YYOA/4ujFxtjA9z9tTzF97bDcP4R+/Szbf/o/XDxnOfuH1j85TdZvunr8
P7soQ+UDW9U/7huvspl1/j8izV4f0LzXPxCqCImATwFAoS7Nxun33z/KkFVn
FEgCQOkEgRUXOuA/hHeiRahAA0DMKQYkG4zdP6YWIdknCAVA7CJ2raND1T9x
OiYQPPIFQLELhJbIbdM/PF4rR1DcBkBQ2B37X7XUPweCMH5kxgdAdKo3z4hg
2D9YM8LSvhcJQPV0Em5n7d0/MC3ypFgQCkAUrBwRCTnfP8/SM0Q=
       "]]}, {}}, {}}, {{}, {}, 
    {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], Opacity[
     1.], LineBox[CompressedData["
1:eJwVmHk81F8Xx41lmLFWfoVEUkiSpVDhXLKVQkj2SrYWIiWJkkTZsqaEbKmU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      "]]}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->True,
  FrameLabel->{
    FormBox["\"time\"", TraditionalForm], 
    FormBox["\"u\"", TraditionalForm]},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  Method->{},
  PlotRange->All,
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.02], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.6385163684528*^9, 3.6386024736275997`*^9}]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 "\[FilledSquare] Numerical results with the method with ",
 StyleBox["fixed timesteps",
  FontSlant->"Italic"],
 " for \[CapitalDelta]=0.01=",
 "htFT"
}], "Subsubsection",
 CellChangeTimes->{{3.633439583415289*^9, 3.6334395909637213`*^9}, {
   3.636904756973955*^9, 3.636904760701168*^9}, 3.637138408549569*^9, {
   3.6372452357805834`*^9, 3.6372452451731205`*^9}, {3.6372463821981544`*^9, 
   3.6372463827581863`*^9}, {3.6372466129283514`*^9, 3.637246617848633*^9}, {
   3.6372481231807327`*^9, 3.6372481307011633`*^9}, {3.637249654032293*^9, 
   3.6372496781846743`*^9}, 3.6373014998393*^9, {3.6373015476473*^9, 
   3.6373015576783*^9}, 3.6373021184543*^9}],

Cell[CellGroupData[{

Cell[TextData[{
 "uMs is a matrix that contains the full solution ",
 Cell[BoxData[
  FormBox[
   RowBox[{"{", 
    RowBox[{
     SubsuperscriptBox["U", "0", 
      RowBox[{"(", "m", ")"}]], ",", 
     SubsuperscriptBox["U", "1", 
      RowBox[{"(", "m", ")"}]], ",", 
     SubsuperscriptBox["U", "2", 
      RowBox[{"(", "m", ")"}]], ",", 
     RowBox[{"...", " ", 
      SubsuperscriptBox["U", "Np", 
       RowBox[{"(", "m", ")"}]]}]}], "}"}], TraditionalForm]]],
 "  for m=0,1,2,....,numSteps."
}], "Text",
 CellChangeTimes->{{3.6372979828863*^9, 3.6372980614302998`*^9}},
 Background->RGBColor[1, 1, 0.85]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"htFT", "=", "0.01"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"numSteps", "=", "50"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"CPUtime", "=", 
   RowBox[{"Timing", "[", 
    RowBox[{"uMs", "=", 
     RowBox[{"uMsolutionFixedTimesteps", "[", 
      RowBox[{
       RowBox[{"numSteps", "*", "htFT"}], ",", "htFT"}], "]"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Print", "[", 
   RowBox[{
   "\"\<Example 1. Method with fixed timesteps of size \>\"", ",", "htFT", 
    ",", "\"\< for \[Gamma]=\>\"", ",", "gammak", ",", "\"\<, Np=\>\"", ",", 
    "Np"}], " ", "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Print", "[", 
   RowBox[{"\"\<CPU time=\>\"", ",", 
    RowBox[{"CPUtime", "[", 
     RowBox[{"[", "1", "]"}], "]"}], ",", "\"\< seconds\>\""}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
  "Print", "[", "\"\<The solution is saved in the matrix uMs\>\"", "]"}], 
  ";"}]}], "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 CellChangeTimes->{{3.56061256346875*^9, 3.56061257284375*^9}, {
   3.56061260303125*^9, 3.560612663828125*^9}, {3.5610884668366947`*^9, 
   3.5610884717649765`*^9}, {3.5611210929323997`*^9, 3.5611211203416*^9}, {
   3.5611212573096*^9, 3.5611212593532*^9}, 3.5611216448120003`*^9, {
   3.5611216844625998`*^9, 3.5611216848213997`*^9}, {3.5611217681558*^9, 
   3.5611217684667997`*^9}, {3.5611222944344*^9, 3.5611223196862*^9}, {
   3.5611253416166*^9, 3.5611253440626*^9}, {3.5611260133876*^9, 
   3.5611260138276*^9}, {3.561127402519*^9, 3.5611274579006*^9}, {
   3.561127527574*^9, 3.5611275627130003`*^9}, {3.5902000697948065`*^9, 
   3.5902000708068647`*^9}, {3.590200323138297*^9, 3.590200324873397*^9}, {
   3.5902003709750333`*^9, 3.5902003711460433`*^9}, 3.590200421820942*^9, 
   3.590213289142*^9, {3.5902135189*^9, 3.590213539836*^9}, {
   3.5902135876359997`*^9, 3.590213616165*^9}, {3.590213707484*^9, 
   3.590213707868*^9}, {3.590213768476*^9, 3.590213768955*^9}, 
   3.5902143461549997`*^9, {3.59021447142*^9, 3.590214495682*^9}, 
   3.5903882375313997`*^9, {3.5903932563884*^9, 3.5903932567464*^9}, {
   3.5903932903714*^9, 3.5903933180104*^9}, {3.5903933542194*^9, 
   3.5903933561303997`*^9}, 3.5903933876914*^9, 3.5903934182594*^9, 
   3.5903941132114*^9, 3.60195384860737*^9, {3.601953894449992*^9, 
   3.601953894987023*^9}, {3.6334400976967044`*^9, 3.6334400980167227`*^9}, 
   3.6369936572364435`*^9, {3.636993750675788*^9, 3.6369937637635365`*^9}, 
   3.637004923308416*^9, 3.6370053615804834`*^9, {3.6372402113622026`*^9, 
   3.637240211367203*^9}, {3.6372452960570307`*^9, 3.6372453605797215`*^9}, {
   3.6372453910404634`*^9, 3.637245428304595*^9}, {3.637245470149988*^9, 
   3.6372455167096515`*^9}, {3.6372456161863413`*^9, 3.637245697827011*^9}, {
   3.637245729372815*^9, 3.637245777960594*^9}, {3.63724584310532*^9, 
   3.6372459587629356`*^9}, {3.637246021107501*^9, 3.6372460259367776`*^9}, {
   3.637246091338518*^9, 3.6372460918335466`*^9}, 3.6372463595788608`*^9, 
   3.637246525799368*^9, {3.6372465623644595`*^9, 3.637246581655563*^9}, {
   3.637246817573056*^9, 3.6372468214022756`*^9}, {3.6372470179475174`*^9, 
   3.637247018278536*^9}, {3.6372471839910145`*^9, 3.6372472107335443`*^9}, {
   3.6372472497587757`*^9, 3.637247279316467*^9}, {3.637247390205809*^9, 
   3.6372473996553497`*^9}, {3.637247443785874*^9, 3.6372474491481805`*^9}, {
   3.637247899618946*^9, 3.6372479030021396`*^9}, {3.637247939714239*^9, 
   3.6372479400092564`*^9}, {3.6372482082135963`*^9, 3.637248224762543*^9}, {
   3.637248553257332*^9, 3.6372485587676473`*^9}, 3.6372496070256042`*^9, 
   3.6372975701323*^9, {3.6372979117462997`*^9, 3.6372979144493*^9}, 
   3.6372981329823*^9, 3.6372981646743*^9, {3.6372982614663*^9, 
   3.6372982617132998`*^9}, {3.6373004952983*^9, 3.6373005432813*^9}, {
   3.6373007987373*^9, 3.6373008130083*^9}, {3.6373015293063*^9, 
   3.6373015299783*^9}, {3.6373015669943*^9, 3.6373015860183*^9}, {
   3.6373020142672997`*^9, 3.6373020146973*^9}, 3.6373021292053003`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Example 1. Method with fixed timesteps of size \"\>", 
   "\[InvisibleSpace]", "0.01`", 
   "\[InvisibleSpace]", "\<\" for \[Gamma]=\"\>", "\[InvisibleSpace]", 
   "0.25`", "\[InvisibleSpace]", "\<\", Np=\"\>", "\[InvisibleSpace]", "40"}],
  SequenceForm[
  "Example 1. Method with fixed timesteps of size ", 0.01, " for \[Gamma]=", 
   0.25, ", Np=", 40],
  Editable->False]], "Print",
 CellChangeTimes->{3.6385163698038*^9, 3.6386024749736*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"CPU time=\"\>", "\[InvisibleSpace]", "1.3260085`", 
   "\[InvisibleSpace]", "\<\" seconds\"\>"}],
  SequenceForm["CPU time=", 1.3260085, " seconds"],
  Editable->False]], "Print",
 CellChangeTimes->{3.6385163698038*^9, 3.6386024749756002`*^9}],

Cell[BoxData["\<\"The solution is saved in the matrix uMs\"\>"], "Print",
 CellChangeTimes->{3.6385163698038*^9, 3.6386024749765997`*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 "The solution for the m-th timestep is just the m+1 element of this matrix:  \
uMs[[m+1]]=",
 Cell[BoxData[
  FormBox[
   RowBox[{"{", 
    RowBox[{
     SubsuperscriptBox["U", "0", 
      RowBox[{"(", "m", ")"}]], ",", 
     SubsuperscriptBox["U", "1", 
      RowBox[{"(", "m", ")"}]], ",", 
     SubsuperscriptBox["U", "2", 
      RowBox[{"(", "m", ")"}]], ",", 
     RowBox[{"...", " ", 
      SubsuperscriptBox["U", "Np", 
       RowBox[{"(", "m", ")"}]]}]}], "}"}], TraditionalForm]]],
 " "
}], "Text",
 CellChangeTimes->{{3.6372981691743*^9, 3.6372982503743*^9}, {
  3.6372983312943*^9, 3.6372983351903*^9}},
 Background->RGBColor[1, 1, 0.85]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"mStep", "=", "5"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Print", "[", 
   RowBox[{"\"\<The numerical solution at time \>\"", ",", 
    RowBox[{"tt", "[", "mStep", "]"}], ",", "\"\< is:\>\""}], "]"}], ";", 
  RowBox[{"uMs", "[", 
   RowBox[{"[", "mStep", "]"}], "]"}]}]}], "Input",
 CellChangeTimes->{{3.6372983391352997`*^9, 3.6372983412483*^9}, {
  3.6372985221443*^9, 3.6372986028712997`*^9}}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"The numerical solution at time \"\>", "\[InvisibleSpace]", 
   "0.05`", "\[InvisibleSpace]", "\<\" is:\"\>"}],
  SequenceForm["The numerical solution at time ", 0.05, " is:"],
  Editable->False]], "Print",
 CellChangeTimes->{3.6385163698648*^9, 3.6386024749986*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "1.4779201941928705`*^-14", ",", "0.05561487141702734`", ",", 
   "0.11088685865793274`", ",", "0.16547519154158993`", ",", 
   "0.21904331484330844`", ",", "0.2712609632697245`", ",", 
   "0.3218061976541591`", ",", "0.37036738981863615`", ",", 
   "0.41664514386522666`", ",", "0.46035414205131847`", ",", 
   "0.5012249038683775`", ",", "0.5390054474788942`", ",", 
   "0.5734628432682042`", ",", "0.6043846499330193`", ",", 
   "0.631580224252707`", ",", "0.6548818964681401`", ",", 
   "0.6741460040215183`", ",", "0.6892537772838091`", ",", 
   "0.7001120718090061`", ",", "0.7066539426006123`", ",", 
   "0.7088390568498045`", ",", "0.7066539426006122`", ",", 
   "0.7001120718090057`", ",", "0.6892537772838082`", ",", 
   "0.674146004021517`", ",", "0.6548818964681383`", ",", 
   "0.6315802242527047`", ",", "0.6043846499330164`", ",", 
   "0.5734628432682007`", ",", "0.5390054474788902`", ",", 
   "0.5012249038683728`", ",", "0.4603541420513131`", ",", 
   "0.4166451438652205`", ",", "0.3703673898186292`", ",", 
   "0.32180619765415125`", ",", "0.27126096326971577`", ",", 
   "0.21904331484329873`", ",", "0.16547519154157916`", ",", 
   "0.11088685865792079`", ",", "0.05561487141701405`", ",", "0.`"}], 
  "}"}]], "Output",
 CellChangeTimes->{3.6385163698688*^9, 3.6386024750016003`*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 "The [[m+1,j+1] element of this matrix is the numerical solution for time ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["t", "m"], TraditionalForm]],
  FormatType->"TraditionalForm"],
 " and position ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["x", "j"], TraditionalForm]],
  FormatType->"TraditionalForm"],
 ":  uMs[[m+1,j+1]]=",
 Cell[BoxData[
  FormBox[
   SubsuperscriptBox["U", "j", 
    RowBox[{"(", "m", ")"}]], TraditionalForm]]],
 " "
}], "Text",
 CellChangeTimes->{{3.6372981691743*^9, 3.6372982503743*^9}, {
  3.6372983312943*^9, 3.6372983351903*^9}, {3.6372983799263*^9, 
  3.6372984925123*^9}},
 Background->RGBColor[1, 1, 0.85]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"mStep", "=", "5"}], ";", 
  RowBox[{"jPos", "=", 
   RowBox[{"Nx", "+", "1"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Print", "[", 
   RowBox[{"\"\<The numerical solution at time t=\>\"", ",", 
    RowBox[{"tt", "[", "mStep", "]"}], ",", "\"\< and position x= \>\"", " ", 
    ",", 
    RowBox[{"jPos", "*", "deltax"}], " ", ",", "\"\< is:\>\""}], "]"}], ";", 
  RowBox[{"uMs", "[", 
   RowBox[{"[", 
    RowBox[{"mStep", ",", "jPos"}], "]"}], "]"}]}]}], "Input",
 CellChangeTimes->{{3.6372983391352997`*^9, 3.6372983412483*^9}, {
  3.6372985221443*^9, 3.6372986028712997`*^9}, {3.6372986373603*^9, 
  3.6372986956313*^9}}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"The numerical solution at time t=\"\>", "\[InvisibleSpace]", 
   "0.05`", "\[InvisibleSpace]", "\<\" and position x= \"\>", 
   "\[InvisibleSpace]", "1.6493361431346414`", 
   "\[InvisibleSpace]", "\<\" is:\"\>"}],
  SequenceForm[
  "The numerical solution at time t=", 0.05, " and position x= ", 
   1.6493361431346414`, " is:"],
  Editable->False]], "Print",
 CellChangeTimes->{3.6385163698828*^9, 3.6386024750086*^9}],

Cell[BoxData["0.7088390568498045`"], "Output",
 CellChangeTimes->{3.6385163698848*^9, 3.6386024750095997`*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 "A plot comparing the numerical and the exact solution at time ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["t", "mStep"], TraditionalForm]],
  FormatType->"TraditionalForm"],
 " "
}], "Text",
 CellChangeTimes->{{3.6372989561913*^9, 3.6372990023753*^9}, {
  3.6372990787602997`*^9, 3.6372990811603003`*^9}},
 Background->RGBColor[1, 1, 0.85]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"mStep", "=", "5"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Print", "[", "\"\<Method with fixed timesteps\>\"", "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Print", "[", 
   RowBox[{
   "\"\<Numerical solution (points) and exact solution (line)  at time \
t=\>\"", ",", 
    RowBox[{"tt", "[", "mStep", "]"}]}], "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{" ", 
  RowBox[{
   RowBox[{"FigNum", "=", 
    RowBox[{"ListPlot", "[", 
     RowBox[{
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"xj", "=", 
           RowBox[{"j", "*", "deltax"}]}], ",", 
          RowBox[{"uMs", "[", 
           RowBox[{"[", 
            RowBox[{
             RowBox[{"mStep", "+", "1"}], ",", 
             RowBox[{"j", "+", "1"}]}], "]"}], "]"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"j", ",", "0", ",", "Np"}], "}"}]}], "]"}], ",", 
      RowBox[{"PlotRange", "\[Rule]", "All"}]}], "]"}]}], ";", 
   RowBox[{"FigExact", "=", 
    RowBox[{"Plot", "[", 
     RowBox[{
      RowBox[{"uSol", "[", 
       RowBox[{"x", ",", 
        RowBox[{"tt", "[", "mStep", "]"}], ",", "gammak"}], "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"x", ",", "0", ",", "Pi"}], "}"}], ",", 
      RowBox[{"PlotRange", "\[Rule]", "All"}]}], "]"}]}], ";", " ", 
   RowBox[{"Show", "[", 
    RowBox[{"FigNum", ",", "FigExact", ",", 
     RowBox[{"Frame", "\[Rule]", "True"}], ",", 
     RowBox[{"FrameLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<x\>\"", ",", "\"\<u\>\""}], "}"}]}]}], 
    "]"}]}]}]}], "Input",
 CellChangeTimes->{{3.6372990098493*^9, 3.6372993557363*^9}, {
   3.6372994017143*^9, 3.6372994018733*^9}, {3.6372994547862997`*^9, 
   3.6372994982653*^9}, {3.6372997348883*^9, 3.6372998253603*^9}, 
   3.6373011632593*^9, {3.6373012486103*^9, 3.6373012562163*^9}, 
   3.6373686827849903`*^9, {3.6385156297888002`*^9, 3.6385156374038*^9}}],

Cell[BoxData["\<\"Method with fixed timesteps\"\>"], "Print",
 CellChangeTimes->{3.6385163698968*^9, 3.6386024750176*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Numerical solution (points) and exact solution (line)  at time \
t=\"\>", "\[InvisibleSpace]", "0.05`"}],
  SequenceForm[
  "Numerical solution (points) and exact solution (line)  at time t=", 0.05],
  Editable->False]], "Print",
 CellChangeTimes->{3.6385163698968*^9, 3.6386024750196*^9}],

Cell[BoxData[
 GraphicsBox[{{{}, {{}, 
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
      0.012833333333333334`], AbsoluteThickness[1.6], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQBGIQDQPBzxqcH/pcsHnwYU6ZvvQWezup/+FX5dbYQ/hH
7PV57L2XcOyxD8h8bXhc45z98nNHss+/OgKVv2Lv5Wcj4LnhtL2ErkvIb8Wb
9k9y5LvZVS9C1d+zn+IYY3s77Ir9kaCT7SenP7QP57l5aUrGdaj+J/bSc0u0
YkJv2f/pK0idOu+ZPds/6+LJEneh5r20192/pfTe2vv2JqfFnROXvra/evPc
rikcD6Hmv7O/f2DJhXD5R/bbmuMniIV9sPeoNm1qkHwMte+j/YxL5b+avz62
v6RoXF9z85O9X8KaH2ybnkDt/2If21b45b7vU/t3+9nyHsV8te95HvtZ4sRT
qHu+2b/St+H9KP/MnivuVozHg+/2PNnNc+6GPIO676f9oihtye60Z/Zqf9Z6
r0v+Zc8NlYe497f9M6h+p1mNViLP/9i3Q82HuP+ffQTU/jiLUM2qrP/2nlD3
QfzD4DAB6n7bbBGeD98YHGxR/MfocAnqf2+rOubFFkwOx6HhA/EvkwM/NPwi
OV/8Cq1idnj9FxK+EP+zODBAwz/9RuAnjj0sDrbQ+IGEB6tDBTT+Spfvfrn7
L6vDMWj8QsKHzUEAGv/NZaoP8+zZHfKh6QMSXuwOZ7gh6Weia/8NxUYOh6mS
kPQFCT9OB1g6BAC1Jzeo
       "]]}, {}}, {}}, {{}, {}, 
    {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], Opacity[
     1.], LineBox[CompressedData["
1:eJwd2Hk8VG0bB3CGNCqUXVKJkJCtqHAdipIeW7RKRSpKtixZyh7Vk120Pcha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      "]]}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->True,
  FrameLabel->{
    FormBox["\"x\"", TraditionalForm], 
    FormBox["\"u\"", TraditionalForm]},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  Method->{},
  PlotRange->{{0, 3.141592653589793}, {0, 0.7000174991215611}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.02], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.6385163700768003`*^9, 3.6386024751766*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Here we give a table that compares the numerical and exact solution at the \
middle point, x=\[Pi]/2, for the first numSteps timesteps. \
\>", "Text",
 CellChangeTimes->{{3.6372981691743*^9, 3.6372982503743*^9}, {
  3.6372983312943*^9, 3.6372983351903*^9}, {3.6372983799263*^9, 
  3.6372984925123*^9}, {3.6372988496542997`*^9, 3.6372989263983*^9}},
 Background->RGBColor[1, 1, 0.85]],

Cell[BoxData[
 RowBox[{
  RowBox[{"headFixedTimesteps", "=", 
   RowBox[{"{", 
    RowBox[{
    "\"\<step\>\"", ",", "\"\<t\>\"", ",", 
     "\"\<\!\(\*SubscriptBox[\(U\), \(Fixed\\\ \
\[CapitalDelta]\)]\)(\[Pi]/2,t)\>\"", ",", 
     "\"\<\!\(\*SubscriptBox[\(u\), \(exact\)]\)(\[Pi]/2,t)\>\"", ",", 
     "\"\<error\>\""}], "}"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.6372462215509663`*^9, 3.6372463423118734`*^9}, {
  3.637246799033996*^9, 3.637246806409418*^9}, {3.637246837090173*^9, 
  3.637246852913078*^9}, {3.6372481343843737`*^9, 3.637248157767711*^9}, {
  3.63724839394522*^9, 3.6372484353835897`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"tabFT", "=", 
   RowBox[{
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"m", ",", 
        RowBox[{"tt", "[", "m", "]"}], ",", 
        RowBox[{"uMs", "[", 
         RowBox[{"[", 
          RowBox[{
           RowBox[{"m", "+", "1"}], ",", 
           RowBox[{"Nx", "+", "1"}]}], "]"}], "]"}], ",", 
        RowBox[{"uSol", "[", 
         RowBox[{
          RowBox[{"Pi", "/", "2"}], ",", 
          RowBox[{"tt", "[", "m", "]"}], ",", "gammak"}], "]"}], ",", 
        RowBox[{
         RowBox[{"uMs", "[", 
          RowBox[{"[", 
           RowBox[{
            RowBox[{"m", "+", "1"}], ",", 
            RowBox[{"Nx", "+", "1"}]}], "]"}], "]"}], "-", 
         RowBox[{"uSol", "[", 
          RowBox[{
           RowBox[{"Pi", "/", "2"}], ",", 
           RowBox[{"tt", "[", "m", "]"}], ",", "gammak"}], "]"}]}]}], "}"}], 
      ",", 
      RowBox[{"{", 
       RowBox[{"m", ",", "0", ",", "numSteps"}], "}"}]}], "]"}], "//", 
    "N"}]}], ";", 
  RowBox[{
   RowBox[{"Insert", "[", 
    RowBox[{"tabFT", ",", "headFixedTimesteps", ",", "1"}], "]"}], "//", 
   "TableForm"}]}]], "Input",
 CellChangeTimes->{
  3.6372987625292997`*^9, {3.6373009292093*^9, 3.6373009376243*^9}, {
   3.6373016236413*^9, 3.6373016256473*^9}, 3.6373017098083*^9, 
   3.637369050084999*^9}],

Cell[BoxData[
 TagBox[GridBox[{
    {"\<\"step\"\>", "\<\"t\"\>", "\<\"\\!\\(\\*SubscriptBox[\\(U\\), \
\\(Fixed\\\\ \[CapitalDelta]\\)]\\)(\[Pi]/2,t)\"\>", \
"\<\"\\!\\(\\*SubscriptBox[\\(u\\), \\(exact\\)]\\)(\[Pi]/2,t)\"\>", \
"\<\"error\"\>"},
    {"0.`", "0.`", "1.`", "1.`", "0.`"},
    {"1.`", "0.01`", "0.7920039942506076`", "0.7436316449833099`", 
     "0.04837234926729772`"},
    {"2.`", "0.02`", "0.744104554288511`", "0.7143327315809447`", 
     "0.029771822707566287`"},
    {"3.`", "0.03`", "0.7220493086637307`", "0.6984750698561638`", 
     "0.023574238807566927`"},
    {"4.`", "0.04`", "0.7088390568498045`", "0.6884275121421762`", 
     "0.020411544707628293`"},
    {"5.`", "0.05`", "0.7000174991215611`", "0.6816308747893188`", 
     "0.018386624332242252`"},
    {"6.`", "0.060000000000000005`", "0.693806211884228`", 
     "0.6768883753781058`", "0.01691783650612222`"},
    {"7.`", "0.07`", "0.6893035126681802`", "0.6735334805907414`", 
     "0.015770032077438878`"},
    {"8.`", "0.08`", "0.685980254646491`", "0.6711511507098995`", 
     "0.014829103936591537`"},
    {"9.`", "0.09`", "0.6834940250002391`", "0.6694617903077766`", 
     "0.014032234692462509`"},
    {"10.`", "0.09999999999999999`", "0.681607150952679`", 
     "0.6682656336457294`", "0.013341517306949546`"},
    {"11.`", "0.10999999999999999`", "0.6801457254502439`", 
     "0.6674132984599428`", "0.012732426990301082`"},
    {"12.`", "0.11999999999999998`", "0.6789771952674886`", 
     "0.6667889870819398`", "0.012188208185548777`"},
    {"13.`", "0.12999999999999998`", "0.6779972328555406`", 
     "0.6663003302412825`", "0.011696902614258042`"},
    {"14.`", "0.13999999999999999`", "0.6771216219253483`", 
     "0.6658719553332537`", "0.011249666592094587`"},
    {"15.`", "0.15`", "0.6762810205047095`", "0.6654412560025051`", 
     "0.010839764502204363`"},
    {"16.`", "0.16`", "0.6754174589316391`", "0.6649555205002114`", 
     "0.01046193843142762`"},
    {"17.`", "0.17`", "0.6744819273889586`", "0.6643699296955685`", 
     "0.010111997693390107`"},
    {"18.`", "0.18000000000000002`", "0.6734326713795448`", 
     "0.6636461289548772`", "0.009786542424667588`"},
    {"19.`", "0.19000000000000003`", "0.6722339605983704`", 
     "0.6627511886362807`", "0.009482771962089687`"},
    {"20.`", "0.20000000000000004`", "0.6708551821555732`", 
     "0.6616568335930136`", "0.009198348562559522`"},
    {"21.`", "0.21000000000000005`", "0.6692701606491875`", 
     "0.6603388623750933`", "0.008931298274094224`"},
    {"22.`", "0.22000000000000006`", "0.6674566396604756`", 
     "0.6587767022869767`", "0.008679937373498925`"},
    {"23.`", "0.23000000000000007`", "0.6653958797687516`", 
     "0.6569530629756314`", "0.0084428167931202`"},
    {"24.`", "0.24000000000000007`", "0.6630723416460066`", 
     "0.6548536621862203`", "0.008218679459786271`"},
    {"25.`", "0.25000000000000006`", "0.6604734318226462`", 
     "0.6524670047525454`", "0.008006427070100797`"},
    {"26.`", "0.26000000000000006`", "0.6575892948969381`", 
     "0.6497842010215659`", "0.007805093875372204`"},
    {"27.`", "0.2700000000000001`", "0.6544126402700527`", 
     "0.6467988145186476`", "0.007613825751405123`"},
    {"28.`", "0.2800000000000001`", "0.6509385945440608`", 
     "0.6435067312368479`", "0.007431863307212905`"},
    {"29.`", "0.2900000000000001`", "0.647164572920791`", 
     "0.6399060448017504`", "0.007258528119040597`"},
    {"30.`", "0.3000000000000001`", "0.6430901645476103`", 
     "0.6359969531370719`", "0.007093211410538314`"},
    {"31.`", "0.3100000000000001`", "0.6387170279475844`", 
     "0.6317816632798279`", "0.006935364667756572`"},
    {"32.`", "0.3200000000000001`", "0.6340487935656424`", 
     "0.6272643017661564`", "0.0067844917994859255`"},
    {"33.`", "0.3300000000000001`", "0.6290909711417448`", 
     "0.6224508285987285`", "0.00664014254301637`"},
    {"34.`", "0.34000000000000014`", "0.6238508601443555`", 
     "0.6173489532623371`", "0.00650190688201846`"},
    {"35.`", "0.35000000000000014`", "0.6183374619035756`", 
     "0.6119680516102078`", "0.006369410293367794`"},
    {"36.`", "0.36000000000000015`", "0.612561392402471`", 
     "0.6063190827246543`", "0.006242309677816693`"},
    {"37.`", "0.37000000000000016`", "0.6065347949385255`", 
     "0.6004145050798979`", "0.006120289858627559`"},
    {"38.`", "0.38000000000000017`", "0.6002712520704195`", 
     "0.5942681915154974`", "0.006003060554922168`"},
    {"39.`", "0.3900000000000002`", "0.593785696429851`", 
     "0.5878953426757086`", "0.0058903537541423745`"},
    {"40.`", "0.4000000000000002`", "0.5870943201124506`", 
     "0.581312398690512`", "0.005781921421938563`"},
    {"41.`", "0.4100000000000002`", "0.5802144824724365`", 
     "0.5745369489736217`", "0.005677533498814724`"},
    {"42.`", "0.4200000000000002`", "0.5731646162373216`", 
     "0.5675876400956635`", "0.005576976141658085`"},
    {"43.`", "0.4300000000000002`", "0.5659641319354429`", 
     "0.56048408176008`", "0.005480050175362905`"},
    {"44.`", "0.4400000000000002`", "0.5586333206932037`", 
     "0.5532467509677235`", "0.005386569725480239`"},
    {"45.`", "0.45000000000000023`", "0.5511932555128332`", 
     "0.5458968945053561`", "0.005296361007477102`"},
    {"46.`", "0.46000000000000024`", "0.5436656911869364`", 
     "0.5384564299349313`", "0.0052092612520051595`"},
    {"47.`", "0.47000000000000025`", "0.5360729630444316`", 
     "0.5309478452957308`", "0.005125117748700836`"},
    {"48.`", "0.48000000000000026`", "0.528437884754737`", 
     "0.5233940977610801`", "0.005043786993656818`"},
    {"49.`", "0.49000000000000027`", "0.520783645444027`", 
     "0.5158185115161963`", "0.004965133927830712`"},
    {"50.`", "0.5000000000000002`", "0.513133706399811`", 
     "0.5082446751443515`", "0.004889031255459586`"}
   },
   GridBoxAlignment->{
    "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
     "RowsIndexed" -> {}},
   GridBoxSpacings->{"Columns" -> {
       Offset[0.27999999999999997`], {
        Offset[2.0999999999999996`]}, 
       Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
       Offset[0.2], {
        Offset[0.4]}, 
       Offset[0.2]}, "RowsIndexed" -> {}}],
  Function[BoxForm`e$, 
   TableForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{3.6385163701608*^9, 3.6386024752525997`*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 "A plot comparing the numerical and the exact solution at  position \
x=\[Pi]/2 for times  t  with   0\[LessEqual]t\[LessEqual] ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["t", "numSteps"], TraditionalForm]],
  FormatType->"TraditionalForm"],
 " "
}], "Text",
 CellChangeTimes->{{3.6372989561913*^9, 3.6372990023753*^9}, {
  3.6372990787602997`*^9, 3.6372990811603003`*^9}, {3.6372998614302998`*^9, 
  3.6372998879683*^9}, {3.6373004057753*^9, 3.6373004634223003`*^9}},
 Background->RGBColor[1, 1, 0.85]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"Print", "[", "\"\<Method with fixed timesteps\>\"", "]"}], ";", 
  RowBox[{
  "Print", "[", 
   "\"\<Numerical solution (points) and exact solution (line) at position x=\
\[Pi]/2 vs. time\>\"", "]"}], ";", " ", 
  RowBox[{"FigNum", "=", 
   RowBox[{"ListPlot", "[", 
    RowBox[{
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"tabFT", "[", 
          RowBox[{"[", 
           RowBox[{"n", ",", "2"}], "]"}], "]"}], ",", 
         RowBox[{"tabFT", "[", 
          RowBox[{"[", 
           RowBox[{"n", ",", "3"}], "]"}], "]"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"n", ",", "1", ",", "numSteps"}], "}"}]}], "]"}], ",", 
     RowBox[{"PlotRange", "\[Rule]", "All"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"FigExact", "=", 
   RowBox[{"Plot", "[", 
    RowBox[{
     RowBox[{"uSol", "[", 
      RowBox[{
       RowBox[{"Pi", "/", "2"}], ",", "time", ",", "gammak"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"time", ",", "0", ",", 
       RowBox[{"1.1", "*", 
        RowBox[{"tabFT", "[", 
         RowBox[{"[", 
          RowBox[{
           RowBox[{"numSteps", "+", "1"}], ",", "2"}], "]"}], "]"}]}]}], 
      "}"}], ",", 
     RowBox[{"PlotRange", "\[Rule]", "All"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"Show", "[", 
  RowBox[{"FigNum", ",", "FigExact", ",", 
   RowBox[{"Frame", "\[Rule]", "True"}], ",", 
   RowBox[{"FrameLabel", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"\"\<time\>\"", ",", "\"\<u\>\""}], "}"}]}], ",", 
   RowBox[{"PlotRange", "\[Rule]", "All"}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.6372990098493*^9, 3.6372993557363*^9}, {
   3.6372994017143*^9, 3.6372994018733*^9}, {3.6372994547862997`*^9, 
   3.6372994982653*^9}, {3.6372997348883*^9, 3.6372998253603*^9}, {
   3.6372999061773*^9, 3.6372999638333*^9}, {3.6373000656813*^9, 
   3.6373002790032997`*^9}, {3.6373003226673*^9, 3.6373003301463003`*^9}, 
   3.6373008969223003`*^9, {3.6373010002263002`*^9, 3.6373010046333*^9}, {
   3.6373011368183002`*^9, 3.6373011439313*^9}, {3.6373013944182997`*^9, 
   3.6373014237132998`*^9}, {3.6373017319293003`*^9, 3.6373017582733*^9}, 
   3.6373211117127614`*^9, 3.6373692302623043`*^9, {3.6385156441678*^9, 
   3.6385156532637997`*^9}}],

Cell[BoxData["\<\"Method with fixed timesteps\"\>"], "Print",
 CellChangeTimes->{3.6385163701768*^9, 3.6386024752626*^9}],

Cell[BoxData["\<\"Numerical solution (points) and exact solution (line) at \
position x=\[Pi]/2 vs. time\"\>"], "Print",
 CellChangeTimes->{3.6385163701768*^9, 3.6386024752646*^9}],

Cell[BoxData[
 GraphicsBox[{{{}, {{}, 
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
      0.011000000000000001`], AbsoluteThickness[1.6], PointBox[CompressedData["
1:eJxVkmtIU2EcxmeQkqUgGcxKzW4qXiBN+lD6pH0wzQoXUnkpU2Z2oSTTaGmJ
aVAKttJE0z40B01jOpvovIRueavltKmbutTt7J13kMppUlTnZV964HA4nPM+
/+f5/Y9Xyk0efwOHwwn6d7H3/7WMe67SSKOgAE9uvVNyz83ZnkuR7VsfL9fM
oMWjcCG25RWqFsf2O+yYsb2vwbGCuTCN1ILKClYSvI73cytKs0BBv5dC1qHY
Jgm2YDGWdZAhoCE3tMfZYjsvx6TLkqH4O4GjTpQR6tiMCX6xIXCKgNpVKNCx
2qVWaAh8EkuUKz7t+BE3v9qpImim/u9hmN+SEthKwJ7WiTox+Lz9qHcjwQKd
1wWjtNG6XksQTKWCYi+43Bpim/8BQcd9tm6sJlCtsBO60eCe45lQRrCZ5umF
Q8Ttt8pigjMUQB9OrOd9Ws4neEnz9WOiNTtKfIeAEbCGH5EiKQyXXCXwo3nV
EE2N2w8kEGSy8TI+Q/BHE7MYTdBG8w/gsHNfDnOIwI7uYRBqlSygYjeBmPYZ
RJH9XfmaI0GUkR0whLyndr3fls1Yov2GUFY36587bIZQyRb4At9UgeBZkxkh
tK8WsSV7tAdKzRijgLRoMZyUXcgwI5f2H0a53qlxV7QZXmwcjxFoL6enPvQy
o5vyGIFFf8T1hZXBlTRWo0gt4Yqv9TNwonx0EO7jn99eyUAWyQbU4YG84E1b
OoM4ykuPJlOR8/UQBj/pAvXwtF40RHMYVFN+YzhV5eIg6DchnP4A44g5nWh1
F5pAKM9xPBoN4yWdNeExXegEbpA6TfJOEwIoXwPuS+J/8aaNGFKzMsA/v2dT
ssiILMr7Kw4mZZY38Y1wY+u6TmItS5iT721EB+U/id9iT6F1dhqXWLvEKdj5
1mdH1E7jLz4FlJk=
       "]]}, {}}, {}}, {{}, {}, 
    {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], Opacity[
     1.], LineBox[CompressedData["
1:eJwV13c8Vu0fB3Cr9KQUSRnVkzIaNKhQfJKMUm7ZRUMisjLySBQppWQrZGRm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      "]]}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0.4968228277162284},
  DisplayFunction->Identity,
  Frame->True,
  FrameLabel->{
    FormBox["\"time\"", TraditionalForm], 
    FormBox["\"u\"", TraditionalForm]},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  Method->{},
  PlotRange->All,
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.6385163703568*^9, 3.6386024754306*^9}]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[" ", "Text",
 CellChangeTimes->{{3.6373024057792997`*^9, 3.6373024248943*^9}}],

Cell[TextData[{
 "Example 3\n",
 Cell[GraphicsData["Metafile", "\<\
CF5dJ6E]HGAYHf4PEfU^I6mgLb15CDHPAVmbKF5d0@0009]L0@0006`0003ooooooooooiH4003@0P00
00000000001M4`00i0/00215CDH00040G9/003@1000600000000000000000000HA<006PK003B0000
:@400000000000000000050d0`0XR0@0AP0002`0000P0000ADe6:`500@0L00004000008@`=/00000
F08005P200160000O04007010015CDH[7T0500`0000000007d0300`000000000<402010000040000
0020?b501`0<000000000290100<0000000002Y0000T000060000000P3l0000000000000P3l00000
000002]0000<0000000001i01P0<0000000002501@0<0000000001i02@0<0000000002Y0000T0000
60000000P3l0000000000000P3l00000000002501`0<0000000002Y0000T000060000;02;3X00000
00000;02;3X089G40?0haB]0000<0000000002Y0000T000060000;02;3X0000000000;02;3X089G4
0?0haB]0000<0000000002Y0000T000060000;02;3X0000000000;02;3X009FX000iZ@Y0080T0000
60000?ooool100000000000000202=Y90?:5BB4000080000HP0000`000010000900002@00000080m
000000000000080m00000000000200009@0000`0000000209@0000`000080020EP000300003ooooo
oooooi@4003@0P001@000?Son?ohooP/>4Wh;3Q9n?ohooSo9@0000`0000700209@0000`000000020
900002@00000081100000000000008110000000000020000AP000619001DB@00ADe6:b]0000<0000
000001i01P0<0000000002501@0<0000000001i02@0<0000000002Y0000T000060000;02;3X00000
00000;02;3X009FX000iZB501`0<0000000002]0000<0000000002Y0000T0000600000Di94400000
00000?lo946YLAo5_k_?ABA0100<0000000000Q000E@B000A4P0008@`=/200000`0003A800010000
c0000?X0001ioOooJP400;cmooll8P00a:Koom<a001;/?oo84E=AP000@0dB000004000@0000`0000
K000000000201`00>0@00:D2001m0@000000000000000000eED:04S@1@1W06D0KP1U0780H@1d06D0
I00P0680N@0P05L0C@1602l0A@1=04H0801R0640H`1[06D0KP1T0200K`1V0200L01c07@0K`1U06@0
J@1d0000J@1^0700M@1d0000000A0000300000H0000:000040000000000000004P0000`000010000
5P0000`0000H0000600000`000000000DP00070100010000>Oooo`00000000000000090100000000
00020T<0C@1=04T0<@0`000000000000000000000000000000000000000000000000000000000000
000000000000000010000<S:60000000200000L000000000SU=EMLS:600`bQP0k;1300@000240000
b<XH00000000000030000000000100008<XH000000240000X0l0008000030000b<XH000000000000
?<XH07nN@`3l2SD0P<XH0000@`040000S[E30?c0BgI`OSD08HQ600000000000000000040001<bQP0
02m:00c;603PW480;2hDM_koool004<0gKE3071n=@000000000e071n=@38bQP00@0003P07P0;0000
b<XH071n=@010`00^7de0040001XOSD0I7H02000000U000030000040001D0000E0000?/0001joOoo
0@4008Cmool10000Zj[Q?ag7hKnI4`00fc400040001<00000000000000000000oooooooooom@0000
@00006@0000H000030000000000U0000300000d0080X000030000040001B0000L0400040001eoooo
0000000000000000T040000000000082@`1=04d0B@0g000000000000000000000000000000000000
000000000000000000000000000000000000000000000000?`00?`@000020000B=IJ0<S:60000000
6`0n07@1F0000000D05H05P3fP4004<0:=9J0:2_F`00000010000000001L0@010000020000000041
E<TH08cS?WN<bQP0mG53Mo`?J`3nooooZSPoMj8d?gL00000001J02SBFP3H7PX;0000023BFP2LbQP0
RU=_M@00F0000000XEA_MJM7BWKH7PX;:=9J0801W7D8QSD0B03J0@00fP5XbQP0f1h:2hC<6000L75e
:`HS0okooonQE6me1A:HMBSBFP3XAE/0e1hQ6@002P3XAE/0e<XH05`iV7ETMP08000002D0000<0000
0@0005@0001D00000@4007Wmool50@00Oogoo`40002[Z^4o7LOQ_`hD000S<P000@0004`000000000
00000000003ooooooooooe00002`0000D00001P0000<0000000002D0000<00003@00P2P0000<0000
0@000580001`0@000@0003Woool0000000000000002@0@00000000000P9304d0C@190340<0000000
000000000000000000000000000000000000000000000000000000000000000000000000000o000o
100005C96018eUX0S<XH0?Ea@gLK03h0M05H0000001@0EP0F0?J0@00FP0XdUX0X:mK000000040000
000005`100400000800000000@5DbAP0000008c:603eLD=go0m[0?kooonZ>3mgXS@oM`00000005X0
:=9J0=PN2P`000008=9J09c:602:Dfme001H0000002QE6meYdM:M]PN2P`XdUX0P06LM@0000180=X1
003J0FS:603H7PX<Q<`H001`LGD[1R<3o_oooj5DKgD54YQe:=9J0>Q5F`3D7R4I000:0>Q5F`3DbQP0
G3VHMFAf00P000009@0000`000010000E00005@000060@00N_goo``10024oOoo0@000:^ZhClMan6o
MA@00=/a00010000C00000000000000000000?ooooooooooD00007D0001h00009P0001`000020000
0000000000000000000002D0000<00000P0002L0000H00000`00000000000000000002D0000<0000
0`0001<0000<00000P0005/0000h0000n`0008Kmool<0@00Q_goo`40000500001@0009`CR37Z58Pa
jQB@<I`CT36L4hPa600000`000000000E00005@0003l0000Qogoo`81002AoOoo0@000:^ZhClMan6o
[a<00<``00010000C00000000000000000000?ooooooooooD0000400001T0000600000`000000000
E00005@000020@00Qogoo`H1002AoOoo0@000:^ZhClMan6o8a@00<``00010000C000000000000000
00000?ooooooooooD00007@0001@0000600000`0000000009@0000`0000=0020:00000`000010000
DP00070100010000MOooo`0000000000000009010000000000020T<0C@1=04T0=`00000000000000
0000000000000000000000000000000000000000000000000000000000000000000003l003l40000
05_X0DSFFP0H@3D0j00001/0?P1d0EP000000501F01H0mX1>04e02SBFP38NeX0000000@000000000
G0400@00000P000000010EC960000000S<XH0?Ea@gOl3f/0o_ooojXh?gNR=3mg00000000FP0XdUX0
f1h:3@00000PdUX0W<XH08YCKgD005P000000:5DKgFWAdYff1h:3BSBFP200Iae2P000?2M=@0003D0
J<XH0=PN2Pf4c1P0071aMB/68`?nooooXEA_M@DBV7DXdUX0j4EK0=@N8AT000X0j4EK0=C:601L>IQe
I7H02000000U000030000040001D0000E00000D10028oOoo2@4008kmool10000Zj[Q?ag7hKm[5000
1S400040001<00000000000000000000oooooooooom@0000/0000500000H000030000000000U0000
300000d0080X000030000040001B0000L0400040000ioooo0000000000000000T040000000000082
@`1=0580<@0`00000000000000000000000000000000000000000000000000000000000000000000
0000000000000000?`00?`@0001DbAP0B=IJ08c:603eLD=g6`0n07@1F0000000D05H05P3fP4005X0
:=9J0<QkFP00000010000000001L0@010000020000000041E<TH0000002<bQP0mG53Mo`?J`3noooo
ZSPoMj8d?gL00000001J02SBFP3H7PX>0000023BFP2LbQP0RU=_M@00F0000000XEA_MJM7BWKH7PX>
:=9J0801W7D00000l9de0000=@1XbQP0f1h:3XC<6000L75e:`HS0okooonQE6me1A:HMBSBFP3XAE/0
e1hQ6@002P3XAE/0e<XH05`iV7ETMP08000002D0000<00000@0005@0001D00004040087moolH0@00
Rogoo`40002[Z^4o7LOQ_cHE001E<@000@0004`00000000000000000003ooooooooooe00000m0000
X00001P0000<0000000002D0000<00003@00P2P0000<00000@000580001`0@000@0003Woool00000
00000000002@0@00000000000P9304d0C@190340<000000000000000000000000000000000000000
0000000000000000000000000000000000000000000o000o100005C96018eUX0S<XH0?Ea@gLK03h0
M05H0000001@0EP0F0?J0@00FP0XdUX0b7]J000000040000000005`100400000800000000@5DbAP0
000008c:603eLD=go0m[0?kooonZ>3mgXS@oM`00000005X0:=9J0=PN2Pl000008=9J09c:602:Dfme
001H0000002QE6meYdM:M]PN2PlXdUX0P06LM@00003`WCD0000e06S:603H7PX?Q<`H001`LGD[1R<3
o_oooj5DKgD54YQe:=9J0>Q5F`3D7R4I000:0>Q5F`3DbQP0G3VHMFAf00P000009@0000`000010000
E00005@0000K0@00N_goob410024oOoo0@000:^ZhClMan6o81H00=/a00010000C000000000000000
00000?ooooooooooD0000400001T0000600000`0000000009@0000`0000=0020:00000`000010000
DP00070100010000MOooo`0000000000000009010000000000020T<0C@1B03L00000000000000000
0000000000000000000000000000000000000000000000000000000000000000000003l003l40000
E<TH04SFFP2<bQP0mG53Ma/0?P1d0EP000000501F01H0mX1001J02SBFP38NeX0000000@000000000
G0400@00000P000000010EC960000000S<XH0?Ea@gOl3f/0o_ooojXh?gNR=3mg00000000FP0XdUX0
f1h:4000000PdUX0W<XH08YCKgD005P000000:5DKgFWAdYff1h:42SBFP200Iae00000?2M=@0003D0
J<XH0=PN2Q24c1P0071aMB/68`?nooooXEA_M@DBV7DXdUX0j4EK0=@N8AT000X0j4EK0=C:601L>IQe
I7H02000000U000030000040001D0000E0000241001ioOoo9@4007omool10000Zj[Q?ag7hKnD5P00
8c800040001<00000000000000000000oooooooooom@0000<P000500000H000030000000000U0000
300000d0080X000030000040001B0000L0400040000ioooo0000000000000000T040000000000082
@`1=04d0B@0a03000000000000000000000000000000000000000000000000000000000000000000
0000000000000000?`00?`@0001DbAP0B=IJ08c:603eLD=g6`0n07@1F0000000D05H05P3fP4005X0
:=9J0<QkFP00000010000000001L0@010000020000000041E<TH0000002<bQP0mG53Mo`?J`3noooo
ZSPoMj8d?gL00000001J02SBFP3H7PXA0000023BFP2LbQP0RU=_M@00F0000000XEA_MJM7BWKH7PXA
:=9J0801W7D00000l9de0000=@1XbQP0f1h:4HC<6000L75e:`HS0okooonQE6me1A:HMBSBFP3XAE/0
e1hQ6@002P3XAE/0e<XH05`iV7ETMP08000002D0000<00000@0005@0001D00009P4007[mool/0@00
Q?goo`40002[Z^4o7LOQ_nhF003K<@000@0004`00000000000000000003ooooooooooe00001e0000
N00002D0000<00001`00P2P0000<00000P0002H0000L00000P0000000000000000000000000U0000
30000080000U000030000000080X0000300000<0000W0000600000<00000000000000000000U0000
300000<0000C000030000080001K0000>00001/10026oOoo:`4008Kmool100001@0000D0000L5XPa
G1N8<E`GT34L5Y0a71J8<AP0000<0000000005@0001D00006`4008OmoolQ0@00TOgoo`40002[Z^4o
7LOQ_b0F003<<0000@0004`00000000000000000003ooooooooooe0000100000I00001P0000<0000
000005@0001D00008@4008OmoolW0@00TOgoo`40002[Z^4o7LOQ_i@F003<<0000@0004`000000000
00000000003ooooooooooe00001h0000N00001P0000<0000000002D0000<00003@00P2P0000<0000
0@000580001`0@000@0007Goool0000000000000002@0@00000000000P9304d0DP0g000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000o000o
1000001Kj058eUX0640e0>P0000K03h0M05H0000001@0EP0F0?J0CP1=@0XdUX0b7]J000000040000
000005`100400000800000000@5DbAP0000008c:603eLD=go0m[0?kooonZ>3mgXS@oM`00000005X0
:=9J0=PN2Q8000008=9J09c:602:Dfme001H0000002QE6meYdM:M]PN2Q8XdUX0P06LM@X0003`WCD0
000e06S:603H7PXBQ<`H001`LGD[1R<3o_oooj5DKgD54YQe:=9J0>Q5F`3D7R4I000:0>Q5F`3DbQP0
G3VHMFAf00P000009@0000`000010000E00005@0000W0@00R?goob/1002>oOoo0@000:^ZhClMan6o
1QL000Ha00010000C00000000000000000000?ooooooooooD0000380001@0000600000`000000000
9@0000`0000=0020:00000`000010000DP00070100010000>Oooo`00000000000000090100000000
00020T<0C@1=04T0<@0`000000000000000000000000000000000000000000000000000000000000
0000000000000000000003l003l40000E<TH04SFFP2<bQP0mG53Ma/0?P1d0EP000000501F01H0mX1
001J02SBFP38NeX0000000@000000000G0400@00000P000000010EC960000000S<XH0?Ea@gOl3f/0
o_ooojXh?gNR=3mg00000000FP0XdUX0f1h:4`00000PdUX0W<XH08YCKgD005P000000:5DKgFWAdYf
f1h:4bSBFP200Iae00000?2M=@0003D0J<XH0=PN2Q>4c1P0071aMB/68`?nooooXEA_M@DBV7DXdUX0
j4EK0=@N8AT000X0j4EK0=C:601L>IQeI7H02000000U000030000040001D0000E00002`10021oOoo
;`4008_mool10000Zj[Q?ag7hKmh5`00EC400040001<00000000000000000000oooooooooom@0000
>`0003`0000H000030000000000U0000300000d0080X000030000040001B0000L0400040000ioooo
0000000000000000T040000000000082@`1=0580<@0`000000000000000000000000000000000000
000000000000000000000000000000000000000000000000?`00?`@0001DbAP0B=IJ08c:603eLD=g
6`0n07@1F0000000D05H05P3fP4005X0:=9J0<QkFP00000010000000001L0@010000020000000041
E<TH0000002<bQP0mG53Mo`?J`3nooooZSPoMj8d?gL00000001J02SBFP3H7PXD0000023BFP2LbQP0
RU=_M@00F0000000XEA_MJM7BWKH7PXD:=9J0801W7D00000l9de0000=@1XbQP0f1h:58C<6000L75e
:`HS0okooonQE6me1A:HMBSBFP3XAE/0e1hQ6@002P3XAE/0e<XH05`iV7ETMP08000002D0000<0000
0@0005@0001D0000>`40087moom00@00Rogoo`40002[Z^4o7LOQ_iPH001E<@000@0004`000000000
00000000003ooooooooooe00000`0000I00001P0000<0000000002D0000<00003@00P2P0000<0000
0@000580001`0@000@0003Woool0000000000000002@0@00000000000P9304d0D`1I0340<01?0580
B@1700000000000000000000000000000000000000000000000000000000000000000000000o000o
100005C96018eUX0S<XH0?Ea@gLK03h0M05H0000001@0EP0F0?J0@00FP0XdUX0b7]J000000040000
000005`100400000800000000@5DbAP0000008c:603eLD=go0m[0?kooonZ>3mgXS@oM`00000005X0
:=9J0=PN2QD000008=9J09c:602:Dfme001H0000002QE6meYdM:M]PN2QDXdUX0P06LM@00003`WCD0
000e06S:603H7PXEQ<`H001`LGD[1R<3o_oooj5DKgD54YQe:=9J0>Q5F`3D7R4I000:0>Q5F`3DbQP0
G3VHMFAf00P000009@0000`000010000E00005@000130@00POgood/1002BoOoo0@000:^ZhClMan6o
<aT005Da00010000C00000000000000000000?ooooooooooD0000;L0002P0000600000`000000000
9@0000`0000=0020:00000`000010000DP00070100010000>Oooo`00000000000000090100000000
00020T<0C@1=04T0<@0`000000000000000000000000000000000000000000000000000000000000
0000000000000000000003l003l40000E<TH04SFFP2<bQP0mG53Ma/0?P1d0EP000000501F01H0mX1
001J02SBFP38NeX0000000@000000000G0400@00000P000000010EC960000000S<XH0?Ea@gOl3f/0
o_ooojXh?gNR=3mg00000000FP0XdUX0f1h:5P00000PdUX0W<XH08YCKgD005P000000:5DKgFWAdYf
f1h:5RSBFP200Iae00000?2M=@0003D0J<XH0=PN2QJ4c1P0071aMB/68`?nooooXEA_M@DBV7DXdUX0
j4EK0=@N8AT000X0j4EK0=C:601L>IQeI7H02000000U000030000040001D0000E00004d10021oOoo
D`4008_mool10000Zj[Q?ag7hKl56P00EC400040001<00000000000000000000oooooooooom@0000
N00007P0000H000030000000000U0000300000d0080X000030000040001B0000L0400040000ioooo
0000000000000000T040000000000082@`1=05<0F@0a0300C`1B04T0A`0000000000000000000000
000000000000000000000000000000000000000000000000?`00?`@0001DbAP0B=IJ08c:603eLD=g
6`0n07@1F0000000D05H05P3fP4005X0:=9J0<QkFP00000010000000001L0@010000020000000041
E<TH0000002<bQP0mG53Mo`?J`3nooooZSPoMj8d?gL00000001J02SBFP3H7PXG0000023BFP2LbQP0
RU=_M@00F0000000XEA_MJM7BWKH7PXG:=9J0801W7D00000l9de0000=@1XbQP0f1h:5hC<6000L75e
:`HS0okooonQE6me1A:HMBSBFP3XAE/0e1hQ6@002P3XAE/0e<XH05`iV7ETMP08000002D0000<0000
0@0005@0001D0000EP40087moomN0@00T_goo`40002[Z^4o7LOQ_jhJ001E<@000@0004`000000000
00000000003ooooooooooe00002g0000X00001P0000<0000000002D0000<00003@00P2P0000<0000
0@000580001`0@000@0003Woool0000000000000002@0@00000000000P9304d0C@190340<0000000
000000000000000000000000000000000000000000000000000000000000000000000000000o000o
100005C96018eUX0S<XH0?Ea@gLK03h0M05H0000001@0EP0F0?J0@00FP0XdUX0b7]J000000040000
000005`100400000800000000@5DbAP0000008c:603eLD=go0m[0?kooonZ>3mgXS@oM`00000005X0
:=9J0=PN2QP000008=9J09c:602:Dfme001H0000002QE6meYdM:M]PN2QPXdUX0P06LM@00003`WCD0
000e06S:603H7PXHQ<`H001`LGD[1R<3o_oooj5DKgD54YQe:=9J0>Q5F`3D7R4I000:0>Q5F`3DbQP0
G3VHMFAf00P000009@0000`000010000E00005@0001P0@00POgoofL1002;oOoo0@000:^ZhClMan6o
P1/005Da00010000C00000000000000000000?ooooooooooD00004`0002<0000600000`000000000
E00005@0001W0@00POgoofX1002;oOoo0@000:^ZhClMan6o21`005Da00010000C000000000000000
00000?ooooooooooD00003/0000l0000600000`000000000E00005@0003j0000U?goo`01002NoOoo
0@000:^ZhClMan6oPA<00=D_00010000C00000000000000000000?ooooooooooD00007D0001h0000
600000`0000000009@0000`0000=0020:00000`000010000DP00070100010000>Oooo`0000000000
000009010000000000020T<0C@1B0340<00000000000000000000000000000000000000000000000
00000000000000000000000000000000000003l003l40000E<TH04SFFP2<bQP0mG53Ma/0?P1d0EP0
00000501F01H0mX1001J02SBFP38NeX0000000@000000000G0400@00000P000000010EC960000000
S<XH0?Ea@gOl3f/0o_ooojXh?gNR=3mg00000000FP0XdUX0f1h:6@00000PdUX0W<XH08YCKgD005P0
00000:5DKgFWAdYff1h:6BSBFP200Iae00000?2M=@0003D0J<XH0=PN2QV4c1P0071aMB/68`?noooo
XEA_M@DBV7DXdUX0j4EK0=@N8AT000X0j4EK0=C:601L>IQeI7H02000000U000030000040001D0000
E0000?l0002DoOoo0`4009kmool10000Zj[Q?ag7hKoc4`00eBl00040001<00000000000000000000
oooooooooom@0000:0000500000H000030000000000U0000300000d0080X000030000040001B0000
L0400040000ioooo0000000000000000T040000000000082@`1=04d0B@0a03000000000000000000
0000000000000000000000000000000000000000000000000000000000000000?`00?`@0001DbAP0
B=IJ08c:603eLD=g6`0n07@1F0000000D05H05P3fP4005X0:=9J0<QkFP00000010000000001L0@01
0000020000000041E<TH0000002<bQP0mG53Mo`?J`3nooooZSPoMj8d?gL00000001J02SBFP3H7PXJ
0000023BFP2LbQP0RU=_M@00F0000000XEA_MJM7BWKH7PXJ:=9J0801W7D00000l9de0000=@1XbQP0
f1h:6XC<6000L75e:`HS0okooonQE6me1A:HMBSBFP3XAE/0e1hQ6@002P3XAE/0e<XH05`iV7ETMP08
000002D0000<00000@0005@0001D00000`4009Cmool90@00W_goo`40002[Z^4o7LOQ_d4D003E;`00
0@0004`00000000000000000003ooooooooooe00001h0000N00001P0000<0000000002D0000<0000
3@00P2P0000<00000@000580001`0@000@0003Woool0000000000000002@0@00000000000P9304d0
DP0a0300000000000000000000000000000000000000000000000000000000000000000000000000
00000000000o000o100005C96018eUX0S<XH0?Ea@gLK03h0M05H0000001@0EP0F0?J0@00FP0XdUX0
b7]J000000040000000005`100400000800000000@5DbAP0000008c:603eLD=go0m[0?kooonZ>3mg
XS@oM`00000005X0:=9J0=PN2Q/000008=9J09c:602:Dfme001H0000002QE6meYdM:M]PN2Q/XdUX0
P06LM@00003`WCD0000e06S:603H7PXKQ<`H001`LGD[1R<3o_oooj5DKgD54YQe:=9J0>Q5F`3D7R4I
000:0>Q5F`3DbQP0G3VHMFAf00P000009@0000`000010000E00005@0000<0@00U?gooa@1002NoOoo
0@000:^ZhClMan6ojQ@00=D_00010000C00000000000000000000?ooooooooooD00003d0002P0000
600000`000000000E00005@0000F0@00U?gooa/1002NoOoo0@000:^ZhClMan6o_1D00=D_00010000
C00000000000000000000?ooooooooooD0000300001T0000600000`0000000009@0000`0000=0020
:00000`000010000DP00070100010000>Oooo`0000000000000009010000000000020T<0C@1=04T0
<@0`0000000000000000000000000000000000000000000000000000000000000000000000000000
000003l003l40000E<TH04SFFP2<bQP0mG53Ma/0?P1d0EP000000501F01H0mX1001J02SBFP38NeX0
000000@000000000G0400@00000P000000010EC960000000S<XH0?Ea@gOl3f/0o_ooojXh?gNR=3mg
00000000FP0XdUX0f1h:7000000PdUX0W<XH08YCKgD005P000000:5DKgFWAdYff1h:72SBFP200Iae
00000?2M=@0003D0J<XH0=PN2Qb4c1P0071aMB/68`?nooooXEA_M@DBV7DXdUX0j4EK0=@N8AT000X0
j4EK0=C:601L>IQeI7H02000000U000030000040001D0000E00001/1002DoOoo7P4009kmool10000
Zj[Q?ag7hKlP5P00eBl00040001<00000000000000000000oooooooooom@0000>`0003`0000H0000
30000000001D0000E0000201002DoOoo904009kmool10000Zj[Q?ag7hKmi5P00eBl00040001<0000
0000000000000000oooooooooom@0000M0000500000H000030000000000U0000300000d0080X0000
30000040001B0000L0400040000ioooo0000000000000000T040000000000082@`1=0580<@0`0000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
?`00?`@0001DbAP0B=IJ08c:603eLD=g6`0n07@1F0000000D05H05P3fP4005X0:=9J0<QkFP000000
10000000001L0@010000020000000041E<TH0000002<bQP0mG53Mo`?J`3nooooZSPoMj8d?gL00000
001J02SBFP3H7PXM0000023BFP2LbQP0RU=_M@00F0000000XEA_MJM7BWKH7PXM:=9J0801W7D00000
l9de0000=@1XbQP0f1h:7HC<6000L75e:`HS0okooonQE6me1A:HMBSBFP3XAE/0e1hQ6@002P3XAE/0
e<XH05`iV7ETMP08000002D0000<00000@0005@0001D00008`4009CmoolW0@00W_goo`40002[Z^4o
7LOQ_l4F003E;`000@0004`00000000000000000003ooooooooooe00000Y0000D00001P0000<0000
000005@0001D0000:P4009Cmoolb0@00W_goo`40002[Z^4o7LOQ_dDG003E;`000@0004`000000000
00000000003ooooooooooe00000m0000X00001P0000<0000000002D0000<00003@00P2P0000<0000
0@000580001`0@000@0003Woool0000000000000002@0@00000000000P9304d0C@190340<0000000
000000000000000000000000000000000000000000000000000000000000000000000000000o000o
100005C96018eUX0S<XH0?Ea@gLK03h0M05H0000001@0EP0F0?J0@00FP0XdUX0b7]J000000040000
000005`100400000800000000@5DbAP0000008c:603eLD=go0m[0?kooonZ>3mgXS@oM`00000005X0
:=9J0=PN2Qh000008=9J09c:602:Dfme001H0000002QE6meYdM:M]PN2QhXdUX0P06LM@00003`WCD0
000e06S:603H7PXNQ<`H001`LGD[1R<3o_oooj5DKgD54YQe:=9J0>Q5F`3D7R4I000:0>Q5F`3DbQP0
G3VHMFAf00P000009@0000`000010000E00005@0000d0@00U?goocX1002NoOoo0@000:^ZhClMan6o
61P00=D_00010000C00000000000000000000?ooooooooooD00007D0001h0000600000`000000000
9@0000`0000=0020:00000`000010000DP00070100010000MOooo`00000000000000090100000000
00020T<0C@1B03L00000000000000000000000000000000000000000000000000000000000000000
0000000000000000000003l003l40000E<TH04SFFP2<bQP0mG53Ma/0?P1d0EP000000501F01H0mX1
001J02SBFP38NeX0000000@000000000G0400@00000P000000010EC960000000S<XH0?Ea@gOl3f/0
o_ooojXh?gNR=3mg00000000FP0XdUX0f1h:7`00000PdUX0W<XH08YCKgD005P000000:5DKgFWAdYf
f1h:7bSBFP200Iae00000?2M=@0003D0J<XH0=PN2Qn4c1P0071aMB/68`?nooooXEA_M@DBV7DXdUX0
j4EK0=@N8AT000X0j4EK0=C:601L>IQeI7H02000000U000030000040001D0000E00003X1002HoOoo
?P4009kmool10000Zj[Q?ag7hKn:6000]bl00040001<00000000000000000000oooooooooom@0000
<0000500000H000030000000000U0000300000d0080X000030000040001B0000L0400040000ioooo
0000000000000000T040000000000082@`1=04d0B@0a030000000000000000000000000000000000
000000000000000000000000000000000000000000000000?`00?`@0001DbAP0B=IJ08c:603eLD=g
6`0n07@1F0000000D05H05P3fP4005X0:=9J0<QkFP00000010000000001L0@010000020000000041
E<TH0000002<bQP0mG53Mo`?J`3nooooZSPoMj8d?gL00000001J02SBFP3H7PXP0000023BFP2LbQP0
RU=_M@00F0000000XEA_MJM7BWKH7PXP:=9J0801W7D00000l9de0000=@1XbQP0f1h:88C<6000L75e
:`HS0okooonQE6me1A:HMBSBFP3XAE/0e1hQ6@002P3XAE/0e<XH05`iV7ETMP08000002D0000<0000
0@0005@0001D0000?`4009Cmoom20@00W_goo`40002[Z^4o7LOQ_n<H003E;`000@0004`000000000
00000000003ooooooooooe00000k0000?00001P0000<0000000005@0001D0000nP000:?mool00@00
[Ogoo`40002[Z^4o7LOQ_h4C002Z;P000@0004`00000000000000000003ooooooooooe00001e0000
N00001P0000<0000000002D0000<00003@00P2P0000<00000@000580001`0@000@0003Woool00000
00000000002@0@00000000000P9304d0DP0a03000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000o000o100005C96018eUX0S<XH0?Ea@gLK03h0
M05H0000001@0EP0F0?J0@00FP0XdUX0b7]J000000040000000005`100400000800000000@5DbAP0
000008c:603eLD=go0m[0?kooonZ>3mgXS@oM`00000005X0:=9J0=PN2R4000008=9J09c:602:Dfme
001H0000002QE6meYdM:M]PN2R4XdUX0P06LM@00003`WCD0000e06S:603H7PXQQ<`H001`LGD[1R<3
o_oooj5DKgD54YQe:=9J0>Q5F`3D7R4I000:0>Q5F`3DbQP0G3VHMFAf00P000009@0000`000010000
E00005@0003o0000Xogoo`<1002]oOoo0@000:^ZhClMan6ola<00:X^00010000C000000000000000
00000?ooooooooooD00002P0001@0000600000`0000000009@0000`0000=0020:00000`000010000
DP00070100010000>Oooo`0000000000000009010000000000020T<0C@1=04T0<@0`000000000000
0000000000000000000000000000000000000000000000000000000000000000000003l003l40000
E<TH04SFFP2<bQP0mG53Ma/0?P1d0EP000000501F01H0mX1001J02SBFP38NeX0000000@000000000
G0400@00000P000000010EC960000000S<XH0?Ea@gOl3f/0o_ooojXh?gNR=3mg00000000FP0XdUX0
f1h:8P00000PdUX0W<XH08YCKgD005P000000:5DKgFWAdYff1h:8RSBFP200Iae00000?2M=@0003D0
J<XH0=PN2R:4c1P0071aMB/68`?nooooXEA_M@DBV7DXdUX0j4EK0=@N8AT000X0j4EK0=C:601L>IQe
I7H02000000U000030000040001D0000E00000<1002SoOoo2@400:gmool10000Zj[Q?ag7hKm15000
ZRh00040001<00000000000000000000oooooooooom@0000N00007P0000H000030000000000U0000
300000d0080X000030000040001B0000L0400040000ioooo0000000000000000T040000000000082
@`1=0580<@0`00000000000000000000000000000000000000000000000000000000000000000000
0000000000000000?`00?`@0001DbAP0B=IJ08c:603eLD=g6`0n07@1F0000000D05H05P3fP4005X0
:=9J0<QkFP00000010000000001L0@010000020000000041E<TH0000002<bQP0mG53Mo`?J`3noooo
ZSPoMj8d?gL00000001J02SBFP3H7PXS0000023BFP2LbQP0RU=_M@00F0000000XEA_MJM7BWKH7PXS
:=9J0801W7D00000l9de0000=@1XbQP0f1h:8hC<6000L75e:`HS0okooonQE6me1A:HMBSBFP3XAE/0
e1hQ6@002P3XAE/0e<XH05`iV7ETMP08000002D0000<00000@0005@0001D000030400:?moolD0@00
[Ogoo`40002[Z^4o7LOQ_nXD002Z;P000@0004`00000000000000000003ooooooooooe00000m0000
X00001P0000<0000000002D0000<00003@00P2P0000<00000@000580001`0@000@0003Woool00000
00000000002@0@00000000000P9304d0C@190340<000000000000000000000000000000000000000
0000000000000000000000000000000000000000000o000o100005C96018eUX0S<XH0?Ea@gLK03h0
M05H0000001@0EP0F0?J0@00FP0XdUX0b7]J000000040000000005`100400000800000000@5DbAP0
000008c:603eLD=go0m[0?kooonZ>3mgXS@oM`00000005X0:=9J0=PN2R@000008=9J09c:602:Dfme
001H0000002QE6meYdM:M]PN2R@XdUX0P06LM@00003`WCD0000e06S:603H7PXTQ<`H001`LGD[1R<3
o_oooj5DKgD54YQe:=9J0>Q5F`3D7R4I000:0>Q5F`3DbQP0G3VHMFAf00P000009@0000`000010000
E00005@0000F0@00Xogooad1002]oOoo0@000:^ZhClMan6o_1D00:X^00010000C000000000000000
00000?ooooooooooD00004`0002<0000600000`000000000E00005@0000M0@00Xogoob01002]oOoo
0@000:^ZhClMan6oA1H00:X^00010000C00000000000000000000?ooooooooooD00003/0000l0000
600000`000000000E00005@0000Q0@00XogoobD1002]oOoo0@000:^ZhClMan6oWAH00:X^00010000
C00000000000000000000?ooooooooooD00007@0001@0000600000`0000000009@0000`0000=0020
:00000`000010000DP00070100010000>Oooo`0000000000000009010000000000020T<0C@1B0340
<0000000000000000000000000000000000000000000000000000000000000000000000000000000
000003l003l40000E<TH04SFFP2<bQP0mG53Ma/0?P1d0EP000000501F01H0mX1001J02SBFP38NeX0
000000@000000000G0400@00000P000000010EC960000000S<XH0?Ea@gOl3f/0o_ooojXh?gNR=3mg
00000000FP0XdUX0f1h:9@00000PdUX0W<XH08YCKgD005P000000:5DKgFWAdYff1h:9BSBFP200Iae
00000?2M=@0003D0J<XH0=PN2RF4c1P0071aMB/68`?nooooXEA_M@DBV7DXdUX0j4EK0=@N8AT000X0
j4EK0=C:601L>IQeI7H02000000U000030000040001D0000E00002D1002SoOoo:@400:gmool10000
Zj[Q?ag7hKoU5P00ZRh00040001<00000000000000000000oooooooooom@0000:@000500000H0000
30000000001D0000E00002`1002SoOoo=0400:gmool10000Zj[Q?ag7hKmY5`00ZRh00040001<0000
0000000000000000oooooooooom@0000?@000:00000H000030000000001D0000E00003H1002SoOoo
>`400:gmool10000Zj[Q?ag7hKll6000ZRh00040001<00000000000000000000oooooooooom@0000
<00006@0000H000030000000000U0000300000d0080X000030000040001B0000L0400040000ioooo
0000000000000000T040000000000082@`1=04d0B@0a030000000000000000000000000000000000
000000000000000000000000000000000000000000000000?`00?`@0001DbAP0B=IJ08c:603eLD=g
6`0n07@1F0000000D05H05P3fP4005X0:=9J0<QkFP00000010000000001L0@010000020000000041
E<TH0000002<bQP0mG53Mo`?J`3nooooZSPoMj8d?gL00000001J02SBFP3H7PXV0000023BFP2LbQP0
RU=_M@00F0000000XEA_MJM7BWKH7PXV:=9J0801W7D00000l9de0000=@1XbQP0f1h:9XC<6000L75e
:`HS0okooonQE6me1A:HMBSBFP3XAE/0e1hQ6@002P3XAE/0e<XH05`iV7ETMP08000002D0000<0000
0@0005@0001D0000>`400:?mooln0@00[Ogoo`40002[Z^4o7LOQ_ilH002Z;P000@0004`000000000
00000000003ooooooooooe00000k0000?00001P0000<0000000005@0001D0000nP000;;mool00@00
_?goo`40002[Z^4o7LOQ_h4C001o;@000@0004`00000000000000000003ooooooooooe00001e07<0
N00001P0000<0000000002D0000<00003@00P2P0000<00000@000580001`0@000@0003Woool00000
00000000002@0@00000000000P9304d0DP0a03000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000o000o100005C96018eUX0S<XH0?Ea@gLK03h0
M05H0000001@0EP0F0?J0@00FP0XdUX0b7]J000000040000000005`100400000800000000@5DbAP0
000008c:603eLD=go0m[0?kooonZ>3mgXS@oM`00000005X0:=9J0=PN2RL000008=9J09c:602:Dfme
001H0000002QE6meYdM:M]PN2RLXdUX0P06LM@00003`WCD0000e06S:603H7PXWQ<`H001`LGD[1R<3
o_oooj5DKgD54YQe:=9J0>Q5F`3D7R4I000:0>Q5F`3DbQP0G3VHMFAf00P000009@0000`000010000
E00005@0003o0000/_goo`<1002loOoo0@000:^ZhClMan6ola<007l]00010000C000000000000000
00000?ooooooooooD00002P0001@0000600000`0000000009@0000`0000=0020:00000`000010000
DP00070100010000>Oooo`0000000000000009010000000000020T<0C@1=04T0<@0`000000000000
0000000000000000000000000000000000000000000000000000000000000000000003l003l40000
E<TH04SFFP2<bQP0mG53Ma/0?P1d0EP000000501F01H0mX1001J02SBFP38NeX0000000@000000000
G0400@00000P000000010EC960000000S<XH0?Ea@gOl3f/0o_ooojXh?gNR=3mg00000000FP0XdUX0
f1h::000000PdUX0W<XH08YCKgD005P000000:5DKgFWAdYff1h::2SBFP200Iae00000?2M=@0003D0
J<XH0=PN2RR4c1P0071aMB/68`?nooooXEA_M@DBV7DXdUX0j4EK0=@N8AT000X0j4EK0=C:601L>IQe
I7H02000000U000030000040001D0000E00000<1002boOoo2@400;cmool10000Zj[Q?ag7hKm15000
Obd00040001<00000000000000000000oooooooooom@0000N00007P0000H000030000000001D0000
E00000T1002boOoo30400;cmool10000Zj[Q?ag7hKnc5000Obd00040001<00000000000000000000
oooooooooom@0000>`0003`0000H000030000000000U0000300000d0080X000030000040001B0000
L0400040000ioooo0000000000000000T040000000000082@`1=0580<@0`00000000000000000000
0000000000000000000000000000000000000000000000000000000000000000?`00?`@0001DbAP0
B=IJ08c:603eLD=g6`0n07@1F0000000D05H05P3fP4005X0:=9J0<QkFP00000010000000001L0@01
0000020000000041E<TH0000002<bQP0mG53Mo`?J`3nooooZSPoMj8d?gL00000001J02SBFP3H7PXY
0000023BFP2LbQP0RU=_M@00F0000000XEA_MJM7BWKH7PXY:=9J0801W7D00000l9de0000=@1XbQP0
f1h::HC<6000L75e:`HS0okooonQE6me1A:HMBSBFP3XAE/0e1hQ6@002P3XAE/0e<XH05`iV7ETMP08
000002D0000<00000@0005@0001D00003@400;;moolB0@00_?goo`40002[Z^4o7LOQ_``E001o;@00
0@0004`00000000000000000003ooooooooooe00000`0000I00001P0000<0000000005@0001D0000
4P400;;moolF0@00_?goo`40002[Z^4o7LOQ_flE001o;@000@0004`00000000000000000003ooooo
oooooe00000Y090aD00001P0000<0000000005@0001D00006@400;;moolQ0@00_?goo`40002[Z^4o
7LOQ_o<E001o;@000@0004`00000000000000000003ooooooooooe00000m0000X00001P0000<0000
000005@0001D00008`400;;moolX0@00_?goo`40002[Z^4o7LOQ_lDF001o;@000@0004`000000000
00000000003ooooooooooe00000`0000I00002D0000<00001`00P2P0000<00000P0002D0000<0000
0000P2P0000<00000`0002D0000<00003@00P2P0000<00000@0000h0000D000000000100000D0000
240122@0000H00000Q30f`400003000000000000000000006d000400000d00000@000080003eS7Q3
nN8Qa6iOi48TAXa20`000?F<N4?ihR74EUje@oWR8LCeS7Q3=EX@a24000080000HP0000`000010000
8@0000P0000Q0000200007<0000<0000000001`0000800009@0000`0000000209@0000`000070020
9@0000`0000>00206@0000`0003oool0600000`0000000004P0000`0000200004`0000`000010000
500000`0000=00005@0000`0000100005P0000`0000000003@00010000000000000003X0000<0000
2P0001/0000@000000000000000S0000800004289D40000000000>aT9T4V]b35oW7BAB@0000T0000
@8PU@@0000000000k6@V@BJg8<GnLM95100007<0000<0000000000d0000@000000000000001B0000
L0400040000@00001`00000000000000_080000000070P8RD`1i07<0M01U06d0000B0:3hooob0@00
000003c=6`:0n?oo201HO__fool000000000023=6`:0n?ooool00000ooo`[_<8D8XQ1SQl30H00000
6@0007Q:9PJY;CmgQADQob80RP4J2000ZSPoMkm>HgL00000001/0>Q^l`P20002N<3g2<3LW`Nlc3T0
0000000000000000ooooomE:09l006`00@000?Ea@gL300002000042In0Q0VOP8003h2000001dd3T0
001/00<0002XccT0600000CB>@3eLD=gleIT0?kooooC?3mgoS`oM`000@080040>YWh2000n0P00000
h6kc204P002:MJQdc=0i07U5WWBdGlh26PP00000003;c001000008PTcP9VQ@01j=0i02l`V7ETMP08
000002D0000<00000@0004H000280000O00004M4BD<20000n@0007SmoomZ0@00__gooc00001W06D0
KP1U0780H@1d06D0I00P0680N@0P05L0C@1602l0A@1=04H0801R0640H`1[06D0KP1T0200K`1V0200
L01c07@0K`1U06@0J@1d0000J@1^0700M@1d0000000S000080000<Qm13l00000000008XM1KlV]b35
oW7BAB@0000T0000b7d4?`0000000000RQd5_bJg8<GnLM95100002<0000P0000b7d4?`0000000000
RQd5_bJg8<GnLM95900002@00038O@@o00000000002:7@Fo9[LPaOiadTD400004P0000`000010000
5P0000`0000H0000600000`000000000DP00070100020000>Oooo`00000000000000090100000000
1`020T<0C@1=04T0<@0`000000000000000000000000000000000000000000000000000000000000
000000000000000010000<S:60000000200000L000000000SU=EMLS:600`bQP0k;1300@000240000
b<XH00000000000030000000000100008<XH000000240000X0l0008000030000b<XH000000000000
?<XH07nN@`3l2SD0P<XH0000@`040000S[E30?c0BgI`OSD08HQ600000000000000000040001<bQP0
02m:00c;603PW480;2hDM_koool004<0gKE3071n=@000000000e071n=@38bQP00@0003P07P0;0000
b<XH071n=@010`00^7de0040001XOSD0I7H02000000U000030000080001D0000E00001T0000D0000
D`0007/000010000Zj[Q?ag7hKnI4`00fc400040001<00000000000000000000oooooooooom@0000
@00006@0000H000030000000001B0000L04000<0000D00002@00000000000000_080000000070P8R
D`1i07<0M01U06d000000000003R0000000006cdS@:0n?oo00000000000000000000053dS@:0n?oo
^YH00000V7FgI9QeQADQo`00000000000@0008QCn0SXccT0HFBHMHDE8Ol00000000005@000000000
R5?h263@>@3NDIQeQADQonS:70H40000f16]1e@0000000000@0003P07P0;0000b<XH071n=@010`00
^7de0040001XOSD0000020000030g9l7_<`i063@>@0_<9QeH=0i06H`V7G<j_P8N14P1RD0000000X0
V54009CA>@0MnZAdQADQo`0070J8DoP810000=PA[@Nb2ZEd=0NLM@00000d1iaeP06LMN3Zn0Rhd3T0
;c2HMKS@>@1V<9Qe;>_h27PA80ITMP08000002D0000<00000`0002P0000<00000P000580001`0@00
0P0007Goool0000000000000002@0@00000000L00P9304d0C@1903L0000000000000000000000000
00000000000000000000000000000000000000000000000000000000000o000o100000800018eUX0
b<XH0000000K03h0M05H0000001@0EP0F0?J0@00@`0XdUX0X:mK000000040000000005`100400000
800000000@5DbAP0S><nMhc:603eLD=go0m[0?kooonZ>3mgXS@oM`00000005X0:=9J0=PN2P/00000
8=9J09c:602:Dfme001H0000002QE6meYdM:M]PN2P/XdUX0P06LM@R6=@180=X1003J0FS:603H7PX;
Q<`H001`LGD[1R<3o_oooj5DKgD54YQe:=9J0>Q5F`3D7R4I000:0>Q5F`3DbQP0G3VHMFAf00P00000
9@0000`000020000E00005@0001F00001P000880001=00000@000:^ZhClMan6o3Q@002<b00010000
C00000000000000000000?ooooooooooD0000;00001@0000600000`0000000009@0000`000030000
:00000`000020000DP00070100020000>Oooo`000000000000000901000000001`020T<0C@1=04T0
<@0`0000000000000000000000000000000000000000000000000000000000000000000000000000
000003l003l40000E<TH04SFFP2<bQP0mG53Ma/0?P1d0EP000000501F01H0mX1001J02SBFP2P[e/0
000000@000000000G0400@00000P000000010EC960000000S<XH0?Ea@gOl3f/0o_ooojXh?gNR=3mg
00000000FP0XdUX0f1h:3000000PdUX0W<XH08YCKgD005P000000:5DKgFWAdYff1h:32SBFP200Iae
000004P0fP400=X1J<XH0=PN2Pb4c1P0071aMB/68`?nooooXEA_M@DBV7DXdUX0j4EK0=@N8AT000X0
j4EK0=C:601L>IQeI7H02000000U000030000080001D0000E00008/0000D0000bP0007/000010000
Zj[Q?ag7hKme5000fc400040001<00000000000000000000oooooooooom@0000M@0007P0000V0000
700000@00000000000000000000000009@0000`0000400009`0001P0000500000000000000000000
9@0000`0000500004`0000`000020000F`0003P0000J0000R0000<P0002=00000@0000D000050000
W1>8<NXDR37Z590aW1>@<I`CR34H000030000000001D0000E00002@0002Q0000GP0000P100010000
Zj[Q?ag7hKn_4`00c3000040001<00000000000000000000oooooooooom@0000@00006@0000H0000
30000000001D0000E0000640002Q0000R`0000P100010000Zj[Q?ag7hKlS5000c3000040001<0000
0000000000000000oooooooooom@0000M0000500000H000030000000000U0000300000<0000X0000
30000080001B0000L0400080001eoooo0000000000000000T040000000070082@`1=04d0B@0g0000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
?`00?`@00000FnP1B=IJ01Q0=@3X00006`0n07@1F0000000D05H05P3fP4h0CD0:=9J0<QkFP000000
10000000001L0@010000020000000041E<TH0000002<bQP0mG53Mo`?J`3nooooZSPoMj8d?gL00000
001J02SBFP3H7PX=0000023BFP2LbQP0RU=_M@00F0000000XEA_MJM7BWKH7PX=:=9J0801W7D:0000
l9de0000=@1XbQP0f1h:3HC<6000L75e:`HS0okooonQE6me1A:HMBSBFP3XAE/0e1hQ6@002P3XAE/0
e<XH05`iV7ETMP08000002D0000<00000P0005@0001D0000QP0009/0002b0000hP000040002[Z^4o
7LOQ_f/D0006<@000@0004`00000000000000000003ooooooooooe00002`0000D00001P0000<0000
000002D0000<00000`0002P0000<00000P000580001`0@000P0003Woool0000000000000002@0@00
000000L00P9304d0DP0a030000000000000000000000000000000000000000000000000000000000
000000000000000000000000000o000o100005C96018eUX0S<XH0?Ea@gLK03h0M05H0000001@0EP0
F0?J0@00FP0XdUX0b7]J000000040000000005`100400000800000000@5DbAP0000008c:603eLD=g
o0m[0?kooonZ>3mgXS@oM`00000005X0:=9J0=PN2Ph000008=9J09c:602:Dfme001H0000002QE6me
YdM:M]PN2PhXdUX0P06LM@00003`WCD0000e06S:603H7PX>Q<`H001`LGD[1R<3o_oooj5DKgD54YQe
:=9J0>Q5F`3D7R4I000:0>Q5F`3DbQP0G3VHMFAf00P000009@0000`000020000E00005@0003_0000
F@000481003000000@000:^ZhClMan6o=QD005Da00010000C00000000000000000000?oooooooooo
D00003d0002P0000600000`0000000009@0000`000030000:00000`000020000DP00070100020000
>Oooo`000000000000000901000000001`020T<0C@1=04T0<@0`0000000000000000000000000000
000000000000000000000000000000000000000000000000000003l003l40000E<TH04SFFP2<bQP0
mG53Ma/0?P1d0EP000000501F01H0mX1001J02SBFP38NeX0000000@000000000G0400@00000P0000
00010EC960000000S<XH0?Ea@gOl3f/0o_ooojXh?gNR=3mg00000000FP0XdUX0f1h:3`00000PdUX0
W<XH08YCKgD005P000000:5DKgFWAdYff1h:3bSBFP200Iae00000?2M=@0003D0J<XH0=PN2Pn4c1P0
071aMB/68`?nooooXEA_M@DBV7DXdUX0j4EK0=@N8AT000X0j4EK0=C:601L>IQeI7H02000000U0000
30000080001D0000E00006P1000D0000XP4007/000010000Zj[Q?ag7hKlP5P00fc400040001<0000
0000000000000000oooooooooom@0000@00006@0000H000030000000000U0000300000<0000X0000
30000080001B0000L0400080001eoooo0000000000000000T040000000070082@`1=0580=`000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
?`00?`@0001DbAP0B=IJ08c:603eLD=g6`0n07@1F0000000D05H05P3fP4005X0:=9J0<QkFP000000
10000000001L0@010000020000000041E<TH0000002<bQP0mG53Mo`?J`3nooooZSPoMj8d?gL00000
001J02SBFP3H7PX@0000023BFP2LbQP0RU=_M@00F0000000XEA_MJM7BWKH7PX@:=9J0801W7D00000
l9de0000=@1XbQP0f1h:48C<6000L75e:`HS0okooonQE6me1A:HMBSBFP3XAE/0e1hQ6@002P3XAE/0
e<XH05`iV7ETMP08000002D0000<00000P0005@0001D0000Y04000H0003>0@00CP000040002[Z^4o
7LOQ_i@F000S<P000@0004`00000000000000000003ooooooooooe00000b0000D00001P0000<0000
000002D0000<00000`0002P0000<00000P000580001`0@000P0003Woool0000000000000002@0@00
000000L00P9304d0C@190340<0000000000000000000000000000000000000000000000000000000
000000000000000000000000000o000o100005C96018eUX0S<XH0?Ea@gLK03h0M05H0000001@0EP0
F0?J0@00FP0XdUX0b7]J000000040000000005`100400000800000000@5DbAP0000008c:603eLD=g
o0m[0?kooonZ>3mgXS@oM`00000005X0:=9J0=PN2Q4000008=9J09c:602:Dfme001H0000002QE6me
YdM:M]PN2Q4XdUX0P06LM@00003`WCD0000e06S:603H7PXAQ<`H001`LGD[1R<3o_oooj5DKgD54YQe
:=9J0>Q5F`3D7R4I000:0>Q5F`3DbQP0G3VHMFAf00P000009@0000`000020000E00005@0003C0@00
50000182001k00000@000:^ZhClMan6okQH00=/a00010000C00000000000000000000?oooooooooo
D00007D0001h00009@0000`000070020:00000`0000400009P0001`0000400000000000000000000
000002D0000<0000100002D0000<00000000P2P0000<00001@0002L0000H00001@00000000000000
000002D0000<00001@0001<0000<00000P0005/0000h0000I@4008P0000<0P00S@00004000050000
1@0001`FR35L5hPaG1N@<A`FT34L5XPa600000`000000000E00005@0001X0@00X@000:8100080@00
0@000:^ZhClMan6o81H00<``00010000C00000000000000000000?ooooooooooD0000400001T0000
600000`000000000E00005@0002T0@00X@000><100080@000@000:^ZhClMan6oU1H00<``00010000
C00000000000000000000?ooooooooooD00007P0001h0000600000`0000000009@0000`000030000
:00000`000020000DP00070100020000MOooo`000000000000000901000000001`020T<0C@1B03L0
00000000000000000000000000000000000000000000000000000000000000000000000000000000
000003l003l4000005_X0DSFFP0H@3D0j00001/0?P1d0EP000000501F01H0mX1>04e02SBFP38NeX0
000000@000000000G0400@00000P000000010EC960000000S<XH0?Ea@gOl3f/0o_ooojXh?gNR=3mg
00000000FP0XdUX0f1h:4P00000PdUX0W<XH08YCKgD005P000000:5DKgFWAdYff1h:4RSBFP200Iae
2P000?2M=@0003D0J<XH0=PN2Q:4c1P0071aMB/68`?nooooXEA_M@DBV7DXdUX0j4EK0=@N8AT000X0
j4EK0=C:601L>IQeI7H02000000U000030000080001D0000E0000=l1002K00002@800><000010000
Zj[Q?ag7hKl65`001S400040001<00000000000000000000oooooooooom@0000<P000500000H0000
30000000000U0000300000<0000X000030000080001B0000L0400080000ioooo0000000000000000
T040000000070082@`1=04d0B@0a0300000000000000000000000000000000000000000000000000
00000000000000000000000000000000?`00?`@0001DbAP0B=IJ08c:603eLD=g6`0n07@1F0000000
D05H05P3fP4005X0:=9J0<QkFP00000010000000001L0@010000020000000041E<TH0000002<bQP0
mG53Mo`?J`3nooooZSPoMj8d?gL00000001J02SBFP3H7PXC0000023BFP2LbQP0RU=_M@00F0000000
XEA_MJM7BWKH7PXC:=9J0801W7D00000l9de0000=@1XbQP0f1h:4hC<6000L75e:`HS0okooonQE6me
1A:HMBSBFP3XAE/0e1hQ6@002P3XAE/0e<XH05`iV7ETMP08000002D0000<00000P0005@0001D0000
6P8005T0000j0P00`0000040002[Z^4o7LOQ_gPG001E<@000@0004`00000000000000000003ooooo
oooooe00000k0000?00001P0000<0000000002D0000<00000`0002P0000<00000P000580001`0@00
0P0003Woool0000000000000002@0@00000000L00P9304d0DP0a0300000000000000000000000000
00000000000000000000000000000000000000000000000000000000000o000o100005C96018eUX0
S<XH0?Ea@gLK03h0M05H0000001@0EP0F0?J0@00FP0XdUX0b7]J000000040000000005`100400000
800000000@5DbAP0000008c:603eLD=go0m[0?kooonZ>3mgXS@oM`00000005X0:=9J0=PN2Q@00000
8=9J09c:602:Dfme001H0000002QE6meYdM:M]PN2Q@XdUX0P06LM@00003`WCD0000e06S:603H7PXD
Q<`H001`LGD[1R<3o_oooj5DKgD54YQe:=9J0>Q5F`3D7R4I000:0>Q5F`3DbQP0G3VHMFAf00P00000
9@0000`000020000E00005@0002_0P00F@000><2003000000@000:^ZhClMan6oV1P005Da00010000
C00000000000000000000?ooooooooooD0000300001T0000600000`0000000009@0000`000030000
:00000`000020000DP00070100020000>Oooo`000000000000000901000000001`020T<0C@1C05T0
<@0`04l0DP1904L00000000000000000000000000000000000000000000000000000000000000000
000003l003l40000E<TH04SFFP2<bQP0mG53Ma/0?P1d0EP000000501F01H0mX1001J02SBFP38NeX0
000000@000000000G0400@00000P000000010EC960000000S<XH0?Ea@gOl3f/0o_ooojXh?gNR=3mg
00000000FP0XdUX0f1h:5@00000PdUX0W<XH08YCKgD005P000000:5DKgFWAdYff1h:5BSBFP200Iae
00000?2M=@0003D0J<XH0=PN2QF4c1P0071aMB/68`?nooooXEA_M@DBV7DXdUX0j4EK0=@N8AT000X0
j4EK0=C:601L>IQeI7H02000000U000030000080001D0000E0000?l2001F0000DP<000T100010000
Zj[Q?ag7hKlc6@00EC400040001<00000000000000000000oooooooooom@0000]`000:00000H0000
30000000000U0000300000<0000X000030000080001B0000L0400080000ioooo0000000000000000
T040000000070082@`1=04d0B@0a0300000000000000000000000000000000000000000000000000
00000000000000000000000000000000?`00?`@0001DbAP0B=IJ08c:603eLD=g6`0n07@1F0000000
D05H05P3fP4005X0:=9J0<QkFP00000010000000001L0@010000020000000041E<TH0000002<bQP0
mG53Mo`?J`3nooooZSPoMj8d?gL00000001J02SBFP3H7PXF0000023BFP2LbQP0RU=_M@00F0000000
XEA_MJM7BWKH7PXF:=9J0801W7D00000l9de0000=@1XbQP0f1h:5XC<6000L75e:`HS0okooonQE6me
1A:HMBSBFP3XAE/0e1hQ6@002P3XAE/0e<XH05`iV7ETMP08000002D0000<00000P0005@0001D0000
K0<005T0002[0`00`0000040002[Z^4o7LOQ_`DJ001E<@000@0004`00000000000000000003ooooo
oooooe00001h0000N00001P0000<0000000002D0000<00000`0002P0000<00000P000580001`0@00
0P0003Woool0000000000000002@0@00000000L00P9304d0D`1I0340<01?0580B@17000000000000
00000000000000000000000000000000000000000000000000000000000o000o100005C96018eUX0
S<XH0?Ea@gLK03h0M05H0000001@0EP0F0?J0@00FP0XdUX0b7]J000000040000000005`100400000
800000000@5DbAP0000008c:603eLD=go0m[0?kooonZ>3mgXS@oM`00000005X0:=9J0=PN2QL00000
8=9J09c:602:Dfme001H0000002QE6meYdM:M]PN2QLXdUX0P06LM@00003`WCD0000e06S:603H7PXG
Q<`H001`LGD[1R<3o_oooj5DKgD54YQe:=9J0>Q5F`3D7R4I000:0>Q5F`3DbQP0G3VHMFAf00P00000
9@0000`000020000E00005@000330`00EP0001H400090@000@000:^ZhClMan6o[QX005Da00010000
C00000000000000000000?ooooooooooD0000;L0002P0000600000`0000000009@0000`000030000
:00000`000020000DP00070100020000>Oooo`000000000000000901000000001`020T<0C@1=04T0
<@0`0000000000000000000000000000000000000000000000000000000000000000000000000000
000003l003l40000E<TH04SFFP2<bQP0mG53Ma/0?P1d0EP000000501F01H0mX1001J02SBFP38NeX0
000000@000000000G0400@00000P000000010EC960000000S<XH0?Ea@gOl3f/0o_ooojXh?gNR=3mg
00000000FP0XdUX0f1h:6000000PdUX0W<XH08YCKgD005P000000:5DKgFWAdYff1h:62SBFP200Iae
00000?2M=@0003D0J<XH0=PN2QR4c1P0071aMB/68`?nooooXEA_M@DBV7DXdUX0j4EK0=@N8AT000X0
j4EK0=C:601L>IQeI7H02000000U000030000080001D0000E0000304001I0000N@@00<0000010000
Zj[Q?ag7hKn06`00EC400040001<00000000000000000000oooooooooom@0000C00008`0000H0000
30000000001D0000E00007H4001I0000UP@00<0000010000Zj[Q?ag7hKl87000EC400040001<0000
0000000000000000oooooooooom@0000>`0003`0000H000030000000001D0000E00000d0000Q0@00
C00008P100010000Zj[Q?ag7hKn14`00eBl00040001<00000000000000000000oooooooooom@0000
M@0007P0000H000030000000000U0000300000<0000X000030000080001B0000L0400080000ioooo
0000000000000000T040000000070082@`1=0580<@0`000000000000000000000000000000000000
000000000000000000000000000000000000000000000000?`00?`@0001DbAP0B=IJ08c:603eLD=g
6`0n07@1F0000000D05H05P3fP4005X0:=9J0<QkFP00000010000000001L0@010000020000000041
E<TH0000002<bQP0mG53Mo`?J`3nooooZSPoMj8d?gL00000001J02SBFP3H7PXI0000023BFP2LbQP0
RU=_M@00F0000000XEA_MJM7BWKH7PXI:=9J0801W7D00000l9de0000=@1XbQP0f1h:6HC<6000L75e
:`HS0okooonQE6me1A:HMBSBFP3XAE/0e1hQ6@002P3XAE/0e<XH05`iV7ETMP08000002D0000<0000
0P0005@0001D0000B0000241001b0000R0400040002[Z^4o7LOQ_o<C003E;`000@0004`000000000
00000000003ooooooooooe00000X0000D00001P0000<0000000002D0000<00000`0002P0000<0000
0P000580001`0@000P0003Woool0000000000000002@0@00000000L00P9304d0C@190340<0000000
000000000000000000000000000000000000000000000000000000000000000000000000000o000o
100005C96018eUX0S<XH0?Ea@gLK03h0M05H0000001@0EP0F0?J0@00FP0XdUX0b7]J000000040000
000005`100400000800000000@5DbAP0000008c:603eLD=go0m[0?kooonZ>3mgXS@oM`00000005X0
:=9J0=PN2QX000008=9J09c:602:Dfme001H0000002QE6meYdM:M]PN2QXXdUX0P06LM@00003`WCD0
000e06S:603H7PXJQ<`H001`LGD[1R<3o_oooj5DKgD54YQe:=9J0>Q5F`3D7R4I000:0>Q5F`3DbQP0
G3VHMFAf00P000009@0000`000020000E00005@0001`00008@400:l000280@000@000:^ZhClMan6o
@A@00=D_00010000C00000000000000000000?ooooooooooD00007P0001h0000600000`000000000
9@0000`000030000:00000`000020000DP00070100020000>Oooo`00000000000000090100000000
1`020T<0C@1B0340<000000000000000000000000000000000000000000000000000000000000000
0000000000000000000003l003l40000E<TH04SFFP2<bQP0mG53Ma/0?P1d0EP000000501F01H0mX1
001J02SBFP38NeX0000000@000000000G0400@00000P000000010EC960000000S<XH0?Ea@gOl3f/0
o_ooojXh?gNR=3mg00000000FP0XdUX0f1h:6`00000PdUX0W<XH08YCKgD005P000000:5DKgFWAdYf
f1h:6bSBFP200Iae00000?2M=@0003D0J<XH0=PN2Q^4c1P0071aMB/68`?nooooXEA_M@DBV7DXdUX0
j4EK0=@N8AT000X0j4EK0=C:601L>IQeI7H02000000U000030000080001D0000E0000<P0000Q0@00
6`4008P100010000Zj[Q?ag7hKoZ5000eBl00040001<00000000000000000000oooooooooom@0000
?@000:00000H000030000000001D0000E00003@1000Q0@00J04008P100010000Zj[Q?ag7hKnl5@00
eBl00040001<00000000000000000000oooooooooom@0000<00006@0000H000030000000000U0000
300000<0000X000030000080001B0000L0400080000ioooo0000000000000000T040000000070082
@`1=04d0B@0a03000000000000000000000000000000000000000000000000000000000000000000
0000000000000000?`00?`@0001DbAP0B=IJ08c:603eLD=g6`0n07@1F0000000D05H05P3fP4005X0
:=9J0<QkFP00000010000000001L0@010000020000000041E<TH0000002<bQP0mG53Mo`?J`3noooo
ZSPoMj8d?gL00000001J02SBFP3H7PXL0000023BFP2LbQP0RU=_M@00F0000000XEA_MJM7BWKH7PXL
:=9J0801W7D00000l9de0000=@1XbQP0f1h:78C<6000L75e:`HS0okooonQE6me1A:HMBSBFP3XAE/0
e1hQ6@002P3XAE/0e<XH05`iV7ETMP08000002D0000<00000P0005@0001D0000J040024100280@00
R0400040002[Z^4o7LOQ_b0F003E;`000@0004`00000000000000000003ooooooooooe00000k0000
?00001P0000<0000000005@0001D0000UP40024100300@00R0400040002[Z^4o7LOQ_gTF003E;`00
0@0004`00000000000000000003ooooooooooe00001d0000D00001P0000<0000000002D0000<0000
0`0002P0000<00000P000580001`0@000P0003Woool0000000000000002@0@00000000L00P9304d0
DP0a0300000000000000000000000000000000000000000000000000000000000000000000000000
00000000000o000o100005C96018eUX0S<XH0?Ea@gLK03h0M05H0000001@0EP0F0?J0@00FP0XdUX0
b7]J000000040000000005`100400000800000000@5DbAP0000008c:603eLD=go0m[0?kooonZ>3mg
XS@oM`00000005X0:=9J0=PN2Qd000008=9J09c:602:Dfme001H0000002QE6meYdM:M]PN2QdXdUX0
P06LM@00003`WCD0000e06S:603H7PXMQ<`H001`LGD[1R<3o_oooj5DKgD54YQe:=9J0>Q5F`3D7R4I
000:0>Q5F`3DbQP0G3VHMFAf00P000009@0000`000020000E00005@0002k0@008@400>D100280@00
0@000:^ZhClMan6o`AH00=D_00010000C00000000000000000000?ooooooooooD00002T0001@0000
600000`000000000E00005@000000P008@4005<200280@000@000:^ZhClMan6oAAL00=D_00010000
C00000000000000000000?ooooooooooD00003d0002P0000600000`0000000009@0000`000030000
:00000`000020000DP00070100020000>Oooo`000000000000000901000000001`020T<0C@1=04T0
<@0`0000000000000000000000000000000000000000000000000000000000000000000000000000
000003l003l40000E<TH04SFFP2<bQP0mG53Ma/0?P1d0EP000000501F01H0mX1001J02SBFP38NeX0
000000@000000000G0400@00000P000000010EC960000000S<XH0?Ea@gOl3f/0o_ooojXh?gNR=3mg
00000000FP0XdUX0f1h:7P00000PdUX0W<XH08YCKgD005P000000:5DKgFWAdYff1h:7RSBFP200Iae
00000?2M=@0003D0J<XH0=PN2Qj4c1P0071aMB/68`?nooooXEA_M@DBV7DXdUX0j4EK0=@N8AT000X0
j4EK0=C:601L>IQeI7H02000000U000030000080001D0000E00006d2000Q0@00[08008P100010000
Zj[Q?ag7hKlH6000eBl00040001<00000000000000000000oooooooooom@0000M@0007P0000H0000
30000000000U0000300000<0000X000030000080001B0000L0400080001eoooo0000000000000000
T040000000070082@`1=0580=`000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000?`00?`@0001DbAP0B=IJ08c:603eLD=g6`0n07@1F0000000
D05H05P3fP4005X0:=9J0<QkFP00000010000000001L0@010000020000000041E<TH0000002<bQP0
mG53Mo`?J`3nooooZSPoMj8d?gL00000001J02SBFP3H7PXO0000023BFP2LbQP0RU=_M@00F0000000
XEA_MJM7BWKH7PXO:=9J0801W7D00000l9de0000=@1XbQP0f1h:7hC<6000L75e:`HS0okooonQE6me
1A:HMBSBFP3XAE/0e1hQ6@002P3XAE/0e<XH05`iV7ETMP08000002D0000<00000P0005@0001D0000
Z08004T1003B0P00T@400040002[Z^4o7LOQ_hXH002g;`000@0004`00000000000000000003ooooo
oooooe00000`0000D00001P0000<0000000002D0000<00000`0002P0000<00000P000580001`0@00
0P0003Woool0000000000000002@0@00000000L00P9304d0C@190340<00000000000000000000000
00000000000000000000000000000000000000000000000000000000000o000o100005C96018eUX0
S<XH0?Ea@gLK03h0M05H0000001@0EP0F0?J0@00FP0XdUX0b7]J000000040000000005`100400000
800000000@5DbAP0000008c:603eLD=go0m[0?kooonZ>3mgXS@oM`00000005X0:=9J0=PN2R000000
8=9J09c:602:Dfme001H0000002QE6meYdM:M]PN2R0XdUX0P06LM@00003`WCD0000e06S:603H7PXP
Q<`H001`LGD[1R<3o_oooj5DKgD54YQe:=9J0>Q5F`3D7R4I000:0>Q5F`3DbQP0G3VHMFAf00P00000
9@0000`000020000E00005@0003F0P008@400?H200280@000@000:^ZhClMan6ohaP00=D_00010000
C00000000000000000000?ooooooooooD00003/0000l0000600000`000000000E00005@0000=0000
_@4004`0000T0P000@000:^ZhClMan6oPA<00:X^00010000C00000000000000000000?oooooooooo
D00007D0001h0000600000`0000000009@0000`000030000:00000`000020000DP00070100020000
>Oooo`000000000000000901000000001`020T<0C@1B0340<0000000000000000000000000000000
000000000000000000000000000000000000000000000000000003l003l40000E<TH04SFFP2<bQP0
mG53Ma/0?P1d0EP000000501F01H0mX1001J02SBFP38NeX0000000@000000000G0400@00000P0000
00010EC960000000S<XH0?Ea@gOl3f/0o_ooojXh?gNR=3mg00000000FP0XdUX0f1h:8@00000PdUX0
W<XH08YCKgD005P000000:5DKgFWAdYff1h:8BSBFP200Iae00000?2M=@0003D0J<XH0=PN2R64c1P0
071aMB/68`?nooooXEA_M@DBV7DXdUX0j4EK0=@N8AT000X0j4EK0=C:601L>IQeI7H02000000U0000
30000080001D0000E00004P0002m0@00LP0002@200010000Zj[Q?ag7hKoc4`00ZRh00040001<0000
0000000000000000oooooooooom@0000:0000500000H000030000000000U0000300000<0000X0000
30000080001B0000L0400080000ioooo0000000000000000T040000000070082@`1=04d0B@0a0300
00000000000000000000000000000000000000000000000000000000000000000000000000000000
?`00?`@0001DbAP0B=IJ08c:603eLD=g6`0n07@1F0000000D05H05P3fP4005X0:=9J0<QkFP000000
10000000001L0@010000020000000041E<TH0000002<bQP0mG53Mo`?J`3nooooZSPoMj8d?gL00000
001J02SBFP3H7PXR0000023BFP2LbQP0RU=_M@00F0000000XEA_MJM7BWKH7PXR:=9J0801W7D00000
l9de0000=@1XbQP0f1h:8XC<6000L75e:`HS0okooonQE6me1A:HMBSBFP3XAE/0e1hQ6@002P3XAE/0
e<XH05`iV7ETMP08000002D0000<00000P0005@0001D0000L0000;d1002_000090800040002[Z^4o
7LOQ_d4D002Z;P000@0004`00000000000000000003ooooooooooe00001h0000N00001P0000<0000
000002D0000<00000`0002P0000<00000P000580001`0@000P0003Woool0000000000000002@0@00
000000L00P9304d0DP0a030000000000000000000000000000000000000000000000000000000000
000000000000000000000000000o000o100005C96018eUX0S<XH0?Ea@gLK03h0M05H0000001@0EP0
F0?J0@00FP0XdUX0b7]J000000040000000005`100400000800000000@5DbAP0000008c:603eLD=g
o0m[0?kooonZ>3mgXS@oM`00000005X0:=9J0=PN2R<000008=9J09c:602:Dfme001H0000002QE6me
YdM:M]PN2R<XdUX0P06LM@00003`WCD0000e06S:603H7PXSQ<`H001`LGD[1R<3o_oooj5DKgD54YQe
:=9J0>Q5F`3D7R4I000:0>Q5F`3DbQP0G3VHMFAf00P000009@0000`000020000E00005@000380000
_@4001/1000T0P000@000:^ZhClMan6ojQ@00:X^00010000C00000000000000000000?oooooooooo
D00003d0002P0000600000`0000000009@0000`000030000:00000`000020000DP00070100020000
>Oooo`000000000000000901000000001`020T<0C@1=04T0<@0`0000000000000000000000000000
000000000000000000000000000000000000000000000000000003l003l40000E<TH04SFFP2<bQP0
mG53Ma/0?P1d0EP000000501F01H0mX1001J02SBFP38NeX0000000@000000000G0400@00000P0000
00010EC960000000S<XH0?Ea@gOl3f/0o_ooojXh?gNR=3mg00000000FP0XdUX0f1h:9000000PdUX0
W<XH08YCKgD005P000000:5DKgFWAdYff1h:92SBFP200Iae00000?2M=@0003D0J<XH0=PN2RB4c1P0
071aMB/68`?nooooXEA_M@DBV7DXdUX0j4EK0=@N8AT000X0j4EK0=C:601L>IQeI7H02000000U0000
30000080001D0000E00003@1002m0@00O@4002@200010000Zj[Q?ag7hKnl5@00ZRh00040001<0000
0000000000000000oooooooooom@0000C00008`0000H000030000000001D0000E00007/1002m0@00
V`4002@200010000Zj[Q?ag7hKm45P00ZRh00040001<00000000000000000000oooooooooom@0000
>`0003`0000H000030000000001D0000E0000:T1002m0@00d`4002@200010000Zj[Q?ag7hKnM5P00
ZRh00040001<00000000000000000000oooooooooom@0000M0000500000H000030000000000U0000
300000<0000X000030000080001B0000L0400080000ioooo0000000000000000T040000000070082
@`1=0580<@0`00000000000000000000000000000000000000000000000000000000000000000000
0000000000000000?`00?`@0001DbAP0B=IJ08c:603eLD=g6`0n07@1F0000000D05H05P3fP4005X0
:=9J0<QkFP00000010000000001L0@010000020000000041E<TH0000002<bQP0mG53Mo`?J`3noooo
ZSPoMj8d?gL00000001J02SBFP3H7PXU0000023BFP2LbQP0RU=_M@00F0000000XEA_MJM7BWKH7PXU
:=9J0801W7D00000l9de0000=@1XbQP0f1h:9HC<6000L75e:`HS0okooonQE6me1A:HMBSBFP3XAE/0
e1hQ6@002P3XAE/0e<XH05`iV7ETMP08000002D0000<00000P0005@0001D0000cP400;d1003h0@00
90800040002[Z^4o7LOQ_nDF002Z;P000@0004`00000000000000000003ooooooooooe00000Y0000
D00001P0000<0000000005@0001D00004P800;d1001U0P0090800040002[Z^4o7LOQ_fTG002Z;P00
0@0004`00000000000000000003ooooooooooe00000m0000X00001P0000<0000000005@0001D0000
O`800;d1002c0P0090800040002[Z^4o7LOQ_c`H002Z;P000@0004`00000000000000000003ooooo
oooooe00000`0000I00001P0000<0000000002D0000<00000`0002P0000<00000P000580001`0@00
0P0003Woool0000000000000002@0@00000000L00P9304d0C@190340<00000000000000000000000
00000000000000000000000000000000000000000000000000000000000o000o100005C96018eUX0
S<XH0?Ea@gLK03h0M05H0000001@0EP0F0?J0@00FP0XdUX0b7]J000000040000000005`100400000
800000000@5DbAP0000008c:603eLD=go0m[0?kooonZ>3mgXS@oM`00000005X0:=9J0=PN2RH00000
8=9J09c:602:Dfme001H0000002QE6meYdM:M]PN2RHXdUX0P06LM@00003`WCD0000e06S:603H7PXV
Q<`H001`LGD[1R<3o_oooj5DKgD54YQe:=9J0>Q5F`3D7R4I000:0>Q5F`3DbQP0G3VHMFAf00P00000
9@0000`000020000E00005@0002c0P00_@400=<2000T0P000@000:^ZhClMan6oWaP00:X^00010000
C00000000000000000000?ooooooooooD00003/0000l0000600000`000000000E00005@0000=0000
F08004`0002o0P000@000:^ZhClMan6oPA<007l]00010000C00000000000000000000?oooooooooo
D00007D0001h0000600000`0000000009@0000`000030000:00000`000020000DP00070100020000
>Oooo`000000000000000901000000001`020T<0C@1B0340<0000000000000000000000000000000
000000000000000000000000000000000000000000000000000003l003l40000E<TH04SFFP2<bQP0
mG53Ma/0?P1d0EP000000501F01H0mX1001J02SBFP38NeX0000000@000000000G0400@00000P0000
00010EC960000000S<XH0?Ea@gOl3f/0o_ooojXh?gNR=3mg00000000FP0XdUX0f1h:9`00000PdUX0
W<XH08YCKgD005P000000:5DKgFWAdYff1h:9bSBFP200Iae00000?2M=@0003D0J<XH0=PN2RN4c1P0
071aMB/68`?nooooXEA_M@DBV7DXdUX0j4EK0=@N8AT000X0j4EK0=C:601L>IQeI7H02000000U0000
30000080001D0000E00004P0001H0P00LP000;l200010000Zj[Q?ag7hKoc4`00Obd00040001<0000
0000000000000000oooooooooom@0000:0000500000H000030000000000U0000300000<0000X0000
30000080001B0000L0400080000ioooo0000000000000000T040000000070082@`1=04d0B@0a0300
00000000000000000000000000000000000000000000000000000000000000000000000000000000
?`00?`@0001DbAP0B=IJ08c:603eLD=g6`0n07@1F0000000D05H05P3fP4005X0:=9J0<QkFP000000
10000000001L0@010000020000000041E<TH0000002<bQP0mG53Mo`?J`3nooooZSPoMj8d?gL00000
001J02SBFP3H7PXX0000023BFP2LbQP0RU=_M@00F0000000XEA_MJM7BWKH7PXX:=9J0801W7D00000
l9de0000=@1XbQP0f1h::8C<6000L75e:`HS0okooonQE6me1A:HMBSBFP3XAE/0e1hQ6@002P3XAE/0
e<XH05`iV7ETMP08000002D0000<00000P0005@0001D0000L00005P2002_0000_`800040002[Z^4o
7LOQ_d4D001o;@000@0004`00000000000000000003ooooooooooe00001h0000N00001P0000<0000
000005@0001D0000Z`0005P2003;0000_`800040002[Z^4o7LOQ_k<D001o;@000@0004`000000000
00000000003ooooooooooe00000k0000?00001P0000<0000000002D0000<00000`0002P0000<0000
0P000580001`0@000P0003Woool0000000000000002@0@00000000L00P9304d0DP0a030000000000
000000000000000000000000000000000000000000000000000000000000000000000000000o000o
100005C96018eUX0S<XH0?Ea@gLK03h0M05H0000001@0EP0F0?J0@00FP0XdUX0b7]J000000040000
000005`100400000800000000@5DbAP0000008c:603eLD=go0m[0?kooonZ>3mgXS@oM`00000005X0
:=9J0=PN2RT000008=9J09c:602:Dfme001H0000002QE6meYdM:M]PN2RTXdUX0P06LM@00003`WCD0
000e06S:603H7PXYQ<`H001`LGD[1R<3o_oooj5DKgD54YQe:=9J0>Q5F`3D7R4I000:0>Q5F`3DbQP0
G3VHMFAf00P000009@0000`000020000E00005@0003I0000F08000d1002o0P000@000:^ZhClMan6o
31D007l]00010000C00000000000000000000?ooooooooooD0000300001T0000600000`000000000
E00005@0000<0@00F08003H1002o0P000@000:^ZhClMan6oKaD007l]00010000C000000000000000
00000?ooooooooooD00002T0001@0000600000`000000000E00005@0001A0@00F0800:@1002o0P00
0@000:^ZhClMan6olaD007l]00010000C00000000000000000000?ooooooooooD00003d0002P0000
600000`000000000E00005@0002m0@00F0800?41002o0P000@000:^ZhClMan6oaAH007l]00010000
C00000000000000000000?ooooooooooD0000300001T00009@0000`000070020:00000`000040000
9@0000`000000020:00000`0000500009@0000`000030000:00000`000020000AP0001@000080000
AdA9@`<0000R000030000?oooolR000030000?oooolU0000300000d0080X000030000040000X0000
300000<0000R000030000?oooom60000`0400;@10015CDH[;40002@0000H00000020?`0000000000
0020?`0008000020:T0002@0000H00001CTT@@0000000000oclT@JUa7lFo^lm5940000`000000000
:T0002@0000H0000/08/>P0000000000/08/>P00UJP003VY:d0000`0000000007T0600`000000000
8D0500`000000000240211P0000<00000Q30f`000003000@=40200`0000000007T0900`000000000
:T0002@0000H0000/08/>P0000000000/08/>P00UJP003VY8D0700`000000000:T0002@0000H0000
/08/>P0000000000/08/>P00UJP003VY:d0000`000000000:d0000`0000000007T0600`000000000
8D0500`000000000240311P0000<00000Q30f`000003000@=40300`0000000007T0900`000000000
:T0002@0000H00000020?`00000000000020?`00000000008D0700`000000000C00006@000000000
000009<4003?0P0000000000002D1000d08002T0ZP00000000000000P3l0000000000000P3l00000
0000000000000000000000000000000000000280000<0000ooooodH0000L0000400004E=AR/2@000
30000000000>000050000000000@00005000
\>"], "Graphics",
  GeneratedCell->False,
  CellAutoOverwrite->False,
  ImageSize->{236.63157894736835`, 144.60818713450283`},
  ImageMargins->{{23.6, 0.}, {0., 146.65263157894736`}}]
}], "Subchapter",
 CellChangeTimes->{{3.6371524922410097`*^9, 3.63715252674827*^9}, {
   3.6372440832236605`*^9, 3.6372440871428847`*^9}, 3.637244169179577*^9, {
   3.637244299470029*^9, 3.6372443032602463`*^9}, {3.6372453817689333`*^9, 
   3.637245384542092*^9}, 3.6373024456233*^9, {3.6373030333073*^9, 
   3.6373030333083*^9}, {3.6373032594343*^9, 3.6373032619173*^9}, 
   3.6373212822665167`*^9, {3.6373215570692344`*^9, 3.6373215570712347`*^9}, {
   3.637321764908122*^9, 3.6373217662171965`*^9}, {3.6381744309656*^9, 
   3.6381744320046*^9}, {3.6386020108915997`*^9, 3.6386020109926*^9}}],

Cell[CellGroupData[{

Cell["\<\
Here we provide the parameters of the problem and its exact solution\
\>", "Subsubsection",
 CellChangeTimes->{{3.633439583415289*^9, 3.6334395909637213`*^9}, {
   3.636904756973955*^9, 3.636904760701168*^9}, 3.637138408549569*^9, {
   3.6373022788703003`*^9, 3.6373023184623003`*^9}},
 Background->RGBColor[1, 1, 0]],

Cell[CellGroupData[{

Cell[TextData[{
 "Parameters:  ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["K", "\[Gamma]"], TraditionalForm]]],
 "=Kg=1, ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["u", "0"], TraditionalForm]],
  FormatType->"TraditionalForm"],
 "=u0val=1,  ",
 StyleBox["L",
  FontSlant->"Italic"],
 "=LL=4,  ",
 StyleBox["M",
  FontSlant->"Italic"],
 "=Mvalue=8"
}], "Text",
 CellChangeTimes->{{3.6371384131203775`*^9, 3.6371384241807966`*^9}, 
   3.637138525300174*^9, {3.637244470420807*^9, 3.63724447152387*^9}, {
   3.6373025854383*^9, 3.6373025856303*^9}, {3.6373030572462997`*^9, 
   3.6373030970383*^9}, {3.6373218206343093`*^9, 3.63732186645093*^9}, {
   3.637321905179145*^9, 3.637321926402359*^9}, {3.6373230165337105`*^9, 
   3.6373230345817432`*^9}},
 Background->RGBColor[1, 1, 0]],

Cell[BoxData[
 RowBox[{
  RowBox[{"Kg", "=", "1."}], ";", 
  RowBox[{"u0value", "=", "1."}], ";", 
  RowBox[{"LL", "=", "4."}], ";", 
  RowBox[{"Mvalue", "=", "8"}], ";"}]], "Input",
 CellChangeTimes->{{3.6371380791081905`*^9, 3.6371380857850027`*^9}, 
   3.6371383766475134`*^9, {3.6373027211833*^9, 3.6373027594632998`*^9}, {
   3.6373219519878225`*^9, 3.6373219673317003`*^9}, {3.6373229958955307`*^9, 
   3.6373230143515863`*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 "Exact solution [Eq. (26)]\n ",
 Cell[GraphicsData["Metafile", "\<\
CF5dJ6E]HGAYHf4PEfU^I6mgLb15CDHPAVmbKF5d0@000=4l0@0006`0003ooooo^Ooooc@=000m0P00
00000000002?=`00V`D00215CDH00040?=4007l1000500000000000000000000HA<006PK003B0000
:@400000000000000000050d0`0XR0@0AP0002`0000P0000ADe6:`500@0L00004000008@`=/00000
F08005P200160000O04007010015CDH[7T0500`0000000007d0300`000000000<402010000040000
0020?b501`0<000000000290100<0000000002Y0000T000060000000P3l0000000000000P3l00000
000002]0000<0000000001i01P0<0000000002501@0<0000000001i02@0<0000000002Y0000T0000
60000000P3l0000000000000P3l00000000002501`0<0000000002Y0000T000060000;02;3X00000
00000;02;3X0/1G5030WaB]0000<0000000002Y0000T000060000;02;3X0000000000;02;3X0/1G5
030WaB]0000<0000000002Y0000T000060000;02;3X0000000000;02;3X001JY000WZ@Y0080T0000
6000003oool1000000000000003XD9a:00;mB24000080000HP0000`000010000900002@00000000n
000000000000000n00000000000200009`0001P00001000000000?oo000000009@0000`000010000
9@0000`000080020EP000300003oooooooooob4=001D0@001@000?coo?oloi`:16VL2PAYo?olooco
9@0000`0000700209@0000`000000020900002@00000001100000000000000110000000000020000
AP0004AT000hI000ADe6:b]0000<0000000001i01P0<0000000002501@0<0000000001i02@0<0000
000002Y0000T000060000;02;3X0000000000;02;3X001JY000WZB501`0<0000000002]0000<0000
000002Y0000T0000600000=?9440000000000;lP944EX;G4cd;?ABA0100<0000000000Q000DdH`00
:6<0008@`=/200000`0001QS00010000c00008h0001coOooeP400:omoomm4`00ijKoofi0001EZooo
84E=AP000@0HH`00BP400080000`0000K000000000201`00>0@00:D2001m0@000000000000000000
eED:04S@1@1W06D0KP1U0780H@1d06D0I00P0680N@0P05L0C@1602l0A@1=04H0801R0640H`1[06D0
KP1T0200K`1V0200L01c07@0K`1U06@0J@1d0000J@1^0700M@1d0000000A0000300000H0000:0000
40000000000000004P0000`0000100005P0000`0000H0000600000`000000000DP00070100010000
>Oooo`0000000000000009010000000000020T<0C@1=04T0<@0`0000000000000000000000000000
00000000000000000000000000000000000000000000000010000<S:60000000200000L000000000
SU=EMLS:600`bQP0k;1300@000240000b<XH00000000000030000000000100008<XH000000240000
X0l0008000030000b<XH000000000000?<XH07nN@`3l2Ql0P<XH0000@`040000S[E307LX/Xa`OQl0
8HQ600000000000000000040001<bQP002m:00c;603PW480YlK]S?koool004<0gKE3071n7`000000
000O071n7`38bQP00@0003P07P0;0000b<XH071n7`010`00^7dO0040001XOQl0I7H02000000U0000
30000040001D0000E00008h00024oOooU00008kmool10000Zj[Q?ag7hKlG2`004S400040001<0000
0000000000000000oooooooooom@0000M@0007P0000H000030000000000U0000300000d0080X0000
30000040001B0000L0400040000ioooo0000000000000000T040000000000082@`1=0580<@0`0000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
?`00?`@000020000B=Ha0<S:600000006`0n07@1;`000000D04_05P3d@4004<0:=8a0:2_<P000000
10000000001L0@010000020000000041E<TH08cS?WN<bQP0mG53M`^CK@3nooooZSPoMj8d?gL00000
000a02SB<@0K7`X<0000023B<@2LbQP0RU=_M@00;`000000XEA_MMZ7/H`K7`X<:=8a0801W7D8QQl0
B03A0@00d@5XbQP06al:38C<6000L75eE/KHnOkooonQE6me1A:HMBSB<@3XAC80YQhQ6`002P3XAC80
e<XH05`iV7ETMP08000002D0000<00000@0005@0001D0000U00008CmoonH0000S_goo`40002[Z^4o
7LOQ_hT;000B<@000@0004`00000000000000000003ooooooooooe00000X0000D00001P0000<0000
000002D0000<00003@00P2P0000<00000@000580001`0@000@0003Woool0000000000000002@0@00
000000000P9304d0C@190340<0000000000000000000000000000000000000000000000000000000
000000000000000000000000000o000o100005C96018eS40S<XH0?Ea@gLK03h0M04_0000001@0Bl0
F0?A0@00<@0XdS40X:lb000000040000000005`100400000800000000@5DbAP0000008c:603eLD=g
2i=]0?kooonZ>3mgXS@oM`0000000340:=8a01/O2Pd000008=8a09c:602:Dfme000_0000002QE6me
fXNaS1/O2PdXdS40P06LM@0000180=41003A0FS:600K7`X=Q<`H001`LGEFa]Sio_oooj5DKgD54YQe
:=8a0>Q5<P2V7R4K000:0>Q5<P3DbQP0G3VHMFAf00P000009@0000`000010000E00005@0002H0000
Q?gooih0002>oOoo0@000:^ZhClMan6oe`/0018a00010000C00000000000000000000?oooooooooo
D00007P0001h0000600000`000000000E00005@0002M0000Q?gooj00002>oOoo0@000:^ZhClMan6o
B@`0018a00010000C00000000000000000000?ooooooooooD00003/0000l0000600000`000000000
E00005@0002R0000Q?goojH0002>oOoo0@000:^ZhClMan6oXP`0018a00010000C000000000000000
00000?ooooooooooD00007@0001@0000600000`0000000009@0000`0000=0020:00000`000010000
DP00070100010000>Oooo`0000000000000009010000000000020T<0C@1B0340<000000000000000
0000000000000000000000000000000000000000000000000000000000000000000003l003l40000
E<TH04SF<@2<bQP0mG53Ma/0?P1d0Bl000000501;`1H0m41000a02SB<@2P[c80000000@000000000
G0400@00000P000000010EC960000000S<XH0?Ea@gL;Tfd0o_ooojXh?gNR=3mg00000000<@0XdS40
6al:3P00000PdS40W<XH08YCKgD002l000000:5DKgGJQk6<6al:3RSB<@200Iae000004P0d@400=41
J<XH01/O2Pj4c1P0071aMEK6f?WnooooXEA_M@DBV7DXdS40j4Db0:HN8A/000X0j4Db0=C:601L>IQe
I7H02000000U000030000040001D0000E0000:D00024oOooZ@0008kmool10000Zj[Q?ag7hKoZ3000
4S400040001<00000000000000000000oooooooooom@0000:@000500000H000030000000001D0000
E0000:`00024oOoo]00008kmool10000Zj[Q?ag7hKm^3@004S400040001<00000000000000000000
oooooooooom@0000?@000:00000H000030000000000U0000300000d0080X000030000040001B0000
L0400040000ioooo0000000000000000T040000000000082@`1=04d0B@0a03000000000000000000
0000000000000000000000000000000000000000000000000000000000000000?`00?`@0001DbAP0
B=Ha08c:603eLD=g6`0n07@1;`000000D04_05P3d@400340:=8a0:2_<P00000010000000001L0@01
0000020000000041E<TH0000002<bQP0mG53M`^CK@3nooooZSPoMj8d?gL00000000a02SB<@0K7`X?
0000023B<@2LbQP0RU=_M@00;`000000XEA_MMZ7/H`K7`X?:=8a0801W7D00000B03A0@00d@5XbQP0
6al:3hC<6000L75eE/KHnOkooonQE6me1A:HMBSB<@3XAC80YQhQ6`002P3XAC80e<XH05`iV7ETMP08
000002D0000<00000@0005@0001D0000]P0008Cmoonl0000S_goo`40002[Z^4o7LOQ_d0>000B<@00
0@0004`00000000000000000003ooooooooooe00001e0000N00001P0000<0000000002D0000<0000
3@00P2P0000<00000@000580001`0@000@0007Goool0000000000000002@0@00000000000P9304d0
DP0g0000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000o000o100005C96018eS40S<XH0?Ea@gLK03h0M04_0000001@0Bl0F0?A0@00<@0XdS40
X:lb000000040000000005`100400000800000000@5DbAP0000008c:603eLD=g2i=]0?kooonZ>3mg
XS@oM`0000000340:=8a01/O2Q0000008=8a09c:602:Dfme000_0000002QE6mefXNaS1/O2Q0XdS40
P06LM@0000180=41003A0FS:600K7`X@Q<`H001`LGEFa]Sio_oooj5DKgD54YQe:=8a0>Q5<P2V7R4K
000:0>Q5<P3DbQP0G3VHMFAf00P000009@0000`000010000E00005@0002l0000R?gool00002>oOoo
0@000:^ZhClMan6o/Ph00?@`00010000C00000000000000000000?ooooooooooD0000300001@0000
600000`0000000009@0000`0000=0020:00000`000010000DP00070100010000MOooo`0000000000
000009010000000000020T<0C@1=04T0=`0000000000000000000000000000000000000000000000
00000000000000000000000000000000000003l003l40000E<TH04SF<@2<bQP0mG53Ma/0?P1d0Bl0
00000501;`1H0m41000a02SB<@2P[c80000000@000000000G0400@00000P000000010EC960000000
S<XH0?Ea@gL;Tfd0o_ooojXh?gNR=3mg00000000<@0XdS406al:4@00000PdS40W<XH08YCKgD002l0
00000:5DKgGJQk6<6al:4BSB<@200Iae000004P0d@400=41J<XH01/O2Q64c1P0071aMEK6f?Wnoooo
XEA_M@DBV7DXdS40j4Db0:HN8A/000X0j4Db0=C:601L>IQeI7H02000000U000030000040001D0000
E0000<L0001koOooc`00087mool10000Zj[Q?ag7hKn43`002S800040001<00000000000000000000
oooooooooom@0000C@000:00000H000030000000000U0000300000d0080X000030000040001B0000
L0400040000ioooo0000000000000000T040000000000082@`1=04D0F00a03000000000000000000
0000000000000000000000000000000000000000000000000000000000000000?`00?`@0001DbAP0
B=Ha08c:603eLD=g6`0n07@1;`000000D04_05P3d@400340:=8a0:2_<P00000010000000001L0@01
0000020000000041E<TH0000002<bQP0mG53M`^CK@3nooooZSPoMj8d?gL00000000a02SB<@0K7`XB
0000023B<@2LbQP0RU=_M@00;`000000XEA_MMZ7/H`K7`XB:=8a0801W7D00000B03A0@00d@5XbQP0
6al:4XC<6000L75eE/KHnOkooonQE6me1A:HMBSB<@3XAC80YQhQ6`002P3XAC80e<XH05`iV7ETMP08
000002D0000<00000@0005@0001D0000a00007_moooB0000X?goo`40002[Z^4o7LOQ_dP?003><@00
0@0004`00000000000000000003ooooooooooe00001H0000604001P0000<0000000002D0000<0000
3@00P2P0000<00000@000580001`0@000@0007Goool0000000000000002@0@00000000000P9304d0
C@1903L0000000000000000000000000000000000000000000000000000000000000000000000000
00000000000o000o100005C96018eS40S<XH0?Ea@gLK03h0M04_0000001@0Bl0F0?A0@00<@0XdS40
X:lb000000040000000005`100400000800000000@5DbAP0000008c:603eLD=g2i=]0?kooonZ>3mg
XS@oM`0000000340:=8a01/O2Q<000008=8a09c:602:Dfme000_0000002QE6mefXNaS1/O2Q<XdS40
P06LM@0000180=41003A0FS:600K7`XCQ<`H001`LGEFa]Sio_oooj5DKgD54YQe:=8a0>Q5<P2V7R4K
000:0>Q5<P3DbQP0G3VHMFAf00P000009@0000`000010000E00005@000320000TogoolT0002IoOoo
0@000:^ZhClMan6o;0l002T`00010000C00000000000000000000?ooooooooooD00006d0002<0000
600000`0000000009@0000`0000=0020:00000`000010000DP00070100010000MOooo`0000000000
000009010000000000020T<0C@1B03L0000000000000000000000000000000000000000000000000
00000000000000000000000000000000000003l003l40000E<TH04SF<@2<bQP0mG53Ma/0?P1d0Bl0
00000501;`1H0m41000a02SB<@2P[c80000000@000000000G0400@00000P000000010EC960000000
S<XH0?Ea@gL;Tfd0o_ooojXh?gNR=3mg00000000<@0XdS406al:5000000PdS40W<XH08YCKgD002l0
00000:5DKgGJQk6<6al:52SB<@200Iae000004P0d@400=41J<XH01/O2QB4c1P0071aMEK6f?Wnoooo
XEA_M@DBV7DXdS40j4Db0:HN8A/000X0j4Db0=C:601L>IQeI7H02000000U000030000040001D0000
E0000<T0002CoOooc`0009Wmool10000Zj[Q?ag7hKnj3`00:C000040001<00000000000000000000
oooooooooom@0000?@0007P0000H000030000000001D0000E0000<l0002CoOood`0009Wmool10000
Zj[Q?ag7hKld4000:C000040001<00000000000000000000oooooooooom@0000<0000500000H0000
30000000000U0000300000d0080X000030000040001B0000L0400040000ioooo0000000000000000
T040000000000082@`1=04d0B@0a0300000000000000000000000000000000000000000000000000
00000000000000000000000000000000?`00?`@0001DbAP0B=Ha08c:603eLD=g6`0n07@1;`000000
D04_05P3d@400340:=8a0:2_<P00000010000000001L0@010000020000000041E<TH0000002<bQP0
mG53M`^CK@3nooooZSPoMj8d?gL00000000a02SB<@0K7`XE0000023B<@2LbQP0RU=_M@00;`000000
XEA_MMZ7/H`K7`XE:=8a0801W7D00000B03A0@00d@5XbQP06al:5HC<6000L75eE/KHnOkooonQE6me
1A:HMBSB<@3XAC80YQhQ6`002P3XAC80e<XH05`iV7ETMP08000002D0000<00000@0005@0001D0000
e@0008CmoooN0000S_goo`40002[Z^4o7LOQ_jD@000B<@000@0004`00000000000000000003ooooo
oooooe0000180000X00001P0000<0000000002D0000<00003@00P2P0000<00000@000580001`0@00
0@0007Goool0000000000000002@0@00000000000P9304d0DP0g0000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000o000o100005C96018eS40
S<XH0?Ea@gLK03h0M04_0000001@0Bl0F0?A0@00<@0XdS40X:lb000000040000000005`100400000
800000000@5DbAP0000008c:603eLD=g2i=]0?kooonZ>3mgXS@oM`0000000340:=8a01/O2QH00000
8=8a09c:602:Dfme000_0000002QE6mefXNaS1/O2QHXdS40P06LM@0000180=41003A0FS:600K7`XF
Q<`H001`LGEFa]Sio_oooj5DKgD54YQe:=8a0>Q5<P2V7R4K000:0>Q5<P3DbQP0G3VHMFAf00P00000
9@0000`000010000E00005@0003N0000Pogoon800029oOoo0@000:^ZhClMan6oFQ4006<a00010000
C00000000000000000000?ooooooooooD0000340001@0000600000`000000000E00005@0003R0000
PogoonH00029oOoo0@000:^ZhClMan6oZQ4006<a00010000C00000000000000000000?oooooooooo
D0000340001@0000600000`000000000E00005@0003M0000ROgoon40002?oOoo0@000:^ZhClMan6o
Ba400>0`00010000C00000000000000000000?ooooooooooD0000340001@0000600000`000000000
E00005@0003Q0000ROgoonD0002?oOoo0@000:^ZhClMan6oVQ400>0`00010000C000000000000000
00000?ooooooooooD0000300001@0000600000`0000000009@0000`0000=0020:00000`000010000
DP00070100010000>Oooo`0000000000000009010000000000020T<0C@1505P0<@0`000000000000
0000000000000000000000000000000000000000000000000000000000000000000003l003l40000
E<TH04SF<@2<bQP0mG53Ma/0?P1d0Bl000000501;`1H0m41000a02SB<@2P[c80000000@000000000
G0400@00000P000000010EC960000000S<XH0?Ea@gL;Tfd0o_ooojXh?gNR=3mg00000000<@0XdS40
6al:5`00000PdS40W<XH08YCKgD002l000000:5DKgGJQk6<6al:5bSB<@200Iae000004P0d@400=41
J<XH01/O2QN4c1P0071aMEK6f?WnooooXEA_M@DBV7DXdS40j4Db0:HN8A/000X0j4Db0=C:601L>IQe
I7H02000000U000030000040001D0000E0000>P0001coOookP0009Smool10000Zj[Q?ag7hKlU4P00
IS800040001<00000000000000000000oooooooooom@00008P0007P0000H000030000000000U0000
300000d0080X000030000040001B0000L0400040000ioooo0000000000000000T040000000000082
@`1=04d0B@0a03000000000000000000000000000000000000000000000000000000000000000000
0000000000000000?`00?`@0001DbAP0B=Ha08c:603eLD=g6`0n07@1;`000000D04_05P3d@400340
:=8a0:2_<P00000010000000001L0@010000020000000041E<TH0000002<bQP0mG53M`^CK@3noooo
ZSPoMj8d?gL00000000a02SB<@0K7`XH0000023B<@2LbQP0RU=_M@00;`000000XEA_MMZ7/H`K7`XH
:=8a0801W7D00000B03A0@00d@5XbQP06al:68C<6000L75eE/KHnOkooonQE6me1A:HMBSB<@3XAC80
YQhQ6`002P3XAC80e<XH05`iV7ETMP08000002D0000<00000@0005@0001D0000kP0008Cmooog0000
S_goo`40002[Z^4o7LOQ_iPB000B<@000@0004`00000000000000000003ooooooooooe00001]0000
]00001P0000<0000000005@0001D0000m`0008Cmoool0000S_goo`40002[Z^4o7LOQ_dPC000B<@00
0@0004`00000000000000000003ooooooooooe00001j0000I00001P0000<0000000002D0000<0000
3@00P2P0000<00000@000580001`0@000@0007Goool0000000000000002@0@00000000000P9304d0
C@1903L0000000000000000000000000000000000000000000000000000000000000000000000000
00000000000o000o100005C96018eS40S<XH0?Ea@gLK03h0M04_0000001@0Bl0F0?A0@00<@0XdS40
X:lb000000040000000005`100400000800000000@5DbAP0000008c:603eLD=g2i=]0?kooonZ>3mg
XS@oM`0000000340:=8a01/O2QT000008=8a09c:602:Dfme000_0000002QE6mefXNaS1/O2QTXdS40
P06LM@0000180=41003A0FS:600K7`XIQ<`H001`LGEFa]Sio_oooj5DKgD54YQe:=8a0>Q5<P2V7R4K
000:0>Q5<P3DbQP0G3VHMFAf00P000009@0000`000010000E00005@0003k0000R?goool0002>oOoo
0@000:^ZhClMan6oY1<00?@`00010000C00000000000000000000?ooooooooooD00006<0001@0000
600000`0000000009@0000`0000=0020:00000`000010000DP00070100010000>Oooo`0000000000
000009010000000000020T<0C@1B0340<00000000000000000000000000000000000000000000000
00000000000000000000000000000000000003l003l40000E<TH04SF<@2<bQP0mG53Ma/0?P1d0Bl0
00000501;`1H0m41000a02SB<@2P[c80000000@000000000G0400@00000P000000010EC960000000
S<XH0?Ea@gL;Tfd0o_ooojXh?gNR=3mg00000000<@0XdS406al:6P00000PdS40W<XH08YCKgD002l0
00000:5DKgGJQk6<6al:6RSB<@200Iae000004P0d@400=41J<XH01/O2QZ4c1P0071aMEK6f?Wnoooo
XEA_M@DBV7DXdS40j4Db0:HN8A/000X0j4Db0=C:601L>IQeI7H02000000U000030000040001D0000
E00000810024oOoo2P4008kmool10000Zj[Q?ag7hKlR50004S400040001<00000000000000000000
oooooooooom@0000:`000:00000H000030000000000U0000300000d0080X000030000040001B0000
L0400040000ioooo0000000000000000T040000000000082@`1=04d0B@0a03000000000000000000
0000000000000000000000000000000000000000000000000000000000000000?`00?`@0001DbAP0
B=Ha08c:603eLD=g6`0n07@1;`000000D04_05P3d@400340:=8a0:2_<P00000010000000001L0@01
0000020000000041E<TH0000002<bQP0mG53M`^CK@3nooooZSPoMj8d?gL00000000a02SB<@0K7`XK
0000023B<@2LbQP0RU=_M@00;`000000XEA_MMZ7/H`K7`XK:=8a0801W7D00000B03A0@00d@5XbQP0
6al:6hC<6000L75eE/KHnOkooonQE6me1A:HMBSB<@3XAC80YQhQ6`002P3XAC80e<XH05`iV7ETMP08
000002D0000<00000@0005@0001D0000304008CmoolA0@00S_goo`40002[Z^4o7LOQ_nTD000B<@00
0@0004`00000000000000000003ooooooooooe00001j0000I00001P0000<0000000002D0000<0000
3@00P2P0000<00000@000580001`0@000@0003Woool0000000000000002@0@00000000000P9304d0
A@1H0340<00000000000000000000000000000000000000000000000000000000000000000000000
00000000000o000o100005C96018eS40S<XH0?Ea@gLK03h0M04_0000001@0Bl0F0?A0@00<@0XdS40
X:lb000000040000000005`100400000800000000@5DbAP0000008c:603eLD=g2i=]0?kooonZ>3mg
XS@oM`0000000340:=8a01/O2Q`000008=8a09c:602:Dfme000_0000002QE6mefXNaS1/O2Q`XdS40
P06LM@0000180=41003A0FS:600K7`XLQ<`H001`LGEFa]Sio_oooj5DKgD54YQe:=8a0>Q5<P2V7R4K
000:0>Q5<P3DbQP0G3VHMFAf00P000009@0000`000010000E00005@0000B0@00LogooaD1002HoOoo
0@000:^ZhClMan6oL1D006hb00010000C00000000000000000000?ooooooooooD0000:l0000l0000
600000`000000000E00005@0000B0@00N?gooaD1002MoOoo0@000:^ZhClMan6oL1D00?La00010000
C00000000000000000000?ooooooooooD0000:l0000l0000600000`000000000E00005@0000B0@00
O_gooaD1002SoOoo0@000:^ZhClMan6oL1D007la00010000C00000000000000000000?oooooooooo
D0000:l0000l0000600000`000000000E00005@0000B0@00Q?gooaD1002YoOoo0@000:^ZhClMan6o
L1D000La00010000C00000000000000000000?ooooooooooD0000:l0000l0000600000`000000000
E00005@0000B0@00R_gooaD1002_oOoo0@000:^ZhClMan6oL1D0090`00010000C000000000000000
00000?ooooooooooD0000:l0000l0000600000`0000000009@0000`0000=0020:00000`000010000
DP00070100010000>Oooo`0000000000000009010000000000020T<0C@1B0340<000000000000000
0000000000000000000000000000000000000000000000000000000000000000000003l003l40000
E<TH04SF<@2<bQP0mG53Ma/0?P1d0Bl000000501;`1H0m41000a02SB<@2P[c80000000@000000000
G0400@00000P000000010EC960000000S<XH0?Ea@gL;Tfd0o_ooojXh?gNR=3mg00000000<@0XdS40
6al:7@00000PdS40W<XH08YCKgD002l000000:5DKgGJQk6<6al:7BSB<@200Iae000004P0d@400=41
J<XH01/O2Qf4c1P0071aMEK6f?WnooooXEA_M@DBV7DXdS40j4Db0:HN8A/000X0j4Db0=C:601L>IQe
I7H02000000U000030000040001D0000E00001/1001loOoo804008Kmool10000Zj[Q?ag7hKlF5P00
]S400040001<00000000000000000000oooooooooom@0000<@0006@0000H000030000000000U0000
300000d0080X000030000040001B0000L0400040000ioooo0000000000000000T040000000000082
@`1=04d0B@0a03000000000000000000000000000000000000000000000000000000000000000000
0000000000000000?`00?`@0001DbAP0B=Ha08c:603eLD=g6`0n07@1;`000000D04_05P3d@400340
:=8a0:2_<P00000010000000001L0@010000020000000041E<TH0000002<bQP0mG53M`^CK@3noooo
ZSPoMj8d?gL00000000a02SB<@0K7`XN0000023B<@2LbQP0RU=_M@00;`000000XEA_MMZ7/H`K7`XN
:=8a0801W7D00000B03A0@00d@5XbQP06al:7XC<6000L75eE/KHnOkooonQE6me1A:HMBSB<@3XAC80
YQhQ6`002P3XAC80e<XH05`iV7ETMP08000002D0000<00000@0005@0001D0000804007cmoolS0@00
Q_goo`40002[Z^4o7LOQ_gXF002f<@000@0004`00000000000000000003ooooooooooe00000k0000
?00001P0000<0000000005@0001D0000904007cmoolY0@00Q_goo`40002[Z^4o7LOQ_m<F002f<@00
0@0004`00000000000000000003ooooooooooe00002`0000I00001P0000<0000000005@0001D0000
:P4007cmool_0@00Q_goo`40002[Z^4o7LOQ_d@G002f<@000@0004`00000000000000000003ooooo
oooooe00000m0000I00001P0000<0000000002D0000<00003@00P2P0000<00000@000580001`0@00
0@0003Woool0000000000000002@0@00000000000P9304d0DP0a0300000000000000000000000000
00000000000000000000000000000000000000000000000000000000000o000o100005C96018eS40
S<XH0?Ea@gLK03h0M04_0000001@0Bl0F0?A0@00<@0XdS40X:lb000000040000000005`100400000
800000000@5DbAP0000008c:603eLD=g2i=]0?kooonZ>3mgXS@oM`0000000340:=8a01/O2Ql00000
8=8a09c:602:Dfme000_0000002QE6mefXNaS1/O2QlXdS40P06LM@0000180=41003A0FS:600K7`XO
Q<`H001`LGEFa]Sio_oooj5DKgD54YQe:=8a0>Q5<P2V7R4K000:0>Q5<P3DbQP0G3VHMFAf00P00000
9@0000`000010000E00005@0000_0@00O?gooc@10026oOoo0@000:^ZhClMan6oZ1L00;Ha00010000
C00000000000000000000?ooooooooooD0000380001T0000600000`000000000E00005@0000K0@00
S?goob01002FoOoo0@000:^ZhClMan6o5QH0074`00010000C00000000000000000000?oooooooooo
D0000300001T0000600000`0000000009@0000`0000=0020:00000`000010000DP00070100010000
>Oooo`0000000000000009010000000000020T<0C@1=04T0<@0`0000000000000000000000000000
000000000000000000000000000000000000000000000000000003l003l40000E<TH04SF<@2<bQP0
mG53Ma/0?P1d0Bl000000501;`1H0m41000a02SB<@2P[c80000000@000000000G0400@00000P0000
00010EC960000000S<XH0?Ea@gL;Tfd0o_ooojXh?gNR=3mg00000000<@0XdS406al:8000000PdS40
W<XH08YCKgD002l000000:5DKgGJQk6<6al:82SB<@200Iae000004P0d@400=41J<XH01/O2R24c1P0
071aMEK6f?WnooooXEA_M@DBV7DXdS40j4Db0:HN8A/000X0j4Db0=C:601L>IQeI7H02000000U0000
30000040001D0000E0000201002<oOoo8`4009Kmool10000Zj[Q?ag7hKmj5P00LC000040001<0000
0000000000000000oooooooooom@0000>`0003`0000H000030000000000U0000300000d0080X0000
30000040001B0000L0400040000ioooo0000000000000000T040000000000082@`1=0580<@0`0000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
?`00?`@0001DbAP0B=Ha08c:603eLD=g6`0n07@1;`000000D04_05P3d@400340:=8a0:2_<P000000
10000000001L0@010000020000000041E<TH0000002<bQP0mG53M`^CK@3nooooZSPoMj8d?gL00000
000a02SB<@0K7`XQ0000023B<@2LbQP0RU=_M@00;`000000XEA_MMZ7/H`K7`XQ:=8a0801W7D00000
B03A0@00d@5XbQP06al:8HC<6000L75eE/KHnOkooonQE6me1A:HMBSB<@3XAC80YQhQ6`002P3XAC80
e<XH05`iV7ETMP08000002D0000<00000@0005@0001D0000904008cmoolY0@00U_goo`40002[Z^4o
7LOQ_m<F001a<0000@0004`00000000000000000003ooooooooooe00000a0000I00001P0000<0000
000002D0000<00003@00P2P0000<00000@000580001`0@000@0003Woool0000000000000002@0@00
000000000P9304d0A@1H0340<0000000000000000000000000000000000000000000000000000000
000000000000000000000000000o000o100005C96018eS40S<XH0?Ea@gLK03h0M04_0000001@0Bl0
F0?A0@00<@0XdS40X:lb000000040000000005`100400000800000000@5DbAP0000008c:603eLD=g
2i=]0?kooonZ>3mgXS@oM`0000000340:=8a01/O2R8000008=8a09c:602:Dfme000_0000002QE6me
fXNaS1/O2R8XdS40P06LM@0000180=41003A0FS:600K7`XRQ<`H001`LGEFa]Sio_oooj5DKgD54YQe
:=8a0>Q5<P2V7R4K000:0>Q5<P3DbQP0G3VHMFAf00P000009@0000`000010000E00005@0000j0@00
Logood01002HoOoo0@000:^ZhClMan6oR1P006Hb00010000C00000000000000000000?oooooooooo
D00002<0001h0000600000`0000000009@0000`0000=0020:00000`000010000DP00070100010000
>Oooo`0000000000000009010000000000020T<0C@1C05T0<@0`04l0DP1904L00000000000000000
000000000000000000000000000000000000000000000000000003l003l40000E<TH04SF<@2<bQP0
mG53Ma/0?P1d0Bl000000501;`1H0m41000a02SB<@2P[c80000000@000000000G0400@00000P0000
00010EC960000000S<XH0?Ea@gL;Tfd0o_ooojXh?gNR=3mg00000000<@0XdS406al:8`00000PdS40
W<XH08YCKgD002l000000:5DKgGJQk6<6al:8bSB<@200Iae000004P0d@400=41J<XH01/O2R>4c1P0
071aMEK6f?WnooooXEA_M@DBV7DXdS40j4Db0:HN8A/000X0j4Db0=C:601L>IQeI7H02000000U0000
30000040001D0000E00004810024oOooBP4009Gmool10000Zj[Q?ag7hKlW6@004S400040001<0000
0000000000000000oooooooooom@0000X@000:00000H000030000000000U0000300000d0080X0000
30000040001B0000L0400040000ioooo0000000000000000T040000000000082@`1=04d0B@0a0300
00000000000000000000000000000000000000000000000000000000000000000000000000000000
?`00?`@0001DbAP0B=Ha08c:603eLD=g6`0n07@1;`000000D04_05P3d@400340:=8a0:2_<P000000
10000000001L0@010000020000000041E<TH0000002<bQP0mG53M`^CK@3nooooZSPoMj8d?gL00000
000a02SB<@0K7`XT0000023B<@2LbQP0RU=_M@00;`000000XEA_MMZ7/H`K7`XT:=8a0801W7D00000
B03A0@00d@5XbQP06al:98C<6000L75eE/KHnOkooonQE6me1A:HMBSB<@3XAC80YQhQ6`002P3XAC80
e<XH05`iV7ETMP08000002D0000<00000@0005@0001D0000C04008CmoomB0@00S_goo`40002[Z^4o
7LOQ_nhI000B<@000@0004`00000000000000000003ooooooooooe00001e0000N00001P0000<0000
000002D0000<00003@00P2P0000<00000@000580001`0@000@0007Goool0000000000000002@0@00
000000000P9304d0DP0g000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000o000o100005C96018eS40S<XH0?Ea@gLK03h0M04_0000001@0Bl0
F0?A0@00<@0XdS40X:lb000000040000000005`100400000800000000@5DbAP0000008c:603eLD=g
2i=]0?kooonZ>3mgXS@oM`0000000340:=8a01/O2RD000008=8a09c:602:Dfme000_0000002QE6me
fXNaS1/O2RDXdS40P06LM@0000180=41003A0FS:600K7`XUQ<`H001`LGEFa]Sio_oooj5DKgD54YQe
:=8a0>Q5<P2V7R4K000:0>Q5<P3DbQP0G3VHMFAf00P000009@0000`000010000E00005@0001B0@00
R?gooeH1002>oOoo0@000:^ZhClMan6oH1X00?@`00010000C00000000000000000000?oooooooooo
D0000300001@0000600000`0000000009@0000`0000=0020:00000`000010000DP00070100010000
MOooo`0000000000000009010000000000020T<0C@1=04T0=`000000000000000000000000000000
000000000000000000000000000000000000000000000000000003l003l40000E<TH04SF<@2<bQP0
mG53Ma/0?P1d0Bl000000501;`1H0m41000a02SB<@2P[c80000000@000000000G0400@00000P0000
00010EC960000000S<XH0?Ea@gL;Tfd0o_ooojXh?gNR=3mg00000000<@0XdS406al:9P00000PdS40
W<XH08YCKgD002l000000:5DKgGJQk6<6al:9RSB<@200Iae000004P0d@400=41J<XH01/O2RJ4c1P0
071aMEK6f?WnooooXEA_M@DBV7DXdS40j4Db0:HN8A/000X0j4Db0=C:601L>IQeI7H02000000U0000
30000040001D0000E00005`1001koOooI040087mool10000Zj[Q?ag7hKld6`002S800040001<0000
0000000000000000oooooooooom@0000C@000:00000H000030000000000U0000300000d0080X0000
30000040001B0000L0400040000ioooo0000000000000000T040000000000082@`1=04D0F00a0300
00000000000000000000000000000000000000000000000000000000000000000000000000000000
?`00?`@0001DbAP0B=Ha08c:603eLD=g6`0n07@1;`000000D04_05P3d@400340:=8a0:2_<P000000
10000000001L0@010000020000000041E<TH0000002<bQP0mG53M`^CK@3nooooZSPoMj8d?gL00000
000a02SB<@0K7`XW0000023B<@2LbQP0RU=_M@00;`000000XEA_MMZ7/H`K7`XW:=8a0801W7D00000
B03A0@00d@5XbQP06al:9hC<6000L75eE/KHnOkooonQE6me1A:HMBSB<@3XAC80YQhQ6`002P3XAC80
e<XH05`iV7ETMP08000002D0000<00000@0005@0001D0000F@4007_moomW0@00X?goo`40002[Z^4o
7LOQ_oPJ003><@000@0004`00000000000000000003ooooooooooe00001H0000604001P0000<0000
000002D0000<00003@00P2P0000<00000@000580001`0@000@0007Goool0000000000000002@0@00
000000000P9304d0C@1903L000000000000000000000000000000000000000000000000000000000
000000000000000000000000000o000o100005C96018eS40S<XH0?Ea@gLK03h0M04_0000001@0Bl0
F0?A0@00<@0XdS40X:lb000000040000000005`100400000800000000@5DbAP0000008c:603eLD=g
2i=]0?kooonZ>3mgXS@oM`0000000340:=8a01/O2RP000008=8a09c:602:Dfme000_0000002QE6me
fXNaS1/O2RPXdS40P06LM@0000180=41003A0FS:600K7`XXQ<`H001`LGEFa]Sio_oooj5DKgD54YQe
:=8a0>Q5<P2V7R4K000:0>Q5<P3DbQP0G3VHMFAf00P000009@0000`000010000E00005@0001H0@00
Togooel1002IoOoo0@000:^ZhClMan6og1X002T`00010000C00000000000000000000?oooooooooo
D00006d0002<0000600000`0000000009@0000`0000=0020:00000`000010000DP00070100010000
MOooo`0000000000000009010000000000020T<0C@1B03L000000000000000000000000000000000
000000000000000000000000000000000000000000000000000003l003l40000E<TH04SF<@2<bQP0
mG53Ma/0?P1d0Bl000000501;`1H0m41000a02SB<@2P[c80000000@000000000G0400@00000P0000
00010EC960000000S<XH0?Ea@gL;Tfd0o_ooojXh?gNR=3mg00000000<@0XdS406al::@00000PdS40
W<XH08YCKgD002l000000:5DKgGJQk6<6al::BSB<@200Iae000004P0d@400=41J<XH01/O2RV4c1P0
071aMEK6f?WnooooXEA_M@DBV7DXdS40j4Db0:HN8A/000X0j4Db0=C:601L>IQeI7H02000000U0000
30000040001D0000E00005l1002CoOooI@4009Wmool10000Zj[Q?ag7hKmZ6`00:C000040001<0000
0000000000000000oooooooooom@0000?@0007P0000H000030000000001D0000E00006D1002CoOoo
J@4009Wmool10000Zj[Q?ag7hKoT6`00:C000040001<00000000000000000000oooooooooom@0000
<@2LME00000H000030000000000U0000300000d0080X000030000040001B0000L0400040000ioooo
0000000000000000T040000000000082@`1=04d0B@0a030000000000000000000000000000000000
000000000000000000000000000000000000000000000000?`00?`@0001DbAP0B=Ha08c:603eLD=g
6`0n07@1;`000000D04_05P3d@400340:=8a0:2_<P00000010000000001L0@010000020000000041
E<TH0000002<bQP0mG53M`^CK@3nooooZSPoMj8d?gL00000000a02SB<@0K7`XZ0000023B<@2LbQP0
RU=_M@00;`000000XEA_MMZ7/H`K7`XZ:=8a0801W7D00000B03A0@00d@5XbQP06al::XC<6000L75e
E/KHnOkooonQE6me1A:HMBSB<@3XAC80YQhQ6`002P3XAC80e<XH05`iV7ETMP08000002D0000<0000
0@0005@0001D0000J`4008Cmoomd0@00S_goo`40002[Z^4o7LOQ_e@L000B<@000@0004`000000000
00000000003ooooooooooe00001809aeX00001P0000<0000000002D0000<00003@00P2P0000<0000
0@000580001`0@000@0007Goool0000000000000002@0@00000000000P9304d0DP0g000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000o000o
100005C96018eS40S<XH0?Ea@gLK03h0M04_0000001@0Bl0F0?A0@00<@0XdS40X:lb000000040000
000005`100400000800000000@5DbAP0000008c:603eLD=g2i=]0?kooonZ>3mgXS@oM`0000000340
:=8a01/O2R/000008=8a09c:602:Dfme000_0000002QE6mefXNaS1/O2R/XdS40P06LM@0000180=41
003A0FS:600K7`X[Q<`H001`LGEFa]Sio_oooj5DKgD54YQe:=8a0>Q5<P2V7R4K000:0>Q5<P3DbQP0
G3VHMFAf00P000009@0000`000010000E00005@0001d0@00PogoogP10029oOoo0@000:^ZhClMan6o
2Ad006<a00010000C00000000000000000000?ooooooooooD0000340001@0000600000`000000000
E00005@0001h0@00Pogoog`10029oOoo0@000:^ZhClMan6oF1d006<a00010000C000000000000000
00000?ooooooooooD0000340001@0000600000`000000000E00005@0001c0@00ROgoogL1002?oOoo
0@000:^ZhClMan6onA`00>0`00010000C00000000000000000000?ooooooooooD0000340W7E@0000
600000`000000000E00005@0001g0@00ROgoog/1002?oOoo0@000:^ZhClMan6oB1d00>0`00010000
C00000000000000000000?ooooooooooD0000300001@0000600000`0000000009@0000`0000=0020
:00000`000010000DP00070100010000>Oooo`0000000000000009010000000000020T<0C@1505P0
<@0`0000000000000000000000000000000000000000000000000000000000000000000000000000
000003l003l40000E<TH04SF<@2<bQP0mG53Ma/0?P1d0Bl000000501;`1H0m41000a02SB<@2P[c80
000000@000000000G0400@00000P000000010EC960000000S<XH0?Ea@gL;Tfd0o_ooojXh?gNR=3mg
00000000<@0XdS406al:;000000PdS40W<XH08YCKgD002l000000:5DKgGJQk6<6al:;2SB<@200Iae
000004P0d@400=41J<XH01/O2Rb4c1P0071aMEK6f?WnooooXEA_M@DBV7DXdS40j4Db0:HN8A/000X0
j4Db0=C:601L>IQeI7H02000000U000030000040001D0000E00007h1001coOooQ04009Smool10000
Zj[Q?ag7hKoD7@00IS800040001<00000000000000000000oooooooooom@00008P2LMGP0000H0000
30000000000U0000300000d0080X000030000040001B0000L0400040000ioooo0000000000000000
T040000000000082@`1=04d0B@0a0300000000000000000000000000000000000000000000000000
00000000000000000000000000000000?`00?`@0001DbAP0B=Ha08c:603eLD=g6`0n07@1;`000000
D04_05P3d@400340:=8a0:2_<P00000010000000001L0@010000020000000041E<TH0000002<bQP0
mG53M`^CK@3nooooZSPoMj8d?gL00000000a02SB<@0K7`X]0000023B<@2LbQP0RU=_M@00;`000000
XEA_MMZ7/H`K7`X]:=8a0801W7D00000B03A0@00d@5XbQP06al:;HC<6000L75eE/KHnOkooonQE6me
1A:HMBSB<@3XAC80YQhQ6`002P3XAC80e<XH05`iV7ETMP08000002D0000<00000@0005@0001D0000
Q04008Cmoon=0@00S_goo`40002[Z^4o7LOQ_dPN000B<@000@0004`00000000000000000003ooooo
oooooe00001]09ae]00001P0000<0000000005@0001D0000S04008CmoonA0@00S_goo`40002[Z^4o
7LOQ_oLN000B<@000@0004`00000000000000000003ooooooooooe00001j0000I00001P0000<0000
000002D0000<00003@00P2P0000<00000@000580001`0@000@0007Goool0000000000000002@0@00
000000000P9304d0C@1903L000000000000000000000000000000000000000000000000000000000
000000000000000000000000000o000o100005C96018eS40S<XH0?Ea@gLK03h0M04_0000001@0Bl0
F0?A0@00<@0XdS40X:lb000000040000000005`100400000800000000@5DbAP0000008c:603eLD=g
2i=]0?kooonZ>3mgXS@oM`0000000340:=8a01/O2Rh000008=8a09c:602:Dfme000_0000002QE6me
fXNaS1/O2RhXdS40P06LM@0000180=41003A0FS:600K7`X^Q<`H001`LGEFa]Sio_oooj5DKgD54YQe
:=8a0>Q5<P2V7R4K000:0>Q5<P3DbQP0G3VHMFAf00P000009@0000`000010000E00005@0002A0@00
R?gooiD1002>oOoo0@000:^ZhClMan6oE1l00?@`00010000C00000000000000000000?oooooooooo
D00006<0001@0000600000`0000000009@0000`0000=0020:00000`000010000DP00070100010000
>Oooo`0000000000000009010000000000020T<0C@1C05T0<@0`04l0DP1904L00000000000000000
000000000000000000000000000000000000000000000000000003l003l40000E<TH04SF<@2<bQP0
mG53Ma/0?P1d0Bl000000501;`1H0m41000a02SB<@2P[c80000000@000000000G0400@00000P0000
00010EC960000000S<XH0?Ea@gL;Tfd0o_ooojXh?gNR=3mg00000000<@0XdS406al:;`00000PdS40
W<XH08YCKgD002l000000:5DKgGJQk6<6al:;bSB<@200Iae000004P0d@400=41J<XH01/O2Rn4c1P0
071aMEK6f?WnooooXEA_M@DBV7DXdS40j4Db0:HN8A/000X0j4Db0=C:601L>IQeI7H02000000U0000
30000040001D0000E00009L10024oOooW`4009Gmool10000Zj[Q?ag7hKo@7`004S400040001<0000
0000000000000000oooooooooom@0000X@000:00000H000030000000000U0000300000d0080X0000
30000040001B0000L0400040000ioooo0000000000000000T040000000000082@`1=04d0B@0a0300
00000000000000000000000000000000000000000000000000000000000000000000000000000000
?`00?`@0001DbAP0B=Ha08c:603eLD=g6`0n07@1;`000000D04_05P3d@400340:=8a0:2_<P000000
10000000001L0@010000020000000041E<TH0000002<bQP0mG53M`^CK@3nooooZSPoMj8d?gL00000
000a02SB<@0K7`X`0000023B<@2LbQP0RU=_M@00;`000000XEA_MMZ7/H`K7`X`:=8a0801W7D00000
B03A0@00d@5XbQP06al:<8C<6000L75eE/KHnOkooonQE6me1A:HMBSB<@3XAC80YQhQ6`002P3XAC80
e<XH05`iV7ETMP08000002D0000<00000@0005@0001D0000X@4008CmoonV0@00S_goo`40002[Z^4o
7LOQ_iPP000B<@000@0004`00000000000000000003ooooooooooe00001j0000I00001P0000<0000
000002D0000<00003@00P2P0000<00000@000580001`0@000@0003Woool0000000000000002@0@00
000000000P9304d0A@1H0340<0000000000000000000000000000000000000000000000000000000
000000000000000000000000000o000o100005C96018eS40S<XH0?Ea@gLK03h0M04_0000001@0Bl0
F0?A0@00<@0XdS40X:lb000000040000000005`100400000800000000@5DbAP0000008c:603eLD=g
2i=]0?kooonZ>3mgXS@oM`0000000340:=8a01/O2S4000008=8a09c:602:Dfme000_0000002QE6me
fXNaS1/O2S4XdS40P06LM@0000180=41003A0FS:600K7`XaQ<`H001`LGEFa]Sio_oooj5DKgD54YQe
:=8a0>Q5<P2V7R4K000:0>Q5<P3DbQP0G3VHMFAf00P000009@0000`000010000E00005@0002X0@00
Logooj/1002HoOoo0@000:^ZhClMan6o7b4006hb00010000C00000000000000000000?oooooooooo
D0000:l0000l0000600000`000000000E00005@0002X0@00N?gooj/1002MoOoo0@000:^ZhClMan6o
7b400?La00010000C00000000000000000000?ooooooooooD0000:l0000l0000600000`000000000
E00005@0002X0@00O_gooj/1002SoOoo0@000:^ZhClMan6o7b4007la00010000C000000000000000
00000?ooooooooooD0000:l0000l0000600000`000000000E00005@0002X0@00Q?gooj/1002YoOoo
0@000:^ZhClMan6o7b4000La00010000C00000000000000000000?ooooooooooD0000:l0000l0000
600000`000000000E00005@0002X0@00R_gooj/1002_oOoo0@000:^ZhClMan6o7b40090`00010000
C00000000000000000000?ooooooooooD0000:l0000l0000600000`0000000009@0000`0000=0020
:00000`000010000DP00070100010000>Oooo`0000000000000009010000000000020T<0C@1B0340
<0000000000000000000000000000000000000000000000000000000000000000000000000000000
000003l003l40000E<TH04SF<@2<bQP0mG53Ma/0?P1d0Bl000000501;`1H0m41000a02SB<@2P[c80
000000@000000000G0400@00000P000000010EC960000000S<XH0?Ea@gL;Tfd0o_ooojXh?gNR=3mg
00000000<@0XdS406al:<P00000PdS40W<XH08YCKgD002l000000:5DKgGJQk6<6al:<RSB<@200Iae
000004P0d@400=41J<XH01/O2S:4c1P0071aMEK6f?WnooooXEA_M@DBV7DXdS40j4Db0:HN8A/000X0
j4Db0=C:601L>IQeI7H02000000U000030000040001D0000E0000;01001loOoo]@4008Kmool10000
Zj[Q?ag7hKo58@00]S400040001<00000000000000000000oooooooooom@0000<@0006@0000H0000
30000000000U0000300000d0080X000030000040001B0000L0400040000ioooo0000000000000000
T040000000000082@`1=04d0B@0a0300000000000000000000000000000000000000000000000000
00000000000000000000000000000000?`00?`@0001DbAP0B=Ha08c:603eLD=g6`0n07@1;`000000
D04_05P3d@400340:=8a0:2_<P00000010000000001L0@010000020000000041E<TH0000002<bQP0
mG53M`^CK@3nooooZSPoMj8d?gL00000000a02SB<@0K7`Xc0000023B<@2LbQP0RU=_M@00;`000000
XEA_MMZ7/H`K7`Xc:=8a0801W7D00000B03A0@00d@5XbQP06al:<hC<6000L75eE/KHnOkooonQE6me
1A:HMBSB<@3XAC80YQhQ6`002P3XAC80e<XH05`iV7ETMP08000002D0000<00000@0005@0001D0000
]@4007cmoonh0@00Q_goo`40002[Z^4o7LOQ_bPR002f<@000@0004`00000000000000000003ooooo
oooooe00000k0000?00001P0000<0000000005@0001D0000^P4007cmoono0@00Q_goo`40002[Z^4o
7LOQ_h4R002f<@000@0004`00000000000000000003ooooooooooe00002`0000I00001P0000<0000
000005@0001D0000_`4007cmooo40@00Q_goo`40002[Z^4o7LOQ_o<R002f<@000@0004`000000000
00000000003ooooooooooe00000m0000I00001P0000<0000000002D0000<00003@00P2P0000<0000
0@000580001`0@000@0003Woool0000000000000002@0@00000000000P9304d0DP0a030000000000
000000000000000000000000000000000000000000000000000000000000000000000000000o000o
100005C96018eS40S<XH0?Ea@gLK03h0M04_0000001@0Bl0F0?A0@00<@0XdS40X:lb000000040000
000005`100400000800000000@5DbAP0000008c:603eLD=g2i=]0?kooonZ>3mgXS@oM`0000000340
:=8a01/O2S@000008=8a09c:602:Dfme000_0000002QE6mefXNaS1/O2S@XdS40P06LM@0000180=41
003A0FS:600K7`XdQ<`H001`LGEFa]Sio_oooj5DKgD54YQe:=8a0>Q5<P2V7R4K000:0>Q5<P3DbQP0
G3VHMFAf00P000009@0000`000010000E00005@000340@00O?goolT10026oOoo0@000:^ZhClMan6o
ER<00;Ha00010000C00000000000000000000?ooooooooooD0000380001T0000600000`000000000
E00005@0002`0@00S?gookD1002FoOoo0@000:^ZhClMan6oaB40074`00010000C000000000000000
00000?ooooooooooD0000300001T0000600000`0000000009@0000`0000=0020:00000`000010000
DP00070100010000>Oooo`0000000000000009010000000000020T<0C@1=04T0<@0`000000000000
0000000000000000000000000000000000000000000000000000000000000000000003l003l40000
E<TH04SF<@2<bQP0mG53Ma/0?P1d0Bl000000501;`1H0m41000a02SB<@2P[c80000000@000000000
G0400@00000P000000010EC960000000S<XH0?Ea@gL;Tfd0o_ooojXh?gNR=3mg00000000<@0XdS40
6al:=@00000PdS40W<XH08YCKgD002l000000:5DKgGJQk6<6al:=BSB<@200Iae000004P0d@400=41
J<XH01/O2SF4c1P0071aMEK6f?WnooooXEA_M@DBV7DXdS40j4Db0:HN8A/000X0j4Db0=C:601L>IQe
I7H02000000U000030000040001D0000E0000;D1002<oOoo^04009Kmool10000Zj[Q?ag7hKlX8P00
LC000040001<00000000000000000000oooooooooom@0000>`0003`0000H000030000000000U0000
300000d0080X000030000040001B0000L0400040000ioooo0000000000000000T040000000000082
@`1=0580<@0`00000000000000000000000000000000000000000000000000000000000000000000
0000000000000000?`00?`@0001DbAP0B=Ha08c:603eLD=g6`0n07@1;`000000D04_05P3d@400340
:=8a0:2_<P00000010000000001L0@010000020000000041E<TH0000002<bQP0mG53M`^CK@3noooo
ZSPoMj8d?gL00000000a02SB<@0K7`Xf0000023B<@2LbQP0RU=_M@00;`000000XEA_MMZ7/H`K7`Xf
:=8a0801W7D00000B03A0@00d@5XbQP06al:=XC<6000L75eE/KHnOkooonQE6me1A:HMBSB<@3XAC80
YQhQ6`002P3XAC80e<XH05`iV7ETMP08000002D0000<00000@0005@0001D0000^P4008cmoono0@00
U_goo`40002[Z^4o7LOQ_h4R001a<0000@0004`00000000000000000003ooooooooooe00000a0000
I00001P0000<0000000002D0000<00003@00P2P0000<00000@000580001`0@000@0003Woool00000
00000000002@0@00000000000P9304d0A@1H0340<000000000000000000000000000000000000000
0000000000000000000000000000000000000000000o000o100005C96018eS40S<XH0?Ea@gLK03h0
M04_0000001@0Bl0F0?A0@00<@0XdS40X:lb000000040000000005`100400000800000000@5DbAP0
000008c:603eLD=g2i=]0?kooonZ>3mgXS@oM`0000000340:=8a01/O2SL000008=8a09c:602:Dfme
000_0000002QE6mefXNaS1/O2SLXdS40P06LM@0000180=41003A0FS:600K7`XgQ<`H001`LGEFa]Si
o_oooj5DKgD54YQe:=8a0>Q5<P2V7R4K000:0>Q5<P3DbQP0G3VHMFAf00P000009@0000`000010000
E00005@0003@0@00LogoomH1002HoOoo0@000:^ZhClMan6o=R@006Hb00010000C000000000000000
00000?ooooooooooD00002<0001h00009@0000`0000=0020:00000`0000100003P0001@000000000
400001@00008@048900001P000024<3K0@0000<00000000000000000000K@000@00003@000010000
0P0007Em3D=jXb74[:BS@e^D14830000MGd=@gZS8LAVHnY3NZ<Qa7Em3D<eFQW48@0000P0001R0000
30000040000Q00002000024000080000L`0000`000000000700000P0000U000030000000080U0000
300000L0080U0000300000h0080I000030000?ooo`0H000030000000000B000030000080000C0000
30000040000D0000300000d0000E000030000040000F000030000000000=00004000000000000000
>P0000`0000:00006`00010000000000000002<0000P0000GL<T@@0000000000K;`X@KHP]/B15=E5
900002@0001M`bA100000000001/_2Q1]R2fa84DeDD40000L`0000`0000000003@00010000000000
00000580001`0@000P0001000007000000000000002l0P00000000L20R9C07T0L`1d06D0K@000180
X?Sooo8100000000?<dK0X3hool805QnnoKoo`00000000008<dK0X3hooooo`00000J1S3_l`S`[?48
j1XK1P0200150000R4PV1ZT]?gOQ7R5Y8P2:0LH8002Z>3mg_diSM`00000006`0::oc208000803o/8
`=bO1kc<>@00000000000000003oooooE4L04`00K0010000mG53M`<000080000B=Gk24SEn`P00?/8
00000080000006`00`000:S?>@2`d3T01=8i0?Ea@gOcEV@0o_ooom<l?gOn?3mg000100P00@12eO/8
003k2000000P[o<80B0008YeZ7BlecT0071aMIgZ5ig620000000068C00683AX60@000>C@007Xd3T0
;c2HMFAf00P000009@0000`000020000AP0008P0001l0000AdA9@`80002=0000NOgoom@1002JoOoo
<00006L0I@1^06D0LP1Q07@0I@1T0200HP1i0200E`1=04H0;`1504d0AP0P0680H@1S06/0I@1^06@0
801_06H0801`07<0M01_06D0I01Y07@0001Y06h0L01e07@0000002<0000P0000<^03?`0000000000
8od6_kHP]/B15=E5900002@0000bh0<o00000000000So@Jo]R2fa84DeDD400008`000200000bh0<o
00000000000So@Jo]R2fa84DeDDT0000900003;P0cl00000000002?m1[nf8;K4PACEA@@0000B0000
30000040000F0000300001P0000H000030000000001B0000L04000<0000ioooo0000000000000000
T040000000070082@`1=04d0B@0a0300000000000000000000000000000000000000000000000000
00000000000000000000000000040000b<XH0000000800001`000000002>DeEeb<XH033:603//4<0
100008@00038bQP000000000000<000000000040000PbQP0000008@0002P3`000P0000<00038bQP0
00000000000lbQP0Oii30?`:7`20bQP0001300@0002>]D<0MbRbS71n7`0QR4H00000000000000000
0@0004c:6000;dX03</H0>2L@P2Wa^f<o_ooo`00@`3M]D<0L7hO0000000001l0L7hO0<S:60010000
>00N00/00038bQP0L7hO0043002hOAl00@0006Qn7`1TMP08000002D0000<00000`0005@0001D0000
1P0007@000140000g@000040002[Z^4o7LOQ_aL;000B<@000@0004`00000000000000000003ooooo
oooooe00001e0000N00001P0000<000000000580001`0@00100001@00009000000000000002l0P00
000000L20R9C07T0L`1d06D0K@00000000000>8000000000K?B=0X3hool000000000000000000000
D?B=0X3hoonjUP00002HMKMTV7GQ7R5Y0000000000010000/7Ck2>S?>@1QI9QehAhQJ@0000000000
E0000000002`M?/8H=0i0=iAV7GQ7R5YZ3Q[1@80003H4Jd7E000000000010000>00N00/00038bQP0
L7hO0043002hOAl00@0006Qn7`00000800000<3LW`Nlc3T0H=0i02l`V7EPd3T0IS2HMM11o0P`_aL6
9@0000002P2DK000U=4i01gjY7CQ7R5Y001[1K1dn`P20000f16]1k8:YGA01iae00000407W7F00Iae
i47l2;S@>@0_<9Qe^=0i06H`V7D`@_`8<;lG1VAf00P000009@0000`000040000:00000`000030000
DP00070100030000>Oooo`000000000000000901000000001`020T<0C@1B0340<000000000000000
0000000000000000000000000000000000000000000000000000000000000000000003l003l40000
0P0004SF<@38bQP0000001/0?P1d0Bl000000501;`1H0m41001302SB<@2P[c80000000@000000000
G0400@00000P000000010EC9602<hcigS<XH0?Ea@gL;Tfd0o_ooojXh?gNR=3mg00000000<@0XdS40
6al:3000000PdS40W<XH08YCKgD002l000000:5DKgGJQk6<6al:32SB<@200Iae28HO04P0d@400=41
J<XH01/O2Pb4c1P0071aMEK6f?WnooooXEA_M@DBV7DXdS40j4Db0:HN8A/000X0j4Db0=C:601L>IQe
I7H02000000U0000300000<0001D0000E0000400001d0000JP000=d000010000Zj[Q?ag7hKn92`00
4S400040001<00000000000000000000oooooooooom@0000:0000500000H000030000000000U0000
300000@0000X0000300000<0001B0000L04000<0000ioooo0000000000000000T040000000070082
@`1=04d0B@0a03000000000000000000000000000000000000000000000000000000000000000000
0000000000000000?`00?`@0001DbAP0B=Ha08c:603eLD=g6`0n07@1;`000000D04_05P3d@400340
:=8a0:2_<P00000010000000001L0@010000020000000041E<TH0000002<bQP0mG53M`^CK@3noooo
ZSPoMj8d?gL00000000a02SB<@0K7`X=0000023B<@2LbQP0RU=_M@00;`000000XEA_MMZ7/H`K7`X=
:=8a0801W7D00000B03A0@00d@5XbQP06al:3HC<6000L75eE/KHnOkooonQE6me1A:HMBSB<@3XAC80
YQhQ6`002P3XAC80e<XH05`iV7ETMP08000002D0000<00000`0005@0001D0000J00007@0002V0000
g@000040002[Z^4o7LOQ_mL;000B<@000@0004`00000000000000000003ooooooooooe00001h0000
N00001P0000<0000000005@0001D0000X`0007@000320000g@000040002[Z^4o7LOQ_dT<000B<@00
0@0004`00000000000000000003ooooooooooe00000k0000?00001P0000<0000000005@0001D0000
d@0007@0003k0000g@000040002[Z^4o7LOQ_j8<000B<@000@0004`00000000000000000003ooooo
oooooe00001d0000D00001P0000<0000000002D0000<0000100002P0000<00000`000580001`0@00
0`0003Woool0000000000000002@0@00000000L00P9304d0DP0a0300000000000000000000000000
00000000000000000000000000000000000000000000000000000000000o000o100005C96018eS40
S<XH0?Ea@gLK03h0M04_0000001@0Bl0F0?A0@00<@0XdS40X:lb000000040000000005`100400000
800000000@5DbAP0000008c:603eLD=g2i=]0?kooonZ>3mgXS@oM`0000000340:=8a01/O2Ph00000
8=8a09c:602:Dfme000_0000002QE6mefXNaS1/O2PhXdS40P06LM@0000180=41003A0FS:600K7`X>
Q<`H001`LGEFa]Sio_oooj5DKgD54YQe:=8a0>Q5<P2V7R4K000:0>Q5<P3DbQP0G3VHMFAf00P00000
9@0000`000030000E00005@0003f0000M0000201003M00000@000:^ZhClMan6ojP`0018a00010000
C00000000000000000000?ooooooooooD00002T0001@0000600000`000000000E00005@0000j0@00
M00008d1003M00000@000:^ZhClMan6oKPd0018a00010000C00000000000000000000?oooooooooo
D00003d0002P0000600000`0000000009@0000`000040000:00000`000030000DP00070100030000
>Oooo`000000000000000901000000001`020T<0C@1=04T0<@0`0000000000000000000000000000
000000000000000000000000000000000000000000000000000003l003l40000E<TH04SF<@2<bQP0
mG53Ma/0?P1d0Bl000000501;`1H0m41000a02SB<@2P[c80000000@000000000G0400@00000P0000
00010EC960000000S<XH0?Ea@gL;Tfd0o_ooojXh?gNR=3mg00000000<@0XdS406al:3`00000PdS40
W<XH08YCKgD002l000000:5DKgGJQk6<6al:3bSB<@200Iae000004P0d@400=41J<XH01/O2Pn4c1P0
071aMEK6f?WnooooXEA_M@DBV7DXdS40j4Db0:HN8A/000X0j4Db0=C:601L>IQeI7H02000000U0000
300000<0001D0000E0000:H1001d0000i0400=d000010000Zj[Q?ag7hKm03P004S400040001<0000
0000000000000000oooooooooom@0000M@0007P0000H000030000000000U0000300000@0000X0000
300000<0001B0000L04000<0001eoooo0000000000000000T040000000070082@`1=0580=`000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
?`00?`@0001DbAP0B=Ha08c:603eLD=g6`0n07@1;`000000D04_05P3d@400340:=8a0:2_<P000000
10000000001L0@010000020000000041E<TH0000002<bQP0mG53M`^CK@3nooooZSPoMj8d?gL00000
000a02SB<@0K7`X@0000023B<@2LbQP0RU=_M@00;`000000XEA_MMZ7/H`K7`X@:=8a0801W7D00000
B03A0@00d@5XbQP06al:48C<6000L75eE/KHnOkooonQE6me1A:HMBSB<@3XAC80YQhQ6`002P3XAC80
e<XH05`iV7ETMP08000002D0000<00000`0005@0001D0000h@4009/0000;0P00i0000040002[Z^4o
7LOQ_k8>003d<0000@0004`00000000000000000003ooooooooooe00000`0000D00001P0000<0000
000002D0000<0000100002P0000<00000`000580001`0@000`0007Goool0000000000000002@0@00
000000L00P9304d0C@1903L000000000000000000000000000000000000000000000000000000000
000000000000000000000000000o000o100005C96018eS40S<XH0?Ea@gLK03h0M04_0000001@0Bl0
F0?A0@00<@0XdS40X:lb000000040000000005`100400000800000000@5DbAP0000008c:603eLD=g
2i=]0?kooonZ>3mgXS@oM`0000000340:=8a01/O2Q4000008=8a09c:602:Dfme000_0000002QE6me
fXNaS1/O2Q4XdS40P06LM@0000180=41003A0FS:600K7`XAQ<`H001`LGEFa]Sio_oooj5DKgD54YQe
:=8a0>Q5<P2V7R4K000:0>Q5<P3DbQP0G3VHMFAf00P000009@0000`000030000E00005@0001=0P00
2@000:02001B00000@000:^ZhClMan6oQ0l000Xb00010000C00000000000000000000?oooooooooo
D00004d0002P0000600000`0000000009@0000`000040000:00000`000030000DP00070100030000
>Oooo`000000000000000901000000001`020T<0C@1505P0<@0`0000000000000000000000000000
000000000000000000000000000000000000000000000000000003l003l40000E<TH04SF<@2<bQP0
mG53Ma/0?P1d0Bl000000501;`1H0m41000a02SB<@2P[c80000000@000000000G0400@00000P0000
00010EC960000000S<XH0?Ea@gL;Tfd0o_ooojXh?gNR=3mg00000000<@0XdS406al:4P00000PdS40
W<XH08YCKgD002l000000:5DKgGJQk6<6al:4RSB<@200Iae000004P0d@400=41J<XH01/O2Q:4c1P0
071aMEK6f?WnooooXEA_M@DBV7DXdS40j4Db0:HN8A/000X0j4Db0=C:601L>IQeI7H02000000U0000
300000<0001D0000E00002h2000>0000_`8009H100010000Zj[Q?ag7hKm83`00cS400040001<0000
0000000000000000oooooooooom@0000F00001P1000H000030000000000U0000300000@0000X0000
300000<0001B0000L04000<0001eoooo0000000000000000T040000000070082@`1=04d0B@0g0000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
?`00?`@0001DbAP0B=Ha08c:603eLD=g6`0n07@1;`000000D04_05P3d@400340:=8a0:2_<P000000
10000000001L0@010000020000000041E<TH0000002<bQP0mG53M`^CK@3nooooZSPoMj8d?gL00000
000a02SB<@0K7`XC0000023B<@2LbQP0RU=_M@00;`000000XEA_MMZ7/H`K7`XC:=8a0801W7D00000
B03A0@00d@5XbQP06al:4hC<6000L75eE/KHnOkooonQE6me1A:HMBSB<@3XAC80YQhQ6`002P3XAC80
e<XH05`iV7ETMP08000002D0000<00000`0005@0001D0000808000L1001Y0P00D0400040002[Z^4o
7LOQ_b`?000Y<0000@0004`00000000000000000003ooooooooooe00001]0000S00001P0000<0000
000002D0000<0000100002P0000<00000`000580001`0@000`0007Goool0000000000000002@0@00
000000L00P9304d0DP0g000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000o000o100005C96018eS40S<XH0?Ea@gLK03h0M04_0000001@0Bl0
F0?A0@00<@0XdS40X:lb000000040000000005`100400000800000000@5DbAP0000008c:603eLD=g
2i=]0?kooonZ>3mgXS@oM`0000000340:=8a01/O2Q@000008=8a09c:602:Dfme000_0000002QE6me
fXNaS1/O2Q@XdS40P06LM@0000180=41003A0FS:600K7`XDQ<`H001`LGEFa]Sio_oooj5DKgD54YQe
:=8a0>Q5<P2V7R4K000:0>Q5<P3DbQP0G3VHMFAf00P000009@0000`000030000E00005@0001Y0P00
1`400:L2001@0@000@000:^ZhClMan6o^Pl002T`00010000C00000000000000000000?oooooooooo
D00003d0001h0000600000`000000000E00005@0002X0P001`400=82001@0@000@000:^ZhClMan6o
=10002T`00010000C00000000000000000000?ooooooooooD0000300001@0000600000`000000000
9@0000`000040000:00000`000030000DP00070100030000>Oooo`00000000000000090100000000
1`020T<0C@1=04T0<@0`000000000000000000000000000000000000000000000000000000000000
0000000000000000000003l003l40000E<TH04SF<@2<bQP0mG53Ma/0?P1d0Bl000000501;`1H0m41
000a02SB<@2P[c80000000@000000000G0400@00000P000000010EC960000000S<XH0?Ea@gL;Tfd0
o_ooojXh?gNR=3mg00000000<@0XdS406al:5@00000PdS40W<XH08YCKgD002l000000:5DKgGJQk6<
6al:5BSB<@200Iae000004P0d@400=41J<XH01/O2QF4c1P0071aMEK6f?WnooooXEA_M@DBV7DXdS40
j4Db0:HN8A/000X0j4Db0=C:601L>IQeI7H02000000U0000300000<0001D0000E0000>82001d0000
?@<00=d000010000Zj[Q?ag7hKnU40004S400040001<00000000000000000000oooooooooom@0000
B0000:00000H000030000000000U0000300000@0000X0000300000<0001B0000L04000<0001eoooo
0000000000000000T040000000070082@`1=0580=`00000000000000000000000000000000000000
000000000000000000000000000000000000000000000000?`00?`@0001DbAP0B=Ha08c:603eLD=g
6`0n07@1;`000000D04_05P3d@400340:=8a0:2_<P00000010000000001L0@010000020000000041
E<TH0000002<bQP0mG53M`^CK@3nooooZSPoMj8d?gL00000000a02SB<@0K7`XF0000023B<@2LbQP0
RU=_M@00;`000000XEA_MMZ7/H`K7`XF:=8a0801W7D00000B03A0@00d@5XbQP06al:5XC<6000L75e
E/KHnOkooonQE6me1A:HMBSB<@3XAC80YQhQ6`002P3XAC80e<XH05`iV7ETMP08000002D0000<0000
0`0005@0001D0000?`<00640001Y0`00ZP000040002[Z^4o7LOQ_eXA001S<@000@0004`000000000
00000000003ooooooooooe00000a0000D00001P0000<0000000005@0001D0000J0<00640002B0`00
ZP000040002[Z^4o7LOQ_jXA001S<@000@0004`00000000000000000003ooooooooooe00000a0000
D00001P0000<0000000005@0001D0000>0<00:H0001R0`00k`000040002[Z^4o7LOQ_d/A003P<000
0@0004`00000000000000000003ooooooooooe00000a0000D00001P0000<0000000005@0001D0000
H0<00:H0002:0`00k`000040002[Z^4o7LOQ_iXA003P<0000@0004`00000000000000000003ooooo
oooooe00000`0000D00001P0000<0000000002D0000<0000100002P0000<00000`000580001`0@00
0`0003Woool0000000000000002@0@00000000L00P9304d0A@1H0340<00000000000000000000000
00000000000000000000000000000000000000000000000000000000000o000o100005C96018eS40
S<XH0?Ea@gLK03h0M04_0000001@0Bl0F0?A0@00<@0XdS40X:lb000000040000000005`100400000
800000000@5DbAP0000008c:603eLD=g2i=]0?kooonZ>3mgXS@oM`0000000340:=8a01/O2QL00000
8=8a09c:602:Dfme000_0000002QE6mefXNaS1/O2QLXdS40P06LM@0000180=41003A0FS:600K7`XG
Q<`H001`LGEFa]Sio_oooj5DKgD54YQe:=8a0>Q5<P2V7R4K000:0>Q5<P3DbQP0G3VHMFAf00P00000
9@0000`000030000E00005@0002X0`00_OooonH300150@000@000:^ZhClMan6o9A8006Hb00010000
C00000000000000000000?ooooooooooD0000280001h0000600000`0000000009@0000`000040000
:00000`000030000DP00070100030000>Oooo`000000000000000901000000001`020T<0C@1=04T0
<@0`0000000000000000000000000000000000000000000000000000000000000000000000000000
000003l003l40000E<TH04SF<@2<bQP0mG53Ma/0?P1d0Bl000000501;`1H0m41000a02SB<@2P[c80
000000@000000000G0400@00000P000000010EC960000000S<XH0?Ea@gL;Tfd0o_ooojXh?gNR=3mg
00000000<@0XdS406al:6000000PdS40W<XH08YCKgD002l000000:5DKgGJQk6<6al:62SB<@200Iae
000004P0d@400=41J<XH01/O2QR4c1P0071aMEK6f?WnooooXEA_M@DBV7DXdS40j4Db0:HN8A/000X0
j4Db0=C:601L>IQeI7H02000000U0000300000<0001D0000E0000><3001d0000@0@00=d000010000
Zj[Q?ag7hKnH4P004S400040001<00000000000000000000oooooooooom@0000K@000;@0000H0000
30000000001D0000E00003h4001d0000LP@00=d000010000Zj[Q?ag7hKm84`004S400040001<0000
0000000000000000oooooooooom@0000NP0006@0000H000030000000000U0000300000@0000X0000
300000<0001B0000L04000<0001eoooo0000000000000000T040000000070082@`1=04d0B@0g0000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
?`00?`@0001DbAP0B=Ha08c:603eLD=g6`0n07@1;`000000D04_05P3d@400340:=8a0:2_<P000000
10000000001L0@010000020000000041E<TH0000002<bQP0mG53M`^CK@3nooooZSPoMj8d?gL00000
000a02SB<@0K7`XI0000023B<@2LbQP0RU=_M@00;`000000XEA_MMZ7/H`K7`XI:=8a0801W7D00000
B03A0@00d@5XbQP06al:6HC<6000L75eE/KHnOkooonQE6me1A:HMBSB<@3XAC80YQhQ6`002P3XAC80
e<XH05`iV7ETMP08000002D0000<00000`0005@0001D0000K@@009/0002G1000i0000040002[Z^4o
7LOQ_j@C003d<0000@0004`00000000000000000003ooooooooooe00001S0000D00001P0000<0000
000002D0000<0000100002P0000<00000`000580001`0@000`0003Woool0000000000000002@0@00
000000L00P9304d0DP0a030000000000000000000000000000000000000000000000000000000000
000000000000000000000000000o000o100005C96018eS40S<XH0?Ea@gLK03h0M04_0000001@0Bl0
F0?A0@00<@0XdS40X:lb000000040000000005`100400000800000000@5DbAP0000008c:603eLD=g
2i=]0?kooonZ>3mgXS@oM`0000000340:=8a01/O2QX000008=8a09c:602:Dfme000_0000002QE6me
fXNaS1/O2QXXdS40P06LM@0000180=41003A0FS:600K7`XJQ<`H001`LGEFa]Sio_oooj5DKgD54YQe
:=8a0>Q5<P2V7R4K000:0>Q5<P3DbQP0G3VHMFAf00P000009@0000`000030000E00005@0002^1000
M0000045003M00000@000:^ZhClMan6o8Q@0018a00010000C00000000000000000000?oooooooooo
D00002/0002P0000600000`0000000009@0000`000040000:00000`000030000DP00070100030000
>Oooo`000000000000000901000000001`020T<0C@1=04T0<@0`0000000000000000000000000000
000000000000000000000000000000000000000000000000000003l003l40000E<TH04SF<@2<bQP0
mG53Ma/0?P1d0Bl000000501;`1H0m41000a02SB<@2P[c80000000@000000000G0400@00000P0000
00010EC960000000S<XH0?Ea@gL;Tfd0o_ooojXh?gNR=3mg00000000<@0XdS406al:6`00000PdS40
W<XH08YCKgD002l000000:5DKgGJQk6<6al:6bSB<@200Iae000004P0d@400=41J<XH01/O2Q^4c1P0
071aMEK6f?WnooooXEA_M@DBV7DXdS40j4Db0:HN8A/000X0j4Db0=C:601L>IQeI7H02000000U0000
300000<0001D0000E00001D5001d0000B@D00=d000010000Zj[Q?ag7hKoY50004S400040001<0000
0000000000000000oooooooooom@0000NP0006@0000H000030000000000U0000300000@0000X0000
300000<0001B0000L04000<0000ioooo0000000000000000T040000000070082@`1=04D0F00a0300
00000000000000000000000000000000000000000000000000000000000000000000000000000000
?`00?`@0001DbAP0B=Ha08c:603eLD=g6`0n07@1;`000000D04_05P3d@400340:=8a0:2_<P000000
10000000001L0@010000020000000041E<TH0000002<bQP0mG53M`^CK@3nooooZSPoMj8d?gL00000
000a02SB<@0K7`XL0000023B<@2LbQP0RU=_M@00;`000000XEA_MMZ7/H`K7`XL:=8a0801W7D00000
B03A0@00d@5XbQP06al:78C<6000L75eE/KHnOkooonQE6me1A:HMBSB<@3XAC80YQhQ6`002P3XAC80
e<XH05`iV7ETMP08000002D0000<00000`0005@0001D0000FPD00;Wooomi1@00@@400040002[Z^4o
7LOQ_g0E001^<P000@0004`00000000000000000003ooooooooooe00002_0000?00001P0000<0000
000005@0001D0000FPD00?Sooomi1@00P0400040002[Z^4o7LOQ_g0E003g<@000@0004`000000000
00000000003ooooooooooe00002_0000?00001P0000<0000000005@0001D0000FPD003L0001i1@00
_`400040002[Z^4o7LOQ_g0E001o<@000@0004`00000000000000000003ooooooooooe00002_0000
?00001P0000<0000000005@0001D0000FPD007H0001i1@00oP400040002[Z^4o7LOQ_g0E0007<@00
0@0004`00000000000000000003ooooooooooe00002_0000?00001P0000<0000000005@0001D0000
FPD00;D0001i1@00?@800040002[Z^4o7LOQ_g0E002@<0000@0004`00000000000000000003ooooo
oooooe00002_0000?00001P0000<0000000002D0000<0000100002P0000<00000`000580001`0@00
0`0003Woool0000000000000002@0@00000000L00P9304d0DP0a0300000000000000000000000000
00000000000000000000000000000000000000000000000000000000000o000o100005C96018eS40
S<XH0?Ea@gLK03h0M04_0000001@0Bl0F0?A0@00<@0XdS40X:lb000000040000000005`100400000
800000000@5DbAP0000008c:603eLD=g2i=]0?kooonZ>3mgXS@oM`0000000340:=8a01/O2Qd00000
8=8a09c:602:Dfme000_0000002QE6mefXNaS1/O2QdXdS40P06LM@0000180=41003A0FS:600K7`XM
Q<`H001`LGEFa]Sio_oooj5DKgD54YQe:=8a0>Q5<P2V7R4K000:0>Q5<P3DbQP0G3VHMFAf00P00000
9@0000`000030000E00005@0002`1@007@000>@5002600000@000:^ZhClMan6o5QH00;Ha00010000
C00000000000000000000?ooooooooooD0000340001T0000600000`0000000009@0000`000040000
:00000`000030000DP00070100030000>Oooo`000000000000000901000000001`020T<0C@1=04T0
<@0`0000000000000000000000000000000000000000000000000000000000000000000000000000
000003l003l40000E<TH04SF<@2<bQP0mG53Ma/0?P1d0Bl000000501;`1H0m41000a02SB<@2P[c80
000000@000000000G0400@00000P000000010EC960000000S<XH0?Ea@gL;Tfd0o_ooojXh?gNR=3mg
00000000<@0XdS406al:7P00000PdS40W<XH08YCKgD002l000000:5DKgGJQk6<6al:7RSB<@200Iae
000004P0d@400=41J<XH01/O2Qj4c1P0071aMEK6f?WnooooXEA_M@DBV7DXdS40j4Db0:HN8A/000X0
j4Db0=C:601L>IQeI7H02000000U0000300000<0001D0000E0000><5000M00000PH008H000010000
Zj[Q?ag7hKmj5P00]S400040001<00000000000000000000oooooooooom@0000>`0003`0000H0000
30000000001D0000E0000146000M0000B@H008H000010000Zj[Q?ag7hKoC5P00]S400040001<0000
0000000000000000oooooooooom@0000/00006@0000H000030000000001D0000E00004/6000M0000
O`H008H000010000Zj[Q?ag7hKm45`00]S400040001<00000000000000000000oooooooooom@0000
?@0006@0000H000030000000000U0000300000@0000X0000300000<0001B0000L04000<0000ioooo
0000000000000000T040000000070082@`1=0580<@0`000000000000000000000000000000000000
000000000000000000000000000000000000000000000000?`00?`@0001DbAP0B=Ha08c:603eLD=g
6`0n07@1;`000000D04_05P3d@400340:=8a0:2_<P00000010000000001L0@010000020000000041
E<TH0000002<bQP0mG53M`^CK@3nooooZSPoMj8d?gL00000000a02SB<@0K7`XO0000023B<@2LbQP0
RU=_M@00;`000000XEA_MMZ7/H`K7`XO:=8a0801W7D00000B03A0@00d@5XbQP06al:7hC<6000L75e
E/KHnOkooonQE6me1A:HMBSB<@3XAC80YQhQ6`002P3XAC80e<XH05`iV7ETMP08000002D0000<0000
0`0005@0001D0000O`H001d0002c1P00QP000040002[Z^4o7LOQ_jPG002f<@000@0004`000000000
00000000003ooooooooooe00000b0000I00001P0000<0000000005@0001D0000/0D00<T0003T1@00
<P400040002[Z^4o7LOQ_aHF001a<0000@0004`00000000000000000003ooooooooooe00000`0000
I00001P0000<0000000002D0000<0000100002P0000<00000`000580001`0@000`0003Woool00000
00000000002@0@00000000L00P9304d0C@190340<000000000000000000000000000000000000000
0000000000000000000000000000000000000000000o000o100005C96018eS40S<XH0?Ea@gLK03h0
M04_0000001@0Bl0F0?A0@00<@0XdS40X:lb000000040000000005`100400000800000000@5DbAP0
000008c:603eLD=g2i=]0?kooonZ>3mgXS@oM`0000000340:=8a01/O2R0000008=8a09c:602:Dfme
000_0000002QE6mefXNaS1/O2R0XdS40P06LM@0000180=41003A0FS:600K7`XPQ<`H001`LGEFa]Si
o_oooj5DKgD54YQe:=8a0>Q5<P2V7R4K000:0>Q5<P3DbQP0G3VHMFAf00P000009@0000`000030000
E00005@0003S1@00b@000086000b0@000@000:^ZhClMan6oNQH0074`00010000C000000000000000
00000?ooooooooooD00003/0000l0000600000`0000000009@0000`000040000:00000`000030000
DP00070100030000>Oooo`000000000000000901000000001`020T<0C@1B0340<000000000000000
0000000000000000000000000000000000000000000000000000000000000000000003l003l40000
E<TH04SF<@2<bQP0mG53Ma/0?P1d0Bl000000501;`1H0m41000a02SB<@2P[c80000000@000000000
G0400@00000P000000010EC960000000S<XH0?Ea@gL;Tfd0o_ooojXh?gNR=3mg00000000<@0XdS40
6al:8@00000PdS40W<XH08YCKgD002l000000:5DKgGJQk6<6al:8BSB<@200Iae000004P0d@400=41
J<XH01/O2R64c1P0071aMEK6f?WnooooXEA_M@DBV7DXdS40j4Db0:HN8A/000X0j4Db0=C:601L>IQe
I7H02000000U0000300000<0001D0000E000014600390000A@H0038100010000Zj[Q?ag7hKoC5P00
LC000040001<00000000000000000000oooooooooom@0000<@0006@0000H000030000000000U0000
300000@0000X0000300000<0001B0000L04000<0000ioooo0000000000000000T040000000070082
@`1=04D0F00a03000000000000000000000000000000000000000000000000000000000000000000
0000000000000000?`00?`@0001DbAP0B=Ha08c:603eLD=g6`0n07@1;`000000D04_05P3d@400340
:=8a0:2_<P00000010000000001L0@010000020000000041E<TH0000002<bQP0mG53M`^CK@3noooo
ZSPoMj8d?gL00000000a02SB<@0K7`XR0000023B<@2LbQP0RU=_M@00;`000000XEA_MMZ7/H`K7`XR
:=8a0801W7D00000B03A0@00d@5XbQP06al:8XC<6000L75eE/KHnOkooonQE6me1A:HMBSB<@3XAC80
YQhQ6`002P3XAC80e<XH05`iV7ETMP08000002D0000<00000`0005@0001D0000lPH00;goool`1`00
A@400040002[Z^4o7LOQ_hPH001V<P000@0004`00000000000000000003ooooooooooe00000S0000
N00001P0000<0000000002D0000<0000100002P0000<00000`000580001`0@000`0003Woool00000
00000000002@0@00000000L00P9304d0D`1I0340<01?0580B@170000000000000000000000000000
0000000000000000000000000000000000000000000o000o100005C96018eS40S<XH0?Ea@gLK03h0
M04_0000001@0Bl0F0?A0@00<@0XdS40X:lb000000040000000005`100400000800000000@5DbAP0
000008c:603eLD=g2i=]0?kooonZ>3mgXS@oM`0000000340:=8a01/O2R<000008=8a09c:602:Dfme
000_0000002QE6mefXNaS1/O2R<XdS40P06LM@0000180=41003A0FS:600K7`XSQ<`H001`LGEFa]Si
o_oooj5DKgD54YQe:=8a0>Q5<P2V7R4K000:0>Q5<P3DbQP0G3VHMFAf00P000009@0000`000030000
E00005@000141`00L@0009L7000W0@000@000:^ZhClMan6o9aT0018a00010000C000000000000000
00000?ooooooooooD0000:40002P0000600000`0000000009@0000`000040000:00000`000030000
DP00070100030000>Oooo`000000000000000901000000001`020T<0C@1=04T0<@0`000000000000
0000000000000000000000000000000000000000000000000000000000000000000003l003l40000
E<TH04SF<@2<bQP0mG53Ma/0?P1d0Bl000000501;`1H0m41000a02SB<@2P[c80000000@000000000
G0400@00000P000000010EC960000000S<XH0?Ea@gL;Tfd0o_ooojXh?gNR=3mg00000000<@0XdS40
6al:9000000PdS40W<XH08YCKgD002l000000:5DKgGJQk6<6al:92SB<@200Iae000004P0d@400=41
J<XH01/O2RB4c1P0071aMEK6f?WnooooXEA_M@DBV7DXdS40j4Db0:HN8A/000X0j4Db0=C:601L>IQe
I7H02000000U0000300000<0001D0000E0000:/7001d0000j@L00=d000010000Zj[Q?ag7hKo^6@00
4S400040001<00000000000000000000oooooooooom@0000M@0007P0000H000030000000000U0000
300000@0000X0000300000<0001B0000L04000<0001eoooo0000000000000000T040000000070082
@`1=0580=`0000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000?`00?`@0001DbAP0B=Ha08c:603eLD=g6`0n07@1;`000000D04_05P3d@400340
:=8a0:2_<P00000010000000001L0@010000020000000041E<TH0000002<bQP0mG53M`^CK@3noooo
ZSPoMj8d?gL00000000a02SB<@0K7`XU0000023B<@2LbQP0RU=_M@00;`000000XEA_MMZ7/H`K7`XU
:=8a0801W7D00000B03A0@00d@5XbQP06al:9HC<6000L75eE/KHnOkooonQE6me1A:HMBSB<@3XAC80
YQhQ6`002P3XAC80e<XH05`iV7ETMP08000002D0000<00000`0005@0001D0000i@L009/0000?2000
i0000040002[Z^4o7LOQ_f0J003d<0000@0004`00000000000000000003ooooooooooe00000`0000
D00001P0000<0000000002D0000<0000100002P0000<00000`000580001`0@000`0007Goool00000
00000000002@0@00000000L00P9304d0C@1903L00000000000000000000000000000000000000000
0000000000000000000000000000000000000000000o000o100005C96018eS40S<XH0?Ea@gLK03h0
M04_0000001@0Bl0F0?A0@00<@0XdS40X:lb000000040000000005`100400000800000000@5DbAP0
000008c:603eLD=g2i=]0?kooonZ>3mgXS@oM`0000000340:=8a01/O2RH000008=8a09c:602:Dfme
000_0000002QE6mefXNaS1/O2RHXdS40P06LM@0000180=41003A0FS:600K7`XVQ<`H001`LGEFa]Si
o_oooj5DKgD54YQe:=8a0>Q5<P2V7R4K000:0>Q5<P3DbQP0G3VHMFAf00P000009@0000`000030000
E00005@0001B20002@000:D8001B00000@000:^ZhClMan6o=1/000Xb00010000C000000000000000
00000?ooooooooooD00004d0002P0000600000`0000000009@0000`000040000:00000`000030000
DP00070100030000>Oooo`000000000000000901000000001`020T<0C@1505P0<@0`000000000000
0000000000000000000000000000000000000000000000000000000000000000000003l003l40000
E<TH04SF<@2<bQP0mG53Ma/0?P1d0Bl000000501;`1H0m41000a02SB<@2P[c80000000@000000000
G0400@00000P000000010EC960000000S<XH0?Ea@gL;Tfd0o_ooojXh?gNR=3mg00000000<@0XdS40
6al:9`00000PdS40W<XH08YCKgD002l000000:5DKgGJQk6<6al:9bSB<@200Iae000004P0d@400=41
J<XH01/O2RN4c1P0071aMEK6f?WnooooXEA_M@DBV7DXdS40j4Db0:HN8A/000X0j4Db0=C:601L>IQe
I7H02000000U0000300000<0001D0000E00003@8000>0000a@P009H100010000Zj[Q?ag7hKoh6P00
cS400040001<00000000000000000000oooooooooom@0000F00001P1000H000030000000000U0000
300000@0000X0000300000<0001B0000L04000<0001eoooo0000000000000000T040000000070082
@`1=04d0B@0g00000000000000000000000000000000000000000000000000000000000000000000
0000000000000000?`00?`@0001DbAP0B=Ha08c:603eLD=g6`0n07@1;`000000D04_05P3d@400340
:=8a0:2_<P00000010000000001L0@010000020000000041E<TH0000002<bQP0mG53M`^CK@3noooo
ZSPoMj8d?gL00000000a02SB<@0K7`XX0000023B<@2LbQP0RU=_M@00;`000000XEA_MMZ7/H`K7`XX
:=8a0801W7D00000B03A0@00d@5XbQP06al::8C<6000L75eE/KHnOkooonQE6me1A:HMBSB<@3XAC80
YQhQ6`002P3XAC80e<XH05`iV7ETMP08000002D0000<00000`0005@0001D00009@P000L1001^2000
D0400040002[Z^4o7LOQ_m`J000Y<0000@0004`00000000000000000003ooooooooooe00001]0000
S00001P0000<0000000002D0000<0000100002P0000<00000`000580001`0@000`0007Goool00000
00000000002@0@00000000L00P9304d0DP0g00000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000o000o100005C96018eS40S<XH0?Ea@gLK03h0
M04_0000001@0Bl0F0?A0@00<@0XdS40X:lb000000040000000005`100400000800000000@5DbAP0
000008c:603eLD=g2i=]0?kooonZ>3mgXS@oM`0000000340:=8a01/O2RT000008=8a09c:602:Dfme
000_0000002QE6mefXNaS1/O2RTXdS40P06LM@0000180=41003A0FS:600K7`XYQ<`H001`LGEFa]Si
o_oooj5DKgD54YQe:=8a0>Q5<P2V7R4K000:0>Q5<P3DbQP0G3VHMFAf00P000009@0000`000030000
E00005@0001^20001`400:`8001@0@000@000:^ZhClMan6oJQ/002T`00010000C000000000000000
00000?ooooooooooD00003d0001h0000600000`000000000E00005@0002]20001`400=L8001@0@00
0@000:^ZhClMan6oi1/002T`00010000C00000000000000000000?ooooooooooD0000340001@0000
600000`0000000009@0000`000040000:00000`000030000DP00070100030000>Oooo`0000000000
00000901000000001`020T<0C@1=04T0<@0`00000000000000000000000000000000000000000000
00000000000000000000000000000000000003l003l40000E<TH04SF<@2<bQP0mG53Ma/0?P1d0Bl0
00000501;`1H0m41000a02SB<@2P[c80000000@000000000G0400@00000P000000010EC960000000
S<XH0?Ea@gL;Tfd0o_ooojXh?gNR=3mg00000000<@0XdS406al::P00000PdS40W<XH08YCKgD002l0
00000:5DKgGJQk6<6al::RSB<@200Iae000004P0d@400=41J<XH01/O2RZ4c1P0071aMEK6f?Wnoooo
XEA_M@DBV7DXdS40j4Db0:HN8A/000X0j4Db0=C:601L>IQeI7H02000000U0000300000<0001D0000
E0000>L8001d0000@PT00=d000010000Zj[Q?ag7hKmD70004S400040001<00000000000000000000
oooooooooom@0000B0000:00000H000030000000000U0000300000@0000X0000300000<0001B0000
L04000<0001eoooo0000000000000000T040000000070082@`1=0580=`0000000000000000000000
0000000000000000000000000000000000000000000000000000000000000000?`00?`@0001DbAP0
B=Ha08c:603eLD=g6`0n07@1;`000000D04_05P3d@400340:=8a0:2_<P00000010000000001L0@01
0000020000000041E<TH0000002<bQP0mG53M`^CK@3nooooZSPoMj8d?gL00000000a02SB<@0K7`X[
0000023B<@2LbQP0RU=_M@00;`000000XEA_MMZ7/H`K7`X[:=8a0801W7D00000B03A0@00d@5XbQP0
6al::hC<6000L75eE/KHnOkooonQE6me1A:HMBSB<@3XAC80YQhQ6`002P3XAC80e<XH05`iV7ETMP08
000002D0000<00000`0005@0001D0000A0T00640001^2@00ZP000040002[Z^4o7LOQ_`TM001S<@00
0@0004`00000000000000000003ooooooooooe00000a0000D00001P0000<0000000005@0001D0000
K@T00640002G2@00ZP000040002[Z^4o7LOQ_ePM001S<@000@0004`00000000000000000003ooooo
oooooe00000a0000D00001P0000<0000000005@0001D0000?0T00:H0001V2@00k`000040002[Z^4o
7LOQ_oTL003P<0000@0004`00000000000000000003ooooooooooe00000a0000D00001P0000<0000
000005@0001D0000I@T00:H0002?2@00k`000040002[Z^4o7LOQ_dPM003P<0000@0004`000000000
00000000003ooooooooooe00000`0000D00001P0000<0000000002D0000<0000100002P0000<0000
0`000580001`0@000`0003Woool0000000000000002@0@00000000L00P9304d0A@1H0340<0000000
000000000000000000000000000000000000000000000000000000000000000000000000000o000o
100005C96018eS40S<XH0?Ea@gLK03h0M04_0000001@0Bl0F0?A0@00<@0XdS40X:lb000000040000
000005`100400000800000000@5DbAP0000008c:603eLD=g2i=]0?kooonZ>3mgXS@oM`0000000340
:=8a01/O2R`000008=8a09c:602:Dfme000_0000002QE6mefXNaS1/O2R`XdS40P06LM@0000180=41
003A0FS:600K7`X/Q<`H001`LGEFa]Sio_oooj5DKgD54YQe:=8a0>Q5<P2V7R4K000:0>Q5<P3DbQP0
G3VHMFAf00P000009@0000`000030000E00005@0002]2@00_Oooon/900150@000@000:^ZhClMan6o
e1d006Hb00010000C00000000000000000000?ooooooooooD0000280001h0000600000`000000000
9@0000`000040000:00000`000030000DP00070100030000>Oooo`00000000000000090100000000
1`020T<0C@1=04T0<@0`000000000000000000000000000000000000000000000000000000000000
0000000000000000000003l003l40000E<TH04SF<@2<bQP0mG53Ma/0?P1d0Bl000000501;`1H0m41
000a02SB<@2P[c80000000@000000000G0400@00000P000000010EC960000000S<XH0?Ea@gL;Tfd0
o_ooojXh?gNR=3mg00000000<@0XdS406al:;@00000PdS40W<XH08YCKgD002l000000:5DKgGJQk6<
6al:;BSB<@200Iae000004P0d@400=41J<XH01/O2Rf4c1P0071aMEK6f?WnooooXEA_M@DBV7DXdS40
j4Db0:HN8A/000X0j4Db0=C:601L>IQeI7H02000000U0000300000<0001D0000E0000>P9001d0000
A@X00=d000010000Zj[Q?ag7hKm87P004S400040001<00000000000000000000oooooooooom@0000
K@000;@0000H000030000000001D0000E00004<:001d0000M`X00=d000010000Zj[Q?ag7hKog7P00
4S400040001<00000000000000000000oooooooooom@0000NP0006@0000H000030000000000U0000
300000@0000X0000300000<0001B0000L04000<0001eoooo0000000000000000T040000000070082
@`1=04d0B@0g00000000000000000000000000000000000000000000000000000000000000000000
0000000000000000?`00?`@0001DbAP0B=Ha08c:603eLD=g6`0n07@1;`000000D04_05P3d@400340
:=8a0:2_<P00000010000000001L0@010000020000000041E<TH0000002<bQP0mG53M`^CK@3noooo
ZSPoMj8d?gL00000000a02SB<@0K7`X^0000023B<@2LbQP0RU=_M@00;`000000XEA_MMZ7/H`K7`X^
:=8a0801W7D00000B03A0@00d@5XbQP06al:;XC<6000L75eE/KHnOkooonQE6me1A:HMBSB<@3XAC80
YQhQ6`002P3XAC80e<XH05`iV7ETMP08000002D0000<00000`0005@0001D0000LPX009/0002L2P00
i0000040002[Z^4o7LOQ_e@O003d<0000@0004`00000000000000000003ooooooooooe00001S0000
D00001P0000<0000000002D0000<0000100002P0000<00000`000580001`0@000`0003Woool00000
00000000002@0@00000000L00P9304d0D`1I0340<01?0580B@170000000000000000000000000000
0000000000000000000000000000000000000000000o000o100005C96018eS40S<XH0?Ea@gLK03h0
M04_0000001@0Bl0F0?A0@00<@0XdS40X:lb000000040000000005`100400000800000000@5DbAP0
000008c:603eLD=g2i=]0?kooonZ>3mgXS@oM`0000000340:=8a01/O2Rl000008=8a09c:602:Dfme
000_0000002QE6mefXNaS1/O2RlXdS40P06LM@0000180=41003A0FS:600K7`X_Q<`H001`LGEFa]Si
o_oooj5DKgD54YQe:=8a0>Q5<P2V7R4K000:0>Q5<P3DbQP0G3VHMFAf00P000009@0000`000030000
E00005@0002b2P00L@0000D;000W0@000@000:^ZhClMan6od1l0018a00010000C000000000000000
00000?ooooooooooD0000:40002P0000600000`0000000009@0000`000040000:00000`000030000
DP00070100030000>Oooo`000000000000000901000000001`020T<0C@1=04T0<@0`000000000000
0000000000000000000000000000000000000000000000000000000000000000000003l003l40000
E<TH04SF<@2<bQP0mG53Ma/0?P1d0Bl000000501;`1H0m41000a02SB<@2P[c80000000@000000000
G0400@00000P000000010EC960000000S<XH0?Ea@gL;Tfd0o_ooojXh?gNR=3mg00000000<@0XdS40
6al:<000000PdS40W<XH08YCKgD002l000000:5DKgGJQk6<6al:<2SB<@200Iae000004P0d@400=41
J<XH01/O2S24c1P0071aMEK6f?WnooooXEA_M@DBV7DXdS40j4Db0:HN8A/000X0j4Db0=C:601L>IQe
I7H02000000U0000300000<0001D0000E00001T;001d0000C@/00=d000010000Zj[Q?ag7hKnH8000
4S400040001<00000000000000000000oooooooooom@0000NP0006@0000H000030000000000U0000
300000@0000X0000300000<0001B0000L04000<0000ioooo0000000000000000T040000000070082
@`1=04D0F00a03000000000000000000000000000000000000000000000000000000000000000000
0000000000000000?`00?`@0001DbAP0B=Ha08c:603eLD=g6`0n07@1;`000000D04_05P3d@400340
:=8a0:2_<P00000010000000001L0@010000020000000041E<TH0000002<bQP0mG53M`^CK@3noooo
ZSPoMj8d?gL00000000a02SB<@0K7`Xa0000023B<@2LbQP0RU=_M@00;`000000XEA_MMZ7/H`K7`Xa
:=8a0801W7D00000B03A0@00d@5XbQP06al:<HC<6000L75eE/KHnOkooonQE6me1A:HMBSB<@3XAC80
YQhQ6`002P3XAC80e<XH05`iV7ETMP08000002D0000<00000`0005@0001D0000G`/00;Wooomn2`00
@@400040002[Z^4o7LOQ_alQ001^<P000@0004`00000000000000000003ooooooooooe00002_0000
?00001P0000<0000000005@0001D0000G`/00?Sooomn2`00P0400040002[Z^4o7LOQ_alQ003g<@00
0@0004`00000000000000000003ooooooooooe00002_0000?00001P0000<0000000005@0001D0000
G`/003L0001n2`00_`400040002[Z^4o7LOQ_alQ001o<@000@0004`00000000000000000003ooooo
oooooe00002_0000?00001P0000<0000000005@0001D0000G`/007H0001n2`00oP400040002[Z^4o
7LOQ_alQ0007<@000@0004`00000000000000000003ooooooooooe00002_0000?00001P0000<0000
000005@0001D0000G`/00;D0001n2`00?@800040002[Z^4o7LOQ_alQ002@<0000@0004`000000000
00000000003ooooooooooe00002_0000?00001P0000<0000000002D0000<0000100002P0000<0000
0`000580001`0@000`0003Woool0000000000000002@0@00000000L00P9304d0DP0a030000000000
000000000000000000000000000000000000000000000000000000000000000000000000000o000o
100005C96018eS40S<XH0?Ea@gLK03h0M04_0000001@0Bl0F0?A0@00<@0XdS40X:lb000000040000
000005`100400000800000000@5DbAP0000008c:603eLD=g2i=]0?kooonZ>3mgXS@oM`0000000340
:=8a01/O2S8000008=8a09c:602:Dfme000_0000002QE6mefXNaS1/O2S8XdS40P06LM@0000180=41
003A0FS:600K7`XbQ<`H001`LGEFa]Sio_oooj5DKgD54YQe:=8a0>Q5<P2V7R4K000:0>Q5<P3DbQP0
G3VHMFAf00P000009@0000`000030000E00005@0002d2`007@000>P;002600000@000:^ZhClMan6o
aB400;Ha00010000C00000000000000000000?ooooooooooD0000340001T0000600000`000000000
9@0000`000040000:00000`000030000DP00070100030000>Oooo`00000000000000090100000000
1`020T<0C@1=04T0<@0`000000000000000000000000000000000000000000000000000000000000
0000000000000000000003l003l40000E<TH04SF<@2<bQP0mG53Ma/0?P1d0Bl000000501;`1H0m41
000a02SB<@2P[c80000000@000000000G0400@00000P000000010EC960000000S<XH0?Ea@gL;Tfd0
o_ooojXh?gNR=3mg00000000<@0XdS406al:<`00000PdS40W<XH08YCKgD002l000000:5DKgGJQk6<
6al:<bSB<@200Iae000004P0d@400=41J<XH01/O2S>4c1P0071aMEK6f?WnooooXEA_M@DBV7DXdS40
j4Db0:HN8A/000X0j4Db0=C:601L>IQeI7H02000000U0000300000<0001D0000E0000>L;000M0000
1P`008H000010000Zj[Q?ag7hKlX8P00]S400040001<00000000000000000000oooooooooom@0000
>`0003`0000H000030000000001D0000E00001D<000M0000C@`008H000010000Zj[Q?ag7hKn18P00
]S400040001<00000000000000000000oooooooooom@0000/00006@0000H000030000000001D0000
E000050<000M0000Q0`008H000010000Zj[Q?ag7hKoc8P00]S400040001<00000000000000000000
oooooooooom@0000?@0006@0000H000030000000000U0000300000@0000X0000300000<0001B0000
L04000<0000ioooo0000000000000000T040000000070082@`1=0580<@0`00000000000000000000
0000000000000000000000000000000000000000000000000000000000000000?`00?`@0001DbAP0
B=Ha08c:603eLD=g6`0n07@1;`000000D04_05P3d@400340:=8a0:2_<P00000010000000001L0@01
0000020000000041E<TH0000002<bQP0mG53M`^CK@3nooooZSPoMj8d?gL00000000a02SB<@0K7`Xd
0000023B<@2LbQP0RU=_M@00;`000000XEA_MMZ7/H`K7`Xd:=8a0801W7D00000B03A0@00d@5XbQP0
6al:=8C<6000L75eE/KHnOkooonQE6me1A:HMBSB<@3XAC80YQhQ6`002P3XAC80e<XH05`iV7ETMP08
000002D0000<00000`0005@0001D0000P``001d0002g3000QP000040002[Z^4o7LOQ_eHS002f<@00
0@0004`00000000000000000003ooooooooooe00000b0000I00001P0000<0000000005@0001D0000
]0/00<T0003X2`00<P400040002[Z^4o7LOQ_lDQ001a<0000@0004`00000000000000000003ooooo
oooooe00000`0000I00001P0000<0000000002D0000<0000100002P0000<00000`000580001`0@00
0`0003Woool0000000000000002@0@00000000L00P9304d0C@190340<00000000000000000000000
00000000000000000000000000000000000000000000000000000000000o000o100005C96018eS40
S<XH0?Ea@gLK03h0M04_0000001@0Bl0F0?A0@00<@0XdS40X:lb000000040000000005`100400000
800000000@5DbAP0000008c:603eLD=g2i=]0?kooonZ>3mgXS@oM`0000000340:=8a01/O2SD00000
8=8a09c:602:Dfme000_0000002QE6mefXNaS1/O2SDXdS40P06LM@0000180=41003A0FS:600K7`Xe
Q<`H001`LGEFa]Sio_oooj5DKgD54YQe:=8a0>Q5<P2V7R4K000:0>Q5<P3DbQP0G3VHMFAf00P00000
9@0000`000030000E00005@0003W2`00b@0000H<000b0@000@000:^ZhClMan6o:280074`00010000
C00000000000000000000?ooooooooooD00003/0000l0000600000`0000000009@0000`000040000
:00000`000030000DP00070100030000>Oooo`000000000000000901000000001`020T<0C@1B0340
<0000000000000000000000000000000000000000000000000000000000000000000000000000000
000003l003l40000E<TH04SF<@2<bQP0mG53Ma/0?P1d0Bl000000501;`1H0m41000a02SB<@2P[c80
000000@000000000G0400@00000P000000010EC960000000S<XH0?Ea@gL;Tfd0o_ooojXh?gNR=3mg
00000000<@0XdS406al:=P00000PdS40W<XH08YCKgD002l000000:5DKgGJQk6<6al:=RSB<@200Iae
000004P0d@400=41J<XH01/O2SJ4c1P0071aMEK6f?WnooooXEA_M@DBV7DXdS40j4Db0:HN8A/000X0
j4Db0=C:601L>IQeI7H02000000U0000300000<0001D0000E00001D<00390000B@`0038100010000
Zj[Q?ag7hKn18P00LC000040001<00000000000000000000oooooooooom@0000<@0006@0000H0000
30000000000U0000300000@0000X0000300000<0001B0000L04000<0000ioooo0000000000000000
T040000000070082@`1=04D0F00a0300000000000000000000000000000000000000000000000000
00000000000000000000000000000000?`00?`@0001DbAP0B=Ha08c:603eLD=g6`0n07@1;`000000
D04_05P3d@400340:=8a0:2_<P00000010000000001L0@010000020000000041E<TH0000002<bQP0
mG53M`^CK@3nooooZSPoMj8d?gL00000000a02SB<@0K7`Xg0000023B<@2LbQP0RU=_M@00;`000000
XEA_MMZ7/H`K7`Xg:=8a0801W7D00000B03A0@00d@5XbQP06al:=hC<6000L75eE/KHnOkooonQE6me
1A:HMBSB<@3XAC80YQhQ6`002P3XAC80e<XH05`iV7ETMP08000002D0000<00000`0005@0001D0000
mP`00;gooold3@00A@400040002[Z^4o7LOQ_cHT001V<P000@0004`00000000000000000003ooooo
oooooe00000S0000N00002D0000<0000100002P0000<00000`0004H0000D0000200004M4BD<30000
8P0000`0003ooooo8P0000`0003ooooo9@0000`0000=0020:00000`000020000:00000`000040000
8P0000`0003oooooAP000<01002d0@00ADe6:ba0000T000060000000P3l0000000000000P3l00020
0000P2Y0000T0000600000=?9440000000000;lP944EX;G4cd;?ABA0000<0000000002Y0000T0000
60000;02;3X0000000000;02;3X001JY000WZB]0000<0000000001i01P0<0000000002501@0<0000
000000Q00P@H00003000008@`=/000000`0043A00P0<0000000001i02@0<0000000002Y0000T0000
60000;02;3X0000000000;02;3X001JY000WZB501`0<0000000002Y0000T000060000;02;3X00000
00000;02;3X001JY000WZB]0000<0000000002]0000<0000000001i01P0<0000000002501@0<0000
000000Q00`@H00003000008@`=/000000`0043A00`0<0000000001i02@0<0000000002Y0000T0000
60000000P3l0000000000000P3l00000000002501`0<0000000004`0001T000000000000000P3@00
D`400000000000008@d005@1000Y0:X0000000000000080o000000000000080o0000000000000000
000000000000000000000000000R000030000?oooom60000700001000015CDH[0T0000`000000000
3P0001@000000000400001@0
\>"], "Graphics",
  GeneratedCell->False,
  CellAutoOverwrite->False,
  ImageSize->{482.16447368421035`, 48.07294603696738},
  ImageMargins->{{9.802631578947368, 0.}, {0., 42.96052631578947}}],
 "\n where z=x/",
 Cell[BoxData[
  FormBox[
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{"K", " ", 
      SuperscriptBox["t", "\[Gamma]"]}], ")"}], 
    RowBox[{"1", "/", "2"}]], TraditionalForm]]],
 "  and    ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["z", "c"], TraditionalForm]]],
 " = 2",
 StyleBox["L ",
  FontSlant->"Italic"],
 "/ ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{"K", " ", 
      SuperscriptBox["t", "\[Gamma]"]}], ")"}], 
    RowBox[{"1", "/", "2"}]], TraditionalForm]]],
 "   and ",
 StyleBox["M",
  FontSlant->"Italic"],
 "\[RightArrow]\[Infinity]"
}], "Text",
 CellChangeTimes->{{3.633439583415289*^9, 3.6334395909637213`*^9}, {
  3.636904756973955*^9, 3.636904760701168*^9}, {3.6372443229373713`*^9, 
  3.6372443239854317`*^9}, {3.6372443908282547`*^9, 3.637244411443434*^9}, {
  3.637244624301608*^9, 3.6372446392814655`*^9}, {3.6373025625952997`*^9, 
  3.6373025659023*^9}, {3.6373030348303003`*^9, 3.6373030488623*^9}, {
  3.637322132969174*^9, 3.637322340379037*^9}, {3.637322591898423*^9, 
  3.637322591899423*^9}, {3.6386021450706*^9, 3.6386021531106*^9}},
 Background->RGBColor[1, 1, 0]],

Cell[CellGroupData[{

Cell[TextData[{
 "Fox H functions  ",
 Cell[BoxData[
  FormBox[
   SubsuperscriptBox["H", "10", "11"], TraditionalForm]]],
 Cell[BoxData[
  FormBox[
   RowBox[{"[", 
    RowBox[{"z", "|", GridBox[{
       {
        RowBox[{"1", ",", 
         RowBox[{"\[Gamma]", "/", "2"}]}]},
       {
        RowBox[{"0", ",", "1"}]}
      }]}], "]"}], TraditionalForm]]],
 " =H1011[z,\[Gamma]]  for \[Gamma]=1/4, 1/3, 1/2, 2/3, 3/4 and 1: "
}], "Text",
 CellChangeTimes->{{3.4512305796232853`*^9, 3.4512307119736853`*^9}, {
  3.637322662950487*^9, 3.637322864542018*^9}, {3.6373231051817813`*^9, 
  3.6373231068458767`*^9}, {3.637323182206187*^9, 3.637323197590067*^9}},
 Background->RGBColor[1, 1, 0.85]],

Cell[BoxData[
 RowBox[{
  RowBox[{"H1011", "[", 
   RowBox[{"z_", ",", 
    RowBox[{"1", "/", "4"}]}], "]"}], ":=", 
  RowBox[{
   RowBox[{"-", 
    RowBox[{
     FractionBox["1", 
      RowBox[{"Gamma", "[", 
       FractionBox["7", "8"], "]"}]], 
     RowBox[{"z", " ", 
      RowBox[{"HypergeometricPFQ", "[", 
       RowBox[{
        RowBox[{"{", 
         FractionBox["1", "8"], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          FractionBox["1", "4"], ",", 
          FractionBox["3", "8"], ",", 
          FractionBox["1", "2"], ",", 
          FractionBox["5", "8"], ",", 
          FractionBox["3", "4"], ",", 
          FractionBox["7", "8"], ",", 
          FractionBox["9", "8"]}], "}"}], ",", 
        RowBox[{"-", 
         FractionBox[
          SuperscriptBox["z", "8"], "16777216"]}]}], "]"}]}]}]}], "+", 
   RowBox[{
    FractionBox["1", "5040"], 
    RowBox[{"(", 
     RowBox[{"5040", "+", 
      RowBox[{
       FractionBox["1", 
        RowBox[{"Gamma", "[", 
         FractionBox["3", "4"], "]"}]], 
       RowBox[{"2520", " ", 
        SuperscriptBox["z", "2"], " ", 
        RowBox[{"HypergeometricPFQ", "[", 
         RowBox[{
          RowBox[{"{", 
           FractionBox["1", "4"], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            FractionBox["3", "8"], ",", 
            FractionBox["1", "2"], ",", 
            FractionBox["5", "8"], ",", 
            FractionBox["3", "4"], ",", 
            FractionBox["7", "8"], ",", 
            FractionBox["9", "8"], ",", 
            FractionBox["5", "4"]}], "}"}], ",", 
          RowBox[{"-", 
           FractionBox[
            SuperscriptBox["z", "8"], "16777216"]}]}], "]"}]}]}], "-", 
      RowBox[{
       FractionBox["1", 
        RowBox[{"Gamma", "[", 
         FractionBox["5", "8"], "]"}]], 
       RowBox[{"840", " ", 
        SuperscriptBox["z", "3"], " ", 
        RowBox[{"HypergeometricPFQ", "[", 
         RowBox[{
          RowBox[{"{", 
           FractionBox["3", "8"], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            FractionBox["1", "2"], ",", 
            FractionBox["5", "8"], ",", 
            FractionBox["3", "4"], ",", 
            FractionBox["7", "8"], ",", 
            FractionBox["9", "8"], ",", 
            FractionBox["5", "4"], ",", 
            FractionBox["11", "8"]}], "}"}], ",", 
          RowBox[{"-", 
           FractionBox[
            SuperscriptBox["z", "8"], "16777216"]}]}], "]"}]}]}], "+", 
      RowBox[{
       FractionBox["1", 
        SqrtBox["\[Pi]"]], 
       RowBox[{"210", " ", 
        SuperscriptBox["z", "4"], " ", 
        RowBox[{"HypergeometricPFQ", "[", 
         RowBox[{
          RowBox[{"{", 
           FractionBox["1", "2"], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            FractionBox["5", "8"], ",", 
            FractionBox["3", "4"], ",", 
            FractionBox["7", "8"], ",", 
            FractionBox["9", "8"], ",", 
            FractionBox["5", "4"], ",", 
            FractionBox["11", "8"], ",", 
            FractionBox["3", "2"]}], "}"}], ",", 
          RowBox[{"-", 
           FractionBox[
            SuperscriptBox["z", "8"], "16777216"]}]}], "]"}]}]}], "-", 
      RowBox[{
       FractionBox["1", 
        RowBox[{"Gamma", "[", 
         FractionBox["3", "8"], "]"}]], 
       RowBox[{"42", " ", 
        SuperscriptBox["z", "5"], " ", 
        RowBox[{"HypergeometricPFQ", "[", 
         RowBox[{
          RowBox[{"{", 
           FractionBox["5", "8"], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            FractionBox["3", "4"], ",", 
            FractionBox["7", "8"], ",", 
            FractionBox["9", "8"], ",", 
            FractionBox["5", "4"], ",", 
            FractionBox["11", "8"], ",", 
            FractionBox["3", "2"], ",", 
            FractionBox["13", "8"]}], "}"}], ",", 
          RowBox[{"-", 
           FractionBox[
            SuperscriptBox["z", "8"], "16777216"]}]}], "]"}]}]}], "+", 
      RowBox[{
       FractionBox["1", 
        RowBox[{"Gamma", "[", 
         FractionBox["1", "4"], "]"}]], 
       RowBox[{"7", " ", 
        SuperscriptBox["z", "6"], " ", 
        RowBox[{"HypergeometricPFQ", "[", 
         RowBox[{
          RowBox[{"{", 
           FractionBox["3", "4"], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            FractionBox["7", "8"], ",", 
            FractionBox["9", "8"], ",", 
            FractionBox["5", "4"], ",", 
            FractionBox["11", "8"], ",", 
            FractionBox["3", "2"], ",", 
            FractionBox["13", "8"], ",", 
            FractionBox["7", "4"]}], "}"}], ",", 
          RowBox[{"-", 
           FractionBox[
            SuperscriptBox["z", "8"], "16777216"]}]}], "]"}]}]}], "-", 
      RowBox[{
       FractionBox["1", 
        RowBox[{"Gamma", "[", 
         FractionBox["1", "8"], "]"}]], 
       RowBox[{
        SuperscriptBox["z", "7"], " ", 
        RowBox[{"HypergeometricPFQ", "[", 
         RowBox[{
          RowBox[{"{", 
           FractionBox["7", "8"], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            FractionBox["9", "8"], ",", 
            FractionBox["5", "4"], ",", 
            FractionBox["11", "8"], ",", 
            FractionBox["3", "2"], ",", 
            FractionBox["13", "8"], ",", 
            FractionBox["7", "4"], ",", 
            FractionBox["15", "8"]}], "}"}], ",", 
          RowBox[{"-", 
           FractionBox[
            SuperscriptBox["z", "8"], "16777216"]}]}], "]"}]}]}]}], 
     ")"}]}]}]}]], "Input",
 CellChangeTimes->{{3.4512304374292855`*^9, 3.4512304500340853`*^9}},
 FontSize->10],

Cell[BoxData[
 RowBox[{
  RowBox[{"H1011", "[", 
   RowBox[{"z_", ",", 
    RowBox[{"1", "/", "3"}]}], "]"}], ":=", 
  RowBox[{"1", "+", 
   RowBox[{
    FractionBox["1", "120"], " ", "z", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{
        FractionBox["1", 
         RowBox[{"Gamma", "[", 
          FractionBox["5", "6"], "]"}]], 
        RowBox[{"120", " ", 
         RowBox[{"HypergeometricPFQ", "[", 
          RowBox[{
           RowBox[{"{", 
            FractionBox["1", "6"], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             FractionBox["1", "3"], ",", 
             FractionBox["1", "2"], ",", 
             FractionBox["2", "3"], ",", 
             FractionBox["5", "6"], ",", 
             FractionBox["7", "6"]}], "}"}], ",", 
           RowBox[{"-", 
            FractionBox[
             SuperscriptBox["z", "6"], "46656"]}]}], "]"}]}]}]}], "+", 
      RowBox[{"z", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          FractionBox["1", 
           RowBox[{"Gamma", "[", 
            FractionBox["2", "3"], "]"}]], 
          RowBox[{"60", " ", 
           RowBox[{"HypergeometricPFQ", "[", 
            RowBox[{
             RowBox[{"{", 
              FractionBox["1", "3"], "}"}], ",", 
             RowBox[{"{", 
              RowBox[{
               FractionBox["1", "2"], ",", 
               FractionBox["2", "3"], ",", 
               FractionBox["5", "6"], ",", 
               FractionBox["7", "6"], ",", 
               FractionBox["4", "3"]}], "}"}], ",", 
             RowBox[{"-", 
              FractionBox[
               SuperscriptBox["z", "6"], "46656"]}]}], "]"}]}]}], "+", 
         RowBox[{"z", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", 
             RowBox[{
              FractionBox["1", 
               SqrtBox["\[Pi]"]], 
              RowBox[{"20", " ", 
               RowBox[{"HypergeometricPFQ", "[", 
                RowBox[{
                 RowBox[{"{", 
                  FractionBox["1", "2"], "}"}], ",", 
                 RowBox[{"{", 
                  RowBox[{
                   FractionBox["2", "3"], ",", 
                   FractionBox["5", "6"], ",", 
                   FractionBox["7", "6"], ",", 
                   FractionBox["4", "3"], ",", 
                   FractionBox["3", "2"]}], "}"}], ",", 
                 RowBox[{"-", 
                  FractionBox[
                   SuperscriptBox["z", "6"], "46656"]}]}], "]"}]}]}]}], "+", 
            RowBox[{"z", " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                FractionBox["1", 
                 RowBox[{"Gamma", "[", 
                  FractionBox["1", "3"], "]"}]], 
                RowBox[{"5", " ", 
                 RowBox[{"HypergeometricPFQ", "[", 
                  RowBox[{
                   RowBox[{"{", 
                    FractionBox["2", "3"], "}"}], ",", 
                   RowBox[{"{", 
                    RowBox[{
                    FractionBox["5", "6"], ",", 
                    FractionBox["7", "6"], ",", 
                    FractionBox["4", "3"], ",", 
                    FractionBox["3", "2"], ",", 
                    FractionBox["5", "3"]}], "}"}], ",", 
                   RowBox[{"-", 
                    FractionBox[
                    SuperscriptBox["z", "6"], "46656"]}]}], "]"}]}]}], "-", 
               RowBox[{
                FractionBox["1", 
                 RowBox[{"Gamma", "[", 
                  FractionBox["1", "6"], "]"}]], 
                RowBox[{"z", " ", 
                 RowBox[{"HypergeometricPFQ", "[", 
                  RowBox[{
                   RowBox[{"{", 
                    FractionBox["5", "6"], "}"}], ",", 
                   RowBox[{"{", 
                    RowBox[{
                    FractionBox["7", "6"], ",", 
                    FractionBox["4", "3"], ",", 
                    FractionBox["3", "2"], ",", 
                    FractionBox["5", "3"], ",", 
                    FractionBox["11", "6"]}], "}"}], ",", 
                   RowBox[{"-", 
                    FractionBox[
                    SuperscriptBox["z", "6"], "46656"]}]}], "]"}]}]}]}], 
              ")"}]}]}], ")"}]}]}], ")"}]}]}], ")"}]}]}]}]], "Input",
 CellChangeTimes->{{3.451218228609375*^9, 3.451218270046875*^9}},
 FontSize->10],

Cell[BoxData[
 RowBox[{
  RowBox[{"H1011", "[", 
   RowBox[{"z_", ",", 
    RowBox[{"1", "/", "2"}]}], "]"}], ":=", 
  RowBox[{"1", "-", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"z", " ", 
      RowBox[{"HypergeometricPFQ", "[", 
       RowBox[{
        RowBox[{"{", 
         FractionBox["1", "4"], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          FractionBox["1", "2"], ",", 
          FractionBox["3", "4"], ",", 
          FractionBox["5", "4"]}], "}"}], ",", 
        RowBox[{"-", 
         FractionBox[
          SuperscriptBox["z", "4"], "256"]}]}], "]"}]}], ")"}], "/", 
    RowBox[{"Gamma", "[", 
     FractionBox["3", "4"], "]"}]}], "+", 
   RowBox[{
    FractionBox["1", "6"], " ", 
    SuperscriptBox["z", "2"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       FractionBox["1", 
        SqrtBox["\[Pi]"]], 
       RowBox[{"3", " ", 
        RowBox[{"HypergeometricPFQ", "[", 
         RowBox[{
          RowBox[{"{", 
           FractionBox["1", "2"], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            FractionBox["3", "4"], ",", 
            FractionBox["5", "4"], ",", 
            FractionBox["3", "2"]}], "}"}], ",", 
          RowBox[{"-", 
           FractionBox[
            SuperscriptBox["z", "4"], "256"]}]}], "]"}]}]}], "-", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"z", " ", 
         RowBox[{"HypergeometricPFQ", "[", 
          RowBox[{
           RowBox[{"{", 
            FractionBox["3", "4"], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             FractionBox["5", "4"], ",", 
             FractionBox["3", "2"], ",", 
             FractionBox["7", "4"]}], "}"}], ",", 
           RowBox[{"-", 
            FractionBox[
             SuperscriptBox["z", "4"], "256"]}]}], "]"}]}], ")"}], "/", 
       RowBox[{"Gamma", "[", 
        FractionBox["1", "4"], "]"}]}]}], ")"}]}]}]}]], "Input",
 CellChangeTimes->{{3.45121791028125*^9, 3.451217939703125*^9}, {
  3.45121811078125*^9, 3.451218115671875*^9}},
 FontSize->10],

Cell[BoxData[
 RowBox[{
  RowBox[{"H1011", "[", 
   RowBox[{"z_", ",", 
    RowBox[{"2", "/", "3"}]}], "]"}], ":=", 
  RowBox[{"1", "-", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"z", " ", 
      RowBox[{"HypergeometricPFQ", "[", 
       RowBox[{
        RowBox[{"{", 
         FractionBox["1", "3"], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          FractionBox["2", "3"], ",", 
          FractionBox["4", "3"]}], "}"}], ",", 
        FractionBox[
         SuperscriptBox["z", "3"], "27"]}], "]"}]}], ")"}], "/", 
    RowBox[{"Gamma", "[", 
     FractionBox["2", "3"], "]"}]}], "+", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["z", "2"], " ", 
      RowBox[{"HypergeometricPFQ", "[", 
       RowBox[{
        RowBox[{"{", 
         FractionBox["2", "3"], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          FractionBox["4", "3"], ",", 
          FractionBox["5", "3"]}], "}"}], ",", 
        FractionBox[
         SuperscriptBox["z", "3"], "27"]}], "]"}]}], ")"}], "/", 
    RowBox[{"(", 
     RowBox[{"2", " ", 
      RowBox[{"Gamma", "[", 
       FractionBox["1", "3"], "]"}]}], ")"}]}]}]}]], "Input",
 FontSize->10],

Cell[BoxData[
 RowBox[{
  RowBox[{"H1011", "[", 
   RowBox[{"z_", ",", 
    RowBox[{"3", "/", "4"}]}], "]"}], ":=", 
  RowBox[{
   RowBox[{"-", 
    RowBox[{
     FractionBox["1", 
      RowBox[{"Gamma", "[", 
       FractionBox["5", "8"], "]"}]], 
     RowBox[{"z", " ", 
      RowBox[{"HypergeometricPFQ", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          FractionBox["1", "8"], ",", 
          FractionBox["11", "24"], ",", 
          FractionBox["19", "24"]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          FractionBox["1", "4"], ",", 
          FractionBox["3", "8"], ",", 
          FractionBox["1", "2"], ",", 
          FractionBox["5", "8"], ",", 
          FractionBox["3", "4"], ",", 
          FractionBox["7", "8"], ",", 
          FractionBox["9", "8"]}], "}"}], ",", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"27", " ", 
           SuperscriptBox["z", "8"]}], "16777216"]}]}], "]"}]}]}]}], "+", 
   RowBox[{
    FractionBox["1", "5040"], 
    RowBox[{"(", 
     RowBox[{"5040", "+", 
      RowBox[{
       FractionBox["1", 
        RowBox[{"Gamma", "[", 
         FractionBox["1", "4"], "]"}]], 
       RowBox[{"2520", " ", 
        SuperscriptBox["z", "2"], " ", 
        RowBox[{"HypergeometricPFQ", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            FractionBox["1", "4"], ",", 
            FractionBox["7", "12"], ",", 
            FractionBox["11", "12"]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            FractionBox["3", "8"], ",", 
            FractionBox["1", "2"], ",", 
            FractionBox["5", "8"], ",", 
            FractionBox["3", "4"], ",", 
            FractionBox["7", "8"], ",", 
            FractionBox["9", "8"], ",", 
            FractionBox["5", "4"]}], "}"}], ",", 
          RowBox[{"-", 
           FractionBox[
            RowBox[{"27", " ", 
             SuperscriptBox["z", "8"]}], "16777216"]}]}], "]"}]}]}], "-", 
      RowBox[{
       FractionBox["1", 
        RowBox[{"Gamma", "[", 
         RowBox[{"-", 
          FractionBox["1", "8"]}], "]"}]], 
       RowBox[{"840", " ", 
        SuperscriptBox["z", "3"], " ", 
        RowBox[{"HypergeometricPFQ", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            FractionBox["3", "8"], ",", 
            FractionBox["17", "24"], ",", 
            FractionBox["25", "24"]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            FractionBox["1", "2"], ",", 
            FractionBox["5", "8"], ",", 
            FractionBox["3", "4"], ",", 
            FractionBox["7", "8"], ",", 
            FractionBox["9", "8"], ",", 
            FractionBox["5", "4"], ",", 
            FractionBox["11", "8"]}], "}"}], ",", 
          RowBox[{"-", 
           FractionBox[
            RowBox[{"27", " ", 
             SuperscriptBox["z", "8"]}], "16777216"]}]}], "]"}]}]}], "-", 
      RowBox[{
       FractionBox["1", 
        SqrtBox["\[Pi]"]], 
       RowBox[{"105", " ", 
        SuperscriptBox["z", "4"], " ", 
        RowBox[{"HypergeometricPFQ", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            FractionBox["1", "2"], ",", 
            FractionBox["5", "6"], ",", 
            FractionBox["7", "6"]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            FractionBox["5", "8"], ",", 
            FractionBox["3", "4"], ",", 
            FractionBox["7", "8"], ",", 
            FractionBox["9", "8"], ",", 
            FractionBox["5", "4"], ",", 
            FractionBox["11", "8"], ",", 
            FractionBox["3", "2"]}], "}"}], ",", 
          RowBox[{"-", 
           FractionBox[
            RowBox[{"27", " ", 
             SuperscriptBox["z", "8"]}], "16777216"]}]}], "]"}]}]}], "-", 
      RowBox[{
       FractionBox["1", 
        RowBox[{"Gamma", "[", 
         RowBox[{"-", 
          FractionBox["7", "8"]}], "]"}]], 
       RowBox[{"42", " ", 
        SuperscriptBox["z", "5"], " ", 
        RowBox[{"HypergeometricPFQ", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            FractionBox["5", "8"], ",", 
            FractionBox["23", "24"], ",", 
            FractionBox["31", "24"]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            FractionBox["3", "4"], ",", 
            FractionBox["7", "8"], ",", 
            FractionBox["9", "8"], ",", 
            FractionBox["5", "4"], ",", 
            FractionBox["11", "8"], ",", 
            FractionBox["3", "2"], ",", 
            FractionBox["13", "8"]}], "}"}], ",", 
          RowBox[{"-", 
           FractionBox[
            RowBox[{"27", " ", 
             SuperscriptBox["z", "8"]}], "16777216"]}]}], "]"}]}]}], "+", 
      RowBox[{
       FractionBox["1", 
        RowBox[{"Gamma", "[", 
         RowBox[{"-", 
          FractionBox["5", "4"]}], "]"}]], 
       RowBox[{"7", " ", 
        SuperscriptBox["z", "6"], " ", 
        RowBox[{"HypergeometricPFQ", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            FractionBox["3", "4"], ",", 
            FractionBox["13", "12"], ",", 
            FractionBox["17", "12"]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            FractionBox["7", "8"], ",", 
            FractionBox["9", "8"], ",", 
            FractionBox["5", "4"], ",", 
            FractionBox["11", "8"], ",", 
            FractionBox["3", "2"], ",", 
            FractionBox["13", "8"], ",", 
            FractionBox["7", "4"]}], "}"}], ",", 
          RowBox[{"-", 
           FractionBox[
            RowBox[{"27", " ", 
             SuperscriptBox["z", "8"]}], "16777216"]}]}], "]"}]}]}], "-", 
      RowBox[{
       FractionBox["1", 
        RowBox[{"Gamma", "[", 
         RowBox[{"-", 
          FractionBox["13", "8"]}], "]"}]], 
       RowBox[{
        SuperscriptBox["z", "7"], " ", 
        RowBox[{"HypergeometricPFQ", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            FractionBox["7", "8"], ",", 
            FractionBox["29", "24"], ",", 
            FractionBox["37", "24"]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            FractionBox["9", "8"], ",", 
            FractionBox["5", "4"], ",", 
            FractionBox["11", "8"], ",", 
            FractionBox["3", "2"], ",", 
            FractionBox["13", "8"], ",", 
            FractionBox["7", "4"], ",", 
            FractionBox["15", "8"]}], "}"}], ",", 
          RowBox[{"-", 
           FractionBox[
            RowBox[{"27", " ", 
             SuperscriptBox["z", "8"]}], "16777216"]}]}], "]"}]}]}]}], 
     ")"}]}]}]}]], "Input",
 CellChangeTimes->{{3.451230483262086*^9, 3.4512304895020857`*^9}},
 FontSize->10],

Cell[BoxData[
 RowBox[{
  RowBox[{"H1011", "[", 
   RowBox[{"z_", ",", "1"}], "]"}], ":=", 
  RowBox[{"Erfc", "[", 
   RowBox[{"z", "/", "2"}], "]"}]}]], "Input",
 FontSize->10]
}, Open  ]],

Cell[CellGroupData[{

Cell["Auxiliary functions for evaluating the exact solution", "Text",
 CellChangeTimes->{{3.6373231160354023`*^9, 3.6373231569507427`*^9}, {
  3.63732332196218*^9, 3.6373233233132577`*^9}},
 Background->RGBColor[1, 1, 0.85]],

Cell[BoxData[
 RowBox[{
  RowBox[{"HEsca", "[", 
   RowBox[{"z_", ",", "ga_"}], "]"}], ":=", 
  RowBox[{"Which", "[", 
   RowBox[{
    RowBox[{"z", ">", "50"}], ",", "0", ",", 
    RowBox[{"z", "\[LessEqual]", "50"}], ",", 
    RowBox[{"H1011", "[", 
     RowBox[{
      RowBox[{"SetPrecision", "[", 
       RowBox[{"z", ",", "60"}], "]"}], ",", "ga"}], "]"}]}], "]"}], "    ", 
  RowBox[{"(*", 
   RowBox[{
   "for", " ", "z", " ", "larger", " ", "than", " ", "50", " ", "we", " ", 
    "approximate", " ", "this", " ", "function", " ", "by", " ", "zero"}], 
   "*)"}], " "}]], "Input",
 CellChangeTimes->{{3.592058099836*^9, 3.592058163469*^9}, {
   3.637330471774126*^9, 3.6373305671955843`*^9}, 3.6373307600646152`*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"uEscalon", "[", 
   RowBox[{"x_", ",", "t_", ",", "ga_", ",", "LL_", ",", "nterm_"}], "]"}], ":=", 
  RowBox[{"(", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"z", "=", 
     RowBox[{"x", "/", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"Kg", "*", "t"}], ")"}], "^", 
       RowBox[{"(", 
        RowBox[{"ga", "/", "2"}], ")"}]}]}]}], ";", "\[IndentingNewLine]", 
    RowBox[{"zc", "=", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"2", "*", "LL"}], ")"}], "/", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"Kg", "*", "t"}], ")"}], "^", 
       RowBox[{"(", 
        RowBox[{"ga", "/", "2"}], ")"}]}]}]}], ";", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"HEsca", "[", 
      RowBox[{"z", ",", "ga"}], "]"}], " ", "-", 
     RowBox[{"Sum", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"HEsca", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"n", "*", "zc"}], "-", "z"}], ",", "ga"}], "]"}], "-", 
        RowBox[{"HEsca", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"n", "*", "zc"}], "+", "z"}], ",", "ga"}], "]"}]}], ",", 
       RowBox[{"{", 
        RowBox[{"n", ",", "1", ",", "nterm"}], "}"}]}], "]"}]}]}], 
   "\[IndentingNewLine]", ")"}], "  ", 
  RowBox[{"(*", 
   RowBox[{
    RowBox[{"for", " ", "very", " ", "small", " ", "times"}], ",", " ", 
    RowBox[{
     RowBox[{"so", " ", "that", " ", "z"}], ">", "50"}], ",", " ", 
    RowBox[{
    "this", " ", "function", " ", "is", " ", "approximated", " ", "by", " ", 
     "zero"}]}], "*)"}], " "}]], "Input",
 CellChangeTimes->{{3.5916261724138384`*^9, 3.591626360805614*^9}, {
   3.591709806700406*^9, 3.5917098625486*^9}, {3.5917100563356843`*^9, 
   3.591710093810828*^9}, {3.591710138294372*^9, 3.591710163551817*^9}, {
   3.591710221081107*^9, 3.591710225533362*^9}, {3.5917103273881874`*^9, 
   3.5917103325784845`*^9}, {3.5917104407916737`*^9, 3.591710466824163*^9}, {
   3.5917105045503206`*^9, 3.5917105082865343`*^9}, 3.5917106088412857`*^9, {
   3.5920546218859997`*^9, 3.5920546698710003`*^9}, {3.592054713719*^9, 
   3.5920547900950003`*^9}, {3.592054837191*^9, 3.592054924455*^9}, 
   3.592055003624*^9, {3.592058183104*^9, 3.5920583062060003`*^9}, {
   3.592058346415*^9, 3.5920583508859997`*^9}, 3.5920585296870003`*^9, {
   3.5920586930559998`*^9, 3.592058701175*^9}, {3.592058741375*^9, 
   3.592058747486*^9}, 3.5920588092790003`*^9, {3.637322903385239*^9, 
   3.637322954435159*^9}, {3.6373298908659*^9, 3.6373299060167665`*^9}, {
   3.6373305714928303`*^9, 3.637330632718332*^9}, 3.6373307749084644`*^9, 
   3.6373332195512905`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Exact solution (an approximation retaining Mvalue terms in the series \
expansion)\
\>", "Text",
 CellChangeTimes->{{3.6373231160354023`*^9, 3.6373231569507427`*^9}, {
  3.63732332196218*^9, 3.6373233725540743`*^9}},
 Background->RGBColor[1, 1, 0.85]],

Cell[BoxData[
 RowBox[{
  RowBox[{"uSol", "[", 
   RowBox[{"x_", ",", "0", ",", "ga_"}], "]"}], ":=", 
  RowBox[{"0", "/;", 
   RowBox[{"x", ">", "0"}]}]}]], "Input",
 CellChangeTimes->{{3.55982895496875*^9, 3.559828984796875*^9}, {
   3.589297606934722*^9, 3.589297614521156*^9}, {3.58929766495004*^9, 
   3.5892976659740987`*^9}, 3.591539607876666*^9, {3.591539685949132*^9, 
   3.5915396862961516`*^9}, {3.591626951166381*^9, 3.5916269585008*^9}, {
   3.592060414733*^9, 3.592060479308*^9}, 3.598967026215596*^9, {
   3.637322906145397*^9, 3.637322915063907*^9}, {3.637322945152628*^9, 
   3.637322984160859*^9}, {3.6373230552559257`*^9, 3.637323056095974*^9}, {
   3.6373694342199697`*^9, 3.6373694567862606`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"uSol", "[", 
   RowBox[{"x_", ",", "t_", ",", "ga_"}], "]"}], ":=", 
  RowBox[{"u0value", "*", 
   RowBox[{"uEscalon", "[", 
    RowBox[{"x", ",", "t", ",", "ga", ",", "LL", ",", "Mvalue"}], 
    "]"}]}]}]], "Input",
 CellChangeTimes->{{3.55982895496875*^9, 3.559828984796875*^9}, {
   3.589297606934722*^9, 3.589297614521156*^9}, {3.58929766495004*^9, 
   3.5892976659740987`*^9}, 3.591539607876666*^9, {3.591539685949132*^9, 
   3.5915396862961516`*^9}, {3.591626951166381*^9, 3.5916269585008*^9}, {
   3.592060414733*^9, 3.592060479308*^9}, 3.598967026215596*^9, {
   3.637322906145397*^9, 3.637322915063907*^9}, {3.637322945152628*^9, 
   3.637322984160859*^9}, {3.6373230552559257`*^9, 3.637323056095974*^9}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Source term.  In this example is zero.", "Text",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 CellChangeTimes->{{3.561126817421*^9, 3.5611268309564*^9}, {
  3.636904881452074*^9, 3.636904980035713*^9}, {3.6369050699238544`*^9, 
  3.6369050775552907`*^9}, {3.6369769775634212`*^9, 3.6369769906991725`*^9}, {
  3.6371385049577384`*^9, 3.6371385138497543`*^9}, {3.637245196685347*^9, 
  3.637245198101428*^9}},
 Background->RGBColor[1, 1, 0]],

Cell[BoxData[
 RowBox[{
  RowBox[{"funSource", "[", 
   RowBox[{"x_", ",", "t_", ",", "ga_"}], "]"}], ":=", "0."}]], "Input",
 CellChangeTimes->{{3.591431994688729*^9, 3.5914321084812374`*^9}, {
   3.591451756628047*^9, 3.591451758933179*^9}, {3.625845727689809*^9, 
   3.625845731041814*^9}, {3.625846217702113*^9, 3.6258462469911566`*^9}, {
   3.625847584206174*^9, 3.6258476065492067`*^9}, 3.625848178113057*^9, {
   3.6371374450686765`*^9, 3.637137465738713*^9}, {3.637138662007818*^9, 
   3.6371386623354187`*^9}, 3.6374195802813997`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Order of the fractional derivative: \[Gamma]=gammak. Here we choose \
\[Gamma]=1/4\
\>", "Text",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 CellChangeTimes->{{3.561126817421*^9, 3.5611268309564*^9}, {
  3.6371385902274885`*^9, 3.6371386028323107`*^9}, {3.637244700524968*^9, 
  3.637244706452307*^9}, {3.6372448627442465`*^9, 3.637244876903056*^9}, {
  3.637245133464731*^9, 3.6372451551689725`*^9}},
 Background->RGBColor[1, 1, 0]],

Cell[BoxData[{
 RowBox[{
  RowBox[{"gammak", "=", "0.25"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"gammaVal", "=", 
   RowBox[{"Rationalize", "[", "gammak", "]"}]}], ";"}]}], "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 CellChangeTimes->{
  3.561049517788604*^9, 3.561050679357012*^9, {3.5610903980687075`*^9, 
   3.561090407393154*^9}, 3.5611220939094*^9, 3.5611268309564*^9, {
   3.589270600217*^9, 3.589270601552*^9}, 3.589271184201*^9, {
   3.5892976824570417`*^9, 3.589297690719514*^9}, {3.5895180885616817`*^9, 
   3.589518088921702*^9}, 3.5895191624171023`*^9, {3.5895527656894464`*^9, 
   3.5895527660334663`*^9}, {3.5895546010014205`*^9, 
   3.5895546019304733`*^9}, {3.5896016762995996`*^9, 
   3.5896016765648003`*^9}, {3.589602256472*^9, 3.5896022604751997`*^9}, 
   3.5896030482298*^9, 3.589607261262*^9, 3.5897244193129997`*^9, {
   3.589736570752*^9, 3.58973657109*^9}, {3.589892478189557*^9, 
   3.589892479577959*^9}, {3.589896047289415*^9, 3.5898960476124334`*^9}, {
   3.5900402744212723`*^9, 3.5900402746552725`*^9}, {3.5900407451852994`*^9, 
   3.590040745949701*^9}, {3.5900412475908303`*^9, 3.5900412482928314`*^9}, {
   3.5900423256057243`*^9, 3.590042326089325*^9}, {3.5900685957871857`*^9, 
   3.59006859656723*^9}, 3.59007342585645*^9, 3.59021224751*^9, {
   3.5906711458351727`*^9, 3.5906711462141943`*^9}, {3.5907517913939114`*^9, 
   3.5907517917099295`*^9}, {3.591432157985069*^9, 3.591432180683367*^9}, {
   3.591433432296955*^9, 3.591433436503196*^9}, {3.59145199060743*^9, 
   3.591451992849558*^9}, {3.5914533024744644`*^9, 3.5914533051926203`*^9}, {
   3.5915293458577127`*^9, 3.5915293461947317`*^9}, {3.591536410992815*^9, 
   3.591536413805976*^9}, {3.6019157899983253`*^9, 3.6019157928574886`*^9}, {
   3.625846526613616*^9, 3.625846526953616*^9}, {3.625846592786713*^9, 
   3.625846625234762*^9}, 3.626066770157*^9, 3.6371379698887987`*^9, 
   3.63713800489886*^9, {3.637138089029808*^9, 3.6371380899190097`*^9}, {
   3.637138180102768*^9, 3.637138187356781*^9}, {3.6372445229178095`*^9, 
   3.63724452415388*^9}, {3.6373235561625757`*^9, 3.6373235687302947`*^9}, 
   3.6385157146788*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 "Spatial discretization:   ",
 Cell[BoxData[
  FormBox["\[CapitalDelta]x", TraditionalForm]]],
 "\[Congruent]deltax=Pi/Np where, in this case, we choose  Np=2Nx=40"
}], "Text",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 CellChangeTimes->{{3.561126817421*^9, 3.5611268309564*^9}, {
  3.637138214220028*^9, 3.63713822105284*^9}, {3.6371382858085537`*^9, 
  3.6371382934681673`*^9}, {3.6372446824849367`*^9, 3.637244688716293*^9}, {
  3.6372455356097326`*^9, 3.6372455512256255`*^9}, {3.6373023353903*^9, 
  3.6373023528543*^9}},
 Background->RGBColor[1, 1, 0]],

Cell[BoxData[
 RowBox[{
  RowBox[{"Nx", "=", "20"}], ";", 
  RowBox[{"Np", "=", 
   RowBox[{"2", "*", "Nx"}]}], ";", 
  RowBox[{"deltax", "=", 
   RowBox[{"LL", "/", 
    RowBox[{"(", 
     RowBox[{"2.", "*", "Nx"}], ")"}]}]}], ";"}]], "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 CellChangeTimes->{
  3.561049517788604*^9, 3.561050679357012*^9, {3.5610903980687075`*^9, 
   3.561090407393154*^9}, 3.5611220939094*^9, 3.5611268309564*^9, {
   3.589270600217*^9, 3.589270601552*^9}, 3.589271184201*^9, {
   3.5892976824570417`*^9, 3.589297690719514*^9}, {3.5895180885616817`*^9, 
   3.589518088921702*^9}, 3.5895191624171023`*^9, {3.5895527656894464`*^9, 
   3.5895527660334663`*^9}, {3.5895546010014205`*^9, 
   3.5895546019304733`*^9}, {3.5896016762995996`*^9, 
   3.5896016765648003`*^9}, {3.589602256472*^9, 3.5896022604751997`*^9}, 
   3.5896030482298*^9, 3.589607261262*^9, 3.5897244193129997`*^9, {
   3.589736570752*^9, 3.58973657109*^9}, {3.589892478189557*^9, 
   3.589892479577959*^9}, {3.589896047289415*^9, 3.5898960476124334`*^9}, {
   3.5900402744212723`*^9, 3.5900402746552725`*^9}, {3.5900407451852994`*^9, 
   3.590040745949701*^9}, {3.5900412475908303`*^9, 3.5900412482928314`*^9}, {
   3.5900423256057243`*^9, 3.590042326089325*^9}, {3.5900685957871857`*^9, 
   3.59006859656723*^9}, 3.59007342585645*^9, 3.59021224751*^9, {
   3.5906711458351727`*^9, 3.5906711462141943`*^9}, {3.5907517913939114`*^9, 
   3.5907517917099295`*^9}, {3.591432157985069*^9, 3.591432180683367*^9}, {
   3.591433432296955*^9, 3.591433436503196*^9}, {3.59145199060743*^9, 
   3.591451992849558*^9}, {3.5914533024744644`*^9, 3.5914533051926203`*^9}, {
   3.5915293458577127`*^9, 3.5915293461947317`*^9}, {3.591536410992815*^9, 
   3.591536413805976*^9}, {3.6019157899983253`*^9, 3.6019157928574886`*^9}, {
   3.625846526613616*^9, 3.625846526953616*^9}, {3.625846592786713*^9, 
   3.625846625234762*^9}, 3.626066770157*^9, 3.6371379698887987`*^9, 
   3.63713800489886*^9, {3.637138089029808*^9, 3.6371380899190097`*^9}, {
   3.637138206466814*^9, 3.6371382108036222`*^9}, {3.6371382954961705`*^9, 
   3.637138310440997*^9}, 3.637245208360015*^9, {3.6373238748508043`*^9, 
   3.637323878599018*^9}}]
}, Open  ]],

Cell[TextData[{
 "We set the initial condition:  ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["U", 
    RowBox[{"(", "0", ")"}]], TraditionalForm]]],
 "=UmatrixIni "
}], "Text",
 CellChangeTimes->{{3.636905374736289*^9, 3.636905467120573*^9}, {
  3.637237994529871*^9, 3.637237994660878*^9}, {3.6372449459830074`*^9, 
  3.637244989310486*^9}},
 Background->RGBColor[1, 1, 0]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"UmatrixIni", "=", 
  RowBox[{"Table", "[", " ", 
   RowBox[{
    RowBox[{"Which", "[", 
     RowBox[{
      RowBox[{"j", "\[Equal]", "0"}], ",", "u0value", ",", 
      RowBox[{"j", ">", "0"}], ",", "0."}], "]"}], " ", ",", 
    RowBox[{"{", 
     RowBox[{"j", ",", "0", ",", "Np"}], "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.637326632094509*^9, 3.637326654852811*^9}, 
   3.6373267260018806`*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "1.`", ",", "0.`", ",", "0.`", ",", "0.`", ",", "0.`", ",", "0.`", ",", 
   "0.`", ",", "0.`", ",", "0.`", ",", "0.`", ",", "0.`", ",", "0.`", ",", 
   "0.`", ",", "0.`", ",", "0.`", ",", "0.`", ",", "0.`", ",", "0.`", ",", 
   "0.`", ",", "0.`", ",", "0.`", ",", "0.`", ",", "0.`", ",", "0.`", ",", 
   "0.`", ",", "0.`", ",", "0.`", ",", "0.`", ",", "0.`", ",", "0.`", ",", 
   "0.`", ",", "0.`", ",", "0.`", ",", "0.`", ",", "0.`", ",", "0.`", ",", 
   "0.`", ",", "0.`", ",", "0.`", ",", "0.`", ",", "0.`"}], "}"}]], "Output",
 CellChangeTimes->{3.6385163705668*^9, 3.6386024755596*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Boundary conditions:  u(x=0,t)=uL[t]=u0val=1;   u(x=\[Pi],t)=uR[t]=0.\
\>", "Text",
 CellChangeTimes->{{3.636977189200526*^9, 3.636977192456712*^9}, {
  3.63724504621074*^9, 3.637245086579049*^9}, {3.6373217906595945`*^9, 
  3.6373217950108438`*^9}, {3.637321873059308*^9, 3.6373218767225175`*^9}},
 Background->RGBColor[1, 1, 0]],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"uL", "[", "t_", "]"}], "=", "u0value"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"uR", "[", "t_", "]"}], "=", "0."}], ";"}]}], "Input",
 CellChangeTimes->{
  3.636991916174861*^9, {3.637321880979761*^9, 3.637321891211346*^9}, {
   3.637321947995594*^9, 3.6373219484756217`*^9}, 3.6373229910722547`*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
\[FilledSquare] Numerical results with the T&E method for tolerance  \
\[Tau]=0.001\
\>", "Subsubsection",
 CellChangeTimes->{{3.633439583415289*^9, 3.6334395909637213`*^9}, {
   3.636904756973955*^9, 3.636904760701168*^9}, 3.637138408549569*^9, {
   3.6372452357805834`*^9, 3.6372452451731205`*^9}, {3.6372463821981544`*^9, 
   3.6372463827581863`*^9}, {3.63724964646486*^9, 3.6372496489360013`*^9}, {
   3.6373006334223003`*^9, 3.6373006462943*^9}, {3.6373012081363*^9, 
   3.6373012093343*^9}, 3.6381087309804*^9}],

Cell[CellGroupData[{

Cell[TextData[{
 "uMs is a matrix that contains the full solution ",
 Cell[BoxData[
  FormBox[
   RowBox[{"{", 
    RowBox[{
     SubsuperscriptBox["U", "0", 
      RowBox[{"(", "m", ")"}]], ",", 
     SubsuperscriptBox["U", "1", 
      RowBox[{"(", "m", ")"}]], ",", 
     SubsuperscriptBox["U", "2", 
      RowBox[{"(", "m", ")"}]], ",", 
     RowBox[{"...", " ", 
      SubsuperscriptBox["U", "Np", 
       RowBox[{"(", "m", ")"}]]}]}], "}"}], TraditionalForm]]],
 "  for m=0,1,2,....,numSteps."
}], "Text",
 CellChangeTimes->{{3.6372979828863*^9, 3.6372980614302998`*^9}},
 Background->RGBColor[1, 1, 0.85]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"tolerance", "=", "0.001"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"numSteps", "=", "50"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"CPUtime", "=", 
   RowBox[{"Timing", "[", 
    RowBox[{"uMs", "=", 
     RowBox[{"uMsolutionTE", "[", 
      RowBox[{"numSteps", ",", "tolerance"}], "]"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Print", "[", 
   RowBox[{
   "\"\<Example 3. T&E method. Case with Kg=\>\"", ",", "Kg", ",", 
    "\"\<, \!\(\*SubscriptBox[\(u\), \(0\)]\)=\>\"", ",", "u0value", ",", 
    "\"\<, L=\>\"", ",", "LL", ",", " ", "\"\<, M=\>\"", ",", "Mvalue"}], 
   "]"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"Print", "[", 
   RowBox[{
   "\"\<Numerical T&E solution for tolerance \[Tau]=\>\"", ",", "tolerance", 
    ",", "\"\< \[Gamma]=\>\"", ",", "gammak", ",", "\"\<, Np=\>\"", ",", "Np",
     ",", "\"\<,\!\(TraditionalForm\`\(\(\\\ \)\*SubscriptBox[\(\
\[CapitalDelta]\), \(0\)]\)\)=\>\"", ",", "Delta0TE", ",", 
    "\"\<, \!\(TraditionalForm\`\*SubscriptBox[\(\[CapitalDelta]\), \
\(max\)]\)=\>\"", " ", ",", "DeltatcapTE"}], " ", "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Print", "[", 
   RowBox[{"\"\<CPU time=\>\"", ",", 
    RowBox[{"CPUtime", "[", 
     RowBox[{"[", "1", "]"}], "]"}], ",", "\"\< seconds\>\""}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
  "Print", "[", "\"\<The solution is saved in the matrix uMs\>\"", "]"}], 
  ";"}]}], "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 CellChangeTimes->{{3.56061256346875*^9, 3.56061257284375*^9}, {
   3.56061260303125*^9, 3.560612663828125*^9}, {3.5610884668366947`*^9, 
   3.5610884717649765`*^9}, {3.5611210929323997`*^9, 3.5611211203416*^9}, {
   3.5611212573096*^9, 3.5611212593532*^9}, 3.5611216448120003`*^9, {
   3.5611216844625998`*^9, 3.5611216848213997`*^9}, {3.5611217681558*^9, 
   3.5611217684667997`*^9}, {3.5611222944344*^9, 3.5611223196862*^9}, {
   3.5611253416166*^9, 3.5611253440626*^9}, {3.5611260133876*^9, 
   3.5611260138276*^9}, {3.561127402519*^9, 3.5611274579006*^9}, {
   3.561127527574*^9, 3.5611275627130003`*^9}, {3.5902000697948065`*^9, 
   3.5902000708068647`*^9}, {3.590200323138297*^9, 3.590200324873397*^9}, {
   3.5902003709750333`*^9, 3.5902003711460433`*^9}, 3.590200421820942*^9, 
   3.590213289142*^9, {3.5902135189*^9, 3.590213539836*^9}, {
   3.5902135876359997`*^9, 3.590213616165*^9}, {3.590213707484*^9, 
   3.590213707868*^9}, {3.590213768476*^9, 3.590213768955*^9}, 
   3.5902143461549997`*^9, {3.59021447142*^9, 3.590214495682*^9}, 
   3.5903882375313997`*^9, {3.5903932563884*^9, 3.5903932567464*^9}, {
   3.5903932903714*^9, 3.5903933180104*^9}, {3.5903933542194*^9, 
   3.5903933561303997`*^9}, 3.5903933876914*^9, 3.5903934182594*^9, 
   3.5903941132114*^9, 3.60195384860737*^9, {3.601953894449992*^9, 
   3.601953894987023*^9}, {3.6334400976967044`*^9, 3.6334400980167227`*^9}, 
   3.6369936572364435`*^9, {3.636993750675788*^9, 3.6369937637635365`*^9}, 
   3.637004923308416*^9, 3.6370053615804834`*^9, {3.6372402113622026`*^9, 
   3.637240211367203*^9}, {3.6372452960570307`*^9, 3.6372453605797215`*^9}, {
   3.6372453910404634`*^9, 3.637245428304595*^9}, {3.637245470149988*^9, 
   3.6372455167096515`*^9}, {3.6372456161863413`*^9, 3.637245697827011*^9}, {
   3.637245729372815*^9, 3.637245777960594*^9}, {3.63724584310532*^9, 
   3.6372459587629356`*^9}, {3.637246021107501*^9, 3.6372460259367776`*^9}, {
   3.637246091338518*^9, 3.6372460918335466`*^9}, 3.6372463595788608`*^9, 
   3.637246525799368*^9, {3.6372465623644595`*^9, 3.637246581655563*^9}, {
   3.637246817573056*^9, 3.6372468214022756`*^9}, {3.6372470179475174`*^9, 
   3.637247018278536*^9}, {3.6372471839910145`*^9, 3.6372472107335443`*^9}, {
   3.6372472497587757`*^9, 3.637247279316467*^9}, {3.637247390205809*^9, 
   3.6372473996553497`*^9}, {3.637247443785874*^9, 3.6372474491481805`*^9}, {
   3.637247899618946*^9, 3.6372479030021396`*^9}, {3.637247939714239*^9, 
   3.6372479400092564`*^9}, {3.6372482082135963`*^9, 3.637248224762543*^9}, {
   3.637248553257332*^9, 3.6372485587676473`*^9}, 3.6372496070256042`*^9, 
   3.6372975701323*^9, {3.6372979117462997`*^9, 3.6372979144493*^9}, 
   3.6372981329823*^9, 3.6372981646743*^9, {3.6372982614663*^9, 
   3.6372982617132998`*^9}, {3.6373004952983*^9, 3.6373005432813*^9}, {
   3.6373033665233*^9, 3.6373033817303*^9}, {3.6373234280722494`*^9, 
   3.637323433520561*^9}, {3.6373236020372*^9, 3.637323602360218*^9}, {
   3.637324358832486*^9, 3.6373243809457507`*^9}, {3.637324411766514*^9, 
   3.6373244562360573`*^9}, {3.6373246013003545`*^9, 3.6373246181413174`*^9}, 
   3.637324680909908*^9, {3.6373314548813567`*^9, 3.637331455415387*^9}, 
   3.63736753096211*^9, 3.63736775248378*^9, 3.6381088232194*^9, 
   3.6381088538274*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Example 3. T&E method. Case with Kg=\"\>", "\[InvisibleSpace]",
    "1.`", "\[InvisibleSpace]", "\<\", \\!\\(\\*SubscriptBox[\\(u\\), \
\\(0\\)]\\)=\"\>", "\[InvisibleSpace]", "1.`", 
   "\[InvisibleSpace]", "\<\", L=\"\>", "\[InvisibleSpace]", "4.`", 
   "\[InvisibleSpace]", "\<\", M=\"\>", "\[InvisibleSpace]", "8"}],
  SequenceForm[
  "Example 3. T&E method. Case with Kg=", 1., 
   ", \!\(\*SubscriptBox[\(u\), \(0\)]\)=", 1., ", L=", 4., ", M=", 8],
  Editable->False]], "Print",
 CellChangeTimes->{3.6385163881858*^9, 3.6386024931535997`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Numerical T&E solution for tolerance \[Tau]=\"\>", 
   "\[InvisibleSpace]", "0.001`", "\[InvisibleSpace]", "\<\" \[Gamma]=\"\>", 
   "\[InvisibleSpace]", "0.25`", "\[InvisibleSpace]", "\<\", Np=\"\>", 
   "\[InvisibleSpace]", "40", 
   "\[InvisibleSpace]", "\<\",\\!\\(TraditionalForm\\`\\(\\(\\\\ \
\\)\\*SubscriptBox[\\(\[CapitalDelta]\\), \\(0\\)]\\)\\)=\"\>", 
   "\[InvisibleSpace]", "0.01`", 
   "\[InvisibleSpace]", "\<\", \\!\\(TraditionalForm\\`\\*SubscriptBox[\\(\
\[CapitalDelta]\\), \\(max\\)]\\)=\"\>", "\[InvisibleSpace]", "1.`*^6"}],
  SequenceForm[
  "Numerical T&E solution for tolerance \[Tau]=", 0.001, " \[Gamma]=", 0.25, 
   ", Np=", 40, 
   ",\!\(TraditionalForm\`\(\(\\ \)\*SubscriptBox[\(\[CapitalDelta]\), \(0\)]\
\)\)=", 0.01, 
   ", \!\(TraditionalForm\`\*SubscriptBox[\(\[CapitalDelta]\), \(max\)]\)=", 
   1.*^6],
  Editable->False]], "Print",
 CellChangeTimes->{3.6385163881858*^9, 3.6386024931566*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"CPU time=\"\>", "\[InvisibleSpace]", "17.5345124`", 
   "\[InvisibleSpace]", "\<\" seconds\"\>"}],
  SequenceForm["CPU time=", 17.5345124, " seconds"],
  Editable->False]], "Print",
 CellChangeTimes->{3.6385163881858*^9, 3.6386024931586*^9}],

Cell[BoxData["\<\"The solution is saved in the matrix uMs\"\>"], "Print",
 CellChangeTimes->{3.6385163881858*^9, 3.6386024931596003`*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 "The solution for the m-th timestep is just the m+1 element of this matrix:  \
uMs[[m+1]]=",
 Cell[BoxData[
  FormBox[
   RowBox[{"{", 
    RowBox[{
     SubsuperscriptBox["U", "0", 
      RowBox[{"(", "m", ")"}]], ",", 
     SubsuperscriptBox["U", "1", 
      RowBox[{"(", "m", ")"}]], ",", 
     SubsuperscriptBox["U", "2", 
      RowBox[{"(", "m", ")"}]], ",", 
     RowBox[{"...", " ", 
      SubsuperscriptBox["U", "Np", 
       RowBox[{"(", "m", ")"}]]}]}], "}"}], TraditionalForm]]],
 " "
}], "Text",
 CellChangeTimes->{{3.6372981691743*^9, 3.6372982503743*^9}, {
  3.6372983312943*^9, 3.6372983351903*^9}},
 Background->RGBColor[1, 1, 0.85]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"mStep", "=", "10"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Print", "[", 
   RowBox[{"\"\<The numerical solution at time \>\"", ",", 
    RowBox[{"tt", "[", "mStep", "]"}], ",", "\"\< is:\>\""}], "]"}], ";", 
  RowBox[{"uMs", "[", 
   RowBox[{"[", "mStep", "]"}], "]"}]}]}], "Input",
 CellChangeTimes->{{3.6372983391352997`*^9, 3.6372983412483*^9}, {
  3.6372985221443*^9, 3.6372986028712997`*^9}, {3.637331464114885*^9, 
  3.637331464890929*^9}}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"The numerical solution at time \"\>", "\[InvisibleSpace]", 
   "1.8236576693198`*^-11", "\[InvisibleSpace]", "\<\" is:\"\>"}],
  SequenceForm[
  "The numerical solution at time ", 1.8236576693198*^-11, " is:"],
  Editable->False]], "Print",
 CellChangeTimes->{3.6385163882838*^9, 3.6386024932146*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "1.`", ",", "0.1416646235750763`", ",", "0.01905085840456251`", ",", 
   "0.0024617242548256204`", ",", "0.00030828873406280017`", ",", 
   "0.00003765294816747543`", ",", "4.506357060584812`*^-6", ",", 
   "5.304337125024906`*^-7", ",", "6.158419094970936`*^-8", ",", 
   "7.0687164703028885`*^-9", ",", "8.036245676614144`*^-10", ",", 
   "9.062882260013592`*^-11", ",", "1.0151311422240162`*^-11", ",", 
   "1.1304980239782219`*^-12", ",", "1.2528055904622804`*^-13", ",", 
   "1.3825392310775656`*^-14", ",", "1.5202506015142448`*^-15", ",", 
   "1.666556180658659`*^-16", ",", "1.8221367662036428`*^-17", ",", 
   "1.9877378637144912`*^-18", ",", "2.1641709150836603`*^-19", ",", 
   "2.3523153122997127`*^-20", ",", "2.5531211475987968`*^-21", ",", 
   "2.7676126589781843`*^-22", ",", "2.996892339225599`*^-23", ",", 
   "3.2421456861395734`*^-24", ",", "3.5046465809594075`*^-25", ",", 
   "3.7857632909160397`*^-26", ",", "4.086965100145098`*^-27", ",", 
   "4.409829580956488`*^-28", ",", "4.7560505246744683`*^-29", ",", 
   "5.127446558022707`*^-30", ",", "5.525970477419295`*^-31", ",", 
   "5.953719339660354`*^-32", ",", "6.412945353386034`*^-33", ",", 
   "6.90606762023608`*^-34", ",", "7.435684657807583`*^-35", ",", 
   "8.004576244889302`*^-36", ",", "8.614623734063283`*^-37", ",", 
   "9.165113458184457`*^-38", ",", "0.`"}], "}"}]], "Output",
 CellChangeTimes->{3.6385163882868*^9, 3.6386024932176*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 "The [[m+1,j+1] element of this matrix is the numerical solution for time ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["t", "m"], TraditionalForm]]],
 " and position ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["x", "j"], TraditionalForm]]],
 ":  uMs[[m+1,j+1]]=",
 Cell[BoxData[
  FormBox[
   SubsuperscriptBox["U", "j", 
    RowBox[{"(", "m", ")"}]], TraditionalForm]]],
 " "
}], "Text",
 CellChangeTimes->{{3.6372981691743*^9, 3.6372982503743*^9}, {
  3.6372983312943*^9, 3.6372983351903*^9}, {3.6372983799263*^9, 
  3.6372984925123*^9}},
 Background->RGBColor[1, 1, 0.85]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"mStep", "=", "10"}], ";", 
  RowBox[{"jPos", "=", 
   RowBox[{"Nx", "+", "1"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Print", "[", 
   RowBox[{"\"\<The numerical solution at time t=\>\"", ",", 
    RowBox[{"tt", "[", "mStep", "]"}], ",", "\"\< and position x= \>\"", " ", 
    ",", 
    RowBox[{"jPos", "*", "deltax"}], " ", ",", "\"\< is:\>\""}], "]"}], ";", 
  RowBox[{"uMs", "[", 
   RowBox[{"[", 
    RowBox[{"mStep", ",", "jPos"}], "]"}], "]"}]}]}], "Input",
 CellChangeTimes->{{3.6372983391352997`*^9, 3.6372983412483*^9}, {
  3.6372985221443*^9, 3.6372986028712997`*^9}, {3.6372986373603*^9, 
  3.6372986956313*^9}, {3.6373314727953815`*^9, 3.637331473363414*^9}}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"The numerical solution at time t=\"\>", "\[InvisibleSpace]", 
   "1.8236576693198`*^-11", "\[InvisibleSpace]", "\<\" and position x= \"\>", 
   "\[InvisibleSpace]", "2.1`", "\[InvisibleSpace]", "\<\" is:\"\>"}],
  SequenceForm[
  "The numerical solution at time t=", 1.8236576693198*^-11, 
   " and position x= ", 2.1, " is:"],
  Editable->False]], "Print",
 CellChangeTimes->{3.6385163883008003`*^9, 3.6386024932276*^9}],

Cell[BoxData["2.1641709150836603`*^-19"], "Output",
 CellChangeTimes->{3.6385163883028*^9, 3.6386024932296*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 "A plot comparing the numerical and the exact solution at time ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["t", "mStep"], TraditionalForm]]],
 " "
}], "Text",
 CellChangeTimes->{{3.6372989561913*^9, 3.6372990023753*^9}, {
  3.6372990787602997`*^9, 3.6372990811603003`*^9}},
 Background->RGBColor[1, 1, 0.85]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"mStep", "=", "20"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Print", "[", "\"\<T&E method\>\"", "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Print", "[", 
   RowBox[{
   "\"\<Numerical solution (points) and exact solution (line)  at time \
t=\>\"", ",", 
    RowBox[{"tt", "[", "mStep", "]"}]}], "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{" ", 
  RowBox[{
   RowBox[{"FigNum", "=", 
    RowBox[{"ListPlot", "[", 
     RowBox[{
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"xj", "=", 
           RowBox[{"j", "*", "deltax"}]}], ",", 
          RowBox[{"uMs", "[", 
           RowBox[{"[", 
            RowBox[{
             RowBox[{"mStep", "+", "1"}], ",", 
             RowBox[{"j", "+", "1"}]}], "]"}], "]"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"j", ",", "0", ",", "Np"}], "}"}]}], "]"}], ",", 
      RowBox[{"PlotRange", "\[Rule]", "All"}]}], "]"}]}], ";", 
   RowBox[{"FigExact", "=", 
    RowBox[{"Plot", "[", 
     RowBox[{
      RowBox[{"uSol", "[", 
       RowBox[{"x", ",", 
        RowBox[{"tt", "[", "mStep", "]"}], ",", "gammaVal"}], "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"x", ",", "0", ",", "LL"}], "}"}], ",", 
      RowBox[{"PlotRange", "\[Rule]", "All"}]}], "]"}]}], ";", " ", 
   RowBox[{"Show", "[", 
    RowBox[{"FigNum", ",", "FigExact", ",", 
     RowBox[{"Frame", "\[Rule]", "True"}], ",", 
     RowBox[{"FrameLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<x\>\"", ",", "\"\<u\>\""}], "}"}]}], ",", 
     RowBox[{"PlotRange", "\[Rule]", "All"}]}], "]"}]}]}]}], "Input",
 CellChangeTimes->{{3.6372990098493*^9, 3.6372993557363*^9}, {
   3.6372994017143*^9, 3.6372994018733*^9}, {3.6372994547862997`*^9, 
   3.6372994982653*^9}, {3.6372997348883*^9, 3.6372998253603*^9}, {
   3.6373012862503*^9, 3.6373012895603*^9}, {3.637323731729618*^9, 
   3.637323731976632*^9}, {3.6373242632030163`*^9, 3.6373243106717315`*^9}, 
   3.6373686032924433`*^9, {3.6385157283887997`*^9, 3.6385157469588003`*^9}}],

Cell[BoxData["\<\"T&E method\"\>"], "Print",
 CellChangeTimes->{3.6385163883168*^9, 3.6386024932386*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Numerical solution (points) and exact solution (line)  at time \
t=\"\>", "\[InvisibleSpace]", "1.907309645332589`*^-8"}],
  SequenceForm[
  "Numerical solution (points) and exact solution (line)  at time t=", 
   1.907309645332589*^-8],
  Editable->False]], "Print",
 CellChangeTimes->{3.6385163883168*^9, 3.6386024932406*^9}],

Cell[BoxData[
 GraphicsBox[{{{}, {{}, 
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
      0.012833333333333334`], AbsoluteThickness[1.6], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQBGIQjQo+2M+aCQI77dmbbwlw7L4N5Z+0b3d0Fp43+7i9
iTEIXLZ/m8Hh+/nkZqj8TfvD872m/YhZYA8x54H9nldzV+3e0wVV/9j+6bT5
NtvmlNqnp4HAM/t/v4R/3/ZNhOp/ac+wsMptfaW3/dkzIPDGPjV+8p11S03t
Ye6Snn+OueiDAlT9R/u9JwOkRSK5oOZ/tndNWu54NuGLHUT/F3s+2ccLQ2Pv
20Hs+2bvvF6v3Yz9hB3EvB/2KUypvSqhm+wg5v20t793rvrmvdl2EPN+24dp
HnUxl22FmvfHfvbVV3v3PsmHmvfP/uuNR/GZrBFQ8xgcYth1/C9xO0HVMzi8
iaz/nMGrDTWf0WHB9J7Pr61FoPqZHKqFDc4/M/1nC7GP2WECm2ZcVfMzW4hx
LA5iCVN3WRy4YAsxj8XBfP+16Xce77CFmMfq4GJwaevK8kW2EPPYHCyenvr9
Oq4bah67gzPvfOfdTiVQ8zgc3u1lvPbyWyzUPA4H9z/pAWrKblDzOB3sGwwC
LcINoOZxOYiKb1hwV0oCah63wynfs2J6Rxih5vE4fJledPSA9isbiHk8Dm/6
FyxPcLpsAzGP1yHWa/IrS/c9NhDz+Bwyew9edyxfYgMxj99BLlJC0LWpywZi
noADLAUCAEuAEJc=
       "]]}, {}}, {}}, {{}, {}, 
    {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], Opacity[
     1.], LineBox[CompressedData["
1:eJwVV3c01+8X/9gzMiMisiIRKvR5P/epzELIqhAaSpEQUkZIykhWMopQWdmS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      "]]}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->True,
  FrameLabel->{
    FormBox["\"x\"", TraditionalForm], 
    FormBox["\"u\"", TraditionalForm]},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  Method->{},
  PlotRange->All,
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.02], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.6385163948608*^9, 3.6386025000596*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Here we give a table that compares the numerical and exact solution at the \
point xpos=1, for the first numSteps timesteps. \
\>", "Text",
 CellChangeTimes->{{3.6372981691743*^9, 3.6372982503743*^9}, {
  3.6372983312943*^9, 3.6372983351903*^9}, {3.6372983799263*^9, 
  3.6372984925123*^9}, {3.6372988496542997`*^9, 3.6372989263983*^9}, {
  3.63732393719937*^9, 3.637323945207828*^9}},
 Background->RGBColor[1, 1, 0.85]],

Cell[BoxData[
 RowBox[{
  RowBox[{"headTE", "=", 
   RowBox[{"{", 
    RowBox[{
    "\"\<step\>\"", ",", "\"\<t\>\"", ",", 
     "\"\<\!\(\*SubscriptBox[\(U\), \(\(T &\) E\)]\)(1,t)\>\"", ",", 
     "\"\<\!\(\*SubscriptBox[\(u\), \(exact\)]\)(1,t)\>\"", ",", 
     "\"\<error\>\""}], "}"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.6372462215509663`*^9, 3.6372463423118734`*^9}, {
   3.6372468240104246`*^9, 3.637246824353444*^9}, {3.637324796083495*^9, 
   3.6373248007707634`*^9}, 3.6381088583934*^9}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"xPos", "=", "1."}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"jPos", "=", 
   RowBox[{"Round", "[", 
    RowBox[{"xPos", "/", "deltax"}], "]"}]}], ";", 
  RowBox[{"tabTE", "=", 
   RowBox[{
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"m", ",", 
        RowBox[{"tt", "[", "m", "]"}], ",", 
        RowBox[{"uMs", "[", 
         RowBox[{"[", 
          RowBox[{
           RowBox[{"m", "+", "1"}], ",", 
           RowBox[{"jPos", "+", "1"}]}], "]"}], "]"}], ",", 
        RowBox[{"uSol", "[", 
         RowBox[{"xPos", ",", 
          RowBox[{"tt", "[", "m", "]"}], ",", "gammaVal"}], "]"}], ",", 
        RowBox[{
         RowBox[{"uMs", "[", 
          RowBox[{"[", 
           RowBox[{
            RowBox[{"m", "+", "1"}], ",", 
            RowBox[{"jPos", "+", "1"}]}], "]"}], "]"}], "-", 
         RowBox[{"uSol", "[", 
          RowBox[{"xPos", ",", 
           RowBox[{"tt", "[", "m", "]"}], ",", "gammaVal"}], "]"}]}]}], "}"}],
       ",", 
      RowBox[{"{", 
       RowBox[{"m", ",", "0", ",", "numSteps"}], "}"}]}], "]"}], "//", 
    "N"}]}], ";", 
  RowBox[{
   RowBox[{"Insert", "[", 
    RowBox[{"tabTE", ",", "headTE", ",", "1"}], "]"}], "//", 
   "TableForm"}]}]}], "Input",
 CellChangeTimes->{
  3.6372987625292997`*^9, {3.6373235184064164`*^9, 3.6373235247327785`*^9}, {
   3.637323580099945*^9, 3.637323582258068*^9}, {3.6373239516731977`*^9, 
   3.6373239865441923`*^9}, {3.6373240235533094`*^9, 3.637324146326331*^9}, {
   3.6373253220205774`*^9, 3.6373253234056563`*^9}, {3.637327542845601*^9, 
   3.637327551932121*^9}, 3.6373690542212353`*^9}],

Cell[BoxData[
 TagBox[GridBox[{
    {"\<\"step\"\>", "\<\"t\"\>", "\<\"\\!\\(\\*SubscriptBox[\\(U\\), \\(\\(T \
&\\) E\\)]\\)(1,t)\"\>", "\<\"\\!\\(\\*SubscriptBox[\\(u\\), \
\\(exact\\)]\\)(1,t)\"\>", "\<\"error\"\>"},
    {"0.`", "0.`", "0.`", "0.`", "0.`"},
    {"1.`", "7.105427357601002`*^-17", "1.5489759888526`*^-21", "0.`", 
     "1.5489759888526`*^-21"},
    {"2.`", "1.2079226507921704`*^-15", "1.692418294463268`*^-18", "0.`", 
     "1.692418294463268`*^-18"},
    {"3.`", "1.0302869668521452`*^-14", "2.8603924613086465`*^-16", "0.`", 
     "2.8603924613086465`*^-16"},
    {"4.`", "4.6682657739438584`*^-14", "9.373645557949557`*^-15", 
     "3.3865453501716715`*^-24", "9.373645554563012`*^-15"},
    {"5.`", "1.922018100231071`*^-13", "2.3869833850678067`*^-13", 
     "5.2356898866554533`*^-20", "2.386982861498818`*^-13"},
    {"6.`", "7.742784191577812`*^-13", "5.2461579731660396`*^-12", 
     "1.261754081185682`*^-16", "5.246031797757921`*^-12"},
    {"7.`", "1.9384316374271293`*^-12", "3.542833983336448`*^-11", 
     "9.808883470842893`*^-15", "3.5418530949893635`*^-11"},
    {"8.`", "4.266738073965826`*^-12", "1.8086209710816144`*^-10", 
     "2.708539740281346`*^-13", "1.805912431341333`*^-10"},
    {"9.`", "8.923350947043218`*^-12", "8.036245676614144`*^-10", 
     "4.397192549365253`*^-12", "7.992273751120491`*^-10"},
    {"10.`", "1.8236576693198`*^-11", "3.2629288442154226`*^-9", 
     "5.035857267109973`*^-11", "3.212570271544323`*^-9"},
    {"11.`", "3.6863028185507575`*^-11", "1.2347357030314733`*^-8", 
     "4.426104962909186`*^-10", "1.1904746534023815`*^-8"},
    {"12.`", "7.411593117012671`*^-11", "4.3891272370877174`*^-8", 
     "3.127766164226016`*^-9", "4.076350620665116`*^-8"},
    {"13.`", "1.48621737139365`*^-10", "1.4694861245858615`*^-7", 
     "1.8311605544750733`*^-8", "1.2863700691383543`*^-7"},
    {"14.`", "2.9763334907784155`*^-10", "4.635505437825812`*^-7", 
     "9.078300171772522`*^-8", "3.72767542064856`*^-7"},
    {"15.`", "5.956565729547946`*^-10", "1.377167328988377`*^-6", 
     "3.8785457426219713`*^-7", "9.893127547261799`*^-7"},
    {"16.`", "1.1917030207087008`*^-9", "3.851440708458644`*^-6", 
     "1.4492726464839986`*^-6", "2.402168061974645`*^-6"},
    {"17.`", "2.383795916216513`*^-9", "0.000010137517921670733`", 
     "4.798075704039417`*^-6", "5.339442217631316`*^-6"},
    {"18.`", "4.7679817072321386`*^-9", "0.00002512153596497626`", 
     "0.000014236900175375413`", "0.000010884635789600847`"},
    {"19.`", "9.53635328926339`*^-9", "0.00005865879419795148`", 
     "0.000038253952818296845`", "0.000020404841379654638`"},
    {"20.`", "1.907309645332589`*^-8", "0.00012923614295101072`", 
     "0.00009394808748964356`", "0.000035288055461367166`"},
    {"21.`", "3.814658278145089`*^-8", "0.0002691481870997935`", 
     "0.00021266584340356756`", "0.00005648234369622592`"},
    {"22.`", "7.62935554377009`*^-8", "0.0005310261090410074`", 
     "0.0004470993107695562`", "0.00008392679827145123`"},
    {"23.`", "1.5258750075020088`*^-7", "0.0009950563055265201`", 
     "0.0008790043856313845`", "0.00011605191989513559`"},
    {"24.`", "3.051753913752009`*^-7", "0.001775699951412529`", 
     "0.0016261475773698716`", "0.00014955237404265737`"},
    {"25.`", "6.10351172625201`*^-7", "0.0030263660565442224`", 
     "0.0028467931521818815`", "0.0001795729043623409`"},
    {"26.`", "1.220702735125201`*^-6", "0.0049404759434240495`", 
     "0.004740156416740758`", "0.00020031952668329162`"},
    {"27.`", "2.4414058601252013`*^-6", "0.007747762549698765`", 
     "0.007541794607704462`", "0.00020596794199430248`"},
    {"28.`", "4.882812110125201`*^-6", "0.011705408020695137`", 
     "0.011513759104240337`", "0.00019164891645480006`"},
    {"29.`", "9.7656246101252`*^-6", "0.01708454517579526`", 
     "0.016930270060006067`", "0.00015427511578919306`"},
    {"30.`", "0.0000195312496101252`", "0.024153496970089228`", 
     "0.02406046178850238`", "0.00009303518158684798`"},
    {"31.`", "0.0000390624996101252`", "0.033159697826510605`", 
     "0.03315021135633111`", "9.486470179495554`*^-6"},
    {"32.`", "0.0000781249996101252`", "0.04431239707603978`", 
     "0.04440513480627854`", 
     RowBox[{"-", "0.00009273773023876081`"}]},
    {"33.`", "0.0001562499996101252`", "0.05776807370411792`", 
     "0.05797655023042084`", 
     RowBox[{"-", "0.00020847652630291702`"}]},
    {"34.`", "0.0003124999996101252`", "0.07361991836776081`", 
     "0.07395167258108162`", 
     RowBox[{"-", "0.000331754213320809`"}]},
    {"35.`", "0.0006249999996101251`", "0.09189225522574278`", 
     "0.09234865887462512`", 
     RowBox[{"-", "0.00045640364888234475`"}]},
    {"36.`", "0.001249999999610125`", "0.11253978609403445`", 
     "0.1131164902524892`", 
     RowBox[{"-", "0.0005767041584547467`"}]},
    {"37.`", "0.002499999999610125`", "0.1354514134142632`", 
     "0.1361391466144702`", 
     RowBox[{"-", "0.0006877332002070136`"}]},
    {"38.`", "0.004999999999610125`", "0.1604569869949962`", 
     "0.16124313935142076`", 
     RowBox[{"-", "0.0007861523564245687`"}]},
    {"39.`", "0.009999999999610126`", "0.18733755474707395`", 
     "0.18820721837523502`", 
     RowBox[{"-", "0.0008696636281610715`"}]},
    {"40.`", "0.019999999999610128`", "0.21583851564481593`", 
     "0.21677294954255766`", 
     RowBox[{"-", "0.0009344338977417266`"}]},
    {"41.`", "0.039999999999610125`", "0.24567035167893372`", 
     "0.24665487702126707`", 
     RowBox[{"-", "0.0009845253423333422`"}]},
    {"42.`", "0.07999999999961013`", "0.276531315350506`", 
     "0.2775491869549355`", 
     RowBox[{"-", "0.00101787160442951`"}]},
    {"43.`", "0.15999999999961012`", "0.3081015194135337`", 
     "0.3091402260752081`", 
     RowBox[{"-", "0.0010387066616743823`"}]},
    {"44.`", "0.31999999999961015`", "0.34008061640136833`", 
     "0.3411048931266496`", 
     RowBox[{"-", "0.0010242767252812701`"}]},
    {"45.`", "0.6399999999996102`", "0.3720890178668169`", 
     "0.3731156791625935`", 
     RowBox[{"-", "0.0010266612957766097`"}]},
    {"46.`", "1.2799999999996103`", "0.40388521879758565`", 
     "0.4048437301774968`", 
     RowBox[{"-", "0.0009585113799111533`"}]},
    {"47.`", "2.5599999999996106`", "0.43506743195960446`", 
     "0.43596346213196435`", 
     RowBox[{"-", "0.0008960301723598962`"}]},
    {"48.`", "5.11999999999961`", "0.46532057081642053`", 
     "0.46615981947257584`", 
     RowBox[{"-", "0.0008392486561553114`"}]},
    {"49.`", "10.239999999999611`", "0.49438614666567193`", 
     "0.4951383194818556`", 
     RowBox[{"-", "0.0007521728161836716`"}]},
    {"50.`", "20.479999999999613`", "0.5219524823967164`", 
     "0.5226368919740411`", 
     RowBox[{"-", "0.0006844095773246295`"}]}
   },
   GridBoxAlignment->{
    "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
     "RowsIndexed" -> {}},
   GridBoxSpacings->{"Columns" -> {
       Offset[0.27999999999999997`], {
        Offset[2.0999999999999996`]}, 
       Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
       Offset[0.2], {
        Offset[0.4]}, 
       Offset[0.2]}, "RowsIndexed" -> {}}],
  Function[BoxForm`e$, 
   TableForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{3.6385163980948*^9, 3.6386025033646*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 "A plot comparing the numerical and the exact solution at  position x=xpos \
for times  t  with   0\[LessEqual]t\[LessEqual] ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["t", "numSteps"], TraditionalForm]]],
 " "
}], "Text",
 CellChangeTimes->{{3.6372989561913*^9, 3.6372990023753*^9}, {
  3.6372990787602997`*^9, 3.6372990811603003`*^9}, {3.6372998614302998`*^9, 
  3.6372998879683*^9}, {3.6373004057753*^9, 3.6373004634223003`*^9}, {
  3.6373242013104763`*^9, 3.637324201926512*^9}},
 Background->RGBColor[1, 1, 0.85]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"Print", "[", "\"\<T&E method\>\"", "]"}], ";", 
  RowBox[{"Print", "[", 
   RowBox[{
   "\"\<Numerical solution (points) and exact solution (line) at position \
x=\>\"", ",", "xPos", ",", "\"\< vs. time\>\""}], "]"}], ";", " ", 
  RowBox[{"FigNum", "=", 
   RowBox[{"ListPlot", "[", 
    RowBox[{
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"tabTE", "[", 
          RowBox[{"[", 
           RowBox[{"n", ",", "2"}], "]"}], "]"}], ",", 
         RowBox[{"tabTE", "[", 
          RowBox[{"[", 
           RowBox[{"n", ",", "3"}], "]"}], "]"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"n", ",", "1", ",", "numSteps"}], "}"}]}], "]"}], ",", 
     RowBox[{"PlotRange", "\[Rule]", "All"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"FigExact", "=", 
   RowBox[{"Plot", "[", 
    RowBox[{
     RowBox[{"uSol", "[", 
      RowBox[{"xPos", ",", "time", ",", "gammaVal"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"time", ",", "0", ",", 
       RowBox[{"1.1", "*", 
        RowBox[{"tabTE", "[", 
         RowBox[{"[", 
          RowBox[{
           RowBox[{"numSteps", "+", "1"}], ",", "2"}], "]"}], "]"}]}]}], 
      "}"}], ",", 
     RowBox[{"PlotRange", "\[Rule]", "All"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"Show", "[", 
  RowBox[{"FigNum", ",", "FigExact", ",", 
   RowBox[{"Frame", "\[Rule]", "True"}], ",", 
   RowBox[{"FrameLabel", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"\"\<time\>\"", ",", "\"\<u\>\""}], "}"}]}], ",", 
   RowBox[{"PlotRange", "\[Rule]", "All"}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.6372990098493*^9, 3.6372993557363*^9}, {
   3.6372994017143*^9, 3.6372994018733*^9}, {3.6372994547862997`*^9, 
   3.6372994982653*^9}, {3.6372997348883*^9, 3.6372998253603*^9}, {
   3.6372999061773*^9, 3.6372999638333*^9}, {3.6373000656813*^9, 
   3.6373002790032997`*^9}, {3.6373003226673*^9, 3.6373003301463003`*^9}, 
   3.6373012777063*^9, 3.6373013767462997`*^9, 3.6373014286173*^9, 
   3.6373017989203*^9, 3.6373211076755304`*^9, {3.6373236515230303`*^9, 
   3.6373236666498957`*^9}, {3.6373242118020763`*^9, 3.63732421291214*^9}, 
   3.6373242494332285`*^9, 3.637325329974032*^9, 3.6373254446095886`*^9, 
   3.637369174164096*^9, {3.6385157592118*^9, 3.6385157662488003`*^9}, 
   3.6385159467148*^9, {3.6385160985508003`*^9, 3.6385161024217997`*^9}}],

Cell[BoxData["\<\"T&E method\"\>"], "Print",
 CellChangeTimes->{3.6385163981728*^9, 3.6386025034026003`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Numerical solution (points) and exact solution (line) at \
position x=\"\>", "\[InvisibleSpace]", "1.`", 
   "\[InvisibleSpace]", "\<\" vs. time\"\>"}],
  SequenceForm[
  "Numerical solution (points) and exact solution (line) at position x=", 1., 
   " vs. time"],
  Editable->False]], "Print",
 CellChangeTimes->{3.6385163981728*^9, 3.6386025034046*^9}],

Cell[BoxData[
 GraphicsBox[{{{}, {{}, 
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
      0.011000000000000001`], AbsoluteThickness[1.6], PointBox[CompressedData["
1:eJxdkmtI02EUxl3NDLNSG2VKw8jywj5kWhjtfc80l6LlDcsvZlA6JSsvG5qv
abdlGWSbRaktXG4ukzQzQSUx5maWqTO15iai/7IbecumktHl/fexB15efh/O
4TnnPJuPZsSlLLOzs9tBH/v/r3xefRhDbgpn5OdSjoXc3WOY90m83vFGqLTk
C4KCQBjwTw6od6PrtkJVkzCcIbTCD6mSzJPFHvaot4fKKRJl/Yrt5vTEILYb
D6ejqH2c9TrX28iXdpt3Oo/epUznuBEDimvhX/pqKEUbNDAnH/mMJKwqNejn
glmnV63CmcjRvGV1E+LMrNUGOwjwArWzLNSIbuX6cVfKIzBbnnVkCKmYlyNJ
ilRcUV5e7ntyAnkOeNduar2IHc2aTHuZDdW/WGtt86jEHXQeaS4X669aC967
N2NaHuuXx8O9/VPzUu9+zNq3J174z2+VtTjkA9ZmoqtSEoil5uN9FxKWsKJj
Pq2WhOK+uYMDTvo1UPQ1driTxGOPyr7l2bOeQFeoGCTJ2P9e9IMSjT9QA+lW
IsOPrnS+U0qCgY5vGSVyXLZ4rVR5IAYmY1sUY+QmdkOcqMENhyEwIODEONHi
kpyqT8+602BYM2sZJ01YWlfzJUcoA79EkzNDjDgrJELAbzsLcS1YwJAhzJ/h
iTk/LoNEsrCbIRP4TOD2dFWhEjLRgIghNuy8N7z98dMyWPARhTKEC1Ol6YNR
S2po4S+K6YUgLPdszKYGHVSUD+xjiBe491R+fH6jDhwTRPSCgTAmbhXrhxuh
Y2cu5VC4s/f7LlFRM/CrSynHQ0l/5/40Uxv0JKopJ8Ott6mm04f0oA26T1kG
kdIug7XYCApdLWU5fDPkRdctdUHR4Yds3kDx2NZYpn4FdrvrKGtBnOoQ5plt
gnYdy03QwJ2VNDS+BtUoy0a4UnMqY6Z5EJx+sDwEgqrEAsbwBowr2MRNQASv
TRbVbwb1apZt4PNEfizYYoE1LixzRdUlNpetwyNgdP2XUFE4RzZt6hoF9TqW
vUTtSqbbXjsGfwH/D35e
       "]]}, {}}, {}}, {{}, {}, 
    {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], Opacity[
     1.], LineBox[CompressedData["
1:eJwVznk41XkDBXBMSBuqsUxIZd+upFsi55tCIRolSzvFqEiDCCW0YLwyKiUk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      "]]}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->True,
  FrameLabel->{
    FormBox["\"time\"", TraditionalForm], 
    FormBox["\"u\"", TraditionalForm]},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  Method->{},
  PlotRange->All,
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.02], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.6385164142918*^9, 3.6386025190165997`*^9}]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 "\[FilledSquare] Numerical results with the ",
 StyleBox["predictive",
  FontSlant->"Italic"],
 " method for tolerance  \[Tau]=0.001"
}], "Subsubsection",
 CellChangeTimes->{{3.633439583415289*^9, 3.6334395909637213`*^9}, {
   3.636904756973955*^9, 3.636904760701168*^9}, 3.637138408549569*^9, {
   3.6372452357805834`*^9, 3.6372452451731205`*^9}, {3.6372463821981544`*^9, 
   3.6372463827581863`*^9}, {3.63724964646486*^9, 3.6372496489360013`*^9}, {
   3.6373006334223003`*^9, 3.6373006462943*^9}, {3.6373012081363*^9, 
   3.6373012093343*^9}, 3.637324917549443*^9}],

Cell[CellGroupData[{

Cell[TextData[{
 "uMs is a matrix that contains the full solution ",
 Cell[BoxData[
  FormBox[
   RowBox[{"{", 
    RowBox[{
     SubsuperscriptBox["U", "0", 
      RowBox[{"(", "m", ")"}]], ",", 
     SubsuperscriptBox["U", "1", 
      RowBox[{"(", "m", ")"}]], ",", 
     SubsuperscriptBox["U", "2", 
      RowBox[{"(", "m", ")"}]], ",", 
     RowBox[{"...", " ", 
      SubsuperscriptBox["U", "Np", 
       RowBox[{"(", "m", ")"}]]}]}], "}"}], TraditionalForm]]],
 "  for m=0,1,2,....,numSteps."
}], "Text",
 CellChangeTimes->{{3.6372979828863*^9, 3.6372980614302998`*^9}},
 Background->RGBColor[1, 1, 0.85]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"tolerance", "=", "0.001"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"numSteps", "=", "50"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"CPUtime", "=", 
   RowBox[{"Timing", "[", 
    RowBox[{"uMs", "=", 
     RowBox[{"uMsolutionPredictive", "[", 
      RowBox[{"numSteps", ",", "tolerance"}], "]"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Print", "[", 
   RowBox[{
   "\"\<Example 3. Predictive method. Case with Kg=\>\"", ",", "Kg", ",", 
    "\"\<, \!\(\*SubscriptBox[\(u\), \(0\)]\)=\>\"", ",", "u0value", ",", 
    "\"\<, L=\>\"", ",", "LL", ",", " ", "\"\<, M=\>\"", ",", "Mvalue"}], 
   "]"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"Print", "[", 
   RowBox[{
   "\"\<Numerical Predictive solution for tolerance \[Tau]=\>\"", ",", 
    "tolerance", ",", "\"\< \[Gamma]=\>\"", ",", "gammak", ",", 
    "\"\<, Np=\>\"", ",", "Np", ",", 
    "\"\<,\!\(TraditionalForm\`\(\(\\\ \)\*SubscriptBox[\(\[CapitalDelta]\), \
\(0\)]\)\)=\>\"", ",", "Delta0Predictive", ",", 
    "\"\<, \!\(TraditionalForm\`\*SubscriptBox[\(\[CapitalDelta]\), \
\(max\)]\)=\>\"", " ", ",", 
    RowBox[{"DeltatcapPredictive", "   ", "\"\<,\[Omega]=\>\""}], ",", "  ", 
    "omegaParameter", ",", " ", 
    "\"\<,\!\(TraditionalForm\`\(\(\\\ \)\(\[Theta]\)\)\)=\>\"", ",", "  ", 
    "thetaParameter"}], " ", "  ", "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Print", "[", 
   RowBox[{"\"\<CPU time=\>\"", ",", 
    RowBox[{"CPUtime", "[", 
     RowBox[{"[", "1", "]"}], "]"}], ",", "\"\< seconds\>\""}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
  "Print", "[", "\"\<The solution is saved in the matrix uMs\>\"", "]"}], 
  ";"}]}], "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 CellChangeTimes->{{3.56061256346875*^9, 3.56061257284375*^9}, {
   3.56061260303125*^9, 3.560612663828125*^9}, {3.5610884668366947`*^9, 
   3.5610884717649765`*^9}, {3.5611210929323997`*^9, 3.5611211203416*^9}, {
   3.5611212573096*^9, 3.5611212593532*^9}, 3.5611216448120003`*^9, {
   3.5611216844625998`*^9, 3.5611216848213997`*^9}, {3.5611217681558*^9, 
   3.5611217684667997`*^9}, {3.5611222944344*^9, 3.5611223196862*^9}, {
   3.5611253416166*^9, 3.5611253440626*^9}, {3.5611260133876*^9, 
   3.5611260138276*^9}, {3.561127402519*^9, 3.5611274579006*^9}, {
   3.561127527574*^9, 3.5611275627130003`*^9}, {3.5902000697948065`*^9, 
   3.5902000708068647`*^9}, {3.590200323138297*^9, 3.590200324873397*^9}, {
   3.5902003709750333`*^9, 3.5902003711460433`*^9}, 3.590200421820942*^9, 
   3.590213289142*^9, {3.5902135189*^9, 3.590213539836*^9}, {
   3.5902135876359997`*^9, 3.590213616165*^9}, {3.590213707484*^9, 
   3.590213707868*^9}, {3.590213768476*^9, 3.590213768955*^9}, 
   3.5902143461549997`*^9, {3.59021447142*^9, 3.590214495682*^9}, 
   3.5903882375313997`*^9, {3.5903932563884*^9, 3.5903932567464*^9}, {
   3.5903932903714*^9, 3.5903933180104*^9}, {3.5903933542194*^9, 
   3.5903933561303997`*^9}, 3.5903933876914*^9, 3.5903934182594*^9, 
   3.5903941132114*^9, 3.60195384860737*^9, {3.601953894449992*^9, 
   3.601953894987023*^9}, {3.6334400976967044`*^9, 3.6334400980167227`*^9}, 
   3.6369936572364435`*^9, {3.636993750675788*^9, 3.6369937637635365`*^9}, 
   3.637004923308416*^9, 3.6370053615804834`*^9, {3.6372402113622026`*^9, 
   3.637240211367203*^9}, {3.6372452960570307`*^9, 3.6372453605797215`*^9}, {
   3.6372453910404634`*^9, 3.637245428304595*^9}, {3.637245470149988*^9, 
   3.6372455167096515`*^9}, {3.6372456161863413`*^9, 3.637245697827011*^9}, {
   3.637245729372815*^9, 3.637245777960594*^9}, {3.63724584310532*^9, 
   3.6372459587629356`*^9}, {3.637246021107501*^9, 3.6372460259367776`*^9}, {
   3.637246091338518*^9, 3.6372460918335466`*^9}, 3.6372463595788608`*^9, 
   3.637246525799368*^9, {3.6372465623644595`*^9, 3.637246581655563*^9}, {
   3.637246817573056*^9, 3.6372468214022756`*^9}, {3.6372470179475174`*^9, 
   3.637247018278536*^9}, {3.6372471839910145`*^9, 3.6372472107335443`*^9}, {
   3.6372472497587757`*^9, 3.637247279316467*^9}, {3.637247390205809*^9, 
   3.6372473996553497`*^9}, {3.637247443785874*^9, 3.6372474491481805`*^9}, {
   3.637247899618946*^9, 3.6372479030021396`*^9}, {3.637247939714239*^9, 
   3.6372479400092564`*^9}, {3.6372482082135963`*^9, 3.637248224762543*^9}, {
   3.637248553257332*^9, 3.6372485587676473`*^9}, 3.6372496070256042`*^9, 
   3.6372975701323*^9, {3.6372979117462997`*^9, 3.6372979144493*^9}, 
   3.6372981329823*^9, 3.6372981646743*^9, {3.6372982614663*^9, 
   3.6372982617132998`*^9}, {3.6373004952983*^9, 3.6373005432813*^9}, {
   3.6373033665233*^9, 3.6373033817303*^9}, {3.6373234280722494`*^9, 
   3.637323433520561*^9}, {3.6373236020372*^9, 3.637323602360218*^9}, {
   3.637324358832486*^9, 3.6373243809457507`*^9}, {3.637324411766514*^9, 
   3.6373244562360573`*^9}, {3.6373246013003545`*^9, 3.6373246181413174`*^9}, 
   3.637324680909908*^9, {3.6373249522884297`*^9, 3.6373249523544335`*^9}, 
   3.637326018017386*^9, 3.6373262662925863`*^9, {3.6373269464134874`*^9, 
   3.637326946825511*^9}, {3.637329087371943*^9, 3.6373290893580565`*^9}, {
   3.637331528856588*^9, 3.637331529871646*^9}, 3.6373675927076416`*^9, {
   3.637367935200231*^9, 3.637367936257292*^9}}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Example 3. Predictive method. Case with Kg=\"\>", 
   "\[InvisibleSpace]", "1.`", 
   "\[InvisibleSpace]", "\<\", \\!\\(\\*SubscriptBox[\\(u\\), \
\\(0\\)]\\)=\"\>", "\[InvisibleSpace]", "1.`", 
   "\[InvisibleSpace]", "\<\", L=\"\>", "\[InvisibleSpace]", "4.`", 
   "\[InvisibleSpace]", "\<\", M=\"\>", "\[InvisibleSpace]", "8"}],
  SequenceForm[
  "Example 3. Predictive method. Case with Kg=", 1., 
   ", \!\(\*SubscriptBox[\(u\), \(0\)]\)=", 1., ", L=", 4., ", M=", 8],
  Editable->False]], "Print",
 CellChangeTimes->{3.6385164241538*^9, 3.6386025288006*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Numerical Predictive solution for tolerance \[Tau]=\"\>", 
   "\[InvisibleSpace]", "0.001`", "\[InvisibleSpace]", "\<\" \[Gamma]=\"\>", 
   "\[InvisibleSpace]", "0.25`", "\[InvisibleSpace]", "\<\", Np=\"\>", 
   "\[InvisibleSpace]", "40", 
   "\[InvisibleSpace]", "\<\",\\!\\(TraditionalForm\\`\\(\\(\\\\ \
\\)\\*SubscriptBox[\\(\[CapitalDelta]\\), \\(0\\)]\\)\\)=\"\>", 
   "\[InvisibleSpace]", "0.01`", 
   "\[InvisibleSpace]", "\<\", \\!\\(TraditionalForm\\`\\*SubscriptBox[\\(\
\[CapitalDelta]\\), \\(max\\)]\\)=\"\>", "\[InvisibleSpace]", 
   RowBox[{"1.`*^6", " ", "\<\",\[Omega]=\"\>"}], "\[InvisibleSpace]", "0.5`",
    "\[InvisibleSpace]", "\<\",\\!\\(TraditionalForm\\`\\(\\(\\\\ \\)\\(\
\[Theta]\\)\\)\\)=\"\>", "\[InvisibleSpace]", "1.5`"}],
  SequenceForm[
  "Numerical Predictive solution for tolerance \[Tau]=", 0.001, " \[Gamma]=", 
   0.25, ", Np=", 40, 
   ",\!\(TraditionalForm\`\(\(\\ \)\*SubscriptBox[\(\[CapitalDelta]\), \(0\)]\
\)\)=", 0.01, 
   ", \!\(TraditionalForm\`\*SubscriptBox[\(\[CapitalDelta]\), \(max\)]\)=", 
   1.*^6 ",\[Omega]=", 0.5, 
   ",\!\(TraditionalForm\`\(\(\\ \)\(\[Theta]\)\)\)=", 1.5],
  Editable->False]], "Print",
 CellChangeTimes->{3.6385164241538*^9, 3.6386025288196*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"CPU time=\"\>", "\[InvisibleSpace]", "9.7188623`", 
   "\[InvisibleSpace]", "\<\" seconds\"\>"}],
  SequenceForm["CPU time=", 9.7188623, " seconds"],
  Editable->False]], "Print",
 CellChangeTimes->{3.6385164241538*^9, 3.6386025288216*^9}],

Cell[BoxData["\<\"The solution is saved in the matrix uMs\"\>"], "Print",
 CellChangeTimes->{3.6385164241538*^9, 3.6386025288226*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 "The solution for the m-th timestep is just the m+1 element of this matrix:  \
uMs[[m+1]]=",
 Cell[BoxData[
  FormBox[
   RowBox[{"{", 
    RowBox[{
     SubsuperscriptBox["U", "0", 
      RowBox[{"(", "m", ")"}]], ",", 
     SubsuperscriptBox["U", "1", 
      RowBox[{"(", "m", ")"}]], ",", 
     SubsuperscriptBox["U", "2", 
      RowBox[{"(", "m", ")"}]], ",", 
     RowBox[{"...", " ", 
      SubsuperscriptBox["U", "Np", 
       RowBox[{"(", "m", ")"}]]}]}], "}"}], TraditionalForm]]],
 " "
}], "Text",
 CellChangeTimes->{{3.6372981691743*^9, 3.6372982503743*^9}, {
  3.6372983312943*^9, 3.6372983351903*^9}},
 Background->RGBColor[1, 1, 0.85]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"mStep", "=", "5"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Print", "[", 
   RowBox[{"\"\<The numerical solution at time \>\"", ",", 
    RowBox[{"tt", "[", "mStep", "]"}], ",", "\"\< is:\>\""}], "]"}], ";", 
  RowBox[{"uMs", "[", 
   RowBox[{"[", "mStep", "]"}], "]"}]}]}], "Input",
 CellChangeTimes->{{3.6372983391352997`*^9, 3.6372983412483*^9}, {
  3.6372985221443*^9, 3.6372986028712997`*^9}}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"The numerical solution at time \"\>", "\[InvisibleSpace]", 
   "2.7215099495888163`*^-13", "\[InvisibleSpace]", "\<\" is:\"\>"}],
  SequenceForm[
  "The numerical solution at time ", 2.7215099495888163`*^-13, " is:"],
  Editable->False]], "Print",
 CellChangeTimes->{3.6385164242258*^9, 3.6386025288445997`*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "1.`", ",", "0.05278553865519516`", ",", "0.0026038673637762233`", ",", 
   "0.00012274951086872093`", ",", "5.607578211357658`*^-6", ",", 
   "2.505332528994038`*^-7", ",", "1.1015384703739008`*^-8", ",", 
   "4.787082317746702`*^-10", ",", "2.062651121922494`*^-11", ",", 
   "8.831526752887701`*^-13", ",", "3.7636474461415335`*^-14", ",", 
   "1.5983254397560837`*^-15", ",", "6.770001871164185`*^-17", ",", 
   "2.861967956984897`*^-18", ",", "1.2081071769174633`*^-19", ",", 
   "5.094122910650645`*^-21", ",", "2.146225054213074`*^-22", ",", 
   "9.03674224600927`*^-24", ",", "3.803172646707559`*^-25", ",", 
   "1.6000288423934223`*^-26", ",", "6.729687190254093`*^-28", ",", 
   "2.82992922620553`*^-29", ",", "1.1898472813266266`*^-30", ",", 
   "5.002163380800748`*^-32", ",", "2.1027498438222512`*^-33", ",", 
   "8.838723228873309`*^-35", ",", "3.715099971085644`*^-36", ",", 
   "1.5614773334536437`*^-37", ",", "6.56279690680496`*^-39", ",", 
   "2.7582477848939422`*^-40", ",", "1.1592332617480777`*^-41", ",", 
   "4.8719553205530145`*^-43", ",", "2.0475377705214843`*^-44", ",", 
   "8.605134332188374`*^-46", ",", "3.6164395234936267`*^-47", ",", 
   "1.5198583597146056`*^-48", ",", "6.387395206556865`*^-50", ",", 
   "2.684377091729621`*^-51", ",", "1.128135346175752`*^-52", ",", 
   "4.7327476020532426`*^-54", ",", "0.`"}], "}"}]], "Output",
 CellChangeTimes->{3.6385164242298*^9, 3.6386025288466*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 "The [[m+1,j+1] element of this matrix is the numerical solution for time ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["t", "m"], TraditionalForm]]],
 " and position ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["x", "j"], TraditionalForm]]],
 ":  uMs[[m+1,j+1]]=",
 Cell[BoxData[
  FormBox[
   SubsuperscriptBox["U", "j", 
    RowBox[{"(", "m", ")"}]], TraditionalForm]]],
 " "
}], "Text",
 CellChangeTimes->{{3.6372981691743*^9, 3.6372982503743*^9}, {
  3.6372983312943*^9, 3.6372983351903*^9}, {3.6372983799263*^9, 
  3.6372984925123*^9}},
 Background->RGBColor[1, 1, 0.85]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"mStep", "=", "5"}], ";", 
  RowBox[{"jPos", "=", 
   RowBox[{"Nx", "+", "1"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Print", "[", 
   RowBox[{"\"\<The numerical solution at time t=\>\"", ",", 
    RowBox[{"tt", "[", "mStep", "]"}], ",", "\"\< and position x= \>\"", " ", 
    ",", 
    RowBox[{"jPos", "*", "deltax"}], " ", ",", "\"\< is:\>\""}], "]"}], ";", 
  RowBox[{"uMs", "[", 
   RowBox[{"[", 
    RowBox[{"mStep", ",", "jPos"}], "]"}], "]"}]}]}], "Input",
 CellChangeTimes->{{3.6372983391352997`*^9, 3.6372983412483*^9}, {
  3.6372985221443*^9, 3.6372986028712997`*^9}, {3.6372986373603*^9, 
  3.6372986956313*^9}}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"The numerical solution at time t=\"\>", "\[InvisibleSpace]", 
   "2.7215099495888163`*^-13", 
   "\[InvisibleSpace]", "\<\" and position x= \"\>", "\[InvisibleSpace]", 
   "2.1`", "\[InvisibleSpace]", "\<\" is:\"\>"}],
  SequenceForm[
  "The numerical solution at time t=", 2.7215099495888163`*^-13, 
   " and position x= ", 2.1, " is:"],
  Editable->False]], "Print",
 CellChangeTimes->{3.6385164242448*^9, 3.6386025288556004`*^9}],

Cell[BoxData["6.729687190254093`*^-28"], "Output",
 CellChangeTimes->{3.6385164242478*^9, 3.6386025288566*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 "A plot comparing the numerical and the exact solution at time ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["t", "mStep"], TraditionalForm]]],
 " "
}], "Text",
 CellChangeTimes->{{3.6372989561913*^9, 3.6372990023753*^9}, {
  3.6372990787602997`*^9, 3.6372990811603003`*^9}},
 Background->RGBColor[1, 1, 0.85]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"mStep", "=", "30"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Print", "[", "\"\<Predictive method\>\"", "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Print", "[", 
   RowBox[{
   "\"\<Numerical solution (points) and exact solution (line)  at time \
t=\>\"", ",", 
    RowBox[{"tt", "[", "mStep", "]"}]}], "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{" ", 
  RowBox[{
   RowBox[{"FigNum", "=", 
    RowBox[{"ListPlot", "[", 
     RowBox[{
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"xj", "=", 
           RowBox[{"j", "*", "deltax"}]}], ",", 
          RowBox[{"uMs", "[", 
           RowBox[{"[", 
            RowBox[{
             RowBox[{"mStep", "+", "1"}], ",", 
             RowBox[{"j", "+", "1"}]}], "]"}], "]"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"j", ",", "0", ",", "Np"}], "}"}]}], "]"}], ",", 
      RowBox[{"PlotRange", "\[Rule]", "All"}]}], "]"}]}], ";", 
   RowBox[{"FigExact", "=", 
    RowBox[{"Plot", "[", 
     RowBox[{
      RowBox[{"uSol", "[", 
       RowBox[{"x", ",", 
        RowBox[{"tt", "[", "mStep", "]"}], ",", "gammaVal"}], "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"x", ",", "0", ",", "LL"}], "}"}], ",", 
      RowBox[{"PlotRange", "\[Rule]", "All"}]}], "]"}]}], ";", " ", 
   RowBox[{"Show", "[", 
    RowBox[{"FigNum", ",", "FigExact", ",", 
     RowBox[{"Frame", "\[Rule]", "True"}], ",", 
     RowBox[{"FrameLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<x\>\"", ",", "\"\<u\>\""}], "}"}]}], ",", 
     RowBox[{"PlotRange", "\[Rule]", "All"}]}], "]"}]}]}]}], "Input",
 CellChangeTimes->{{3.6372990098493*^9, 3.6372993557363*^9}, {
   3.6372994017143*^9, 3.6372994018733*^9}, {3.6372994547862997`*^9, 
   3.6372994982653*^9}, {3.6372997348883*^9, 3.6372998253603*^9}, {
   3.6373012862503*^9, 3.6373012895603*^9}, {3.637323731729618*^9, 
   3.637323731976632*^9}, {3.6373242632030163`*^9, 3.6373243106717315`*^9}, {
   3.6373684611463137`*^9, 3.6373684723349533`*^9}, {3.637368539044769*^9, 
   3.6373685563507586`*^9}, 3.6373686855371475`*^9, {3.6385157721808*^9, 
   3.6385158101828003`*^9}}],

Cell[BoxData["\<\"Predictive method\"\>"], "Print",
 CellChangeTimes->{3.6385164242598*^9, 3.6386025288646*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Numerical solution (points) and exact solution (line)  at time \
t=\"\>", "\[InvisibleSpace]", "0.000011743311092484627`"}],
  SequenceForm[
  "Numerical solution (points) and exact solution (line)  at time t=", 
   0.000011743311092484627`],
  Editable->False]], "Print",
 CellChangeTimes->{3.6385164242598*^9, 3.6386025288656*^9}],

Cell[BoxData[
 GraphicsBox[{{{}, {{}, 
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
      0.012833333333333334`], AbsoluteThickness[1.6], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQBGIQDQOMYPKD/ayZILDTXmvvxb9RD59C+SftC4KLnrid
umtvYgwCl+3t2osUdI2uQOVv2rsYqBp9cjttDzHtgb1e6I2ezKhDUPWP7cXK
pvYembPDPj0NBJ7Zv8ydzMddvAGq/6V9WgB3fvXrpfZnz4DAG/t//CYTHsvP
hZr3wT5n39U9s70nQ9V/tK+f1vf2b30n1PzP9g0X7eY9PNcA1f/FfvGRtZHi
0mVQ+77Z35yu06bMlAs174d92VG314r/kqDm/bTX+BoR8PFiBNS83/YbFDj8
jugHQM37Y6+wa2rxUyFXqHn/7HO+J/r2J1tDzWNweHRtwtuTRwyh6hkcrl6R
FjzBog41n9EhSXmqQcIxWah+Jocti8MldlsJQ+1jdvjx9FrAvrMcUPNYHLSl
zizf8vm/HcQ8Fgcl7iWWH3u/2EHMY3UIrY/8fj3zlR3EPDaHVW7fy1Z9fmAH
MY/dQZh183TFPVftIOZxONhs+eWXcO001DwOh9aMLJGF5w5CzeN0eMz/zVTr
4DaoeVwOpjUa58041kLN43aY3Saa9bxyEdQ8Hod1G8JirTOmQ83jcZC6v35/
SUQv1DxeB+FrYqc2vm2EmsfnIFVqfD67oARqHr+D18fyhtCWJKh5Ag6wdAgA
cVgTug==
       "]]}, {}}, {}}, {{}, {}, 
    {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], Opacity[
     1.], LineBox[CompressedData["
1:eJwVV3c0F+4X/tib0EAqK3tlRNJ7XylF+JqFUiSFhLKzt+xZkmRFVlZFyCxk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      "]]}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->True,
  FrameLabel->{
    FormBox["\"x\"", TraditionalForm], 
    FormBox["\"u\"", TraditionalForm]},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  Method->{},
  PlotRange->All,
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.02], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.6385164372058*^9, 3.6386025418796*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Here we give a table that compares the numerical and exact solution at the \
point xpos=1, for the first numSteps timesteps. \
\>", "Text",
 CellChangeTimes->{{3.6372981691743*^9, 3.6372982503743*^9}, {
  3.6372983312943*^9, 3.6372983351903*^9}, {3.6372983799263*^9, 
  3.6372984925123*^9}, {3.6372988496542997`*^9, 3.6372989263983*^9}, {
  3.63732393719937*^9, 3.637323945207828*^9}},
 Background->RGBColor[1, 1, 0.85]],

Cell[BoxData[
 RowBox[{
  RowBox[{"headPredictive", "=", 
   RowBox[{"{", 
    RowBox[{
    "\"\<step\>\"", ",", "\"\<t\>\"", ",", 
     "\"\<\!\(\*SubscriptBox[\(U\), \(Predic\)]\)(1,t)\>\"", ",", 
     "\"\<\!\(\*SubscriptBox[\(u\), \(exact\)]\)(1,t)\>\"", ",", 
     "\"\<error\>\""}], "}"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.6372462215509663`*^9, 3.6372463423118734`*^9}, {
  3.6372468240104246`*^9, 3.637246824353444*^9}, {3.637324796083495*^9, 
  3.6373248007707634`*^9}, {3.637324952389436*^9, 3.6373249524154367`*^9}, {
  3.6373263400688066`*^9, 3.6373263427159576`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"xPos", "=", "1."}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"jPos", "=", 
   RowBox[{"Round", "[", 
    RowBox[{"xPos", "/", "deltax"}], "]"}]}], ";", 
  RowBox[{"tabPred", "=", 
   RowBox[{
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"m", ",", 
        RowBox[{"tt", "[", "m", "]"}], ",", 
        RowBox[{"uMs", "[", 
         RowBox[{"[", 
          RowBox[{
           RowBox[{"m", "+", "1"}], ",", 
           RowBox[{"jPos", "+", "1"}]}], "]"}], "]"}], ",", 
        RowBox[{"uSol", "[", 
         RowBox[{"xPos", ",", 
          RowBox[{"tt", "[", "m", "]"}], ",", "gammaVal"}], "]"}], ",", 
        RowBox[{
         RowBox[{"uMs", "[", 
          RowBox[{"[", 
           RowBox[{
            RowBox[{"m", "+", "1"}], ",", 
            RowBox[{"jPos", "+", "1"}]}], "]"}], "]"}], "-", 
         RowBox[{"uSol", "[", 
          RowBox[{"xPos", ",", 
           RowBox[{"tt", "[", "m", "]"}], ",", "gammaVal"}], "]"}]}]}], "}"}],
       ",", 
      RowBox[{"{", 
       RowBox[{"m", ",", "0", ",", "numSteps"}], "}"}]}], "]"}], "//", 
    "N"}]}], ";", 
  RowBox[{
   RowBox[{"Insert", "[", 
    RowBox[{"tabPred", ",", "headPredictive", ",", "1"}], "]"}], "//", 
   "TableForm"}]}]}], "Input",
 CellChangeTimes->{
  3.6372987625292997`*^9, {3.6373235184064164`*^9, 3.6373235247327785`*^9}, {
   3.637323580099945*^9, 3.637323582258068*^9}, {3.6373239516731977`*^9, 
   3.6373239865441923`*^9}, {3.6373240235533094`*^9, 3.637324146326331*^9}, {
   3.6373249524424386`*^9, 3.6373249524754405`*^9}, {3.6373253507192187`*^9, 
   3.6373253518612843`*^9}, {3.6373264254706907`*^9, 3.6373264433577137`*^9}, 
   3.6373690586684895`*^9}],

Cell[BoxData[
 TagBox[GridBox[{
    {"\<\"step\"\>", "\<\"t\"\>", "\<\"\\!\\(\\*SubscriptBox[\\(U\\), \
\\(Predic\\)]\\)(1,t)\"\>", "\<\"\\!\\(\\*SubscriptBox[\\(u\\), \
\\(exact\\)]\\)(1,t)\"\>", "\<\"error\"\>"},
    {"0.`", "0.`", "0.`", "0.`", "0.`"},
    {"1.`", "1.8890676391449085`*^-15", "4.5944400518194105`*^-18", "0.`", 
     "4.5944400518194105`*^-18"},
    {"2.`", "6.715557130218575`*^-15", "8.516207332334538`*^-17", "0.`", 
     "8.516207332334538`*^-17"},
    {"3.`", "2.496473249493091`*^-14", "2.0552362947321246`*^-15", "0.`", 
     "2.0552362947321246`*^-15"},
    {"4.`", "8.660394869267816`*^-14", "3.7636474461415335`*^-14", 
     "2.901352094837045`*^-22", "3.7636474171280126`*^-14"},
    {"5.`", "2.7215099495888163`*^-13", "5.037808789992354`*^-13", 
     "4.231410354521874`*^-19", "5.037804558582`*^-13"},
    {"6.`", "7.83538917735437`*^-13", "5.170850381429999`*^-12", 
     "1.3398784636412227`*^-16", "5.170716393583635`*^-12"},
    {"7.`", "2.0999699579256423`*^-12", "4.250451392781912`*^-11", 
     "1.3970972443778809`*^-14", "4.249054295537534`*^-11"},
    {"8.`", "5.314174362117797`*^-12", "2.895874038983565`*^-10", 
     "6.398642140104158`*^-13", "2.889475396843461`*^-10"},
    {"9.`", "1.115280111211617`*^-11", "1.255050783483605`*^-9", 
     "9.66140331909988`*^-12", "1.2453893801645052`*^-9"},
    {"10.`", "2.615086594141467`*^-11", "6.5636064500644675`*^-9", 
     "1.574525094153161`*^-10", "6.4061539406491515`*^-9"},
    {"11.`", "5.2530410449551094`*^-11", "2.3624395973114632`*^-8", 
     "1.221893455976803`*^-9", "2.240250251713783`*^-8"},
    {"12.`", "1.027917729343262`*^-10", "7.778587470662629`*^-8", 
     "7.333527140685511`*^-9", "7.045234756594078`*^-8"},
    {"13.`", "1.989866373063425`*^-10", "2.393482085019163`*^-7", 
     "3.6569372749316494`*^-8", "2.0277883575259981`*^-7"},
    {"14.`", "3.823056624409647`*^-10", "6.907611509853543`*^-7", 
     "1.5582048544429114`*^-7", "5.349406655410631`*^-7"},
    {"15.`", "7.307923422212279`*^-10", "1.8770252415064164`*^-6", 
     "5.797255269033781`*^-7", "1.2972997146030382`*^-6"},
    {"16.`", "1.39329044168245`*^-9", "4.821047558750824`*^-6", 
     "1.9175321599953392`*^-6", "2.9035153987554843`*^-6"},
    {"17.`", "2.655740289080791`*^-9", "0.000011745323770232824`", 
     "5.723772353203049`*^-6", "6.021551417029775`*^-6"},
    {"18.`", "5.7878703890904575`*^-9", "0.00003201335458791775`", 
     "0.000018950015026471376`", "0.000013063339561446374`"},
    {"19.`", "1.1252188443889314`*^-8", "0.0000711914586341319`", 
     "0.00004777709612575771`", "0.000023414362508374186`"},
    {"20.`", "2.1499551387904022`*^-8", "0.00014747760676807155`", 
     "0.00010879770389216601`", "0.00003867990287590554`"},
    {"21.`", "4.07158086439111`*^-8", "0.0002882737656968617`", 
     "0.00022875052494587795`", "0.00005952324075098373`"},
    {"22.`", "7.666572553655919`*^-8", "0.0005352016432521824`", 
     "0.0004493278229448654`", "0.00008587382030731701`"},
    {"23.`", "1.4390612814106654`*^-7", "0.0009489267689449125`", 
     "0.0008322204066264112`", "0.00011670636231850132`"},
    {"24.`", "2.6992236652439834`*^-7", "0.0016142710019235215`", 
     "0.001464399427457297`", "0.00014987157446622458`"},
    {"25.`", "5.070336310226437`*^-7", "0.0026453024246423187`", 
     "0.0024632399349193068`", "0.0001820624897230119`"},
    {"26.`", "9.5556072888706`*^-7", "0.004189275293496168`", 
     "0.003980307303324126`", "0.0002089679901720416`"},
    {"27.`", "1.7926926285313916`*^-6", "0.0063921820581666925`", 
     "0.006164930714209145`", "0.0002272513439575477`"},
    {"28.`", "3.353493446375174`*^-6", "0.00943210649850659`", 
     "0.009199064593150735`", "0.00023304190535585433`"},
    {"29.`", "6.270103449782267`*^-6", "0.01350978413370732`", 
     "0.013286973054845231`", "0.00022281107886208858`"},
    {"30.`", "0.000011743311092484627`", "0.018843110466546895`", 
     "0.018649286412639965`", "0.0001938240539069297`"},
    {"31.`", "0.000021965078596100654`", "0.025604147368645296`", 
     "0.02545640750351621`", "0.00014773986512908385`"},
    {"32.`", "0.000041020207047499964`", "0.03395697211824571`", 
     "0.03387115819379765`", "0.00008581392444805686`"},
    {"33.`", "0.00007664303678899803`", "0.04407207832249569`", 
     "0.044063606392232675`", "8.471930263015404`*^-6"},
    {"34.`", "0.0001431848769216162`", "0.05605578859112695`", 
     "0.056135675088631515`", 
     RowBox[{"-", "0.00007988649750456656`"}]},
    {"35.`", "0.00026723138186223665`", "0.06995860547802586`", 
     "0.07013289329341293`", 
     RowBox[{"-", "0.0001742878153870725`"}]},
    {"36.`", "0.0004992008975467766`", "0.08584641252282292`", 
     "0.08612012599272793`", 
     RowBox[{"-", "0.00027371346990501255`"}]},
    {"37.`", "0.0009314965859936626`", "0.10365075325361212`", 
     "0.10402105045417857`", 
     RowBox[{"-", "0.0003702972005664579`"}]},
    {"38.`", "0.0017386608027470012`", "0.1233407670163134`", 
     "0.12380458963504061`", 
     RowBox[{"-", "0.000463822618727211`"}]},
    {"39.`", "0.0032434369942618353`", "0.14478573920783228`", 
     "0.14533498968690503`", 
     RowBox[{"-", "0.0005492504790727548`"}]},
    {"40.`", "0.006053150439192322`", "0.16787675899928295`", 
     "0.1685033408841393`", 
     RowBox[{"-", "0.000626581884856342`"}]},
    {"41.`", "0.011289954217608538`", "0.1924078537060157`", 
     "0.19309949123054115`", 
     RowBox[{"-", "0.0006916375245254458`"}]},
    {"42.`", "0.02105807026879005`", "0.21820814744635852`", 
     "0.21895371545881706`", 
     RowBox[{"-", "0.0007455680124585362`"}]},
    {"43.`", "0.03929473435682153`", "0.2450856914470625`", 
     "0.24587400147192834`", 
     RowBox[{"-", "0.0007883100248658459`"}]},
    {"44.`", "0.07329093794249442`", "0.2727824957290163`", 
     "0.27360013520210974`", 
     RowBox[{"-", "0.0008176394730934344`"}]},
    {"45.`", "0.13670686176988495`", "0.30108946599503805`", 
     "0.3019250328221859`", 
     RowBox[{"-", "0.00083556682714786`"}]},
    {"46.`", "0.2551154115445053`", "0.32979119171334864`", 
     "0.3306338731898313`", 
     RowBox[{"-", "0.0008426814764826429`"}]},
    {"47.`", "0.47687301871290266`", "0.3587016677407839`", 
     "0.3595436400775454`", 
     RowBox[{"-", "0.0008419723367615317`"}]},
    {"48.`", "0.8931812840058769`", "0.3876019123350847`", 
     "0.388428596545409`", 
     RowBox[{"-", "0.0008266842103243355`"}]},
    {"49.`", "1.682445774790792`", "0.4163973534562769`", 
     "0.4172083242967311`", 
     RowBox[{"-", "0.0008109708404542282`"}]},
    {"50.`", "3.188303138338856`", "0.44484896865548995`", 
     "0.44563938710812967`", 
     RowBox[{"-", "0.0007904184526397184`"}]}
   },
   GridBoxAlignment->{
    "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
     "RowsIndexed" -> {}},
   GridBoxSpacings->{"Columns" -> {
       Offset[0.27999999999999997`], {
        Offset[2.0999999999999996`]}, 
       Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
       Offset[0.2], {
        Offset[0.4]}, 
       Offset[0.2]}, "RowsIndexed" -> {}}],
  Function[BoxForm`e$, 
   TableForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{3.6385164399217997`*^9, 3.6386025446096*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 "A plot comparing the numerical and the exact solution at  position x=xpos \
for times  t  with   0\[LessEqual]t\[LessEqual] ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["t", "numSteps"], TraditionalForm]]],
 " "
}], "Text",
 CellChangeTimes->{{3.6372989561913*^9, 3.6372990023753*^9}, {
  3.6372990787602997`*^9, 3.6372990811603003`*^9}, {3.6372998614302998`*^9, 
  3.6372998879683*^9}, {3.6373004057753*^9, 3.6373004634223003`*^9}, {
  3.6373242013104763`*^9, 3.637324201926512*^9}},
 Background->RGBColor[1, 1, 0.85]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"Print", "[", "\"\<Predictive method\>\"", "]"}], ";", 
  RowBox[{"Print", "[", 
   RowBox[{
   "\"\<Numerical solution (points) and exact solution (line) at position \
x=\>\"", ",", "xPos", ",", "\"\< vs. time\>\""}], "]"}], ";", " ", 
  RowBox[{"FigNum", "=", 
   RowBox[{"ListPlot", "[", 
    RowBox[{
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"tabPred", "[", 
          RowBox[{"[", 
           RowBox[{"n", ",", "2"}], "]"}], "]"}], ",", 
         RowBox[{"tabPred", "[", 
          RowBox[{"[", 
           RowBox[{"n", ",", "3"}], "]"}], "]"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"n", ",", "1", ",", "numSteps"}], "}"}]}], "]"}], ",", 
     RowBox[{"PlotRange", "\[Rule]", "All"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"FigExact", "=", 
   RowBox[{"Plot", "[", 
    RowBox[{
     RowBox[{"uSol", "[", 
      RowBox[{"xPos", ",", "time", ",", "gammaVal"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"time", ",", "0", ",", 
       RowBox[{"1.1", "*", 
        RowBox[{"tabPred", "[", 
         RowBox[{"[", 
          RowBox[{
           RowBox[{"numSteps", "+", "1"}], ",", "2"}], "]"}], "]"}]}]}], 
      "}"}], ",", 
     RowBox[{"PlotRange", "\[Rule]", "All"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"Show", "[", 
  RowBox[{"FigNum", ",", "FigExact", ",", 
   RowBox[{"Frame", "\[Rule]", "True"}], ",", 
   RowBox[{"FrameLabel", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"\"\<time\>\"", ",", "\"\<u\>\""}], "}"}]}], ",", 
   RowBox[{"PlotRange", "\[Rule]", "All"}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.6372990098493*^9, 3.6372993557363*^9}, {
   3.6372994017143*^9, 3.6372994018733*^9}, {3.6372994547862997`*^9, 
   3.6372994982653*^9}, {3.6372997348883*^9, 3.6372998253603*^9}, {
   3.6372999061773*^9, 3.6372999638333*^9}, {3.6373000656813*^9, 
   3.6373002790032997`*^9}, {3.6373003226673*^9, 3.6373003301463003`*^9}, 
   3.6373012777063*^9, 3.6373013767462997`*^9, 3.6373014286173*^9, 
   3.6373017989203*^9, 3.6373211076755304`*^9, {3.6373236515230303`*^9, 
   3.6373236666498957`*^9}, {3.6373242118020763`*^9, 3.63732421291214*^9}, 
   3.6373242494332285`*^9, {3.637324952544444*^9, 3.6373249525784464`*^9}, {
   3.6373253588866863`*^9, 3.637325390918518*^9}, {3.637325427300599*^9, 
   3.6373254305107822`*^9}, {3.6373264575145235`*^9, 3.637326470471265*^9}, 
   3.6373692008466215`*^9, {3.6385158178708*^9, 3.6385158262708*^9}, 
   3.6385161316577997`*^9, {3.6385161713918*^9, 3.6385161802757998`*^9}}],

Cell[BoxData["\<\"Predictive method\"\>"], "Print",
 CellChangeTimes->{3.6385164399818*^9, 3.6386025446396*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Numerical solution (points) and exact solution (line) at \
position x=\"\>", "\[InvisibleSpace]", "1.`", 
   "\[InvisibleSpace]", "\<\" vs. time\"\>"}],
  SequenceForm[
  "Numerical solution (points) and exact solution (line) at position x=", 1., 
   " vs. time"],
  Editable->False]], "Print",
 CellChangeTimes->{3.6385164399818*^9, 3.6386025446415997`*^9}],

Cell[BoxData[
 GraphicsBox[{{{}, {{}, 
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
      0.011000000000000001`], AbsoluteThickness[1.6], PointBox[CompressedData["
1:eJwBMQPO/CFib1JlAgAAADIAAAACAAAAAAAAAAAAAAAAAAAAAAAAAE++frbk
A+E8+eUjTSgwVTz+F32egj7+PNCGKxXai5g8yJPzH5gbHD1oi8NfDYPiPMQo
l+B4YDg921cP0/wvJT2U5jfwoiZTPYdKNp6nuWE9umhkvH2Raz2Fy4Qm3L2W
Pdi6AkO2eII9E7Mzgfpdxz06Ka95Ol+XPVXtarl55vM9+u+jB3iGqD0PuWmP
xY8VPgXBU3vQwLw9deMA+cIwPD44LNN+/+DMPUoBmxPTXVk+yvMM9lNB3D1b
7FeUZ+F0PiJNj0o4Wes95L6njfgPkD7Qp4+jl0X6Pb+/xdWXLac+pNpfDx4c
CT66aSMUw32/PmI/GJTB7xc+qoBUdo841D5X0z3fCNAmPsnu1QG5oeg+eFrX
rtTbOD5Sg+h8wsgAPwbKdr30KUg+3ShE8pOpEj/hDnpuwBVXPr/F9P6GVCM/
fwtGKfDbZT430V1lbuQyP6li9bRtlHQ+2fT6xpiJQT+nRYmwk1CDPpNxLrgs
GE8/aRZTHzsdkj4Txz9KvnJaP8ec975iA6E+1Rrc7JmrZT/0uughGgiwPsR1
EgbGKHE/P4DdY44Tvj7jCz1OsC56P4jg24SSIcw+jjyM5yNRgz82DqDpeEza
PhAKPogEq4s/TmsIY6Sg6D5svtW8m0uTPwSQJLU0CPc+jnZcPvk3mj8G5PqU
o4EFPzYncOnOYqE/Yt6MWG0XFD9drR+OnZCmP/6oMbp8xCI/1DGAJVizrD+M
B6oLZoMxP00VmqLO6LE/cXW5w5lbQD/zskPOB/q1P5ZPxK/1hU4/bBZuE9uI
uj9UPFjSeHxcP0M/mbBCk78/kcok+vqRaj/ak2nPVojCPxgcyTIwy3g/yofU
Uvx8xT/jjRoBMB+HPwqYlA/SoMg/Jjx8LD+QlT+UXYCcPu7LP4Jj731wHqQ/
eMi9yvdezz/AYY7lMcOyP9/zhLZEddE/nmA4Rpx/wT9MmmfADEXTP8OCUpfP
U9A/k7u6g0wb1T+g3u1oFoXeP6fo/db39NY/gYuG6vCU7D/sKFZAeM7YPzxR
wEJM6/o/FRXPFUGm2j8uDHxw
       "]]}, {}}, {}}, {{}, {}, 
    {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], Opacity[
     1.], LineBox[CompressedData["
1:eJwV02k41QkbBnD7dqQsNSkpe8losbxC7n+n7CIyDGlVkkgiCWUJg5CslZAR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      "]]}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->True,
  FrameLabel->{
    FormBox["\"time\"", TraditionalForm], 
    FormBox["\"u\"", TraditionalForm]},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  Method->{},
  PlotRange->All,
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.02], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.6385164525657997`*^9, 3.6386025575076*^9}]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 "\[FilledSquare] Numerical results with the method with ",
 StyleBox["fixed timesteps",
  FontSlant->"Italic"],
 " for \[CapitalDelta]=0.01=",
 "htFT"
}], "Subsubsection",
 CellChangeTimes->{{3.633439583415289*^9, 3.6334395909637213`*^9}, {
   3.636904756973955*^9, 3.636904760701168*^9}, 3.637138408549569*^9, {
   3.6372452357805834`*^9, 3.6372452451731205`*^9}, {3.6372463821981544`*^9, 
   3.6372463827581863`*^9}, {3.6372466129283514`*^9, 3.637246617848633*^9}, {
   3.6372481231807327`*^9, 3.6372481307011633`*^9}, {3.637249654032293*^9, 
   3.6372496781846743`*^9}, 3.6373014998393*^9, {3.6373015476473*^9, 
   3.6373015576783*^9}, 3.6373021184543*^9}],

Cell[CellGroupData[{

Cell[TextData[{
 "uMs is a matrix that contains the full solution ",
 Cell[BoxData[
  FormBox[
   RowBox[{"{", 
    RowBox[{
     SubsuperscriptBox["U", "0", 
      RowBox[{"(", "m", ")"}]], ",", 
     SubsuperscriptBox["U", "1", 
      RowBox[{"(", "m", ")"}]], ",", 
     SubsuperscriptBox["U", "2", 
      RowBox[{"(", "m", ")"}]], ",", 
     RowBox[{"...", " ", 
      SubsuperscriptBox["U", "Np", 
       RowBox[{"(", "m", ")"}]]}]}], "}"}], TraditionalForm]]],
 "  for m=0,1,2,....,numSteps."
}], "Text",
 CellChangeTimes->{{3.6372979828863*^9, 3.6372980614302998`*^9}},
 Background->RGBColor[1, 1, 0.85]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"htFT", "=", "0.01"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"numSteps", "=", "50"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"CPUtime", "=", 
   RowBox[{"Timing", "[", 
    RowBox[{"uMs", "=", 
     RowBox[{"uMsolutionFixedTimesteps", "[", 
      RowBox[{
       RowBox[{"numSteps", "*", "htFT"}], ",", "htFT"}], "]"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Print", "[", 
   RowBox[{
   "\"\<Example 3. Method with fixed timesteps. Case with Kg=\>\"", ",", "Kg",
     ",", "\"\<, \!\(\*SubscriptBox[\(u\), \(0\)]\)=\>\"", ",", "u0value", 
    ",", "\"\<, L=\>\"", ",", "LL"}], "]"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"Print", "[", 
   RowBox[{
   "\"\<Numerical solution with fixed timesteps of size \>\"", ",", "htFT", 
    ",", "\"\< for \[Gamma]=\>\"", ",", "gammak", ",", "\"\<, Np=\>\"", ",", 
    "Np"}], "  ", "]"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"Print", "[", 
   RowBox[{"\"\<CPU time=\>\"", ",", 
    RowBox[{"CPUtime", "[", 
     RowBox[{"[", "1", "]"}], "]"}], ",", "\"\< seconds\>\""}], "]"}], 
  ";"}], "\n", 
 RowBox[{
  RowBox[{
  "Print", "[", "\"\<The solution is saved in the matrix uMs\>\"", "]"}], 
  ";"}]}], "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 CellChangeTimes->{{3.56061256346875*^9, 3.56061257284375*^9}, {
   3.56061260303125*^9, 3.560612663828125*^9}, {3.5610884668366947`*^9, 
   3.5610884717649765`*^9}, {3.5611210929323997`*^9, 3.5611211203416*^9}, {
   3.5611212573096*^9, 3.5611212593532*^9}, 3.5611216448120003`*^9, {
   3.5611216844625998`*^9, 3.5611216848213997`*^9}, {3.5611217681558*^9, 
   3.5611217684667997`*^9}, {3.5611222944344*^9, 3.5611223196862*^9}, {
   3.5611253416166*^9, 3.5611253440626*^9}, {3.5611260133876*^9, 
   3.5611260138276*^9}, {3.561127402519*^9, 3.5611274579006*^9}, {
   3.561127527574*^9, 3.5611275627130003`*^9}, {3.5902000697948065`*^9, 
   3.5902000708068647`*^9}, {3.590200323138297*^9, 3.590200324873397*^9}, {
   3.5902003709750333`*^9, 3.5902003711460433`*^9}, 3.590200421820942*^9, 
   3.590213289142*^9, {3.5902135189*^9, 3.590213539836*^9}, {
   3.5902135876359997`*^9, 3.590213616165*^9}, {3.590213707484*^9, 
   3.590213707868*^9}, {3.590213768476*^9, 3.590213768955*^9}, 
   3.5902143461549997`*^9, {3.59021447142*^9, 3.590214495682*^9}, 
   3.5903882375313997`*^9, {3.5903932563884*^9, 3.5903932567464*^9}, {
   3.5903932903714*^9, 3.5903933180104*^9}, {3.5903933542194*^9, 
   3.5903933561303997`*^9}, 3.5903933876914*^9, 3.5903934182594*^9, 
   3.5903941132114*^9, 3.60195384860737*^9, {3.601953894449992*^9, 
   3.601953894987023*^9}, {3.6334400976967044`*^9, 3.6334400980167227`*^9}, 
   3.6369936572364435`*^9, {3.636993750675788*^9, 3.6369937637635365`*^9}, 
   3.637004923308416*^9, 3.6370053615804834`*^9, {3.6372402113622026`*^9, 
   3.637240211367203*^9}, {3.6372452960570307`*^9, 3.6372453605797215`*^9}, {
   3.6372453910404634`*^9, 3.637245428304595*^9}, {3.637245470149988*^9, 
   3.6372455167096515`*^9}, {3.6372456161863413`*^9, 3.637245697827011*^9}, {
   3.637245729372815*^9, 3.637245777960594*^9}, {3.63724584310532*^9, 
   3.6372459587629356`*^9}, {3.637246021107501*^9, 3.6372460259367776`*^9}, {
   3.637246091338518*^9, 3.6372460918335466`*^9}, 3.6372463595788608`*^9, 
   3.637246525799368*^9, {3.6372465623644595`*^9, 3.637246581655563*^9}, {
   3.637246817573056*^9, 3.6372468214022756`*^9}, {3.6372470179475174`*^9, 
   3.637247018278536*^9}, {3.6372471839910145`*^9, 3.6372472107335443`*^9}, {
   3.6372472497587757`*^9, 3.637247279316467*^9}, {3.637247390205809*^9, 
   3.6372473996553497`*^9}, {3.637247443785874*^9, 3.6372474491481805`*^9}, {
   3.637247899618946*^9, 3.6372479030021396`*^9}, {3.637247939714239*^9, 
   3.6372479400092564`*^9}, {3.6372482082135963`*^9, 3.637248224762543*^9}, {
   3.637248553257332*^9, 3.6372485587676473`*^9}, 3.6372496070256042`*^9, 
   3.6372975701323*^9, {3.6372979117462997`*^9, 3.6372979144493*^9}, 
   3.6372981329823*^9, 3.6372981646743*^9, {3.6372982614663*^9, 
   3.6372982617132998`*^9}, {3.6373004952983*^9, 3.6373005432813*^9}, {
   3.6373007987373*^9, 3.6373008130083*^9}, {3.6373015293063*^9, 
   3.6373015299783*^9}, {3.6373015669943*^9, 3.6373015860183*^9}, {
   3.6373020142672997`*^9, 3.6373020146973*^9}, 3.6373021292053003`*^9, 
   3.6373309544297323`*^9, {3.637331184516893*^9, 3.6373312230450964`*^9}, {
   3.637331577826389*^9, 3.637331578841447*^9}}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Example 3. Method with fixed timesteps. Case with Kg=\"\>", 
   "\[InvisibleSpace]", "1.`", 
   "\[InvisibleSpace]", "\<\", \\!\\(\\*SubscriptBox[\\(u\\), \
\\(0\\)]\\)=\"\>", "\[InvisibleSpace]", "1.`", 
   "\[InvisibleSpace]", "\<\", L=\"\>", "\[InvisibleSpace]", "4.`"}],
  SequenceForm[
  "Example 3. Method with fixed timesteps. Case with Kg=", 1., 
   ", \!\(\*SubscriptBox[\(u\), \(0\)]\)=", 1., ", L=", 4.],
  Editable->False]], "Print",
 CellChangeTimes->{3.6385164539018*^9, 3.6386025587966003`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Numerical solution with fixed timesteps of size \"\>", 
   "\[InvisibleSpace]", "0.01`", 
   "\[InvisibleSpace]", "\<\" for \[Gamma]=\"\>", "\[InvisibleSpace]", 
   "0.25`", "\[InvisibleSpace]", "\<\", Np=\"\>", "\[InvisibleSpace]", "40"}],
  SequenceForm[
  "Numerical solution with fixed timesteps of size ", 0.01, " for \[Gamma]=", 
   0.25, ", Np=", 40],
  Editable->False]], "Print",
 CellChangeTimes->{3.6385164539018*^9, 3.6386025587986*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"CPU time=\"\>", "\[InvisibleSpace]", "1.2636081`", 
   "\[InvisibleSpace]", "\<\" seconds\"\>"}],
  SequenceForm["CPU time=", 1.2636081, " seconds"],
  Editable->False]], "Print",
 CellChangeTimes->{3.6385164539018*^9, 3.6386025588006*^9}],

Cell[BoxData["\<\"The solution is saved in the matrix uMs\"\>"], "Print",
 CellChangeTimes->{3.6385164539018*^9, 3.6386025588016*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 "The solution for the m-th timestep is just the m+1 element of this matrix:  \
uMs[[m+1]]=",
 Cell[BoxData[
  FormBox[
   RowBox[{"{", 
    RowBox[{
     SubsuperscriptBox["U", "0", 
      RowBox[{"(", "m", ")"}]], ",", 
     SubsuperscriptBox["U", "1", 
      RowBox[{"(", "m", ")"}]], ",", 
     SubsuperscriptBox["U", "2", 
      RowBox[{"(", "m", ")"}]], ",", 
     RowBox[{"...", " ", 
      SubsuperscriptBox["U", "Np", 
       RowBox[{"(", "m", ")"}]]}]}], "}"}], TraditionalForm]]],
 " "
}], "Text",
 CellChangeTimes->{{3.6372981691743*^9, 3.6372982503743*^9}, {
  3.6372983312943*^9, 3.6372983351903*^9}},
 Background->RGBColor[1, 1, 0.85]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"mStep", "=", "5"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Print", "[", 
   RowBox[{"\"\<The numerical solution at time \>\"", ",", 
    RowBox[{"tt", "[", "mStep", "]"}], ",", "\"\< is:\>\""}], "]"}], ";", 
  RowBox[{"uMs", "[", 
   RowBox[{"[", "mStep", "]"}], "]"}]}]}], "Input",
 CellChangeTimes->{{3.6372983391352997`*^9, 3.6372983412483*^9}, {
  3.6372985221443*^9, 3.6372986028712997`*^9}}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"The numerical solution at time \"\>", "\[InvisibleSpace]", 
   "0.05`", "\[InvisibleSpace]", "\<\" is:\"\>"}],
  SequenceForm["The numerical solution at time ", 0.05, " is:"],
  Editable->False]], "Print",
 CellChangeTimes->{3.6385164539598*^9, 3.6386025588226*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "1.0000000000000022`", ",", "0.8694416088216864`", ",", 
   "0.7554683743124474`", ",", "0.6560455695236882`", ",", 
   "0.5693767364500238`", ",", "0.49387757639859503`", ",", 
   "0.4281524132115744`", ",", "0.37097302357474654`", ",", 
   "0.32125963652689593`", ",", "0.27806391371514316`", ",", 
   "0.24055373239522201`", ",", "0.2079996042329035`", ",", 
   "0.1797625742909461`", ",", "0.15528345592554757`", ",", 
   "0.13407326846810677`", ",", "0.11570475538269727`", ",", 
   "0.0998048709582397`", ",", "0.0860481334412568`", ",", 
   "0.07415075179130708`", ",", "0.06386544191901057`", ",", 
   "0.054976856335073404`", ",", "0.047297558599980714`", ",", 
   "0.04066448083006144`", ",", "0.034935808805776083`", ",", 
   "0.02998824496692053`", ",", "0.025714604795088098`", ",", 
   "0.022021706806451102`", ",", "0.018828520639031194`", ",", 
   "0.016064541549625982`", ",", "0.013668363067462677`", ",", 
   "0.011586422614462294`", ",", "0.009771897624331808`", ",", 
   "0.008183732101488022`", ",", "0.00678577568110897`", ",", 
   "0.00554601910644671`", ",", "0.004435911649863667`", ",", 
   "0.0034297473886773303`", ",", "0.0025041084224625442`", ",", 
   "0.0016373540994612627`", ",", "0.0008091461185440943`", ",", "0.`"}], 
  "}"}]], "Output",
 CellChangeTimes->{3.6385164539638*^9, 3.6386025588255997`*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 "The [[m+1,j+1] element of this matrix is the numerical solution for time ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["t", "m"], TraditionalForm]]],
 " and position ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["x", "j"], TraditionalForm]]],
 ":  uMs[[m+1,j+1]]=",
 Cell[BoxData[
  FormBox[
   SubsuperscriptBox["U", "j", 
    RowBox[{"(", "m", ")"}]], TraditionalForm]]],
 " "
}], "Text",
 CellChangeTimes->{{3.6372981691743*^9, 3.6372982503743*^9}, {
  3.6372983312943*^9, 3.6372983351903*^9}, {3.6372983799263*^9, 
  3.6372984925123*^9}},
 Background->RGBColor[1, 1, 0.85]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"mStep", "=", "5"}], ";", 
  RowBox[{"jPos", "=", 
   RowBox[{"Nx", "+", "1"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Print", "[", 
   RowBox[{"\"\<The numerical solution at time t=\>\"", ",", 
    RowBox[{"tt", "[", "mStep", "]"}], ",", "\"\< and position x= \>\"", " ", 
    ",", 
    RowBox[{"jPos", "*", "deltax"}], " ", ",", "\"\< is:\>\""}], "]"}], ";", 
  RowBox[{"uMs", "[", 
   RowBox[{"[", 
    RowBox[{"mStep", ",", "jPos"}], "]"}], "]"}]}]}], "Input",
 CellChangeTimes->{{3.6372983391352997`*^9, 3.6372983412483*^9}, {
  3.6372985221443*^9, 3.6372986028712997`*^9}, {3.6372986373603*^9, 
  3.6372986956313*^9}}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"The numerical solution at time t=\"\>", "\[InvisibleSpace]", 
   "0.05`", "\[InvisibleSpace]", "\<\" and position x= \"\>", 
   "\[InvisibleSpace]", "2.1`", "\[InvisibleSpace]", "\<\" is:\"\>"}],
  SequenceForm[
  "The numerical solution at time t=", 0.05, " and position x= ", 2.1, " is:"],
  Editable->False]], "Print",
 CellChangeTimes->{3.6385164539778*^9, 3.6386025588326*^9}],

Cell[BoxData["0.054976856335073404`"], "Output",
 CellChangeTimes->{3.6385164539798*^9, 3.6386025588346*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 "A plot comparing the numerical and the exact solution at time ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["t", "mStep"], TraditionalForm]]],
 " "
}], "Text",
 CellChangeTimes->{{3.6372989561913*^9, 3.6372990023753*^9}, {
  3.6372990787602997`*^9, 3.6372990811603003`*^9}},
 Background->RGBColor[1, 1, 0.85]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"mStep", "=", "5"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Print", "[", "\"\<Method with fixed timesteps\>\"", "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Print", "[", 
   RowBox[{
   "\"\<Numerical solution (points) and exact solution (line)  at time \
t=\>\"", ",", 
    RowBox[{"tt", "[", "mStep", "]"}]}], "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{" ", 
  RowBox[{
   RowBox[{"FigNum", "=", 
    RowBox[{"ListPlot", "[", 
     RowBox[{
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"xj", "=", 
           RowBox[{"j", "*", "deltax"}]}], ",", 
          RowBox[{"uMs", "[", 
           RowBox[{"[", 
            RowBox[{
             RowBox[{"mStep", "+", "1"}], ",", 
             RowBox[{"j", "+", "1"}]}], "]"}], "]"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"j", ",", "0", ",", "Np"}], "}"}]}], "]"}], ",", 
      RowBox[{"PlotRange", "\[Rule]", "All"}]}], "]"}]}], ";", 
   RowBox[{"FigExact", "=", 
    RowBox[{"Plot", "[", 
     RowBox[{
      RowBox[{"uSol", "[", 
       RowBox[{"x", ",", 
        RowBox[{"tt", "[", "mStep", "]"}], ",", "gammaVal"}], "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"x", ",", "0", ",", "LL"}], "}"}], ",", 
      RowBox[{"PlotRange", "\[Rule]", "All"}]}], "]"}]}], ";", " ", 
   RowBox[{"Show", "[", 
    RowBox[{"FigNum", ",", "FigExact", ",", 
     RowBox[{"Frame", "\[Rule]", "True"}], ",", 
     RowBox[{"FrameLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<x\>\"", ",", "\"\<u\>\""}], "}"}]}]}], 
    "]"}]}]}]}], "Input",
 CellChangeTimes->{{3.6372990098493*^9, 3.6372993557363*^9}, {
   3.6372994017143*^9, 3.6372994018733*^9}, {3.6372994547862997`*^9, 
   3.6372994982653*^9}, {3.6372997348883*^9, 3.6372998253603*^9}, 
   3.6373011632593*^9, {3.6373012486103*^9, 3.6373012562163*^9}, 
   3.637331793555728*^9, {3.637333245786791*^9, 3.637333245934799*^9}, 
   3.6373686876412683`*^9, {3.6385158317488003`*^9, 3.6385158481148*^9}}],

Cell[BoxData["\<\"Method with fixed timesteps\"\>"], "Print",
 CellChangeTimes->{3.6385164539918003`*^9, 3.6386025588426*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Numerical solution (points) and exact solution (line)  at time \
t=\"\>", "\[InvisibleSpace]", "0.05`"}],
  SequenceForm[
  "Numerical solution (points) and exact solution (line)  at time t=", 0.05],
  Editable->False]], "Print",
 CellChangeTimes->{3.6385164539918003`*^9, 3.6386025588445997`*^9}],

Cell[BoxData[
 GraphicsBox[{{{}, {{}, 
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
      0.012833333333333334`], AbsoluteThickness[1.6], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQBGIQDQOcYPKD/ayZILDTPpB7jvKJj6+h/JP2HEVH5s1K
fmFvYgwCl+0ZKhzmmro9hcrftM+ZceOtcM8je4hpD+wTebb32Wo+gKp/bF+h
Fj/dUu2OfXoaCDyzl7lurrK+4QZU/0v7Fx+znCMDr9qfPQMCb+xlLvj0rOi8
BDXvg/1MicbJJ2QuQNV/tO+adz7q9r/TUPM/26993sQS4H8Cqv+L/af06qdl
kkeh9n2z1xN+vuq77yGoeT/sny//UbNl336oeT/t/aLd3eY074aa99v+i9cf
zw9Xt0PN+2OvzMqQ2b14C9S8f/bruEyXd93ZCDWPwWHdt5kafM/WQdUzOGhf
3dG/fusqqPmMDno5BdLbhJZD9TM5iC3/8rr71WKofcwOTBKfFD7rLISax+Lw
dmvGjpLpc6HmsTi8aQ71/VIyE2oeq8OfF/JRW+5MhZrH5nC6Wf/Urt2ToOax
OzjO2dyZwTgBah6Hg9Tu1YaBdt1Q8zgcZK6vuhog0A41j9Ph2qtJ2w2SmqHm
cTnwGR7yfSbfADWP20Gh51eHbn4V1DweBxl5i9IKo1KoeTwOPpNPei/PKYCa
x+vwtG/TJHe2DKh5fA5b89n+fCmJh5rH76AsUhNmLesPNU/AAZYOAfgDFLw=

       "]]}, {}}, {}}, {{}, {}, 
    {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], Opacity[
     1.], LineBox[CompressedData["
1:eJwVxX0803kcAPB5qjbsRw9qtYqlehVOLywpfL7lqR27QuE6T5etI4rKQ1P3
6tAqKQk1aUpmCDFplyKbQxNlGbtUCysRyaTRncbu+uP9elvsj/Vj6uJwOPr/
vv8j80OXeCTBlZ+Z2qrVqmC4KmB/P2kPhNyx+JA3qQIzQ3lmLYkBq1/rn3B8
r4IfnBbzC0jx4NVFHjndroKtz+0F2aTTsG2aURF+RQXi683Ui6RcMJs4+plk
rYK0lIzj50nFUMT5pj4dMg6MeBUpnXQPhjKa3rVLx2BBLu3WxOcW4BZ5Xifc
G4H7z+28vFZJYZpFdOYvG4agNMWr5owe8KiMDwtvH4TYmmM2eeqXIExySZGd
fwuTWX+36ej0A1/OvZ5ZNgBtTY9FUue3cHbA1zGx9A1EsWjGP48Ngu3c0leK
uFfQhLfTVh4ahh2+GQ8cxC+ghNcyt3ztKAi3VHCuUOSAzB4V+VeNQTAjV1Ax
KQMbiaLu8UYVjNtKcjr0u6AH+Y/fHp+AT4GRsZ07OyGGEC2Tb5oE8ozIxGBd
B3T0Bj4iZn6B+79GK2JXtIG/Z5BycFANEYv2FtsdbYXNhRmBhZbTMHJotybU
qRkG5nJ6Ik99BWoSUXjEtAne06Q8s+Z/oOYEtWDT+UYQXOtndVnMQDo/xjQC
qwf+Ob30DcnfYMwuN4BlUAdTEftGD9Rr4FTO/TdfTgrB0P2MX83SORB6dZUu
wtfCSZP3RspgLdxQdTtT5gRg1GiFe0HHoTuRGuEqZhW4JO6abZ7Boe2lD4lR
o+XALb7AW8PVQQdF4oB8/TII3evwDO+ti45vbEpMduSDUM7MaZzWRaLNW2ii
1iJweirQHbqqh+jBpdfCGgrB3OPAVI67PtLuO+bdfaYAqA7Uy/eG9JH/0PqB
rS750D958QmPbYCSPeuV3CAOjNn7skl289DLIZkOlp4L6z7ajOp0z0PMgOrW
57bZ0GKZIItLmY/ootkP5tJLcKlHHuFnuQCRg3wzjTQZoPIXX9ZtWYD6mX2U
8rxzcHfvEjenI3h02DA64a4nG3jP0greLiSgbCqHo05Kha+S4BML/yIgXUEA
J/vAKRi4LJoyOWyI9viErZDEJcN01zZSKtEISR/MpOy0ToS4XIqY1WCEzF/b
zbj2H4Glzygmg6HGqMTtXHnF5hjwl1dqyHPGSEH74uRhz4TJsFsxinIiUuDS
2lye/gKi8Go20QdDEyzPXeqVdHgojfHu+wlD/zq4r1CU+cCfrhtNq3wxZOXm
9nuHvQ9UkvlceiCGGKzws2KaN+T35tde2I+hmw+2+uISaZCw+4ySwMJQeKd1
eb3UA6xQiMv8Egxlnxw+nE10gXXVy/VelGHouLu4UbrWGSirettKKjAU0m6d
uthlGyzT+O3xrMHQa03AodpoJ5hXtzOa3YCh1t6oZegJFZS2Dtf0ujEU/66h
5RHBBhQ3Pod2yzG0fiSL/MnJCnqNqy15vRiSMK7eXhO1ATo/bhDs6MOQII+Q
VCxZCw2lqyUpIxgy5v0h78SvhDqzNxd8xzCUb584zo4kQS07389ChSEdanST
m2QJlEcs6ROrMfQb5WryTbwx8GUyXtZXDJHxB9WOEgMo3J4VFT6DIXZKHKMS
P+vKFdBtN81iSMk0NVfiP7lyVhtOabUYmt9Q9lFGM3L9D29uR0Q=
      "]]}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->True,
  FrameLabel->{
    FormBox["\"x\"", TraditionalForm], 
    FormBox["\"u\"", TraditionalForm]},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  Method->{},
  PlotRange->{{0, 4.}, {0, 1.000000000000002}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.02], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.6385164587138*^9, 3.6386025637716*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Here we give a table that compares the numerical and exact solution at the \
middle point, x=xPos, for the first numSteps timesteps. \
\>", "Text",
 CellChangeTimes->{{3.6372981691743*^9, 3.6372982503743*^9}, {
  3.6372983312943*^9, 3.6372983351903*^9}, {3.6372983799263*^9, 
  3.6372984925123*^9}, {3.6372988496542997`*^9, 3.6372989263983*^9}, {
  3.637333273539378*^9, 3.6373332748194513`*^9}},
 Background->RGBColor[1, 1, 0.85]],

Cell[BoxData[
 RowBox[{
  RowBox[{"headFixedTimesteps", "=", 
   RowBox[{"{", 
    RowBox[{
    "\"\<step\>\"", ",", "\"\<t\>\"", ",", 
     "\"\<\!\(\*SubscriptBox[\(U\), \(Fixed\\\ \[CapitalDelta]\)]\)(xPos,t)\>\
\"", ",", "\"\<\!\(\*SubscriptBox[\(u\), \(exact\)]\)(xPos,t)\>\"", ",", 
     "\"\<error\>\""}], "}"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.6372462215509663`*^9, 3.6372463423118734`*^9}, {
  3.637246799033996*^9, 3.637246806409418*^9}, {3.637246837090173*^9, 
  3.637246852913078*^9}, {3.6372481343843737`*^9, 3.637248157767711*^9}, {
  3.63724839394522*^9, 3.6372484353835897`*^9}, {3.6373317537914534`*^9, 
  3.637331761388888*^9}, {3.637331899789804*^9, 3.6373319217560606`*^9}, {
  3.637331968203717*^9, 3.637331980540423*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"xPos", "=", "1."}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"jPos", "=", 
   RowBox[{"Round", "[", 
    RowBox[{"xPos", "/", "deltax"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Print", "[", 
   RowBox[{"\"\<xPos=\>\"", ",", "xPos"}], "]"}], ";", 
  RowBox[{"tabFT", "=", 
   RowBox[{
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"m", ",", 
        RowBox[{"tt", "[", "m", "]"}], ",", 
        RowBox[{"uMs", "[", 
         RowBox[{"[", 
          RowBox[{
           RowBox[{"m", "+", "1"}], ",", 
           RowBox[{"jPos", "+", "1"}]}], "]"}], "]"}], ",", 
        RowBox[{"uSol", "[", 
         RowBox[{"xPos", ",", 
          RowBox[{"tt", "[", "m", "]"}], ",", "gammaVal"}], "]"}], ",", 
        RowBox[{
         RowBox[{"uMs", "[", 
          RowBox[{"[", 
           RowBox[{
            RowBox[{"m", "+", "1"}], ",", 
            RowBox[{"jPos", "+", "1"}]}], "]"}], "]"}], "-", 
         RowBox[{"uSol", "[", 
          RowBox[{"xPos", ",", 
           RowBox[{"tt", "[", "m", "]"}], ",", "gammaVal"}], "]"}]}]}], "}"}],
       ",", 
      RowBox[{"{", 
       RowBox[{"m", ",", "0", ",", "numSteps"}], "}"}]}], "]"}], "//", 
    "N"}]}], ";", 
  RowBox[{
   RowBox[{"Insert", "[", 
    RowBox[{"tabFT", ",", "headFixedTimesteps", ",", "1"}], "]"}], "//", 
   "TableForm"}]}]}], "Input",
 CellChangeTimes->{
  3.6372987625292997`*^9, {3.6373009292093*^9, 3.6373009376243*^9}, {
   3.6373016236413*^9, 3.6373016256473*^9}, 3.6373017098083*^9, {
   3.637331658007975*^9, 3.6373316892707634`*^9}, {3.6373317749986663`*^9, 
   3.6373317831971354`*^9}, {3.637332068213437*^9, 3.6373320838093295`*^9}, 
   3.637369062316698*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"xPos=\"\>", "\[InvisibleSpace]", "1.`"}],
  SequenceForm["xPos=", 1.],
  Editable->False]], "Print",
 CellChangeTimes->{3.6385164587668*^9, 3.6386025638046*^9}],

Cell[BoxData[
 TagBox[GridBox[{
    {"\<\"step\"\>", "\<\"t\"\>", "\<\"\\!\\(\\*SubscriptBox[\\(U\\), \
\\(Fixed\\\\ \[CapitalDelta]\\)]\\)(xPos,t)\"\>", "\<\"\\!\\(\\*SubscriptBox[\
\\(u\\), \\(exact\\)]\\)(xPos,t)\"\>", "\<\"error\"\>"},
    {"0.`", "0.`", "0.`", "0.`", "0.`"},
    {"1.`", "0.01`", "0.1568766855033327`", "0.18820721837679927`", 
     RowBox[{"-", "0.03133053287346657`"}]},
    {"2.`", "0.02`", "0.20297323048069582`", "0.21677294954338094`", 
     RowBox[{"-", "0.013799719062685123`"}]},
    {"3.`", "0.03`", "0.22562048667439533`", "0.234112137981135`", 
     RowBox[{"-", "0.008491651306739678`"}]},
    {"4.`", "0.04`", "0.24055373239522201`", "0.24665487702169514`", 
     RowBox[{"-", "0.006101144626473126`"}]},
    {"5.`", "0.05`", "0.2517568054648876`", "0.2565051180255517`", 
     RowBox[{"-", "0.004748312560664103`"}]},
    {"6.`", "0.060000000000000005`", "0.2607467329259586`", 
     "0.2646240317136066`", 
     RowBox[{"-", "0.003877298787647976`"}]},
    {"7.`", "0.07`", "0.2682642379150177`", "0.2715334837258022`", 
     RowBox[{"-", "0.003269245810784527`"}]},
    {"8.`", "0.08`", "0.27472859929483323`", "0.27754918695515557`", 
     RowBox[{"-", "0.002820587660322338`"}]},
    {"9.`", "0.09`", "0.28040106423752215`", "0.28287696861887024`", 
     RowBox[{"-", "0.002475904381348093`"}]},
    {"10.`", "0.09999999999999999`", "0.2854557780348296`", 
     "0.28765860613473265`", 
     RowBox[{"-", "0.002202828099903076`"}]},
    {"11.`", "0.10999999999999999`", "0.2900148006210237`", 
     "0.2919959749391083`", 
     RowBox[{"-", "0.0019811743180845887`"}]},
    {"12.`", "0.11999999999999998`", "0.29416707792034585`", 
     "0.2959647754758197`", 
     RowBox[{"-", "0.0017976975554738206`"}]},
    {"13.`", "0.12999999999999998`", "0.29797947110239986`", 
     "0.29962281434092064`", 
     RowBox[{"-", "0.001643343238520778`"}]},
    {"14.`", "0.13999999999999999`", "0.30150353432223076`", 
     "0.30301524497279386`", 
     RowBox[{"-", "0.0015117106505631028`"}]},
    {"15.`", "0.15`", "0.3047798709770024`", "0.30617801750931345`", 
     RowBox[{"-", "0.0013981465323110731`"}]},
    {"16.`", "0.16`", "0.307841039462895`", "0.30914022607532`", 
     RowBox[{"-", "0.0012991866124250073`"}]},
    {"17.`", "0.17`", "0.31071355290174335`", "0.3119257514479203`", 
     RowBox[{"-", "0.0012121985461769347`"}]},
    {"18.`", "0.18000000000000002`", "0.3134192925465084`", 
     "0.31455443883408063`", 
     RowBox[{"-", "0.0011351462875722196`"}]},
    {"19.`", "0.19000000000000003`", "0.31597653007876897`", 
     "0.3170429603578811`", 
     RowBox[{"-", "0.0010664302791121294`"}]},
    {"20.`", "0.20000000000000004`", "0.31840068206641337`", 
     "0.3194054585026955`", 
     RowBox[{"-", "0.001004776436282162`"}]},
    {"21.`", "0.21000000000000005`", "0.3207048767262753`", 
     "0.32165403410787574`", 
     RowBox[{"-", "0.0009491573816004517`"}]},
    {"22.`", "0.22000000000000006`", "0.32290038645226815`", 
     "0.32379912195254457`", 
     RowBox[{"-", "0.0008987355002764152`"}]},
    {"23.`", "0.23000000000000007`", "0.32499696258860666`", 
     "0.3258497836626214`", 
     RowBox[{"-", "0.0008528210740147424`"}]},
    {"24.`", "0.24000000000000007`", "0.32700309784958`", 
     "0.3278139388805911`", 
     RowBox[{"-", "0.0008108410310111447`"}]},
    {"25.`", "0.25000000000000006`", "0.3289262343978774`", 
     "0.3296985496961877`", 
     RowBox[{"-", "0.0007723152983103443`"}]},
    {"26.`", "0.26000000000000006`", "0.3307729305649451`", 
     "0.33150976924756603`", 
     RowBox[{"-", "0.0007368386826209217`"}]},
    {"27.`", "0.2700000000000001`", "0.3325489957126689`", 
     "0.3332530625407639`", 
     RowBox[{"-", "0.0007040668280950402`"}]},
    {"28.`", "0.2800000000000001`", "0.3342596002814773`", 
     "0.3349333055009359`", 
     RowBox[{"-", "0.0006737052194586424`"}]},
    {"29.`", "0.2900000000000001`", "0.33590936631527013`", 
     "0.336554866802074`", 
     RowBox[{"-", "0.000645500486803896`"}]},
    {"30.`", "0.3000000000000001`", "0.3375024424815409`", 
     "0.33812167595050036`", 
     RowBox[{"-", "0.0006192334689594792`"}]},
    {"31.`", "0.3100000000000001`", "0.339042566671272`", 
     "0.3396372803053022`", 
     RowBox[{"-", "0.0005947136340301862`"}]},
    {"32.`", "0.3200000000000001`", "0.3405331185695938`", 
     "0.34110489312670594`", 
     RowBox[{"-", "0.0005717745571121591`"}]},
    {"33.`", "0.3300000000000001`", "0.341977164067427`", 
     "0.3425274342960916`", 
     RowBox[{"-", "0.0005502702286646066`"}]},
    {"34.`", "0.34000000000000014`", "0.3433774929893897`", 
     "0.343907565010221`", 
     RowBox[{"-", "0.0005300720208313292`"}]},
    {"35.`", "0.35000000000000014`", "0.3447366513108709`", 
     "0.34524771748974536`", 
     RowBox[{"-", "0.0005110661788744753`"}]},
    {"36.`", "0.36000000000000015`", "0.34605696880369624`", 
     "0.3465501205383539`", 
     RowBox[{"-", "0.0004931517346576375`"}]},
    {"37.`", "0.37000000000000016`", "0.34734058286796843`", 
     "0.3478168216295933`", 
     RowBox[{"-", "0.000476238761624892`"}]},
    {"38.`", "0.38000000000000017`", "0.3485894591650532`", 
     "0.34904970607284863`", 
     RowBox[{"-", "0.0004602469077954474`"}]},
    {"39.`", "0.3900000000000002`", "0.3498054095539001`", 
     "0.35025051371036486`", 
     RowBox[{"-", "0.00044510415646475954`"}]},
    {"40.`", "0.4000000000000002`", "0.3509901077432208`", 
     "0.3514208535176321`", 
     RowBox[{"-", "0.0004307457744112675`"}]},
    {"41.`", "0.4100000000000002`", "0.3521451030001761`", 
     "0.3525622164155227`", 
     RowBox[{"-", "0.00041711341534661495`"}]},
    {"42.`", "0.4200000000000002`", "0.35327183219836883`", 
     "0.35367598655088733`", 
     RowBox[{"-", "0.0004041543525185043`"}]},
    {"43.`", "0.4300000000000002`", "0.35437163044102804`", 
     "0.3547634512603065`", 
     RowBox[{"-", "0.00039182081927846557`"}]},
    {"44.`", "0.4400000000000002`", "0.3554457404570548`", 
     "0.3558258098973639`", 
     RowBox[{"-", "0.0003800694403091054`"}]},
    {"45.`", "0.45000000000000023`", "0.3564953209363238`", 
     "0.35686418167561584`", 
     RowBox[{"-", "0.0003688607392920429`"}]},
    {"46.`", "0.46000000000000024`", "0.3575214539448557`", 
     "0.35787961265616586`", 
     RowBox[{"-", "0.00035815871131017474`"}]},
    {"47.`", "0.47000000000000025`", "0.3585251515392121`", 
     "0.35887308198946805`", 
     RowBox[{"-", "0.00034793045025593994`"}]},
    {"48.`", "0.48000000000000026`", "0.3595073616817407`", 
     "0.3598455075049275`", 
     RowBox[{"-", "0.0003381458231868084`"}]},
    {"49.`", "0.49000000000000027`", "0.3604689735435965`", 
     "0.36079775072844517`", 
     RowBox[{"-", "0.0003287771848486387`"}]},
    {"50.`", "0.5000000000000002`", "0.36141082227006033`", 
     "0.36173062139678824`", 
     RowBox[{"-", "0.00031979912672791544`"}]}
   },
   GridBoxAlignment->{
    "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
     "RowsIndexed" -> {}},
   GridBoxSpacings->{"Columns" -> {
       Offset[0.27999999999999997`], {
        Offset[2.0999999999999996`]}, 
       Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
       Offset[0.2], {
        Offset[0.4]}, 
       Offset[0.2]}, "RowsIndexed" -> {}}],
  Function[BoxForm`e$, 
   TableForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{3.6385164660438004`*^9, 3.6386025716626*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 "A plot comparing the numerical and the exact solution at  position x=xPos \
for times  t  with   0\[LessEqual]t\[LessEqual] ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["t", "numSteps"], TraditionalForm]]],
 " "
}], "Text",
 CellChangeTimes->{{3.6372989561913*^9, 3.6372990023753*^9}, {
  3.6372990787602997`*^9, 3.6372990811603003`*^9}, {3.6372998614302998`*^9, 
  3.6372998879683*^9}, {3.6373004057753*^9, 3.6373004634223003`*^9}, {
  3.6373332624277425`*^9, 3.637333265915942*^9}},
 Background->RGBColor[1, 1, 0.85]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"Print", "[", "\"\<Method with fixed timesteps\>\"", "]"}], ";", 
  RowBox[{"Print", "[", 
   RowBox[{
   "\"\<Numerical solution (points) and exact solution (line) at position \
x=\>\"", ",", "xPos", ",", "\"\< vs. time\>\""}], "]"}], ";", " ", 
  RowBox[{"FigNum", "=", 
   RowBox[{"ListPlot", "[", 
    RowBox[{
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"tabFT", "[", 
          RowBox[{"[", 
           RowBox[{"n", ",", "2"}], "]"}], "]"}], ",", 
         RowBox[{"tabFT", "[", 
          RowBox[{"[", 
           RowBox[{"n", ",", "3"}], "]"}], "]"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"n", ",", "1", ",", "numSteps"}], "}"}]}], "]"}], ",", 
     RowBox[{"PlotRange", "\[Rule]", "All"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"FigExact", "=", 
   RowBox[{"Plot", "[", 
    RowBox[{
     RowBox[{"uSol", "[", 
      RowBox[{"xPos", ",", "time", ",", "gammaVal"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"time", ",", "0", ",", 
       RowBox[{"1.1", "*", 
        RowBox[{"tabFT", "[", 
         RowBox[{"[", 
          RowBox[{
           RowBox[{"numSteps", "+", "1"}], ",", "2"}], "]"}], "]"}]}]}], 
      "}"}], ",", 
     RowBox[{"PlotRange", "\[Rule]", "All"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"Show", "[", 
  RowBox[{"FigNum", ",", "FigExact", ",", 
   RowBox[{"Frame", "\[Rule]", "True"}], ",", 
   RowBox[{"FrameLabel", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"\"\<time\>\"", ",", "\"\<u\>\""}], "}"}]}], ",", 
   RowBox[{"PlotRange", "\[Rule]", "All"}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.6372990098493*^9, 3.6372993557363*^9}, {
   3.6372994017143*^9, 3.6372994018733*^9}, {3.6372994547862997`*^9, 
   3.6372994982653*^9}, {3.6372997348883*^9, 3.6372998253603*^9}, {
   3.6372999061773*^9, 3.6372999638333*^9}, {3.6373000656813*^9, 
   3.6373002790032997`*^9}, {3.6373003226673*^9, 3.6373003301463003`*^9}, 
   3.6373008969223003`*^9, {3.6373010002263002`*^9, 3.6373010046333*^9}, {
   3.6373011368183002`*^9, 3.6373011439313*^9}, {3.6373013944182997`*^9, 
   3.6373014237132998`*^9}, {3.6373017319293003`*^9, 3.6373017582733*^9}, 
   3.6373211117127614`*^9, {3.6373310018714457`*^9, 3.6373310081918077`*^9}, {
   3.637331814027899*^9, 3.6373318357551413`*^9}, {3.637332018465592*^9, 
   3.637332044496081*^9}, 3.637369231852395*^9, {3.6385158592307997`*^9, 
   3.6385158668308*^9}}],

Cell[BoxData["\<\"Method with fixed timesteps\"\>"], "Print",
 CellChangeTimes->{3.6385164660878*^9, 3.6386025717026*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Numerical solution (points) and exact solution (line) at \
position x=\"\>", "\[InvisibleSpace]", "1.`", 
   "\[InvisibleSpace]", "\<\" vs. time\"\>"}],
  SequenceForm[
  "Numerical solution (points) and exact solution (line) at position x=", 1., 
   " vs. time"],
  Editable->False]], "Print",
 CellChangeTimes->{3.6385164660878*^9, 3.6386025717046003`*^9}],

Cell[BoxData[
 GraphicsBox[{{{}, {{}, 
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
      0.011000000000000001`], AbsoluteThickness[1.6], PointBox[CompressedData["
1:eJxdkltIFGEcxV0JU0u0NFIIL4HXNaJCTUtOlqQluVkYPfigpltRmVCKrG1q
ZrT0IKFia3kp9UEhLxVeMNO85G2VmZ3brroruyVZKoW1ggVa35dPHRiGYeY7
/3N+//FLv3ku097Ozu7g34vc/1e+R0ucRXUfvd/MWzQeQ/j3XI6jGdkmh99j
6PIuWUzqqkGAeoz1s+g23zcAPaOrueNTqNISNUHrWVQ2uodBN/2+Bbmh1W7u
bQyWkohDO+Zke4ei5ezm+TfYpVecCKxg4SzVZ0c7d2JZFZK4e4UFtdN2YzV+
RLEQq0dQSumALegttqtl0VWlenRS/3cYLpsKeMHpQU5L9f1QLjB3PHdyWKTz
3uNJh1UlJHA4RDUIH315VnERtzl/CHUOEZ+bX3MYtJEJwzAOOnr1WDlso3lG
0OoyM+7qyuM8BTAKo6qv1naYx1OabwyhNp+Yl6k8PqqI4Tg0x8703XjAQ07z
6lB4ZTFN2czjFomXPYnC4suu/ToePTT/FLo9e5U1yzxkdAsMyo9ba3xdBDTS
Pgyk6xOR6XIBpyxkAAsLF1mRHy9gmfZjUaiYT72XIeDxACmgR15d64amQEAY
7ctBwRww1GsFGCkgDsklPyrnXglQ0/48zCWmawkTAvxIHG8BkwVf9v+0Chim
PAT80jZUzq8JuKokEnEkYuRsiJsIF8pHQqD/J1+dv4j2OBJQwofbG+tclIhk
yssAy9aO4NMKEWt0gQakmQqiwi+JqKb8jMgquhtemysihv4A03gYG1b9SCNi
nvKcRpMtL0f2TISGLnQGGavSRYcWEfso31kY1tvUtX0iWB3RLDITA/pZRkQO
5W2C43f35ucWEV6krocZTpZglfuKiF7K34wLTidD5PYS0ohdyhxUX/1zlnZI
+AMOpo7f
       "]]}, {}}, {}}, {{}, {}, 
    {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], Opacity[
     1.], LineBox[CompressedData["
1:eJwV1Hk8FAgbB3Ch+KyIpRHG2hTjtVSbtpz9SjnaohyriWJLzlwJCeWI2WzI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      "]]}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->True,
  FrameLabel->{
    FormBox["\"time\"", TraditionalForm], 
    FormBox["\"u\"", TraditionalForm]},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  Method->{},
  PlotRange->All,
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.02], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.6385164753668003`*^9, 3.6386025821656*^9}]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
CellGrouping->Manual,
WindowSize->{1547, 1076},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
PrintingCopies->1,
PrintingPageRange->{32000, 32000},
PrintingOptions->{"Magnification"->1.,
"PaperOrientation"->"Portrait",
"PaperSize"->{594.9599999999999, 842.04}},
Magnification:>1.9 Inherited,
FrontEndVersion->"10.1 for Microsoft Windows (64-bit) (March 23, 2015)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[557, 20, 1587, 53, 476, "Subsection"],
Cell[CellGroupData[{
Cell[2169, 77, 205, 7, 40, "Text"],
Cell[CellGroupData[{
Cell[2399, 88, 503, 12, 50, "Input"],
Cell[2905, 102, 257, 4, 57, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[3211, 112, 207, 4, 203, "Subchapter"],
Cell[3421, 118, 188973, 2353, 653, "Subsubsection"],
Cell[CellGroupData[{
Cell[192419, 2475, 14163, 187, 89, "Text"],
Cell[206585, 2664, 830, 27, 125, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[207452, 2696, 68830, 898, 317, "Text"],
Cell[276285, 3596, 1511, 37, 162, "Input"],
Cell[277799, 3635, 2398, 63, 236, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[280234, 3703, 621, 16, 89, "Text"],
Cell[280858, 3721, 710, 22, 87, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[281605, 3748, 45657, 597, 361, "Text"],
Cell[CellGroupData[{
Cell[327287, 4349, 46399, 620, 354, "Subsubsection",
 CellGroupingRules->{GroupTogetherGrouping, 10000.}],
Cell[373689, 4971, 5074, 108, 421, "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10000.}]
}, Open  ]],
Cell[CellGroupData[{
Cell[378800, 5084, 2905, 80, 230, "Subsubsection",
 CellGroupingRules->{GroupTogetherGrouping, 10000.}],
Cell[381708, 5166, 6538, 134, 680, "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10001.}]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[388295, 5306, 2134, 50, 276, "Subsubsection",
 CellGroupingRules->{GroupTogetherGrouping, 10000.}],
Cell[390432, 5358, 3557, 64, 384, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[394026, 5427, 2112, 44, 276, "Subsubsection",
 CellGroupingRules->{GroupTogetherGrouping, 10000.}],
Cell[CellGroupData[{
Cell[396163, 5475, 12942, 178, 302, "Text"],
Cell[409108, 5655, 476, 9, 87, "Input"]
}, Open  ]],
Cell[409599, 5667, 6551, 131, 1309, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[416187, 5803, 2081, 43, 276, "Subsubsection",
 CellGroupingRules->{GroupTogetherGrouping, 10000.}],
Cell[CellGroupData[{
Cell[418293, 5850, 23578, 316, 457, "Text"],
Cell[441874, 6168, 1240, 22, 162, "Input"]
}, Open  ]],
Cell[443129, 6193, 7356, 149, 865, "Input"]
}, Open  ]]
}, Open  ]],
Cell[450512, 6346, 83, 1, 58, "Text"],
Cell[CellGroupData[{
Cell[450620, 6351, 53486, 666, 342, "Subchapter"],
Cell[CellGroupData[{
Cell[504131, 7021, 327, 6, 104, "Subsubsection"],
Cell[CellGroupData[{
Cell[504483, 7031, 358, 10, 93, "Text"],
Cell[504844, 7043, 167, 4, 57, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[505048, 7052, 24579, 311, 96, "Text"],
Cell[529630, 7365, 615, 14, 57, "Input"],
Cell[530248, 7381, 485, 11, 57, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[530770, 7397, 454, 7, 89, "Text",
 CellGroupingRules->{GroupTogetherGrouping, 10000.}],
Cell[531227, 7406, 543, 9, 57, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[531807, 7420, 453, 9, 89, "Text",
 CellGroupingRules->{GroupTogetherGrouping, 10000.}],
Cell[532263, 7431, 1965, 30, 57, "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10000.}]
}, Open  ]],
Cell[CellGroupData[{
Cell[534265, 7466, 586, 12, 89, "Text",
 CellGroupingRules->{GroupTogetherGrouping, 10000.}],
Cell[534854, 7480, 2159, 36, 57, "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10000.}]
}, Open  ]],
Cell[CellGroupData[{
Cell[537050, 7521, 410, 12, 89, "Text"],
Cell[CellGroupData[{
Cell[537485, 7537, 478, 12, 57, "Input"],
Cell[537966, 7551, 1318, 23, 212, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[539333, 7580, 225, 3, 89, "Text"],
Cell[539561, 7585, 243, 7, 95, "Input"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[539853, 7598, 531, 9, 73, "Subsubsection"],
Cell[CellGroupData[{
Cell[540409, 7611, 611, 18, 105, "Text"],
Cell[CellGroupData[{
Cell[541045, 7633, 4177, 73, 280, "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10000.}],
Cell[545225, 7708, 981, 19, 42, "Print"],
Cell[546209, 7729, 286, 6, 40, "Print"],
Cell[546498, 7737, 133, 1, 40, "Print"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[546680, 7744, 666, 20, 143, "Text"],
Cell[CellGroupData[{
Cell[547371, 7768, 446, 10, 132, "Input"],
Cell[547820, 7780, 364, 7, 40, "Print"],
Cell[548187, 7789, 1355, 24, 212, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[549591, 7819, 659, 21, 141, "Text"],
Cell[CellGroupData[{
Cell[550275, 7844, 674, 16, 169, "Input"],
Cell[550952, 7862, 508, 10, 40, "Print"],
Cell[551463, 7874, 106, 1, 57, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[551618, 7881, 359, 10, 93, "Text"],
Cell[CellGroupData[{
Cell[552002, 7895, 1972, 52, 280, "Input"],
Cell[553977, 7949, 104, 1, 40, "Print"],
Cell[554084, 7952, 381, 8, 40, "Print"],
Cell[554468, 7962, 7079, 130, 471, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[561596, 8098, 393, 7, 127, "Text"],
Cell[561992, 8107, 463, 10, 57, "Input"],
Cell[CellGroupData[{
Cell[562480, 8121, 1211, 36, 169, "Input"],
Cell[563694, 8159, 3131, 59, 741, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[566874, 8224, 522, 12, 93, "Text"],
Cell[CellGroupData[{
Cell[567421, 8240, 2240, 57, 317, "Input"],
Cell[569664, 8299, 112, 1, 40, "Print"],
Cell[569779, 8302, 184, 2, 40, "Print"],
Cell[569966, 8306, 4687, 91, 471, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[574714, 8404, 569, 11, 73, "Subsubsection"],
Cell[CellGroupData[{
Cell[575308, 8419, 611, 18, 105, "Text"],
Cell[CellGroupData[{
Cell[575944, 8441, 4432, 76, 317, "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10000.}],
Cell[580379, 8519, 1279, 23, 74, "Print"],
Cell[581661, 8544, 292, 6, 40, "Print"],
Cell[581956, 8552, 137, 1, 40, "Print"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[582142, 8559, 666, 20, 143, "Text"],
Cell[CellGroupData[{
Cell[582833, 8583, 446, 10, 132, "Input"],
Cell[583282, 8595, 353, 7, 40, "Print"],
Cell[583638, 8604, 1337, 24, 212, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[585024, 8634, 659, 21, 141, "Text"],
Cell[CellGroupData[{
Cell[585708, 8659, 674, 16, 169, "Input"],
Cell[586385, 8677, 505, 10, 40, "Print"],
Cell[586893, 8689, 110, 1, 57, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[587052, 8696, 359, 10, 93, "Text"],
Cell[CellGroupData[{
Cell[587436, 8710, 1951, 51, 243, "Input"],
Cell[589390, 8763, 111, 1, 40, "Print"],
Cell[589504, 8766, 378, 8, 40, "Print"],
Cell[589885, 8776, 7075, 130, 471, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[597009, 8912, 393, 7, 127, "Text"],
Cell[597405, 8921, 494, 11, 57, "Input"],
Cell[CellGroupData[{
Cell[597924, 8936, 1270, 38, 169, "Input"],
Cell[599197, 8976, 3120, 59, 741, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[602366, 9041, 522, 12, 93, "Text"],
Cell[CellGroupData[{
Cell[602913, 9057, 2298, 57, 317, "Input"],
Cell[605214, 9116, 119, 1, 40, "Print"],
Cell[605336, 9119, 184, 2, 40, "Print"],
Cell[605523, 9123, 4683, 90, 471, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[610267, 9220, 676, 13, 73, "Subsubsection"],
Cell[CellGroupData[{
Cell[610968, 9237, 611, 18, 105, "Text"],
Cell[CellGroupData[{
Cell[611604, 9259, 4082, 71, 280, "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10000.}],
Cell[615689, 9332, 495, 10, 40, "Print"],
Cell[616187, 9344, 286, 6, 40, "Print"],
Cell[616476, 9352, 137, 1, 40, "Print"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[616662, 9359, 666, 20, 143, "Text"],
Cell[CellGroupData[{
Cell[617353, 9383, 446, 10, 132, "Input"],
Cell[617802, 9395, 318, 6, 40, "Print"],
Cell[618123, 9403, 1360, 24, 212, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[619532, 9433, 659, 21, 141, "Text"],
Cell[CellGroupData[{
Cell[620216, 9458, 674, 16, 169, "Input"],
Cell[620893, 9476, 469, 10, 40, "Print"],
Cell[621365, 9488, 105, 1, 57, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[621519, 9495, 359, 10, 93, "Text"],
Cell[CellGroupData[{
Cell[621903, 9509, 1963, 51, 280, "Input"],
Cell[623869, 9562, 121, 1, 40, "Print"],
Cell[623993, 9565, 338, 7, 40, "Print"],
Cell[624334, 9574, 7052, 129, 471, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[631435, 9709, 393, 7, 127, "Text"],
Cell[631831, 9718, 616, 13, 57, "Input"],
Cell[CellGroupData[{
Cell[632472, 9735, 1336, 39, 169, "Input"],
Cell[633811, 9776, 6398, 120, 1655, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[640258, 9902, 522, 12, 93, "Text"],
Cell[CellGroupData[{
Cell[640805, 9918, 2307, 57, 280, "Input"],
Cell[643115, 9977, 121, 1, 40, "Print"],
Cell[643239, 9980, 180, 2, 40, "Print"],
Cell[643422, 9984, 5164, 99, 471, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[648637, 10089, 83, 1, 58, "Text"],
Cell[CellGroupData[{
Cell[648745, 10094, 73488, 914, 363, "Subchapter"],
Cell[CellGroupData[{
Cell[722258, 11012, 327, 6, 104, "Subsubsection"],
Cell[CellGroupData[{
Cell[722610, 11022, 514, 15, 93, "Text"],
Cell[723127, 11039, 317, 7, 57, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[723481, 11051, 30309, 381, 98, "Text"],
Cell[753793, 11434, 845, 20, 57, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[754675, 11459, 30058, 379, 98, "Text",
 CellGroupingRules->{GroupTogetherGrouping, 10000.}],
Cell[784736, 11840, 1004, 23, 57, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[785777, 11868, 453, 9, 89, "Text",
 CellGroupingRules->{GroupTogetherGrouping, 10000.}],
Cell[786233, 11879, 1965, 30, 57, "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10000.}]
}, Open  ]],
Cell[CellGroupData[{
Cell[788235, 11914, 586, 12, 89, "Text",
 CellGroupingRules->{GroupTogetherGrouping, 10000.}],
Cell[788824, 11928, 2159, 36, 57, "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10000.}]
}, Open  ]],
Cell[CellGroupData[{
Cell[791020, 11969, 377, 11, 89, "Text"],
Cell[CellGroupData[{
Cell[791422, 11984, 478, 12, 57, "Input"],
Cell[791903, 11998, 1322, 23, 212, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[793274, 12027, 225, 3, 89, "Text"],
Cell[793502, 12032, 243, 7, 95, "Input"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[793794, 12045, 527, 9, 73, "Subsubsection"],
Cell[CellGroupData[{
Cell[794346, 12058, 611, 18, 105, "Text"],
Cell[CellGroupData[{
Cell[794982, 12080, 4193, 73, 280, "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10000.}],
Cell[799178, 12155, 981, 19, 42, "Print"],
Cell[800162, 12176, 294, 6, 40, "Print"],
Cell[800459, 12184, 137, 1, 40, "Print"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[800645, 12191, 666, 20, 143, "Text"],
Cell[CellGroupData[{
Cell[801336, 12215, 446, 10, 132, "Input"],
Cell[801785, 12227, 356, 7, 40, "Print"],
Cell[802144, 12236, 1340, 24, 212, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[803533, 12266, 659, 21, 141, "Text"],
Cell[CellGroupData[{
Cell[804217, 12291, 674, 16, 169, "Input"],
Cell[804894, 12309, 508, 10, 40, "Print"],
Cell[805405, 12321, 114, 1, 57, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[805568, 12328, 359, 10, 93, "Text"],
Cell[CellGroupData[{
Cell[805952, 12342, 1924, 51, 280, "Input"],
Cell[807879, 12395, 108, 1, 40, "Print"],
Cell[807990, 12398, 381, 8, 40, "Print"],
Cell[808374, 12408, 7056, 129, 494, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[815479, 12543, 393, 7, 127, "Text"],
Cell[815875, 12552, 467, 10, 80, "Input"],
Cell[CellGroupData[{
Cell[816367, 12566, 1211, 36, 192, "Input"],
Cell[817581, 12604, 5456, 101, 1361, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[823086, 12711, 522, 12, 93, "Text"],
Cell[CellGroupData[{
Cell[823633, 12727, 2184, 55, 303, "Input"],
Cell[825820, 12784, 108, 1, 40, "Print"],
Cell[825931, 12787, 184, 2, 40, "Print"],
Cell[826118, 12791, 18428, 316, 494, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[844607, 13114, 569, 11, 73, "Subsubsection"],
Cell[CellGroupData[{
Cell[845201, 13129, 611, 18, 105, "Text"],
Cell[CellGroupData[{
Cell[845837, 13151, 4689, 80, 340, "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10000.}],
Cell[850529, 13233, 1279, 23, 74, "Print"],
Cell[851811, 13258, 288, 6, 40, "Print"],
Cell[852102, 13266, 137, 1, 40, "Print"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[852288, 13273, 666, 20, 143, "Text"],
Cell[CellGroupData[{
Cell[852979, 13297, 446, 10, 155, "Input"],
Cell[853428, 13309, 356, 7, 40, "Print"],
Cell[853787, 13318, 1355, 24, 235, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[855191, 13348, 659, 21, 141, "Text"],
Cell[CellGroupData[{
Cell[855875, 13373, 674, 16, 192, "Input"],
Cell[856552, 13391, 512, 10, 40, "Print"],
Cell[857067, 13403, 106, 1, 80, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[857222, 13410, 359, 10, 93, "Text"],
Cell[CellGroupData[{
Cell[857606, 13424, 2005, 52, 303, "Input"],
Cell[859614, 13478, 111, 1, 40, "Print"],
Cell[859728, 13481, 385, 8, 40, "Print"],
Cell[860116, 13491, 7036, 129, 494, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[867201, 13626, 393, 7, 127, "Text"],
Cell[867597, 13635, 494, 11, 80, "Input"],
Cell[CellGroupData[{
Cell[868116, 13650, 1272, 38, 192, "Input"],
Cell[869391, 13690, 5598, 108, 1361, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[875038, 13804, 522, 12, 93, "Text"],
Cell[CellGroupData[{
Cell[875585, 13820, 2299, 57, 340, "Input"],
Cell[877887, 13879, 115, 1, 40, "Print"],
Cell[878005, 13882, 188, 2, 40, "Print"],
Cell[878196, 13886, 22698, 386, 494, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[900955, 14279, 676, 13, 73, "Subsubsection"],
Cell[CellGroupData[{
Cell[901656, 14296, 611, 18, 105, "Text"],
Cell[CellGroupData[{
Cell[902292, 14318, 4082, 71, 303, "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10000.}],
Cell[906377, 14391, 495, 10, 40, "Print"],
Cell[906875, 14403, 292, 6, 40, "Print"],
Cell[907170, 14411, 137, 1, 40, "Print"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[907356, 14418, 666, 20, 143, "Text"],
Cell[CellGroupData[{
Cell[908047, 14442, 446, 10, 155, "Input"],
Cell[908496, 14454, 314, 6, 40, "Print"],
Cell[908813, 14462, 1347, 24, 235, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[910209, 14492, 659, 21, 141, "Text"],
Cell[CellGroupData[{
Cell[910893, 14517, 674, 16, 192, "Input"],
Cell[911570, 14535, 469, 10, 40, "Print"],
Cell[912042, 14547, 110, 1, 80, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[912201, 14554, 359, 10, 93, "Text"],
Cell[CellGroupData[{
Cell[912585, 14568, 1967, 51, 303, "Input"],
Cell[914555, 14621, 121, 1, 40, "Print"],
Cell[914679, 14624, 338, 7, 40, "Print"],
Cell[915020, 14633, 7032, 129, 494, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[922101, 14768, 393, 7, 127, "Text"],
Cell[922497, 14777, 616, 13, 80, "Input"],
Cell[CellGroupData[{
Cell[923138, 14794, 1336, 39, 192, "Input"],
Cell[924477, 14835, 6369, 120, 1655, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[930895, 14961, 522, 12, 93, "Text"],
Cell[CellGroupData[{
Cell[931442, 14977, 2313, 57, 303, "Input"],
Cell[933758, 15036, 121, 1, 40, "Print"],
Cell[933882, 15039, 180, 2, 40, "Print"],
Cell[934065, 15043, 7571, 138, 494, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[941687, 15187, 83, 1, 58, "Text"],
Cell[941773, 15190, 54586, 680, 431, "Subchapter"],
Cell[CellGroupData[{
Cell[996384, 15874, 327, 6, 89, "Subsubsection"],
Cell[CellGroupData[{
Cell[996736, 15884, 783, 24, 93, "Text"],
Cell[997522, 15910, 434, 9, 80, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[997993, 15924, 73796, 937, 240, "Text"],
Cell[CellGroupData[{
Cell[1071814, 16865, 692, 20, 120, "Text"],
Cell[1072509, 16887, 5615, 165, 705, "Input"],
Cell[1078127, 17054, 4358, 117, 622, "Input"],
Cell[1082488, 17173, 2021, 63, 194, "Input"],
Cell[1084512, 17238, 1167, 39, 192, "Input"],
Cell[1085682, 17279, 6713, 197, 705, "Input"],
Cell[1092398, 17478, 177, 6, 73, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1092612, 17489, 224, 3, 89, "Text"],
Cell[1092839, 17494, 723, 18, 118, "Input"],
Cell[1093565, 17514, 2622, 61, 229, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1096224, 17580, 261, 6, 89, "Text"],
Cell[1096488, 17588, 718, 13, 80, "Input"],
Cell[1097209, 17603, 749, 14, 80, "Input"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[1098007, 17623, 454, 7, 89, "Text",
 CellGroupingRules->{GroupTogetherGrouping, 10000.}],
Cell[1098464, 17632, 543, 9, 80, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1099044, 17646, 453, 9, 89, "Text",
 CellGroupingRules->{GroupTogetherGrouping, 10000.}],
Cell[1099500, 17657, 2160, 34, 118, "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10000.}]
}, Open  ]],
Cell[CellGroupData[{
Cell[1101697, 17696, 586, 12, 89, "Text",
 CellGroupingRules->{GroupTogetherGrouping, 10000.}],
Cell[1102286, 17710, 2211, 37, 80, "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10000.}]
}, Open  ]],
Cell[1104512, 17750, 377, 11, 89, "Text"],
Cell[CellGroupData[{
Cell[1104914, 17765, 428, 11, 80, "Input"],
Cell[1105345, 17778, 632, 10, 118, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1106014, 17793, 340, 6, 89, "Text"],
Cell[1106357, 17801, 376, 10, 118, "Input"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[1106782, 17817, 527, 9, 73, "Subsubsection"],
Cell[CellGroupData[{
Cell[1107334, 17830, 611, 18, 105, "Text"],
Cell[CellGroupData[{
Cell[1107970, 17852, 4826, 85, 377, "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10000.}],
Cell[1112799, 17939, 598, 11, 40, "Print"],
Cell[1113400, 17952, 981, 19, 42, "Print"],
Cell[1114384, 17973, 290, 6, 40, "Print"],
Cell[1114677, 17981, 137, 1, 40, "Print"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[1114863, 17988, 666, 20, 143, "Text"],
Cell[CellGroupData[{
Cell[1115554, 18012, 496, 11, 155, "Input"],
Cell[1116053, 18025, 349, 7, 42, "Print"],
Cell[1116405, 18034, 1467, 23, 309, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[1117921, 18063, 593, 19, 141, "Text"],
Cell[CellGroupData[{
Cell[1118539, 18086, 723, 16, 192, "Input"],
Cell[1119265, 18104, 470, 9, 42, "Print"],
Cell[1119738, 18115, 111, 1, 80, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[1119898, 18122, 326, 9, 93, "Text"],
Cell[CellGroupData[{
Cell[1120249, 18135, 2084, 52, 303, "Input"],
Cell[1122336, 18189, 104, 1, 40, "Print"],
Cell[1122443, 18192, 376, 8, 42, "Print"],
Cell[1122822, 18202, 19157, 328, 494, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[1142028, 18536, 430, 8, 127, "Text"],
Cell[1142461, 18546, 503, 11, 80, "Input"],
Cell[CellGroupData[{
Cell[1142989, 18561, 1645, 44, 266, "Input"],
Cell[1144637, 18607, 7266, 138, 1775, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[1151952, 18751, 537, 12, 93, "Text"],
Cell[CellGroupData[{
Cell[1152514, 18767, 2417, 57, 303, "Input"],
Cell[1154934, 18826, 108, 1, 40, "Print"],
Cell[1155045, 18829, 403, 9, 40, "Print"],
Cell[1155451, 18840, 5533, 105, 494, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[1161045, 18952, 584, 11, 73, "Subsubsection"],
Cell[CellGroupData[{
Cell[1161654, 18967, 611, 18, 105, "Text"],
Cell[CellGroupData[{
Cell[1162290, 18989, 5246, 91, 414, "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10000.}],
Cell[1167539, 19082, 612, 12, 40, "Print"],
Cell[1168154, 19096, 1272, 23, 74, "Print"],
Cell[1169429, 19121, 288, 6, 40, "Print"],
Cell[1169720, 19129, 133, 1, 40, "Print"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[1169902, 19136, 666, 20, 143, "Text"],
Cell[CellGroupData[{
Cell[1170593, 19160, 446, 10, 155, "Input"],
Cell[1171042, 19172, 360, 7, 42, "Print"],
Cell[1171405, 19181, 1469, 23, 309, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[1172923, 19210, 593, 19, 141, "Text"],
Cell[CellGroupData[{
Cell[1173541, 19233, 674, 16, 192, "Input"],
Cell[1174218, 19251, 481, 10, 42, "Print"],
Cell[1174702, 19263, 110, 1, 80, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[1174861, 19270, 326, 9, 93, "Text"],
Cell[CellGroupData[{
Cell[1175212, 19283, 2193, 54, 303, "Input"],
Cell[1177408, 19339, 111, 1, 40, "Print"],
Cell[1177522, 19342, 381, 8, 40, "Print"],
Cell[1177906, 19352, 14066, 245, 494, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[1192021, 19603, 430, 8, 127, "Text"],
Cell[1192454, 19613, 587, 12, 80, "Input"],
Cell[CellGroupData[{
Cell[1193066, 19629, 1715, 45, 266, "Input"],
Cell[1194784, 19676, 7238, 136, 1775, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[1202071, 19818, 537, 12, 93, "Text"],
Cell[CellGroupData[{
Cell[1202633, 19834, 2582, 59, 340, "Input"],
Cell[1205218, 19895, 111, 1, 40, "Print"],
Cell[1205332, 19898, 407, 9, 40, "Print"],
Cell[1205742, 19909, 5472, 104, 494, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[1211275, 20020, 676, 13, 73, "Subsubsection"],
Cell[CellGroupData[{
Cell[1211976, 20037, 611, 18, 105, "Text"],
Cell[CellGroupData[{
Cell[1212612, 20059, 4437, 79, 377, "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10000.}],
Cell[1217052, 20140, 558, 11, 40, "Print"],
Cell[1217613, 20153, 497, 10, 40, "Print"],
Cell[1218113, 20165, 288, 6, 40, "Print"],
Cell[1218404, 20173, 133, 1, 40, "Print"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[1218586, 20180, 666, 20, 143, "Text"],
Cell[CellGroupData[{
Cell[1219277, 20204, 446, 10, 155, "Input"],
Cell[1219726, 20216, 314, 6, 40, "Print"],
Cell[1220043, 20224, 1381, 24, 229, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[1221473, 20254, 593, 19, 141, "Text"],
Cell[CellGroupData[{
Cell[1222091, 20277, 674, 16, 192, "Input"],
Cell[1222768, 20295, 430, 8, 40, "Print"],
Cell[1223201, 20305, 108, 1, 80, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[1223358, 20312, 326, 9, 93, "Text"],
Cell[CellGroupData[{
Cell[1223709, 20325, 2041, 52, 303, "Input"],
Cell[1225753, 20379, 125, 1, 40, "Print"],
Cell[1225881, 20382, 346, 7, 40, "Print"],
Cell[1226230, 20391, 3429, 70, 494, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[1229708, 20467, 441, 8, 127, "Text"],
Cell[1230152, 20477, 752, 14, 80, "Input"],
Cell[CellGroupData[{
Cell[1230929, 20495, 1731, 47, 303, "Input"],
Cell[1232663, 20544, 209, 5, 40, "Print"],
Cell[1232875, 20551, 7436, 158, 1655, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[1240360, 20715, 537, 12, 93, "Text"],
Cell[CellGroupData[{
Cell[1240922, 20731, 2473, 58, 303, "Input"],
Cell[1243398, 20791, 121, 1, 40, "Print"],
Cell[1243522, 20794, 407, 9, 40, "Print"],
Cell[1243932, 20805, 5143, 99, 487, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
